@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * module_manager.cc 
+ * module_manager.cc
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -43,7 +43,9 @@
 #include "main/settings.h"
 #include "main/sword.h"
 
-#ifdef DEBUG 
+#include "gui/debug_glib_null.h"
+
+#ifdef DEBUG
 static const gchar *f_message = "backend/module_manager.cc line #%d \"%s\" = %s\n";
 #endif
 using namespace sword;
@@ -64,18 +66,18 @@ static ModMap::iterator end;
  * Synopsis
  *   #include "backend/module_manager.hh"
  *
- *   void StatusReporter::preStatus(long totalBytes, long completedBytes, 
+ *   void StatusReporter::preStatus(long totalBytes, long completedBytes,
  *				   const char *message)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void GSStatusReporter::preStatus(long totalBytes,
-				 long completedBytes, 
+				 long completedBytes,
 				 const char *message)
 {
 	GS_print((f_message,83,"message",message));
@@ -92,38 +94,38 @@ void GSStatusReporter::preStatus(long totalBytes,
  *   void StatusReporter::statusUpdate(double dltotal, double dlnow)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void GSStatusReporter::statusUpdate(double dltotal,
-				    double dlnow) 
+				    double dlnow)
 {
 	if (!dltotal)
-		return;	
+		return;
 	double filefraction  = (dlnow / dltotal);
 	update_install_progress(filefraction);
 }
 
 
-ModuleManager::ModuleManager() {	
+ModuleManager::ModuleManager() {
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	baseDir = (envhomedir) ? envhomedir : ".";
 	baseDir += "/" DOTSWORD "/InstallMgr";
 	statusReporter = new GSStatusReporter();
 }
- 
+
 ModuleManager::~ModuleManager() {
-	
+
 }
 
 char *backend_mod_mgr_get_config_entry(char *module_name,
 				       const char *entry) {
 	SWModule *mod;
 	ModMap::iterator it;	//-- iteratior
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = mgr->Modules.find(module_name);
 	//-- if we find the module
 	if (it != mgr->Modules.end()) {
@@ -151,7 +153,7 @@ int backend_mod_mgr_is_module(const char *mod_name) {
  *   GList *backend_module_mgr_get_next_module()
  *
  * Description
- *   
+ *
  *
  * Return value
  *   MOD_MGR *
@@ -161,7 +163,7 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 {
 	MOD_MGR *mod_info = NULL;
 	SWModule *module;
-	
+
 	if (it != end) {
 		module = it->second;
 		mod_info = g_new(MOD_MGR, 1);
@@ -207,12 +209,12 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
 			mod_info->installed =
 			    backend_mod_mgr_is_module(name);
 			mod_info->description = module->Description();
-			mod_info->locked = 
+			mod_info->locked =
 			    ((module->getConfigEntry("CipherKey")) ? 1 : 0);
-			it++;	
+			it++;
 			return (MOD_MGR *) mod_info;
 		}
-	} 
+	}
 	return NULL;
 }
 
@@ -227,7 +229,7 @@ MOD_MGR *backend_module_mgr_get_next_module(void)
  *   GList *backend_module_mgr_remote_list_modules(const char *sourceName)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GList *
@@ -257,7 +259,7 @@ void backend_module_mgr_remote_list_modules_init(const char *sourceName)
  *   GList *backend_module_mgr_list_local_modules(const char *dir)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GList *
@@ -286,7 +288,7 @@ void backend_module_mgr_list_local_modules_init(bool for_install)
 
  *
  * Description
- *   
+ *
  *
  * Return value
  *   int
@@ -302,7 +304,7 @@ int backend_uninstall_module(const char *dir,
 		tmp_mgr = new SWMgr(dir);
 	else
 		tmp_mgr = new SWMgr();
-	
+
 	ModMap::iterator it = tmp_mgr->Modules.find(modName);
 	if (it == tmp_mgr->Modules.end()) {
 		printf("Couldn't find module [%s] to remove\n",
@@ -327,7 +329,7 @@ int backend_uninstall_module(const char *dir,
 
  *
  * Description
- *   
+ *
  *
  * Return value
  *   int
@@ -370,7 +372,7 @@ int backend_remote_install_module(const char *destdir,
  *   int backend_local_install_module(const char *destdir, const char *srcdir, const char *mod_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   int
@@ -396,7 +398,7 @@ int backend_local_install_module(const char *destdir,
  *   GList *backend_module_mgr_list_remote_sources(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GList *
@@ -419,7 +421,7 @@ GList *backend_module_mgr_list_remote_sources(void)
 #else
 	InstallMgr *inst_mgr = new InstallMgr(baseDir);
 #endif
-	
+
 	for (InstallSourceMap::iterator it =
 	     inst_mgr->sources.begin();
 	     it != inst_mgr->sources.end(); it++) {
@@ -454,7 +456,7 @@ GList *backend_module_mgr_list_remote_sources(void)
  *   GList *backend_module_mgr_list_local_sources(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GList *
@@ -463,16 +465,16 @@ GList *backend_module_mgr_list_remote_sources(void)
 GList *backend_module_mgr_list_local_sources(void)
 {
 	MOD_MGR_SOURCE *mms;
-	GList *retval = NULL;	
+	GList *retval = NULL;
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf confPath = (envhomedir) ? envhomedir : ".";
 	confPath += "/" DOTSWORD "/InstallMgr/InstallMgr.conf";
 	SWConfig *installConf= new SWConfig(confPath.c_str());
-	
+
 	SectionMap::iterator sourcesSection;
 	ConfigEntMap::iterator sourceBegin;
 	ConfigEntMap::iterator sourceEnd;
-	
+
 	sourcesSection = installConf->Sections.find("Sources");
 	if (sourcesSection != installConf->Sections.end()) {
 		sourceBegin = sourcesSection->second.lower_bound("DIRSource");
@@ -480,7 +482,7 @@ GList *backend_module_mgr_list_local_sources(void)
 
 		while (sourceBegin != sourceEnd) {
 			mms = g_new(MOD_MGR_SOURCE, 1);
-			InstallSource *is = new InstallSource("DIR", 
+			InstallSource *is = new InstallSource("DIR",
 					sourceBegin->second.c_str());
 			mms->caption = is->caption;
 			mms->type = is->type;
@@ -514,7 +516,7 @@ GList *backend_module_mgr_list_local_sources(void)
  *   int backend_module_mgr_refresh_remote_source(const char *sourceName)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   int
@@ -543,7 +545,7 @@ int backend_module_mgr_refresh_remote_source(const char *sourceName)
  *   void backend_init_module_mgr_config(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -551,7 +553,7 @@ int backend_module_mgr_refresh_remote_source(const char *sourceName)
 
 void backend_init_module_mgr_config(void)
 {
-	
+
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf confPath = (envhomedir) ? envhomedir : ".";
 	confPath += "/" DOTSWORD "/InstallMgr/InstallMgr.conf";
@@ -573,7 +575,7 @@ void backend_init_module_mgr_config(void)
 	is_local.caption = "cdrom";
 	is_local.source = "[local]";
 	is_local.directory = "/mnt/cdrom";
-	config["Sources"]["DIRSource"] = is_local.getConfEnt();	
+	config["Sources"]["DIRSource"] = is_local.getConfEnt();
 	config.Save();
 }
 
@@ -630,7 +632,7 @@ backend_init_module_mgr_config_extras()
  *   void backend_module_mgr_clear_config(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -643,11 +645,35 @@ void backend_module_mgr_clear_config(void)
 	confPath += "/" DOTSWORD "/InstallMgr/InstallMgr.conf";
 	FileMgr::createParent(confPath.c_str());
 	remove(confPath.c_str());
-	
+
 	SWConfig config(confPath.c_str());
-	
+
 	config["General"]["PassiveFTP"] = "true";
-	config.Save();	
+	config.Save();
+	backend_module_mgr_reread_config();
+}
+
+/******************************************************************************
+ * Name
+ *   backend_module_mgr_reread_config
+ *
+ * Synopsis
+ *   #include "backend/module_manager.hh"
+ *
+ *   void backend_module_mgr_reread_config(void)
+ *
+ * Description
+ *   re-init's installMgr's sense of sources.
+ *
+ * Return value
+ *   void
+ */
+
+void backend_module_mgr_reread_config(void)
+{
+#ifdef SWORD_MULTIVERSE
+	installMgr->readInstallConf();
+#endif
 }
 
 
@@ -662,10 +688,13 @@ void backend_module_mgr_clear_config(void)
  *				   const char * type,
  *				   const char * caption,
  *				   const char * source,
- *				   const char * directory)
+ *				   const char * directory,
+ *				   const char * user,
+ *				   const char * pass,
+ *				   const char * uid)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -684,7 +713,7 @@ void backend_module_mgr_add_source(const char * vtype,
 	SWBuf confPath = (envhomedir) ? envhomedir : ".";
 	confPath += "/" DOTSWORD "/InstallMgr/InstallMgr.conf";
 	FileMgr::createParent(confPath.c_str());
-	
+
 	SWConfig config(confPath.c_str());
 
 	InstallSource is(type);
@@ -696,81 +725,11 @@ void backend_module_mgr_add_source(const char * vtype,
 	is.p = pass;
 	is.uid = uid;
 #endif
-	config.Sections["Sources"].insert(ConfigEntMap::value_type(vtype, 
-		is.getConfEnt().c_str()));	
+	config.Sections["Sources"].insert(ConfigEntMap::value_type(vtype,
+		is.getConfEnt().c_str()));
 	config.Save();
 }
 
-void set_mod_mgr_locale(const char *sys_locale) {
-	char buf[32];
-	int i = 0;
-	SWLocale *sw_locale = NULL;
-	
-	if (sys_locale) {
-		if (!strncmp(sys_locale,"ru_RU",5)) {
-			sys_locale = "ru_RU-koi8-r";		
-		} else if (!strncmp(sys_locale,"ru_RU-koi8-r",10)){
-			if (strlen(sys_locale) >  12) {
-				for(i = 0; i < 12; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if (!strncmp(sys_locale,"uk_UA-cp1251",10)){
-			if (strlen(sys_locale) > 12 ) {
-				for(i = 0; i < 12; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if (!strncmp(sys_locale,"uk_UA-koi8-u",10)){
-			if (strlen(sys_locale) > 12 ) {
-				for(i = 0; i < 12; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if (!strncmp(sys_locale,"pt_BR",5)){
-			if (strlen(sys_locale) > 5 ) {
-				for(i = 0; i < 5; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if (!strncmp(sys_locale,"en_GB",5)){
-			if (strlen(sys_locale) > 5 ) {
-				for(i = 0; i < 5; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-		} else {
-			if (strlen(sys_locale) > 2 ) {
-				buf[0] = sys_locale[0];
-				buf[1] = sys_locale[1];
-				buf[2] = '\0';
-				sys_locale = buf;
-			}
-		}
-		LocaleMgr::getSystemLocaleMgr()->setDefaultLocaleName(sys_locale);
-		sw_locale = LocaleMgr::getSystemLocaleMgr()->getLocale(sys_locale);
-	}
-	if (sw_locale) {
-		OLD_CODESET = (char*)sw_locale->getEncoding();
-	} else {
-		OLD_CODESET = (char*)"iso8859-1";
-	}
-}
-
 /******************************************************************************
  * Name
  *   backend_init_module_mgr
@@ -781,7 +740,7 @@ void set_mod_mgr_locale(const char *sys_locale) {
  *   void backend_init_module_mgr(const char *dir, gboolean augment)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -800,6 +759,10 @@ void backend_init_module_mgr(const char *dir,
 	//                then "as sent" ([a] total list or [b] per-area list)
 	//		  else "false for local install" (always per-area)
 
+	GTimer *t;
+	double d;
+	t = g_timer_new();
+
 	if (regular) {		// use main (regular) swmgr.
 		if (mgr)
 			delete mgr;
@@ -809,11 +772,9 @@ void backend_init_module_mgr(const char *dir,
 			delete list_mgr;
 		list_mgr = new SWMgr(dir, true, 0, false, false);
 	}
-
-	const char *lang = g_getenv("LANG");	
-	if (!lang)
-		lang="C";
-	set_mod_mgr_locale(lang);
+	g_timer_stop(t);
+	d = g_timer_elapsed(t, NULL);
+	GS_message(("create SWMgr time is %f", d));
 
 	const gchar *envhomedir = g_getenv(HOMEVAR);
 	SWBuf baseDir = (envhomedir) ? envhomedir : ".";
@@ -832,6 +793,7 @@ void backend_init_module_mgr(const char *dir,
 #else
 	installMgr = new InstallMgr(baseDir, statusReporter);
 #endif
+
 }
 
 /******************************************************************************
@@ -844,7 +806,7 @@ void backend_init_module_mgr(const char *dir,
  *   void backend_terminate_module_mgr(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -865,7 +827,7 @@ void backend_terminate_module_mgr(void)
  *   void backend_shut_down_module_mgr(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -877,6 +839,6 @@ void backend_shut_down_module_mgr(void)
 	installMgr = NULL;
 	delete mgr;
 	mgr = NULL;
-        delete list_mgr; 
+        delete list_mgr;
 	list_mgr = NULL;
 }
