@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * sword_main.cc - 
+ * sword_main.cc -
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -26,11 +26,12 @@
 #include <swmodule.h>
 #include <localemgr.h>
 #include <swversion.h>
+#include <filemgr.h>
 
 #include <markupfiltmgr.h>
 #include <swlocale.h>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <versekey.h>
 #include <regex.h>
 #include <string.h>
@@ -46,24 +47,33 @@
 #include "main/search_dialog.h"
 #include "gui/dialog.h"
 
+#include "gui/debug_glib_null.h"
+
 using namespace sword;
 using namespace std;
 
 BackEnd *backend = NULL;
 
 
- 
-#ifdef DEBUG 
+
+#ifdef DEBUG
 static const char *f_message = "backend/sword_main.cc line #%d \"%s\" = %s";
 #endif
 
 BackEnd::BackEnd()
-{	
+{
+	GTimer *t;
+	double d;
+	t = g_timer_new();
+
 	main_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
-	display_mgr = new SWMgr(new MarkupFilterMgr(FMT_HTMLHREF));
-	
-	display_mod = NULL;	
-	tree_key = NULL;	
+
+	g_timer_stop(t);
+	d = g_timer_elapsed(t, NULL);
+	GS_message(("create main_mgr time is %f", d));
+
+	display_mod = NULL;
+	tree_key = NULL;
 	commDisplay          = 0;
 	bookDisplay          = 0;
 	dictDisplay          = 0;
@@ -73,16 +83,12 @@ BackEnd::BackEnd()
 	verselistDisplay     = 0;
 	viewerDisplay        = 0;
 }
- 
 
 BackEnd::~BackEnd()
 {
-	if(main_mgr)
+	if (main_mgr)
 		delete main_mgr;
-	if(display_mgr)
-		delete display_mgr;
 	main_mgr = 0;
-	display_mgr = 0;
 	if (commDisplay)
 		delete commDisplay;
 	if (bookDisplay)
@@ -114,10 +120,10 @@ BackEnd::~BackEnd()
 void BackEnd::init_SWORD(int gsType)
 {
 	ModMap::iterator it;
-	if(gsType == 0) {
-		main_setup_displays();		
-		for (it = display_mgr->Modules.begin();
-					it != display_mgr->Modules.end(); it++) {
+	if (gsType == 0) {
+		main_setup_displays();
+		for (it = main_mgr->Modules.begin();
+					it != main_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
 			if (!strcmp(display_mod->Type(), TEXT_MODS)) {
 				display_mod->setDisplay(textDisplay);
@@ -130,105 +136,29 @@ void BackEnd::init_SWORD(int gsType)
 			}
 			if (!strcmp(display_mod->Type(), BOOK_MODS)) {
 				display_mod->setDisplay(bookDisplay);
-			}			
+			}
 		}
-	} else if(gsType == 1) { // dialogs
-		for (it = display_mgr->Modules.begin(); it != display_mgr->Modules.end(); it++) {	
+	} else if (gsType == 1) { // dialogs
+		for (it = main_mgr->Modules.begin(); it != main_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
-			if (!strcmp(display_mod->Type(), TEXT_MODS)) {	
+			if (!strcmp(display_mod->Type(), TEXT_MODS)) {
 				display_mod->setDisplay(chapDisplay);
 			} else {
 				display_mod->setDisplay(entryDisplay);
 			}
-		}	
-	} else if(gsType == 2) { // search
-		for (it = display_mgr->Modules.begin(); it != display_mgr->Modules.end(); it++) {	
+		}
+	} else if (gsType == 2) { // search
+		for (it = main_mgr->Modules.begin(); it != main_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
 			display_mod->setDisplay(entryDisplay);
-		}	
-	}
-}
-
-char *BackEnd::set_sword_locale(const char *sys_locale)
-{
-	char *retval = NULL;
-	char buf[32];
-	int i = 0;
-	SWLocale *sw_locale = NULL;
-	
-	if(sys_locale) {
-		if(!strncmp(sys_locale,"ru_RU",5)) {
-			sys_locale = "ru_RU-koi8-r";		
-		} else if(!strncmp(sys_locale,"ru_RU-koi8-r",10)) {
-			if(strlen(sys_locale) >  12) {
-				for(i = 0; i < 12; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if(!strncmp(sys_locale,"uk_UA-cp1251",10)) {
-			if(strlen(sys_locale) > 12 ) {
-				for(i = 0; i < 12; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if(!strncmp(sys_locale,"uk_UA-koi8-u",10)) {
-			if(strlen(sys_locale) > 12 ) {
-				for(i = 0; i < 12; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if(!strncmp(sys_locale,"pt_BR",5)) {
-			if(strlen(sys_locale) > 5 ) {
-				for(i = 0; i < 5; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-			
-		} else if(!strncmp(sys_locale,"en_GB",5)) {
-			if(strlen(sys_locale) > 5 ) {
-				for(i = 0; i < 5; i++) {
-					buf[i] = sys_locale[i];
-					buf[i+1] = '\0';
-				}
-				sys_locale = buf;
-			}
-		} else if(!strncmp(sys_locale,"fa",2)) {
-				sys_locale = "fa-utf8";
-		} else {
-			if(strlen(sys_locale) > 2 ) {
-				buf[0] = sys_locale[0];
-				buf[1] = sys_locale[1];
-				buf[2] = '\0';
-				sys_locale = buf;
-			}
 		}
-		retval = strdup(sys_locale);
-		LocaleMgr::getSystemLocaleMgr()->setDefaultLocaleName(sys_locale);
-		sw_locale = LocaleMgr::getSystemLocaleMgr()->getLocale(sys_locale);
 	}
-	if(sw_locale) {
-		OLD_CODESET = (char*)sw_locale->getEncoding();
-	} else {
-		OLD_CODESET = (char*)"UTF-8";
-	}
-	return retval;
 }
 
 void BackEnd::init_lists(MOD_LISTS * mods)
 {
 	ModMap::iterator it;
-	
+
 	for (it = main_mgr->Modules.begin();
 				it != main_mgr->Modules.end(); it++) {
 		if (!strcmp((*it).second->Type(), TEXT_MODS)) {
@@ -252,28 +182,28 @@ void BackEnd::init_lists(MOD_LISTS * mods)
 				    , "RawFiles")) {
 				mods->percommods = g_list_append(mods->percommods,
 				    strdup((char *) (*it).second->Name()));
-			} 
+			}
 		}
 		if (!strcmp((*it).second->Type(), DICT_MODS)) {
-			mods->dictionarymods =
-			    g_list_append(mods->dictionarymods,
-			    strdup((char *) (*it).second->Name()));
-			mods->dict_descriptions =
-			    g_list_append(mods->dict_descriptions,
-			    strdup((char *) (*it).second->
-				   Description()));
-			
 			char *feature =
 			    (char *) (*it).second->getConfigEntry("Feature");
-			if (!feature)
-				continue;
-			if (!strcmp(feature, "DailyDevotion"))
-				mods->devotionmods
-				   = g_list_append(mods->devotionmods,
-				    strdup((char *) (*it).second->Name()));
+
+			if (feature && !strcmp(feature, "DailyDevotion")) {
+				mods->devotionmods =
+				    g_list_append(mods->devotionmods,
+						  strdup((char *) (*it).second->Name()));
+			} else {
+				mods->dictionarymods =
+				    g_list_append(mods->dictionarymods,
+						  strdup((char *) (*it).second->Name()));
+				mods->dict_descriptions =
+				    g_list_append(mods->dict_descriptions,
+						  strdup((char *) (*it).second->
+							 Description()));
+			}
 		}
 		if (!strcmp((*it).second->Type(), BOOK_MODS)) {
-			if ((*it).second->getConfigEntry("GSType") && 
+			if ((*it).second->getConfigEntry("GSType") &&
 				!strcmp((*it).second->getConfigEntry("GSType")
 				    , "PrayerList")) {
 				mods->prayermods = g_list_append(mods->prayermods,
@@ -314,8 +244,8 @@ const char *BackEnd::get_sword_version(void)
 GList *BackEnd::get_module_options(void)
 {
 	GList *options = NULL;
-	StringList optionslist = main_mgr->getGlobalOptions();	
-	for (StringList::iterator it = optionslist.begin(); 
+	StringList optionslist = main_mgr->getGlobalOptions();
+	for (StringList::iterator it = optionslist.begin();
 				  it != optionslist.end(); it++) {
 		options = g_list_append(options, strdup((char *) (*it).c_str()));
 	}
@@ -326,7 +256,7 @@ int BackEnd::has_global_option(char * module_name, char * option)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
@@ -342,7 +272,7 @@ char *BackEnd::get_config_entry(char * module_name, char * entry)
 		return NULL;
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
@@ -355,13 +285,13 @@ char *BackEnd::get_config_entry(char * module_name, char * entry)
 
 void BackEnd::set_cipher_key(char * mod_name, char * key)
 {
-	display_mgr->setCipherKey(mod_name, key);	
+	main_mgr->setCipherKey(mod_name, key);
 }
 
 int BackEnd::is_Bible_key(const char * list, char * current_key)
 {
 	VerseKey key;
-	
+
 	key.setText(current_key);
 	ListKey vs = key.ParseVerseList(list, key);
 	return vs.Count();
@@ -372,64 +302,64 @@ char *BackEnd::get_render_text(const char *module_name, const char *key)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
-	it = display_mgr->Modules.find(module_name);
+	//-- iterate through the modules until we find modName
+	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
-	if (it != display_mgr->Modules.end()) {
+	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
 		return strdup((char *) mod->RenderText());
 	}
-	return NULL;	
+	return NULL;
 }
 
 char *BackEnd::get_raw_text(const char *module_name, const char *key)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
-	it = display_mgr->Modules.find(module_name);
+	//-- iterate through the modules until we find modName
+	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
-	if (it != display_mgr->Modules.end()) {
+	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		mod->setKey(key);
 		return strdup((char *) mod->getRawEntry());
 	}
-	return NULL;	
+	return NULL;
 }
 
 char *BackEnd::render_this_text(const char * module_name, const char * text)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
-	it = display_mgr->Modules.find(module_name);
+	//-- iterate through the modules until we find modName
+	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
-	if (it != display_mgr->Modules.end()) {
-		mod = (*it).second;		
+	if (it != main_mgr->Modules.end()) {
+		mod = (*it).second;
 		return strdup((char *) mod->RenderText(text));
 	}
-	return NULL;	
+	return NULL;
 }
 
 char *BackEnd::get_strip_text_from_string(const char * module_name, const char *string)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		return strdup((char *) mod->StripText(string));
 	}
-	return NULL;	
+	return NULL;
 }
 char *BackEnd::get_strip_text(const char *module_name, const char *key)
 {
 	SWModule *mod;
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
@@ -437,17 +367,17 @@ char *BackEnd::get_strip_text(const char *module_name, const char *key)
 		mod->setKey(key);
 		return strdup((char *) mod->StripText());
 	}
-	return NULL;	
+	return NULL;
 }
 
 
 char *BackEnd::get_valid_key(const char *key)
 {
 	VerseKey vkey;
-	char *mykey;                                                 
+	char *mykey;
 	vkey.AutoNormalize(1);
 	vkey = key;
-	if((sword_locale) && (!strcmp(sword_locale,"en")))
+	if ((sword_locale) && (!strcmp(sword_locale,"en")))
 		mykey = (char*)vkey.getShortText();
 	else
 		mykey = (char*)vkey.getText();
@@ -459,7 +389,7 @@ char *BackEnd::key_get_book(const char *key)
 	VerseKey vkey;
 	vkey.AutoNormalize(1);
 	vkey = key;
-	
+
 #ifdef SWORD_MULTIVERSE
 	return strdup((char*)vkey.getBookName());
 #else
@@ -489,7 +419,7 @@ unsigned int BackEnd::key_chapter_count(const char *key)
 	VerseKey vkey;
 	vkey.AutoNormalize(1);
 	vkey = key;
-	
+
 #ifdef SWORD_MULTIVERSE
 	return (vkey.getChapterMax());
 #else
@@ -502,25 +432,25 @@ unsigned int BackEnd::key_chapter_count(const char *key)
 
 unsigned int BackEnd::key_verse_count(const char *key)
 {
-	VerseKey vkey;  
+	VerseKey vkey;
 	vkey.AutoNormalize(1);
 	vkey = key;
-	
+
 #ifdef SWORD_MULTIVERSE
 	return (vkey.getVerseMax());
 #else
 	char testament = vkey.Testament() ;
 	char book = vkey.Book();
-	int chapter = vkey.Chapter();	
+	int chapter = vkey.Chapter();
 	return (vkey.books[testament-1][book-1].versemax[chapter-1]);
 #endif
 }
 
 
 char *BackEnd::get_module_key()
-{ 
+{
 	(const char *) *display_mod;
-	
+
 	return strdup((char*)display_mod->KeyText());
 }
 
@@ -532,9 +462,9 @@ void BackEnd::save_entry(const char * entry)
 
 void BackEnd::save_note_entry(const char * module, const char * key, const char * entry)
 {
-	display_mod = display_mgr->Modules[module];
-	
-	if (display_mod) {		
+	display_mod = main_mgr->Modules[module];
+
+	if (display_mod) {
 		display_mod->setKey(key);
 		display_mod->KeyText(); /* snap to entry */
 		display_mod->setEntry((const char *) entry);
@@ -554,7 +484,7 @@ void BackEnd::delete_entry(void)
 const char *BackEnd::module_get_language(const char *module_name)
 {
 	ModMap::iterator it;
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
 	if (it != main_mgr->Modules.end())
@@ -578,9 +508,9 @@ int BackEnd::is_module(const char *mod_name)
 int BackEnd::module_type(const char *mod_name)
 {
 	ModMap::iterator it;
-	if((!mod_name) || (strlen(mod_name) < 2)) 
+	if ((!mod_name) || (strlen(mod_name) < 2))
 		return -1;
-	//-- iterate through the modules until we find modName 
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(mod_name);
 	//-- if we find the module
 	if (it != main_mgr->Modules.end()) {
@@ -590,8 +520,8 @@ int BackEnd::module_type(const char *mod_name)
 		}
 
 		if (!strcmp((*it).second->Type(), COMM_MODS)) {
-			if (!strcmp((char *) (*it).second->getConfigEntry("ModDrv"), "RawFiles")) 
-				return PERCOM_TYPE;			
+			if (!strcmp((char *) (*it).second->getConfigEntry("ModDrv"), "RawFiles"))
+				return PERCOM_TYPE;
 			return COMMENTARY_TYPE;
 		}
 
@@ -600,8 +530,8 @@ int BackEnd::module_type(const char *mod_name)
 		}
 
 		if (!strcmp((*it).second->Type(), BOOK_MODS)) {
-			if ((*it).second->getConfigEntry("GSType") && 
-				!strcmp((char *) (*it).second->getConfigEntry("GSType"), "PrayerList")) 
+			if ((*it).second->getConfigEntry("GSType") &&
+				!strcmp((char *) (*it).second->getConfigEntry("GSType"), "PrayerList"))
 				return PRAYERLIST_TYPE;
 			return BOOK_TYPE;
 		}
@@ -612,26 +542,26 @@ int BackEnd::module_type(const char *mod_name)
 char *BackEnd::module_description(char *mod_name)
 {
 	ModMap::iterator it;
-	
-	if((!mod_name) || (strlen(mod_name) < 2)) 
+
+	if ((!mod_name) || (strlen(mod_name) < 2))
 		return NULL;
-	//-- iterate through the modules until we find modName 
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(mod_name);
 	//-- if we find the module
-	if (it != main_mgr->Modules.end()) {	
+	if (it != main_mgr->Modules.end()) {
 		return (*it).second->Description();
 	}
 	return NULL;
 }
- 
+
 char *BackEnd::module_name_from_description(char *description)
 {
 	ModMap::iterator it;
 	char *retval = NULL;
-	 
-	if(!description)
+
+	if (!description)
 		return NULL;
-	
+
 	for (it = main_mgr->Modules.begin();
 	     it != main_mgr->Modules.end(); it++) {
 		  if (!strcmp((*it).second->Description(), description))
@@ -644,7 +574,7 @@ char *BackEnd::module_name_from_description(char *description)
 int BackEnd::get_key_testament(const char * key)
 {
 	sword::VerseKey ikey( key );
-	return ikey.Testament();	
+	return ikey.Testament();
 }
 
 int BackEnd::module_has_testament(const char * module_name,  int testament)
@@ -652,7 +582,7 @@ int BackEnd::module_has_testament(const char * module_name,  int testament)
 	ModMap::iterator it;
 	int ot = 0;
 	int nt = 0;
-	
+
 	it = main_mgr->Modules.find(module_name);
 	if (it != main_mgr->Modules.end()) {
 		SWModule *module = (*it).second;
@@ -665,7 +595,7 @@ int BackEnd::module_has_testament(const char * module_name,  int testament)
 		} else if (key.Testament() == 2) { //no OT
 			ot = 0;
 		}
-	
+
 		*module = sword::BOTTOM;
 		key = module->KeyText();
 		if (key.Testament() == 1) { // only OT, no NT
@@ -691,7 +621,7 @@ int BackEnd::module_get_testaments(const char * module_name)
 	ModMap::iterator it;
 	int ot = 0;
 	int nt = 0;
-	
+
 	it = main_mgr->Modules.find(module_name);
 	if (it != main_mgr->Modules.end()) {
 		SWModule *module = (*it).second;
@@ -703,7 +633,7 @@ int BackEnd::module_get_testaments(const char * module_name)
 			} else if (key.Testament() == 2) { //no OT
 				ot = 0;
 			}
-	
+
 			*module = sword::BOTTOM;
 			key = module->KeyText();
 			if (key.Testament() == 1) { // only OT, no NT
@@ -713,11 +643,11 @@ int BackEnd::module_get_testaments(const char * module_name)
 			}
 	         module->setSkipConsecutiveLinks(false);
 	}
-	if(ot && nt)
+	if (ot && nt)
 		return 2;
-	else if(!ot && nt)
+	else if (!ot && nt)
 		return 1;
-	else if(ot && !nt)
+	else if (ot && !nt)
 		return 0;
 	return -1;
 }
@@ -725,45 +655,45 @@ int BackEnd::module_get_testaments(const char * module_name)
 char *BackEnd::get_entry_attribute(const char *level1, const char *level2, const char *level3)
 {
 	UTF8HTML u2html;
-	display_mod->RenderText();                 	
+	display_mod->RenderText();
 	SWBuf attribute2 = display_mod->getEntryAttributes()[level1][level2][level3].c_str();
-	
+
 	u2html.processText(attribute2);
-	
-	if (attribute2.length()) {  
+
+	if (attribute2.length()) {
 		return strdup(attribute2.c_str());
-	}  
-	return NULL;	
+	}
+	return NULL;
 }
 
- 
+
 int BackEnd::set_module(const char *module_name)
 {
-	display_mod = display_mgr->Modules[module_name];
-	if (display_mod) 
+	display_mod = main_mgr->Modules[module_name];
+	if (display_mod)
 		return 1;
-	else 
+	else
 		return 0;
-	
+
 }
 
 int BackEnd::set_module_key(const char *module_name, const char *key)
 {
-	display_mod = display_mgr->Modules[module_name];
-	
+	display_mod = main_mgr->Modules[module_name];
+
 	if (display_mod) {
 		GS_message((f_message,878,"key",key));
 		display_mod->setKey(key);
 		return 1;
 	}
-	else 
+	else
 		return 0;
-	
+
 }
 
 int BackEnd::set_key(const char *key)
 {
-	if(!key)
+	if (!key)
 		return 0;
 	if (display_mod) {
 		GS_message((f_message,758,"key",key));
@@ -771,7 +701,7 @@ int BackEnd::set_key(const char *key)
 		return 1;
 	}
 	return 0;
-	
+
 }
 
 char *BackEnd::get_key_from_offset(unsigned long offset)
@@ -791,7 +721,7 @@ char *BackEnd::get_key_from_offset(unsigned long offset)
 
 unsigned long BackEnd::treekey_set_key(char * key)
 {
-	if(tree_key) {
+	if (tree_key) {
                 TreeKeyIdx treenode = *tree_key;
 		treenode.setText(key);
                 display_mod->SetKey(treenode);
@@ -802,7 +732,7 @@ unsigned long BackEnd::treekey_set_key(char * key)
 }
 void BackEnd::set_treekey(unsigned long offset)
 {
-	if(tree_key)
+	if (tree_key)
 		delete tree_key;
 	tree_key = (TreeKeyIdx *) display_mod->CreateKey();
 	if (tree_key) {
@@ -821,10 +751,10 @@ unsigned long BackEnd::get_treekey_offset_from_key(const char * module_name, con
         SWModule *mod;
 	ModMap::iterator it;
 	unsigned long retval = 0;
-	//-- iterate through the modules until we find modName  
+	//-- iterate through the modules until we find modName
 	it = main_mgr->Modules.find(module_name);
 	//-- if we find the module
-	if (it != main_mgr->Modules.end()) {		
+	if (it != main_mgr->Modules.end()) {
 		mod = (*it).second;
 		TreeKeyIdx *tree_key_idx = (TreeKeyIdx *) mod->CreateKey();
 		tree_key_idx->setText(key);
@@ -838,15 +768,15 @@ unsigned long BackEnd::get_treekey_offset_from_key(const char * module_name, con
 
 
 unsigned long BackEnd::get_treekey_offset(void)
-{	
-        if (tree_key) 
+{
+        if (tree_key)
                 return tree_key->getOffset();
         return 0;
 }
 
 
 int BackEnd::treekey_has_children(unsigned long offset)
-{	
+{
         if (tree_key) {
                 tree_key->setOffset(offset);
 		return tree_key->hasChildren();
@@ -876,7 +806,7 @@ int BackEnd::treekey_parent(unsigned long offset)
 
 
 char *BackEnd::treekey_get_local_name(unsigned long offset)
-{	
+{
         if (tree_key) {
                 tree_key->setOffset(offset);
                 //-- returned value must be freed by calling function
@@ -890,9 +820,9 @@ int BackEnd::treekey_next_sibling(unsigned long offset)
 {
         if (tree_key) {
                 tree_key->setOffset(offset);
-                if(tree_key->nextSibling()) {
+                if (tree_key->nextSibling()) {
 			return 1;
-		}	
+		}
         }
         return 0;
 }
@@ -903,9 +833,9 @@ int BackEnd::treekey_prev_sibling(unsigned long offset)
 {
         if (tree_key) {
                 tree_key->setOffset(offset);
-                if(tree_key->previousSibling()) {
+                if (tree_key->previousSibling()) {
 			return 1;
-		}	
+		}
         }
         return 0;
 }
@@ -932,9 +862,9 @@ GList *BackEnd::parse_verse_list(const char * list, char * current_key)
 {
 	GList *retlist = NULL;
 	VerseKey key;
-	ListKey vs;                                                   
-	
-	if(!list)
+	ListKey vs;
+
+	if (!list)
 		return retlist;
 	GS_message(("current_key=%s",current_key));
 	key.setText(current_key);
@@ -953,13 +883,13 @@ GList *BackEnd::parse_range_list(const char * list)
 	GList *retlist = NULL;
 	const char *buf = NULL;
 	VerseKey key;
-	
+
 	verses.ClearList();
 	verses = key.ParseVerseList(list, key, true);
 
 	buf = verses.getRangeText();
 	retlist = g_list_append(retlist, g_strdup(buf));
-    
+
 	return retlist;
 }
 
@@ -978,19 +908,19 @@ const char *BackEnd::get_next_listkey(void)
 	// we solve the problem by copying the data while it's current.
 	// it's ugly (returning a pointer to a static char []) but it works.
 
-	static char retval[128];                                                  
-	
-	while(!results.Error()) {		
+	static char retval[128];
+
+	while (!results.Error()) {
 		(void) g_strlcpy(retval, results.getText(), 126);
 		results++;
 		return retval;
 	}
-	return NULL;	
+	return NULL;
 }
 
 int BackEnd::clear_scope(void)
 {
-	current_scope = 0;	
+	current_scope = 0;
 	return 1;
 }
 
@@ -1019,14 +949,14 @@ int BackEnd::set_scope2last_search(void)
 
 int BackEnd::do_module_index(char *module_name)
 {
-	
+
 	search_mod = main_mgr->Modules[module_name];
 	if (!search_mod)
 		return -1;
 	char progressunits = 70;
 	if (!search_mod->hasSearchFramework())
 		return 0;
-	
+
 	search_mod->deleteSearchFramework();
 	search_mod->createSearchFramework(main_index_percent_update,
 					(void *) &progressunits);
@@ -1035,13 +965,13 @@ int BackEnd::do_module_index(char *module_name)
 
 int BackEnd::do_module_delete_index(char *module_name)
 {
-	
+
 	search_mod = main_mgr->Modules[module_name];
 	if (!search_mod)
 		return -1;
 	if (!search_mod->hasSearchFramework())
 		return 0;
-	
+
 	search_mod->deleteSearchFramework();
 	return 1;
 }
@@ -1049,12 +979,12 @@ int BackEnd::do_module_delete_index(char *module_name)
 int BackEnd::check_for_optimal_search(char * module_name)
 {
 	search_mod = main_mgr->Modules[module_name];
-	
+
 	if (!search_mod)
 		return -2;
 	if (search_mod->hasSearchFramework() &&
 	    search_mod->isSearchOptimallySupported("God", -4, 0, 0))
-		return -4; // ** indexed search - clucene ** 
+		return -4; // ** indexed search - clucene **
 	else
 		return -2; // ** word search **
 }
@@ -1076,7 +1006,7 @@ int BackEnd::do_module_search(char *module_name,
 	if ((current_scope == &search_scope_list) &&
 	    (search_scope_list.Count() == 0))
 		return 0;
-	
+
 	results = search_mod->search(search_string,
 				search_type,
 				search_params,
@@ -1096,7 +1026,7 @@ void BackEnd::terminate_search()
 	if (search_mod)
 		search_mod->terminateSearch = true;
 }
- 
+
 char *BackEnd::get_conf_file_item(const char * file, const char * mod_name, const char * item)
 {
 	char *buf = NULL;
@@ -1104,7 +1034,7 @@ char *BackEnd::get_conf_file_item(const char * file, const char * mod_name, cons
 	conf_file.Load();
 
 	buf = (char *) conf_file[mod_name][item].c_str();
-	if(strlen(buf))
+	if (strlen(buf))
 		return strdup(buf);
 	else
 		return NULL;
@@ -1119,7 +1049,7 @@ void BackEnd::save_conf_file_item(const char * file,
 	conf_file[mod_name][item] = value;
 	conf_file.Save();
 }
- 
+
 void BackEnd::save_module_key(char *mod_name, char *key)
 {
 	SectionMap::iterator section;
@@ -1170,4 +1100,26 @@ void BackEnd::save_module_key(char *mod_name, char *key)
 	}
 	delete myConfig;
 }
+
+const char *BackEnd::get_osisref_from_key(const char *module, const char *key)
+{
+	ModMap::iterator it;
+
+	// we need an OSISRef in module-sensitive context.
+	// fallback positions: we hope for a supplied module.
+	// if not, assume KJV (v11n historical reasons; not anglocentric).
+	// if not, use the 1st module...by which time we're just guessing.
+
+	it = main_mgr->Modules.find((module && *module) ? module : "KJV");
+	if (it == main_mgr->Modules.end()) {
+		it = main_mgr->Modules.begin();
+		if (it == main_mgr->Modules.end())
+			return "";
+	}
+
+	VerseKey *vk = (VerseKey *)(*it).second->getKey();
+	*vk = key;
+	return vk->getOSISRef();
+}
+
 /* end of file */
