@@ -20,16 +20,13 @@
  */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
 
-#include <gnome.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
- 
+
 #include <glib.h>
 
-#ifdef USE_GTKHTML3_14_23
 
 #include <libintl.h>
 #include <locale.h>
@@ -39,12 +36,15 @@
 #include <editor/gtkhtml-editor.h>
 #include <gtkhtml/gtkhtml-stream.h>
 
+
 #include "editor/slib-editor.h"
+#include "editor/link_dialog.h"
 
 
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/sword_treekey.h"
+#include "main/url.hh"
 #include "main/xml.h"
 
 #include "gui/navbar_versekey_editor.h"
@@ -54,21 +54,26 @@
 #include "gui/treekey-editor.h"
 #include "gui/utilities.h"
 
+#include "gui/debug_glib_null.h"
+
 extern gboolean do_display;
 
-static 
+static
+gboolean editor_is_dirty(EDITOR * e);
+
+static
 int app_delete_cb(GtkWidget * widget, GdkEvent * event, gpointer data);
 
-static 
+static
 void _load_file (EDITOR * e, const gchar * filename);
 
-static 
+static
 void _save_file (EDITOR * e);
 
-static 
+static
 void _save_note (EDITOR * e);
 
-static 
+static
 void _save_book (EDITOR * e);
 
 static
@@ -77,7 +82,7 @@ gint ask_about_saving(EDITOR * e);
 
 static GList *editors_all = NULL;
 
- 
+
 static void
 handle_error (GError **error)
 {
@@ -106,7 +111,7 @@ void do_exit(EDITOR * e)
 	if (e->key) {
 		g_free(e->key);
 	}
-	if(e->window)	
+	if (e->window)
 		gtk_widget_destroy(e->window);
 		//GS_message(("e->widow still exist!"));
 	g_free(e);
@@ -119,7 +124,6 @@ void change_window_title(GtkWidget * window, const gchar * window_title)
 }
 
 
-#ifdef USE_GTKHTML3_14
 #if 0
 static gint
 _calc_header_height (GtkHTML *html, GtkPrintOperation *operation,
@@ -261,29 +265,29 @@ _do_print (EDITOR * e,
 	GtkPrintOperationResult result;
 	GError *error = NULL;
 
-	operation = gtk_print_operation_new ();	
+	operation = gtk_print_operation_new ();
 	psettings = gtk_print_settings_new ();
-	
-	psettings = gtk_print_operation_get_print_settings (operation);	
-	
+
+	psettings = gtk_print_operation_get_print_settings (operation);
+
 	setup = gtk_page_setup_new ();
 	gtk_page_setup_set_top_margin (setup,30,GTK_UNIT_PIXEL);
 	gtk_page_setup_set_left_margin (setup,50,GTK_UNIT_PIXEL);
-	
+
 #ifdef WIN32
 	gtk_print_operation_set_unit(operation, GTK_UNIT_POINTS);
-#endif	
+#endif
 	gtk_print_operation_set_default_page_setup (operation, setup);
-	
-	result = gtk_html_print_operation_run (GTK_HTML(e->html_widget), 
-					       operation, 
+
+	result = gtk_html_print_operation_run (GTK_HTML(e->html_widget),
+					       operation,
 					       action,
-					       GTK_WINDOW (e->window), 
+					       GTK_WINDOW (e->window),
 					       (GtkHTMLPrintCalcHeight) _calc_header_height, /* GtkHTMLPrintCalcHeight  calc_header_height*/
-					       (GtkHTMLPrintCalcHeight) _calc_footer_height, /* GtkHTMLPrintCalcHeight  calc_footer_height*/ 
-					       (GtkHTMLPrintDrawFunc) _draw_header, /* GtkHTMLPrintDrawFunc draw_header */ 
+					       (GtkHTMLPrintCalcHeight) _calc_footer_height, /* GtkHTMLPrintCalcHeight  calc_footer_height*/
+					       (GtkHTMLPrintDrawFunc) _draw_header, /* GtkHTMLPrintDrawFunc draw_header */
 					       (GtkHTMLPrintDrawFunc) _draw_footer, /* GtkHTMLPrintDrawFunc draw_footer */
-					       e, /* gpointer user_data */ 
+					       e, /* gpointer user_data */
 					       &error);
 
 	g_object_unref (operation);
@@ -292,7 +296,7 @@ _do_print (EDITOR * e,
 	return result;
 }
 #endif /* 0 */
-#endif
+
 
 
 
@@ -303,6 +307,7 @@ static const gchar *file_ui =
 "     <menuitem action='open'/>\n"
 "     <menuitem action='save'/>\n"
 "     <menuitem action='save-as'/>\n"
+"     <menuitem action='new'/>\n"
 "     <separator/>\n"
 "     <menuitem action='print-preview'/>\n"
 "     <menuitem action='print'/>\n"
@@ -318,6 +323,7 @@ static const gchar *note_file_ui =
 "    <menu action='file-menu'>\n"
 "     <menuitem action='save'/>\n"
 "     <menuitem action='save-as'/>\n"
+"     <menuitem action='delete'/>\n"
 "     <separator/>\n"
 "     <menuitem action='print-preview'/>\n"
 "     <menuitem action='print'/>\n"
@@ -339,17 +345,28 @@ static const gchar *view_ui =
 "</ui>";
 
 
-static const gchar *main_ui =
+static const gchar *main_ui_note =
 "<ui>\n"
 "  <toolbar name='main-toolbar'> \n"
 "    <placeholder name='pre-main-toolbar'> \n"
 "      <toolitem action='save'/> \n"
+"      <toolitem action='delete'/> \n"
 "      <separator/> \n"
 "    </placeholder> \n"
 "  </toolbar> \n"
 "</ui>";
 
 
+static const gchar *main_ui_studypad =
+"<ui>\n"
+"  <toolbar name='main-toolbar'> \n"
+"    <placeholder name='pre-main-toolbar'> \n"
+"      <toolitem action='save'/> \n"
+"      <toolitem action='new'/> \n"
+"      <separator/> \n"
+"    </placeholder> \n"
+"  </toolbar> \n"
+"</ui>";
 
 static GtkPrintOperationResult
 print (GtkhtmlEditor *editor,
@@ -419,7 +436,7 @@ open_dialog (EDITOR * e)
 
 
 static gint
-save_dialog (GtkhtmlEditor *editor)
+save_dialog (GtkhtmlEditor *editor, EDITOR * e)
 {
 	GtkWidget *dialog;
 	const gchar *filename;
@@ -454,7 +471,20 @@ save_dialog (GtkhtmlEditor *editor)
 
 		new_filename = gtk_file_chooser_get_filename (
 			GTK_FILE_CHOOSER (dialog));
+		//GS_message (("\nnew_filename: %s\n",new_filename));
 		gtkhtml_editor_set_filename (editor, new_filename);
+
+		if (e->filename)
+			g_free(e->filename);
+		e->filename = g_strdup(new_filename);
+
+		xml_set_value("Xiphos", "studypad", "lastfile",
+			      e->filename);
+		settings.studypadfilename =
+		    xml_get_value("studypad", "lastfile");
+
+		change_window_title(e->window, e->filename);
+
 		g_free (new_filename);
 	}
 
@@ -571,8 +601,8 @@ static void
 action_save_cb (GtkAction *action,
                 EDITOR *e)
 {
-	switch(e->type) {
-	case STUDYPAD_EDITOR:	
+	switch (e->type) {
+	case STUDYPAD_EDITOR:
 		_save_file (e);
 		break;
 	case NOTE_EDITOR:
@@ -587,6 +617,64 @@ action_save_cb (GtkAction *action,
 	}
 }
 
+static void
+action_new_cb (GtkAction *action,
+                EDITOR *e)	/* for studypad only */
+{
+
+	if (editor_is_dirty(e))
+		_save_file (e);
+
+	_load_file(e, g_strdup_printf("%s/%s",settings.gSwordDir,"template.pad"));
+
+	if (e->filename)
+		g_free(e->filename);
+	e->filename = g_strdup(_("Untitled document"));
+
+	xml_set_value("Xiphos", "studypad", "lastfile",
+		      e->filename);
+	settings.studypadfilename =
+	    xml_get_value("studypad", "lastfile");
+	change_window_title(e->window, e->filename);
+
+	gtkhtml_editor_set_filename(GTKHTML_EDITOR(e->window), NULL);
+	gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), TRUE);
+}
+
+
+static void
+action_delete_cb (GtkAction *action,
+                EDITOR *e)	/* for note only */
+{
+
+	gchar *buf;
+
+	if (e->studypad)
+		return;
+
+	buf = g_strdup_printf
+	    ("<span weight=\"bold\" size=\"larger\">%s %s?</span>",
+	    _("Are you sure you want to delete the note for") , e->key);
+
+	if (gui_yes_no_dialog(buf, GTK_STOCK_DIALOG_WARNING)) {
+		main_delete_note(e->module, e->key);
+		gtkhtml_editor_set_text_html (GTKHTML_EDITOR(e->window),
+					      "",
+					      strlen(""));
+	}
+	g_free(buf);
+
+}
+
+
+static void
+action_insert_link_cb (GtkAction *action, EDITOR *e)
+{
+	editor_link_dialog (e);
+}
+
+
+
 static void
 action_save_as_cb (GtkAction *action,
                    EDITOR *e)
@@ -595,7 +683,7 @@ action_save_as_cb (GtkAction *action,
 	gboolean as_html;
 	GError *error = NULL;
 
-	if (save_dialog (GTKHTML_EDITOR(e->window)) == GTK_RESPONSE_CANCEL)
+	if (save_dialog (GTKHTML_EDITOR(e->window), e) == GTK_RESPONSE_CANCEL)
 		return;
 
 	filename = gtkhtml_editor_get_filename (GTKHTML_EDITOR(e->window));
@@ -626,6 +714,9 @@ action_view_plain_source (GtkAction *action,
 	view_source_dialog (editor, _("Plain Source"), "text/plain", FALSE);
 }
 
+
+
+
 static GtkActionEntry file_entries[] = {
 
 	{ "print",
@@ -669,6 +760,18 @@ static GtkActionEntry file_entries[] = {
 	  NULL,
 	  NULL,
 	  G_CALLBACK (action_save_as_cb) },
+	{ "new",
+	  "gtk-new",
+	  N_("New"),
+	  NULL,
+	  N_("Open new document"),
+	  G_CALLBACK (action_new_cb) },
+	{ "delete",
+	  "gtk-delete",
+	  N_("Delete"),
+	  NULL,
+	  N_("Delete current note"),
+	  G_CALLBACK (action_delete_cb) },
 
 	{ "file-menu",
 	  NULL,
@@ -766,6 +869,24 @@ static GtkActionEntry main_entries[] = {
 };
 
 
+static GtkActionEntry test_entries[] = {
+
+	{ "context-insert-link",
+	  "insert-link",
+	  N_("Insert Link"),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (action_insert_link_cb) },
+
+	{ "insert-link",
+	  "insert-link",
+	  N_("Insert Link"),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (action_insert_link_cb) }
+};
+
+
 GtkWidget * editor_new (const gchar * title, EDITOR *e)
 {
 	GtkActionGroup *action_group;
@@ -777,20 +898,26 @@ GtkWidget * editor_new (const gchar * title, EDITOR *e)
 	e->window = editor;
 	e->html_widget = GTK_WIDGET(gtkhtml_editor_get_html (GTKHTML_EDITOR (editor)));
 	gtk_window_set_title(GTK_WINDOW(editor),title);
-	
+
+	set_window_icon (GTK_WINDOW(editor));
+
 	manager = gtkhtml_editor_get_ui_manager (GTKHTML_EDITOR (editor));
-	if (e->type == STUDYPAD_EDITOR) 	
+	if (e->type == STUDYPAD_EDITOR)
 		gtk_ui_manager_add_ui_from_string (manager, file_ui, -1, &error);
-	else	
+	else
 		gtk_ui_manager_add_ui_from_string (manager, note_file_ui, -1, &error);
-		
+
 	handle_error (&error);
 
-	
+
 	gtk_ui_manager_add_ui_from_string (manager, view_ui, -1, &error);
 	handle_error (&error);
-	
-	gtk_ui_manager_add_ui_from_string (manager, main_ui, -1, &error);
+
+	if (e->type == STUDYPAD_EDITOR)
+		gtk_ui_manager_add_ui_from_string (manager, main_ui_studypad, -1, &error);
+	else
+		gtk_ui_manager_add_ui_from_string (manager, main_ui_note, -1, &error);
+
 	handle_error (&error);
 
 	action_group = gtk_action_group_new ("file");
@@ -816,16 +943,25 @@ GtkWidget * editor_new (const gchar * title, EDITOR *e)
 		action_group, main_entries,
 		G_N_ELEMENTS (main_entries), e);
 	gtk_ui_manager_insert_action_group (manager, action_group, 0);
-	
+
+
+	action_group = gtk_action_group_new ("context-menu");
+	gtk_action_group_set_translation_domain (
+		action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (
+		action_group, test_entries,
+		G_N_ELEMENTS (test_entries), e);
+	gtk_ui_manager_insert_action_group (manager, action_group, 0);
+
+
 	gtk_ui_manager_ensure_update (manager);
 	gtk_widget_show (editor);
 
 	gtkhtml_editor_drop_undo(GTKHTML_EDITOR(e->window));
 	gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), FALSE);
-	
+
 	g_signal_connect(editor, "delete-event",
 			 G_CALLBACK(app_delete_cb), (EDITOR *) e);
-
 	return editor;
 
 }
@@ -848,18 +984,20 @@ static void
 _save_note(EDITOR * e)
 {
 	GString *string;
-	
+
 	string = g_string_sized_new (4096);
-	
+
 	gtk_html_export (gtkhtml_editor_get_html
 			 (GTKHTML_EDITOR (e->window)),
-			"text/html", 
-			(GtkHTMLSaveReceiverFn) _save_receiver, 
+			"text/html",
+			(GtkHTMLSaveReceiverFn) _save_receiver,
 			string);
 	GS_message(("\n_save_note: %s\n",string->str));
 	main_save_note (e->module, e->key, string->str);
-	
+
 	g_string_free(string,TRUE);
+	gtkhtml_editor_drop_undo(GTKHTML_EDITOR(e->window));
+	gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), FALSE);
 }
 
 
@@ -867,18 +1005,20 @@ static void
 _save_book(EDITOR * e)
 {
 	GString *string;
-	
+
 	string = g_string_sized_new (4096);
-	
+
 	gtk_html_export (gtkhtml_editor_get_html
 			(GTKHTML_EDITOR (e->window)),
-			"text/html", 
-			(GtkHTMLSaveReceiverFn) _save_receiver, 
+			"text/html",
+			(GtkHTMLSaveReceiverFn) _save_receiver,
 			string);
-	
+
 	main_treekey_save_book_text(e->module, e->key, string->str);
 	g_string_free(string,TRUE);
-}	
+	gtkhtml_editor_drop_undo(GTKHTML_EDITOR(e->window));
+	gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), FALSE);
+}
 
 
 static void
@@ -887,17 +1027,22 @@ _save_file (EDITOR * e)
 	const gchar *filename;
 	gboolean as_html;
 	GError *error = NULL;
-	
+
 	if (gtkhtml_editor_get_filename (GTKHTML_EDITOR(e->window)) == NULL)
-		if (save_dialog (GTKHTML_EDITOR(e->window)) == GTK_RESPONSE_CANCEL)
+		if (save_dialog (GTKHTML_EDITOR(e->window), e) == GTK_RESPONSE_CANCEL)
 			return;
 
 	filename = gtkhtml_editor_get_filename (GTKHTML_EDITOR(e->window));
 	as_html = gtkhtml_editor_get_html_mode (GTKHTML_EDITOR(e->window));
 
+	GS_message (("\n_save_file filename: %s\n",filename));
+
 	gtkhtml_editor_save (GTKHTML_EDITOR(e->window), filename, as_html, &error);
-	handle_error (&error);	
-}	
+	handle_error (&error);
+
+	gtkhtml_editor_drop_undo(GTKHTML_EDITOR(e->window));
+	gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), FALSE);
+}
 
 
 static void
@@ -909,20 +1054,20 @@ _load_file (EDITOR * e, const gchar * filename)
 	e->filename = g_strdup(filename);
 
 	GS_message(("_load_file filename: %s",filename));
-	
+
 	xml_set_value("Xiphos", "studypad", "lastfile",
 		      e->filename);
 	settings.studypadfilename =
 	    xml_get_value("studypad", "lastfile");
 	change_window_title(e->window, e->filename);
-	
+
 	char *contents;
 	char *etag_out;
-	gsize length; 
+	gsize length;
 	GFile *file;
 	file = g_file_new_for_path(filename);
 	gtkhtml_editor_set_filename(GTKHTML_EDITOR(e->window),e->filename);
-	if(g_file_load_contents (file,
+	if (g_file_load_contents (file,
                               NULL,
                               &contents,
                               &length,
@@ -955,20 +1100,20 @@ void editor_save_book(EDITOR * e)
 void editor_load_book(EDITOR * e)
 {
 	gchar *title = NULL;
-	gchar *text = NULL;	
+	gchar *text = NULL;
+
+	if (!g_ascii_isdigit(e->key[0])) return; /* make sure is a number (offset) */
+
 
-	if(!g_ascii_isdigit(e->key[0])) return; /* make sure is a number (offset) */
-	
-	
 	title = g_strdup_printf("%s", e->module);
 	GS_message (("book: %s\noffset :%s", e->module, e->key));
-	
-	if(atol(e->key) != 0)
+
+	if (atol(e->key) != 0)
 		text = main_get_book_raw_text (e->module, e->key);
 	else
 		text = g_strdup(e->module);
-	
-	if(strlen(text)) {
+
+	if (strlen(text)) {
 		gtkhtml_editor_set_text_html (GTKHTML_EDITOR(e->window),
 					      text,
 					      strlen(text));
@@ -981,9 +1126,9 @@ void editor_load_book(EDITOR * e)
 		gtkhtml_editor_drop_undo (GTKHTML_EDITOR(e->window));
 		gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), FALSE);
 	}
-	
+
 	change_window_title(e->window, title);
-	
+
 	if (text)
 		g_free(text);
 	if (title)
@@ -997,47 +1142,29 @@ void editor_load_book(EDITOR * e)
  * Synopsis
  *   #include "/.h"
  *
- *   void sync_toggled(GtkToggleButton * button, DIALOG_DATA * vc)	
+ *   void sync_toggled(GtkToggleButton * button, DIALOG_DATA * vc)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
-void editor_sync_toggled(GtkToggleButton * button, EDITOR * e)
-{/*
-#ifdef USE_GTKHTML3_14_23
-	
-#else
-	if (button->active) {
-		if (editor_is_dirty(e))
-			save_through_persist_stream_cb(NULL, (EDITOR*)e);
-		editor_load_note(e, NULL,settings.currentverse);
-		e->sync = TRUE;
-	}
-	else		
-		e->sync = FALSE;
-#endif*/
-}
-
-
 void editor_sync_with_main(void)
 {
 	GList *tmp = NULL;
 	EDITOR * e;
-	
+
 	tmp = g_list_first(editors_all);
 	while (tmp != NULL) {
 		e = (EDITOR*)tmp->data;
 		//if (!e->studypad) {
-		switch(e->type) {
+		switch (e->type) {
 			case STUDYPAD_EDITOR:
 			case BOOK_EDITOR:
-				break;			
+				break;
 			case NOTE_EDITOR:
-			editor_sync_toggled(GTK_TOGGLE_BUTTON(e->navbar.button_sync), e);
 			break;
 		}
 		tmp = g_list_next(tmp);
@@ -1051,25 +1178,25 @@ editor_load_note(EDITOR * e, const gchar * module_name,
 	gchar *title;
 	gchar *text;
 
-	
+
 	if (editor_is_dirty(e))
 		_save_note (e);
-	
+
 	if (module_name) {
 		if (e->module)
 			g_free(e->module);
 		e->module = g_strdup(module_name);
 	}
-	if (key) {	
-		if (e->key) 
+	if (key) {
+		if (e->key)
 			g_free(e->key);
 		e->key = g_strdup(key);
 	}
-		
-	
+
+
 	title = g_strdup_printf("%s - %s", e->module, e->key);
 	text = main_get_raw_text((gchar *) e->module, (gchar *) e->key);
-	if(strlen(text)) {
+	if (strlen(text)) {
 		//GS_message(("\n\n\neditor_load_note:\n%s\n\n\n", text));
 		gtkhtml_editor_set_text_html (GTKHTML_EDITOR(e->window),
 					      text,
@@ -1085,11 +1212,11 @@ editor_load_note(EDITOR * e, const gchar * module_name,
 		gtkhtml_editor_set_changed (GTKHTML_EDITOR(e->window), FALSE);
 
 	}
-	
+
 	change_window_title(e->window, title);
-    	if(e->type == NOTE_EDITOR)
+    	if (e->type == NOTE_EDITOR)
 		main_navbar_versekey_set(e->navbar, e->key);
-	
+
 	if (text)
 		g_free(text);
 	if (title)
@@ -1097,27 +1224,6 @@ editor_load_note(EDITOR * e, const gchar * module_name,
 }
 
 
-gboolean editor_close_all(void)
-{
-/*
-	GList *tmp = NULL;
-	EDITOR *e = NULL;
-#ifdef USE_GTKHTML3_14_23
-	
-#else	
-	tmp = g_list_first(editors_all);
-	GS_message(("number of editors = %d",g_list_length(tmp)));
-	while (tmp != NULL) {
-		e = (EDITOR*)tmp->data;
-		if (e->window)
-			do_exit(e);			
-		tmp = g_list_next(tmp);
-	}
-	g_list_free(editors_all);
-#endif*/
-	return TRUE;
-}
-
 static int
 app_delete_cb(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
@@ -1149,14 +1255,14 @@ gint ask_about_saving(EDITOR * e)
 	gchar *buf1 = NULL;
 	gchar *buf2 = NULL;
 	gchar *buf3 = NULL;
-	gint retval = FALSE;	
+	gint retval = FALSE;
 
-	switch(e->type) {
+	switch (e->type) {
 	case BOOK_EDITOR:
 	case NOTE_EDITOR:
 		info = gui_new_dialog();
 		info->stock_icon = GTK_STOCK_DIALOG_WARNING;
-		
+
 		buf = g_strdup_printf("%s: %s",e->module, e->key);
 		buf1 = _("Save the changes to document");
 		buf2 = _("before closing?");
@@ -1173,7 +1279,7 @@ gint ask_about_saving(EDITOR * e)
 
 		test = gui_alert_dialog(info);
 		retval = test;
-		
+
 		if (test == GS_YES) {
 			if (e->type == NOTE_EDITOR) {
 				/* save notes and prayer lists */
@@ -1187,7 +1293,7 @@ gint ask_about_saving(EDITOR * e)
 		g_free(info);
 		g_free(buf3);
 		break;
-	
+
 	case STUDYPAD_EDITOR:
 		info = gui_new_dialog();
 		info->stock_icon = GTK_STOCK_DIALOG_WARNING;
@@ -1224,9 +1330,7 @@ gint ask_about_saving(EDITOR * e)
 		g_free(buf3);
 		break;
 	}
-	while (gtk_events_pending()) {
-		gtk_main_iteration();
-	}
+	sync_windows();
 	return retval;
 }
 
@@ -1237,22 +1341,22 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 	EDITOR *editor;
 	GtkWidget *vbox = NULL;
 	GtkWidget *toolbar_nav = NULL;
-	
-	
+
+
 	editor = g_new(EDITOR, 1);
 	editor->html_widget = NULL;
 	editor->sync = FALSE;
 	editor->type = editor_type;
-	
-	switch(editor_type) {
-	case STUDYPAD_EDITOR:	
+
+	switch (editor_type) {
+	case STUDYPAD_EDITOR:
 		editor->studypad = TRUE;
 		editor->module = NULL;
 		editor->key = NULL;
 		editor->filename = NULL;
-		widgets.studypad_dialog = 
+		widgets.studypad_dialog =
 			editor_new(_("StudyPad"), editor);
-		
+
 		if (filename) {
 			editor->filename = g_strdup(filename);
 			_load_file(editor, g_strdup(filename));
@@ -1266,12 +1370,12 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 		editor->key = g_strdup(key);
 		editor->navbar.key = NULL;
 		editor_new(_("Note Editor"), editor);
-		vbox = GTKHTML_EDITOR(editor->window)->vbox;			
+		vbox = GTKHTML_EDITOR(editor->window)->vbox;
 		toolbar_nav = gui_navbar_versekey_editor_new(editor);
 		gtk_widget_show(toolbar_nav);
 		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET(toolbar_nav), FALSE, TRUE, 0);
 		gtk_box_reorder_child (GTK_BOX (vbox),GTK_WIDGET(toolbar_nav),1);
-		
+
 		editor_load_note(editor, NULL, NULL);
 		break;
 	case BOOK_EDITOR:
@@ -1280,13 +1384,13 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 		editor->module = g_strdup(filename);
 		editor->key = g_strdup(key);
 		editor_new(_("Prayer List/Journal Editor"), editor);
-		
+
 		GtkWidget *box = gtk_vbox_new (FALSE, 0);
 		gtk_widget_show (box);
 		GtkWidget *hpaned1 = gtk_hpaned_new ();
 		gtk_widget_show (hpaned1);
 		gtk_paned_pack2 (GTK_PANED (hpaned1), box, TRUE, TRUE);
-		
+
 		GtkWidget *scrollbar = gtk_scrolled_window_new(NULL, NULL);
 		gtk_widget_show(scrollbar);
 		gtk_paned_pack1(GTK_PANED(hpaned1), GTK_WIDGET(scrollbar),
@@ -1296,9 +1400,9 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 					       GTK_POLICY_AUTOMATIC);
 		gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)
 						    scrollbar,
-				    settings.shadow_type);	     
-    
-		editor->treeview = gui_create_editor_tree(editor); 
+				    settings.shadow_type);
+
+		editor->treeview = gui_create_editor_tree(editor);
 		gtk_widget_show(editor->treeview);
 		gtk_container_add(GTK_CONTAINER(scrollbar),
 				 editor->treeview);
@@ -1307,16 +1411,16 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 		gtk_tree_view_collapse_all((GtkTreeView *)editor->treeview);
 		// then we should expand on the item to which we've opened for edit.
 		vbox = GTKHTML_EDITOR(editor->window)->vbox;
-		
+
 		gtk_widget_reparent (vbox,box);
-		
+
 		gtk_container_add (GTK_CONTAINER (editor->window), hpaned1);
-		
+
 		editor_load_book(editor);
-			
+
 		break;
 	}
-	editor->is_changed = FALSE;		
+	editor->is_changed = FALSE;
 	editors_all = g_list_append(editors_all,(EDITOR*) editor);
 	return 1;
 
@@ -1338,16 +1442,16 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
  * Return value
  *   gint
  */
- 
+
 gint editor_create_new(const gchar * filename, const gchar * key, gint editor_type)
 {
 	GList *tmp = NULL;
 	EDITOR *e;
-	
+
 	tmp = g_list_first(editors_all);
 	while (tmp != NULL) {
 		e = (EDITOR*)tmp->data;
-		switch(editor_type) {
+		switch (editor_type) {
 		case STUDYPAD_EDITOR:
 			if (e->studypad) {
 				if (editor_is_dirty(e))
@@ -1357,7 +1461,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 				e->filename = g_strdup(filename);
 				gtk_widget_show(e->window);
 				gdk_window_raise(GTK_WIDGET(e->window)->window);
-				
+
 				_load_file(e, g_strdup(filename));
 				return 1;
 			}
@@ -1373,10 +1477,10 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 			e->key = g_strdup(key);
 			gtk_widget_show(e->window);
 			gdk_window_raise(GTK_WIDGET(e->window)->window);
-			
+
 			editor_load_note(e, NULL, NULL);
-			
-			return 1;		
+
+			return 1;
 			break;
 		case BOOK_EDITOR:
 			if (editor_is_dirty(e))
@@ -1389,22 +1493,22 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 			e->key = g_strdup(key);
 			gtk_widget_show(e->window);
 			gdk_window_raise(GTK_WIDGET(e->window)->window);
-			
+
 			editor_load_book(e);
-			
+
 			return 1;
 			break;
 		}
 		tmp = g_list_next(tmp);
 	}
-    	GS_message (("filename %s, key %s",filename, key));
+    	GS_message (("filename %s, key %s", (filename ? filename : "-null-"), (key ? key : "-null-")));
 	return _create_new(filename, key, editor_type);
 }
 
 void editor_maybe_save_all(void)
 {
 	GList *tmp, *tmp2;
-	
+
 	tmp = g_list_first(editors_all);
 	while (tmp != NULL) {
 		/* 2ndary list chaser:
@@ -1416,4 +1520,3 @@ void editor_maybe_save_all(void)
 	}
 }
 
-#endif /* USE_GTKHTML3_14_23 */
