@@ -24,6 +24,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "gui/about_xiphos.h"
 #include "gui/utilities.h"
@@ -43,10 +44,11 @@ static const gchar *authors[] = {
     "Peter von Kaehne",
     "Simon Meers",
     "Martin Zibricky",
+    "Dmitrijs Ledkovs",
     NULL
 };
-  
-static const gchar *documenters[] = { 
+
+static const gchar *documenters[] = {
     "Pierre Benz",
     "Andy Piper",
     "Peter von Kaehne",
@@ -66,24 +68,23 @@ static gchar *translators = "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZ
  * Synopsis
  *   #include "gui/.h"
  *
- *   void on_dialog_response(GtkDialog * dialog, gint response_id, 
+ *   void on_dialog_response(GtkDialog * dialog, gint response_id,
 					gpointer user_data)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 static void
-on_dialog_response(GtkDialog * dialog, gint response_id, 
+on_dialog_response(GtkDialog * dialog, gint response_id,
 		   gpointer user_data)
 {
 	gtk_widget_destroy(GTK_WIDGET(dialog));
 }
 
-
 /******************************************************************************
  * Name
  *   gui_create_about_xiphos
@@ -116,15 +117,12 @@ gui_create_about_xiphos(void)
 #endif
 		);
 
-	about1_logo_pixbuf = pixbuf_finder("about.png", NULL);
+	about1_logo_pixbuf = pixbuf_finder("about.png", 0, NULL);
 
 	about1 = gtk_about_dialog_new();
-  
 	g_signal_connect(about1, "response",
 			 G_CALLBACK(on_dialog_response), NULL);
-  
-	gtk_about_dialog_set_name
-	    (GTK_ABOUT_DIALOG (about1), PACKAGE);
+
 	gtk_about_dialog_set_version
 	    (GTK_ABOUT_DIALOG (about1), versionbuild);
 	gtk_about_dialog_set_copyright
@@ -144,5 +142,7 @@ gui_create_about_xiphos(void)
 	gtk_about_dialog_set_logo
 	    (GTK_ABOUT_DIALOG (about1), about1_logo_pixbuf);
 
+	set_window_icon (GTK_WINDOW(about1));
+
 	return about1;
 }
