@@ -23,7 +23,8 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 #include <libxml/parser.h>
 //#include <gal/shortcut-bar/e-shortcut-bar.h>
 #include <math.h>
@@ -55,6 +56,8 @@
 #include "main/module_dialogs.h"
 #include "main/url.hh"
 
+#include "gui/debug_glib_null.h"
+
 //TreePixbufs *pixbufs;
 GtkTreeStore *model;
 GtkTreeModel *tree_model;
@@ -146,17 +149,17 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 				   bm_pixbufs->pixbuf_opened,
 				   COL_CLOSED_PIXBUF,
 				   bm_pixbufs->pixbuf_closed,
-				   COL_CAPTION, info->text1, 
-				   COL_KEY, NULL, 
-				   COL_MODULE, NULL, 
+				   COL_CAPTION, info->text1,
+				   COL_KEY, NULL,
+				   COL_MODULE, NULL,
 				   -1);
-//              set_results_position((char) 1); // TOP 
+//              set_results_position((char) 1); // TOP
 		str = g_string_new(" ");
 		while (verses) {
 			list_item = (RESULTS *) verses->data;
 			module_name = list_item->module;
 			tmpbuf = list_item->key;
-			g_string_sprintf(str, "%s, %s", tmpbuf,
+			g_string_printf(str, "%s, %s", tmpbuf,
 					 module_name);
 			GS_message(("bookmark: %s",str->str));
 			gtk_tree_store_append(GTK_TREE_STORE(model),
@@ -166,8 +169,8 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 					   bm_pixbufs->pixbuf_helpdoc,
 					   COL_CLOSED_PIXBUF, NULL,
 					   COL_CAPTION, str->str,
-					   COL_KEY, tmpbuf, 
-					   COL_MODULE, module_name, 
+					   COL_KEY, tmpbuf,
+					   COL_MODULE, module_name,
 					   -1);
 			verses = g_list_next(verses);
 		}
@@ -189,7 +192,7 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
  *   void gui_save_old_bookmarks_to_new(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
- *   save bookmark tree 
+ *   save bookmark tree
  *
  * Return value
  *   void
@@ -215,7 +218,7 @@ void gui_save_old_bookmarks_to_new(GNode * gnode)
  *   void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
  *
  * Description
- *    get date from xml bookmark folder and put into 
+ *    get date from xml bookmark folder and put into
  *    BOOKMARK_DATA structure
  *
  * Return value
@@ -245,7 +248,7 @@ static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
  * Synopsis
  *   #include "gui/bookmarks_treeview.h"
  *
- *   void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)	
+ *   void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
  *
  * Description
  *    get date from xml bookmark and put into BOOKMARK_DATA structure
@@ -267,7 +270,7 @@ static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 	data->closed = NULL;
 	mod1 = xmlGetProp(cur, (const xmlChar *)"modulename");
 	key = xmlGetProp(cur, (const xmlChar *)"key");
-	//caption = xmlGetProp(cur, "caption"); 
+	//caption = xmlGetProp(cur, "caption");
 	mod_desc = xmlGetProp(cur, (const xmlChar *)"moduledescription");
 	description = xmlGetProp(cur, (const xmlChar *)"description");
 	caption = xmlGetProp(cur, (const xmlChar *)"description");
@@ -325,8 +328,8 @@ static void free_bookmark_data(BOOKMARK_DATA * data)
  * Synopsis
  *   #include "gui/bookmarks_treeview.h"
  *
- *   GtkCTreeNode *gui_add_node_to_ctree(GtkCTree * ctree, 
- *			GtkCTreeNode *node, BOOKMARK_DATA * data)	
+ *   GtkCTreeNode *gui_add_node_to_ctree(GtkCTree * ctree,
+ *			GtkCTreeNode *node, BOOKMARK_DATA * data)
  *
  * Description
  *    actually add the GtkCTreeNode to the bookmark ctree
@@ -358,7 +361,7 @@ void gui_add_item_to_tree(GtkTreeIter * iter, GtkTreeIter * parent,
  *   #include "gui/bookmarks_treeview.h"
  *
  *   void add_node(xmlDocPtr doc, xmlNodePtr cur, GtkCTree * ctree,
-						GtkCTreeNode *node)	
+						GtkCTreeNode *node)
  *
  * Description
  *    parse the xml bookmarks and add to bookmark ctree
@@ -401,7 +404,7 @@ static void add_node(xmlNodePtr cur, GtkTreeIter * parent)
  * Synopsis
  *   #include "gui/bookmarks_treeview.h"
  *
- *   void gui_parse_bookmarks(GtkCTree * ctree)	
+ *   void gui_parse_bookmarks(GtkCTree * ctree)
  *
  * Description
  *    load a xml bookmark file
@@ -514,10 +517,10 @@ void gui_load_removed(const xmlChar * file)
  * Synopsis
  *   #include "gui/bookmarks_treeview.h"
  *
- *   void load_xml_bookmarks(GtkCTree * ctree)	
+ *   void load_xml_bookmarks(GtkCTree * ctree)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -529,7 +532,7 @@ static void load_xml_bookmarks(GtkTreeView * tree, GtkTreeIter * iter)
 	const xmlChar *file;
 
 	str = g_string_new(settings.swbmDir);
-	g_string_sprintf(str, "%s/bookmarks.xml", settings.swbmDir);
+	g_string_printf(str, "%s/bookmarks.xml", settings.swbmDir);
 	file = (const xmlChar *) str->str;
 	gui_parse_bookmarks(tree, file, iter);
 	g_string_free(str, TRUE);
@@ -547,7 +550,7 @@ static void load_xml_bookmarks(GtkTreeView * tree, GtkTreeIter * iter)
  *                             GtkTreeIter *arg2, gpointer user_data)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -567,11 +570,11 @@ static void row_changed(GtkTreeModel * treemodel, GtkTreePath * arg1,
  * Synopsis
  *   #include "gui/bookmarks_treeview.h"
  *
- *   void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1, 
+ *   void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1,
  *							gpointer user_data)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -595,7 +598,7 @@ static void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1,
  *   void create_pixbufs(void)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -603,24 +606,37 @@ static void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1,
 
 static void create_pixbufs(void)
 {
-	//GtkWidget *image;
+	GtkTextDirection dir = gtk_widget_get_direction (GTK_WIDGET(widgets.app));
 
 	bm_pixbufs = g_new0(BookMarksPixbufs, 1);
+
+	if (dir == GTK_TEXT_DIR_LTR) {
+		/* leave this for if we make custom reversable icons
+		  if (!bm_pixbufs->pixbuf_closed)
+			bm_pixbufs->pixbuf_closed =
+				pixbuf_finder("book_closed.png", 16, NULL);
+		*/
+
+		bm_pixbufs->pixbuf_opened =
+			pixbuf_finder("book_open.png", 16, NULL);
+	}
+	else {
+		/* leave this for if we make custom reversable icons
+		  if (!bm_pixbufs->pixbuf_closed)
+			bm_pixbufs->pixbuf_closed =
+				pixbuf_finder("book_closed_rtol.png", 16, NULL);
+		*/
+
+		bm_pixbufs->pixbuf_opened =
+			pixbuf_finder("book_open_rtol.png", 16, NULL);
+	}
+
 	bm_pixbufs->pixbuf_closed =
-	    pixbuf_finder("epiphany-bookmarks.png", NULL);
+		pixbuf_finder("epiphany-bookmarks.png", 0, NULL);
 
-	if (!bm_pixbufs->pixbuf_closed)
-		bm_pixbufs->pixbuf_closed
-		    = gtk_widget_render_icon(widgets.app,
-					     GNOME_STOCK_BOOK_BLUE,
-					     GTK_ICON_SIZE_MENU, NULL);
 
-	bm_pixbufs->pixbuf_opened =
-	    gtk_widget_render_icon(widgets.app,
-				   GNOME_STOCK_BOOK_OPEN,
-				   GTK_ICON_SIZE_MENU, NULL);
 	bm_pixbufs->pixbuf_helpdoc =
-	    pixbuf_finder("epiphany-bookmark-page.png", NULL);
+		pixbuf_finder("epiphany-bookmark-page.png", 0, NULL);
 
 	if (!bm_pixbufs->pixbuf_helpdoc)
 		bm_pixbufs->pixbuf_helpdoc
@@ -639,7 +655,7 @@ static void create_pixbufs(void)
  *   void add_columns(GtkTreeView * tree)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -715,9 +731,9 @@ void gui_add_columns(GtkTreeView * tree)
  *
  *   GtkTreeModel *create_model(void)
  *
- * 
+ *
  * Description
- *    
+ *
  *
  * Return value
  *   GtkTreeModel *
@@ -749,7 +765,7 @@ static GtkTreeModel *create_model(void)
  *
  * Description
  *   catch button 3 and select the row the pointer is over
- *   but does not display the bookmark 
+ *   but does not display the bookmark
  *
  * Return value
  *   void
@@ -787,25 +803,24 @@ static gboolean button_release_event(GtkWidget * widget,
 			gtk_widget_set_sensitive(menu.in_dialog, !multi);
 			gtk_widget_set_sensitive(menu.new, FALSE);
 			gtk_widget_set_sensitive(menu.insert, FALSE);
-			gtk_widget_set_sensitive(menu.rr_submenu,
-						 FALSE);
+			gtk_widget_set_sensitive(menu.remove, FALSE);
 		} else {
-			/* click on treeview folder to expand or collapse it */			
+			/* click on treeview folder to expand or collapse it */
 			path = gtk_tree_model_get_path(
 					GTK_TREE_MODEL (model), &selected);
 			if (gtk_tree_view_row_expanded (bookmark_tree, path))
-			       gtk_tree_view_collapse_row (bookmark_tree, 
+			       gtk_tree_view_collapse_row (bookmark_tree,
 							   path);
 			else
-			       gtk_tree_view_expand_row (bookmark_tree, 
+			       gtk_tree_view_expand_row (bookmark_tree,
 							 path, FALSE);
 			gtk_tree_path_free ( path );
-			
+
 			gtk_widget_set_sensitive(menu.in_tab, FALSE);
 			gtk_widget_set_sensitive(menu.in_dialog, FALSE);
 			gtk_widget_set_sensitive(menu.new, TRUE);
 			gtk_widget_set_sensitive(menu.insert, TRUE);
-			gtk_widget_set_sensitive(menu.rr_submenu, TRUE);
+			gtk_widget_set_sensitive(menu.remove, TRUE);
 		}
 
 		gtk_widget_set_sensitive(menu.bibletime,
@@ -828,10 +843,10 @@ static gboolean button_release_event(GtkWidget * widget,
 		gtk_menu_popup(GTK_MENU(menu.menu),
 			       NULL, NULL, NULL, NULL,
 			       event->button, event->time);
-		
-		if(!settings.browsing)  
+
+		if (!settings.browsing)
 			gtk_widget_hide(menu.in_tab);
-		
+
 		if (GTK_CHECK_MENU_ITEM(menu.reorder)->active) {
 			gtk_widget_set_sensitive(menu.in_tab, FALSE);
 			gtk_widget_set_sensitive(menu.in_dialog, FALSE);
@@ -840,10 +855,9 @@ static gboolean button_release_event(GtkWidget * widget,
 			gtk_widget_set_sensitive(menu.edit, FALSE);
 			gtk_widget_set_sensitive(menu.delete, FALSE);
 			gtk_widget_set_sensitive(menu.bibletime, FALSE);
-			gtk_widget_set_sensitive(menu.rr_submenu,
-						 FALSE);
 			gtk_widget_set_sensitive(menu.remove, FALSE);
-			gtk_widget_set_sensitive(menu.restore, FALSE);
+			//gtk_widget_set_sensitive(menu.remove, FALSE);
+			//gtk_widget_set_sensitive(menu.restore, FALSE);
 			return TRUE;
 		} else {
 			gtk_widget_set_sensitive(menu.bibletime,
@@ -856,15 +870,15 @@ static gboolean button_release_event(GtkWidget * widget,
 	}
 	if (is_selected) {
 		if (!gtk_tree_model_iter_has_child
-		    (GTK_TREE_MODEL(model), &selected) && key != NULL) {			
-			if(!strcmp(module,"studypad"))
+		    (GTK_TREE_MODEL(model), &selected) && key != NULL) {
+			if (!strcmp(module,"studypad"))
 				url =
 				    g_strdup_printf
 				    ("xiphos.url?action=showStudypad&"
 				     "type=9&value=%s&module=%s",
 				     main_url_encode(key),
 				     main_url_encode(module));
-				
+
 			else
 				url =
 				    g_strdup_printf
@@ -909,7 +923,7 @@ g_message("on_treeview_modules_drag_drop");
  *   GtkWidget *gui_create_bookmark_tree(void)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   GtkWidget*
@@ -936,7 +950,7 @@ GtkWidget *gui_create_bookmark_tree(void)
 
 	load_xml_bookmarks(GTK_TREE_VIEW(tree), &iter);
 	/*g_signal_connect(G_OBJECT(tree),
-	   "row-collapsed", 
+	   "row-collapsed",
 	   G_CALLBACK(expand_release_cursor_row),
 	   NULL); */
 	/*
