@@ -25,7 +25,11 @@
 
 #include <gtk/gtk.h>
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif
 #else
 #include <gtkhtml/gtkhtml.h>
 #include "gui/html.h"
@@ -48,43 +52,21 @@
 #include "main/navbar_versekey.h"
 #include "main/display.hh"
 
-//static void create_menu(DIALOG_DATA * d, GdkEventButton * event);
+#include "gui/debug_glib_null.h"
+
+#ifndef USE_GTKMOZEMBED
+void commentary_prefixable_link(GtkHTML *html, const gchar *url, gpointer data);
+#endif
 
 extern gboolean dialog_freed;
 extern gboolean do_display;
+
 /****************************************************************************************
  * static - global to this file only
  */
-
 DIALOG_DATA *cur_d;
-//static gboolean apply_change;
 
 
-/******************************************************************************
- * Name
- *   gui_display_commentary_with_struct
- *
- * Synopsis
- *   #include "commentary.h"
- *
- *   void gui_display_commentary_with_struct(gchar * key)	
- *
- * Description
- *    display new key in current commentary
- *
- * Return value
- *   void
- */
-
-void gui_display_commentary_with_struct(DIALOG_DATA *d,
-					gchar *key)
-{
-	strcpy(settings.comm_key, key);
-	if (d->key)
-		g_free(d->key);
-	d->key = g_strdup(key);
-}
-
 /******************************************************************************
  * Name
  *   on_dialog_destroy
@@ -92,8 +74,8 @@ void gui_display_commentary_with_struct(DIALOG_DATA *d,
  * Synopsis
  *   #include "commentary_dialog.h"
  *
- *   void on_dialog_destroy(GtkObject * object, 
- *						DIALOG_DATA * d)	
+ *   void on_dialog_destroy(GtkObject * object,
+ *						DIALOG_DATA * d)
  *
  * Description
  *   shut down the View Commentay Dialog
@@ -119,10 +101,10 @@ static void on_dialog_destroy(GtkObject *object,
  * Synopsis
  *   #include "commentary_dialog.h"
  *
- *   void gui_close_comm_dialog(DIALOG_DATA * d)	
+ *   void gui_close_comm_dialog(DIALOG_DATA * d)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -145,10 +127,10 @@ void gui_close_comm_dialog(DIALOG_DATA * d)
  *   #include "commentary_dialog.h"
  *
  *   gboolean on_dialog_motion_notify_event(GtkWidget *widget,
-                      GdkEventMotion  *event, DIALOG_DATA * d)	
+                      GdkEventMotion  *event, DIALOG_DATA * d)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   gboolean
@@ -172,10 +154,10 @@ static gboolean on_dialog_motion_notify_event(GtkWidget *widget,
  * Synopsis
  *   #include "commentary_dialog.h"
  *
- *   void dialog_url(GtkHTML * html, const gchar * url, DIALOG_DATA * d)	
+ *   void dialog_url(GtkHTML * html, const gchar * url, DIALOG_DATA * d)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -196,7 +178,7 @@ static void dialog_url(GtkHTML *html,
  *   #include "gui/commentary_dialog.h"
  *
  *   gint html_button_pressed(GtkWidget * html, GdkEventButton * event,
- *					DIALOG_DATA * d)	
+ *					DIALOG_DATA * d)
  *
  * Description
  *    mouse button pressed in window - used to set cur_d to the current
@@ -232,7 +214,7 @@ static gint button_press_event(GtkWidget *html,
  * Synopsis
  *   #include ".h"
  *
- *   void commentary_prefixable_link(void)	
+ *   void commentary_prefixable_link(void)
  *
  * Description
  *    front-end-ish handler for xref clicks, to supply book name to prefix.
@@ -252,7 +234,7 @@ void commentary_prefixable_link(GtkHTML *html,
 	*(strrchr(buf, ' ')) = '\0';
 	gui_prefixable_link_clicked(html, url, data, buf);
 }
-#endif
+#endif /* !USE_GTKMOZEMBED */
 
 
 /******************************************************************************
@@ -262,7 +244,7 @@ void commentary_prefixable_link(GtkHTML *html,
  * Synopsis
  *   #include "gui/commentary_dialog.h"
  *
- *   void sync_with_main(DIALOG_DATA * d)	
+ *   void sync_with_main(DIALOG_DATA * d)
  *
  * Descriptiond->navbar.lookup_entry
  *   bring the the View Commentay Dialog module into sync with main window
@@ -288,10 +270,10 @@ static void sync_with_main(DIALOG_DATA *d)
  * Synopsis
  *   #include ".h"
  *
- *   GtkWidget *create_nav_toolbar(void)	
+ *   GtkWidget *create_nav_toolbar(void)
  *
  * Description
- *    create navigation toolbar and 
+ *    create navigation toolbar and
  *
  * Return value
  *   void
@@ -308,11 +290,11 @@ static void
 _popupmenu_requested_cb (GeckoHtml *html,
 			 gchar *uri,
 			 DIALOG_DATA *d)
-{	
+{
     	gui_menu_popup (NULL, d);
-	//gui_commentary_dialog_create_menu(d); 
+	//gui_commentary_dialog_create_menu(d);
 }
-#endif
+#endif /* USE_GTKMOZEMBED */
 
 /******************************************************************************
  * Name
@@ -321,7 +303,7 @@ _popupmenu_requested_cb (GeckoHtml *html,
  * Synopsis
  *   #include "commentary_dialog.h"
  *
- *   void gui_create_commentary_dialog(void)	
+ *   void gui_create_commentary_dialog(void)
  *
  * Description
  *   create a Commentary Dialog
@@ -337,15 +319,17 @@ void gui_create_commentary_dialog(DIALOG_DATA *d,
 	GtkWidget *vbox_toolbars;
 	GtkWidget *toolbar_nav;
 	GtkWidget *frame19;
-#ifndef USE_GTKMOZEMBED
+#ifdef USE_GTKMOZEMBED
+	GtkWidget *eventbox;
+#else
 	GtkWidget *scrolledwindow38;
 #endif
-	
+
 	cur_d = d;
 	d->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
-	gtk_object_set_data(GTK_OBJECT(d->dialog), "d->dialog",
-			    d->dialog);
+	g_object_set_data(G_OBJECT(d->dialog), "d->dialog",
+			  d->dialog);
 	gtk_window_set_title(GTK_WINDOW(d->dialog),
 			     main_get_module_description(d->mod_name));
 	//gtk_window_set_default_size(GTK_WINDOW(d->dialog), 462, 280);
@@ -375,10 +359,15 @@ void gui_create_commentary_dialog(DIALOG_DATA *d,
 	gtk_box_pack_start(GTK_BOX(vbox30), frame19, TRUE, TRUE, 0);
 	gtk_frame_set_shadow_type(GTK_FRAME(frame19), GTK_SHADOW_IN);
 
-#ifdef USE_GTKMOZEMBED	
+#ifdef USE_GTKMOZEMBED
+
+	eventbox = gtk_event_box_new();
+	gtk_widget_show(eventbox);
+	gtk_container_add(GTK_CONTAINER(frame19), eventbox);
+
 	d->html = GTK_WIDGET(gecko_html_new(((DIALOG_DATA*) d),TRUE,DIALOG_COMMENTARY_TYPE));
-	gtk_container_add(GTK_CONTAINER(frame19), d->html);
-	gtk_widget_show(d->html);	
+	gtk_container_add(GTK_CONTAINER(eventbox), d->html);
+	gtk_widget_show(d->html);
 	g_signal_connect((gpointer)d->html,
 		      "popupmenu_requested",
 		      G_CALLBACK (_popupmenu_requested_cb),
@@ -400,12 +389,12 @@ void gui_create_commentary_dialog(DIALOG_DATA *d,
 			  d->html);
 	gtk_html_load_empty(GTK_HTML(d->html));
 
-#ifndef USE_GTKMOZEMBED	
+#ifndef USE_GTKMOZEMBED
 	g_signal_connect(GTK_OBJECT(d->html),
 			 "link_clicked",
 			 G_CALLBACK(commentary_prefixable_link), d);
-#endif	
-	
+#endif
+
 	g_signal_connect(GTK_OBJECT(d->html), "on_url",
 			 G_CALLBACK(dialog_url), d);
 	g_signal_connect(GTK_OBJECT(d->html),
