@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * dialog.c - 
+ * dialog.c -
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -32,6 +32,8 @@
 #include "main/settings.h"
 #include "main/sword.h"
 
+#include "gui/debug_glib_null.h"
+
 //static GtkWidget *gs_dialog;
 static GtkWidget *entry1 = NULL;
 static GtkWidget *entry2 = NULL;
@@ -41,7 +43,8 @@ static GtkWidget *entry5 = NULL;
 static GtkWidget *entry6 = NULL;
 static gint retval = 3;
 
-
+GS_DIALOG * standard_info;
+GtkWidget * dialog_request;
 
 /******************************************************************************
  * Name
@@ -109,18 +112,16 @@ static void get_entry_text(GS_DIALOG * info)
  * Synopsis
  *   #include "gui/dialog.h"
  *
- *   void on_dialog_response(GtkDialog * dialog, gint response_id,
- *							GS_DIALOG * info)
+ *   void on_dialog_response(GtkDialog * dialog, gint response_id, GS_DIALOG * info)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
-static void on_dialog_response(GtkDialog * dialog, gint response_id,
-			       GS_DIALOG * info)
+static void on_dialog_response(GtkDialog * dialog, gint response_id, GS_DIALOG * info)
 {
 	GS_warning(("%d", response_id));
 	switch (response_id) {
@@ -142,6 +143,29 @@ static void on_dialog_response(GtkDialog * dialog, gint response_id,
 	}
 }
 
+/******************************************************************************
+ * Name
+ *   on_dialog_enter
+ *
+ * Synopsis
+ *   #include "gui/dialog.h"
+ *
+ *   void on_dialog_enter(void)
+ *
+ * Description
+ *   canned Enter key route to on_dialog_response
+ *
+ * Return value
+ *   void
+ */
+
+static void on_dialog_enter(void)
+{
+	on_dialog_response(GTK_DIALOG(dialog_request), GTK_RESPONSE_OK, standard_info);
+	gtk_widget_destroy(GTK_WIDGET(dialog_request));
+}
+
+
 static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 {
 	GtkWidget *dialog_alert;
@@ -181,39 +205,39 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 		gtk_misc_set_alignment(GTK_MISC(image5), 0.5, 0);
 		gtk_misc_set_padding(GTK_MISC(image5), 12, 0);
 	}
-	
-	
+
+
 	vbox2 = gtk_vbox_new(FALSE, 6);
 	gtk_widget_show(vbox2);
 	gtk_box_pack_start(GTK_BOX(hbox3), vbox2, TRUE, TRUE, 0);
 
 	label7 = gtk_label_new(info->label_top);
-	gtk_widget_show(label7);	
+	gtk_widget_show(label7);
 	gtk_box_pack_start(GTK_BOX(vbox2), label7, FALSE, FALSE, 0);
 	gtk_label_set_use_markup(GTK_LABEL(label7), TRUE);
 	gtk_label_set_justify(GTK_LABEL(label7), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap(GTK_LABEL(label7), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label7), 0, 0.5);
 
-	if (info->label2) {	
+	if (info->label2) {
 		gtk_window_set_default_size (GTK_WINDOW (dialog_alert), 380, 200);
 		scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 		gtk_widget_show (scrolledwindow);
 		gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow, TRUE, TRUE, 0);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), 
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-		
+
 		viewport = gtk_viewport_new (NULL, NULL);
 		gtk_widget_show (viewport);
 		gtk_container_add (GTK_CONTAINER (scrolledwindow), viewport);
-		
+
 		label10 = gtk_label_new(info->label2);
 		gtk_widget_show(label10);
 		gtk_container_add (GTK_CONTAINER (viewport), label10);
 		gtk_label_set_justify(GTK_LABEL(label10), GTK_JUSTIFY_LEFT);
 		gtk_misc_set_alignment(GTK_MISC(label10), 0, 0.5);
 	}
-	
+
 	dialog_action_area2 = GTK_DIALOG(dialog_alert)->action_area;
 	gtk_widget_show(dialog_action_area2);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area2),
@@ -266,7 +290,6 @@ static GtkWidget *create_dialog_alert(GS_DIALOG * info)
 
 static GtkWidget *create_dialog_request(GS_DIALOG * info)
 {
-	GtkWidget *dialog_request;
 	GtkWidget *dialog_vbox3;
 	GtkWidget *hbox4;
 	GtkWidget *image6;
@@ -283,10 +306,9 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 	dialog_request = gtk_dialog_new();
 	info->dialog = dialog_request;
-	gtk_container_set_border_width(GTK_CONTAINER(dialog_request),
-				       6);
-	gtk_window_set_title(GTK_WINDOW(dialog_request), 
-			     info->title ? info->title : " ");
+	gtk_container_set_border_width(GTK_CONTAINER(dialog_request), 6);
+	gtk_window_set_title(GTK_WINDOW(dialog_request),
+			     (info->title ? info->title : " "));
 	gtk_window_set_modal(GTK_WINDOW(dialog_request), TRUE);
 	gtk_window_set_resizable(GTK_WINDOW(dialog_request), FALSE);
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog_request), FALSE);
@@ -346,6 +368,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		if (info->text1)
 			gtk_entry_set_text(GTK_ENTRY(entry1),
 					   info->text1);
+		g_signal_connect((gpointer) entry1, "activate",
+				 G_CALLBACK(on_dialog_enter), info);
 	}
 
 	if (info->label2) {
@@ -367,7 +391,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		if (info->text2)
 			gtk_entry_set_text(GTK_ENTRY(entry2),
 					   info->text2);
-
+		g_signal_connect((gpointer) entry2, "activate",
+				 G_CALLBACK(on_dialog_enter), info);
 	}
 
 	if (info->label3) {
@@ -389,7 +414,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		if (info->text3)
 			gtk_entry_set_text(GTK_ENTRY(entry3),
 					   info->text3);
-
+		g_signal_connect((gpointer) entry3, "activate",
+				 G_CALLBACK(on_dialog_enter), info);
 	}
 
 	if (info->label4) {
@@ -411,7 +437,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		if (info->text4)
 			gtk_entry_set_text(GTK_ENTRY(entry4),
 					   info->text4);
-
+		g_signal_connect((gpointer) entry4, "activate",
+				 G_CALLBACK(on_dialog_enter), info);
 	}
 
 	if (info->label5) {
@@ -433,7 +460,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		if (info->text5)
 			gtk_entry_set_text(GTK_ENTRY(entry5),
 					   info->text5);
-
+		g_signal_connect((gpointer) entry5, "activate",
+				 G_CALLBACK(on_dialog_enter), info);
 	}
 
 	if (info->label6) {
@@ -455,7 +483,8 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 		if (info->text6)
 			gtk_entry_set_text(GTK_ENTRY(entry6),
 					   info->text6);
-
+		g_signal_connect((gpointer) entry6, "activate",
+				 G_CALLBACK(on_dialog_enter), info);
 	}
 
 	dialog_action_area3 = GTK_DIALOG(dialog_request)->action_area;
@@ -495,7 +524,7 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
  *   GS_DIALOG *gui_new_dialog(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GS_DIALOG *
@@ -503,32 +532,30 @@ static GtkWidget *create_dialog_request(GS_DIALOG * info)
 
 GS_DIALOG *gui_new_dialog(void)
 {
-	GS_DIALOG *info;
+	standard_info = g_new0(GS_DIALOG, 1);
 
-	info = g_new0(GS_DIALOG, 1);
-
-	info->stock_icon = NULL;
-	info->dialog = NULL;
-	info->title = NULL;
-	info->text1 = NULL;
-	info->text2 = NULL;
-	info->text3 = NULL;
-	info->text4 = NULL;
-	info->text5 = NULL;
-	info->text6 = NULL;
-	info->label_top = NULL;
-	info->label_middle = NULL;
-	info->label1 = NULL;
-	info->label2 = NULL;
-	info->label3 = NULL;
-	info->label4 = NULL;
-	info->label5 = NULL;
-	info->label6 = NULL;
-	info->label_bottom = NULL;
-	info->ok = FALSE;
-	info->cancel = FALSE;
-	info->yes = FALSE;
-	info->no = FALSE;
+	standard_info->stock_icon = NULL;
+	standard_info->dialog = NULL;
+	standard_info->title = NULL;
+	standard_info->text1 = NULL;
+	standard_info->text2 = NULL;
+	standard_info->text3 = NULL;
+	standard_info->text4 = NULL;
+	standard_info->text5 = NULL;
+	standard_info->text6 = NULL;
+	standard_info->label_top = NULL;
+	standard_info->label_middle = NULL;
+	standard_info->label1 = NULL;
+	standard_info->label2 = NULL;
+	standard_info->label3 = NULL;
+	standard_info->label4 = NULL;
+	standard_info->label5 = NULL;
+	standard_info->label6 = NULL;
+	standard_info->label_bottom = NULL;
+	standard_info->ok = FALSE;
+	standard_info->cancel = FALSE;
+	standard_info->yes = FALSE;
+	standard_info->no = FALSE;
 	/* set entrys to null */
 	entry1 = NULL;
 	entry2 = NULL;
@@ -537,7 +564,7 @@ GS_DIALOG *gui_new_dialog(void)
 	entry5 = NULL;
 	entry6 = NULL;
 
-	return info;
+	return standard_info;
 }
 
 
@@ -564,7 +591,7 @@ void gui_generic_warning(char *message)
 
 	dialog = gui_new_dialog();
 	dialog->stock_icon = GTK_STOCK_DIALOG_INFO;
-	
+
 	dialog_text = g_strdup_printf("<span weight=\"bold\">%s</span>",
 				      _("Xiphos:"));
 	dialog->label_top = dialog_text;
@@ -587,7 +614,7 @@ void gui_generic_warning(char *message)
  *   gint gui_gs_dialog(GS_DIALOG * info)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   gint
@@ -620,7 +647,7 @@ gint gui_gs_dialog(GS_DIALOG * info)
  *   gint gui_alert_dialog(GS_DIALOG * info)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   gint
@@ -653,7 +680,7 @@ gint gui_alert_dialog(GS_DIALOG * info)
  *   gint gui_close_confirmation_dialog(GS_DIALOG * info)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   gint
@@ -665,11 +692,11 @@ gint gui_close_confirmation_dialog(GS_DIALOG * info)
 	static gboolean is_running = FALSE;
 
 	if (!is_running) {
-		dialog = create_dialog_alert(info);	//gs_dialog_build(info);
+		dialog = create_dialog_alert(info);
 		gtk_dialog_add_button (GTK_DIALOG (dialog),
 				       _("Close _without Saving"),
 				       GTK_RESPONSE_NO);
-	
+
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					GTK_STOCK_SAVE, GTK_RESPONSE_YES, NULL);
