@@ -24,13 +24,11 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <unistd.h>
+
 #include <glade/glade-xml.h>
 
-#ifdef USE_GTKHTML3_14_23
 #include "editor/slib-editor.h"
-#else
-#include "editor/bonobo-editor.h"
-#endif
 
 #include "gui/about_xiphos.h"
 #include "gui/about_sword.h"
@@ -41,6 +39,7 @@
 #include "gui/main_menu.h"
 #include "gui/mod_mgr.h"
 #include "gui/preferences_dialog.h"
+#include "gui/parallel_tab.h"
 #include "gui/sidebar.h"
 #include "gui/sidebar_dialog.h"
 #include "gui/search_dialog.h"
@@ -57,6 +56,16 @@
 
 #include <glib/gstdio.h>
 
+#include "gui/debug_glib_null.h"
+
+//global function to handle gtk_uri calls
+void
+link_uri_hook(GtkLinkButton *button,
+	      const gchar *link,
+	      gpointer user_data)
+{
+	xiphos_open_default(link);
+}
 
 /******************************************************************************
  * Name
@@ -65,8 +74,8 @@
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_help_contents_activate(GtkMenuItem * menuitem, 
- *						gpointer user_data)	
+ *   void on_help_contents_activate(GtkMenuItem * menuitem,
+ *						gpointer user_data)
  *
  * Description
  *   display the help contents file
@@ -76,31 +85,27 @@
  */
 G_MODULE_EXPORT void
 on_help_contents_activate(GtkMenuItem * menuitem, gpointer user_data)
-{	
+{
 	GError *error = NULL;
 #ifdef WIN32
-	gchar *showstr;
-	const char *lang = getenv("LANG");
+	const char *lang = g_getenv("LANG");
 	gchar *help_file = g_win32_get_package_installation_directory_of_module(NULL);
 	help_file = g_strconcat(help_file, "\0", NULL);
-	if (strncmp(lang,"fr",2)==0)
-		help_file = g_build_filename(help_file, "share", "help", "fr", "xiphos_fr.chm", NULL);
+	if (!strncmp(lang, "fr", 2))
+		help_file = g_build_filename(help_file, "share", "help", "xiphos_fr.chm", NULL);
+	else if (!strncmp(lang, "fa", 2))
+		help_file = g_build_filename(help_file, "share", "help", "xiphos_fa.chm", NULL);
 	else
-		help_file = g_build_filename(help_file, "share", "help", "C", "xiphos.chm", NULL);
-	showstr = g_strconcat("file:///", help_file, NULL);
-	if (gnome_url_show(showstr, &error) == FALSE) {
-		GS_warning((error->message));
-		g_error_free(error);
-	}
-	g_free(showstr);
+		help_file = g_build_filename(help_file, "share", "help", "xiphos.chm", NULL);
+	xiphos_open_default(help_file);
 	g_free(help_file);
 #else
-	
-	if (gnome_help_display((const gchar*)"xiphos.xml", 
-			       NULL, &error) == FALSE) {
-		GS_warning(("%s",error->message));
-		g_error_free(error);        
+	gtk_show_uri (NULL, "ghelp:xiphos", gtk_get_current_event_time(), &error);
+	if (error != NULL) {
+		GS_warning(("%s", error->message));
+		g_error_free(error);
 	}
+
 #endif /* WIN32 */
 }
 
@@ -111,8 +116,8 @@ on_help_contents_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_mailing_list_activate(GtkMenuItem * menuitem, 
- *						gpointer user_data)	
+ *   void on_mailing_list_activate(GtkMenuItem * menuitem,
+ *						gpointer user_data)
  *
  * Description
  *   open web browser to the mailing list signup page
@@ -123,19 +128,7 @@ on_help_contents_activate(GtkMenuItem * menuitem, gpointer user_data)
 G_MODULE_EXPORT void
 on_mailing_list_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	GError *error = NULL;
-	/*if (gtk_show_uri (NULL,
-			"https://lists.sourceforge.net/lists/listinfo/gnomesword-users/",
-			GDK_CURRENT_TIME,
-			&error) == FALSE) {
-		GS_warning((error->message));
-		g_error_free (error);
-	}*/	
-	if (gnome_url_show("https://lists.sourceforge.net/lists/listinfo/gnomesword-users/",
-				&error) == FALSE) {
-		GS_warning(("%s",error->message));
-		g_error_free (error);
-	}
+	xiphos_open_default("https://lists.sourceforge.net/lists/listinfo/gnomesword-users/");
 }
 
 
@@ -146,11 +139,11 @@ on_mailing_list_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_live_chat_activate(GtkMenuItem * menuitem, 
- *						gpointer user_data)	
+ *   void on_live_chat_activate(GtkMenuItem * menuitem,
+ *						gpointer user_data)
  *
  * Description
- *   open web browser to mibbit irc chat
+ *   open web browser to freenode irc chat
  *
  * Return value
  *   void
@@ -158,19 +151,15 @@ on_mailing_list_activate(GtkMenuItem * menuitem, gpointer user_data)
 G_MODULE_EXPORT void
 on_live_chat_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	GError *error = NULL;
-	/*if (gtk_show_uri (NULL,
-			"http://webchat.freenode.net/?randomnick=1&channels=xiphos&prompt=1",
-			GDK_CURRENT_TIME,
-			&error) == FALSE) {
-		GS_warning((error->message));
-		g_error_free (error);
-	}*/
-	if (gnome_url_show("http://webchat.freenode.net/?randomnick=1&channels=xiphos&prompt=1",
-				&error) == FALSE) {
-		GS_warning(("%s",error->message));
-		g_error_free (error);
-	}
+	gchar *user = g_strdup_printf("%s", g_get_user_name()), *s, *url;
+	for (s = strchr(user, ' '); s; s = strchr(s, ' '))
+		*s = '_';
+	url = g_strdup_printf(
+	    "http://webchat.freenode.net/?nick=%s|xiphos&channels=xiphos&prompt=1",
+	    user);
+	xiphos_open_default(url);
+	g_free(url);
+	g_free(user);
 }
 
 /******************************************************************************
@@ -180,8 +169,8 @@ on_live_chat_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_report_bug_activate(GtkMenuItem * menuitem, 
- *						gpointer user_data)	
+ *   void on_report_bug_activate(GtkMenuItem * menuitem,
+ *						gpointer user_data)
  *
  * Description
  *   open web browser to sourceforge bug tracker
@@ -192,19 +181,7 @@ on_live_chat_activate(GtkMenuItem * menuitem, gpointer user_data)
 G_MODULE_EXPORT void
 on_report_bug_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	GError *error = NULL;
-	/*if (gtk_show_uri (NULL,
-			,
-			GDK_CURRENT_TIME,
-			&error) == FALSE) {
-		GS_warning((error->message));
-		g_error_free (error);
-	}*/
-	if (gnome_url_show(PACKAGE_BUGREPORT,
-				&error) == FALSE) {
-		GS_warning(("%s",error->message));
-		g_error_free (error);
-	}
+	xiphos_open_default(PACKAGE_BUGREPORT);
 }
 
 
@@ -216,7 +193,7 @@ on_report_bug_activate(GtkMenuItem * menuitem, gpointer user_data)
  *   #include "gui/main_menu.h"
  *
  *   void on_about_the_sword_project1_activate(GtkMenuItem * menuitem,
- *						gpointer user_data)	
+ *						gpointer user_data)
  *
  * Description
  *   display - The SWORD Project - about information
@@ -241,7 +218,7 @@ on_about_the_sword_project_activate(GtkMenuItem * menuitem, gpointer user_data)
  *   #include "gui/main_menu.h"
  *
  *   void on_about_translation_activate(GtkMenuItem * menuitem,
- *					gpointer user_data)	
+ *					gpointer user_data)
  *
  * Description
  *   display - The SWORD Project - about information
@@ -265,8 +242,8 @@ on_about_translation_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_daily_devotion_activate(GtkMenuItem *menuitem, 
- *						gpointer user_data)	
+ *   void on_daily_devotion_activate(GtkMenuItem *menuitem,
+ *						gpointer user_data)
  *
  * Description
  *   display daily devotion in shortcut bar viewer
@@ -287,7 +264,7 @@ on_daily_devotion_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_preferences_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_preferences_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   open preferences dialog
@@ -308,7 +285,7 @@ on_preferences_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_search_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_search_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *   display search group in shortcut bar
@@ -318,7 +295,7 @@ on_preferences_activate(GtkMenuItem * menuitem, gpointer user_data)
  */
 G_MODULE_EXPORT void on_search_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	if (!settings.showshortcutbar) 
+	if (!settings.showshortcutbar)
 		gui_sidebar_showhide();
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_sidebar),2);
 }
@@ -330,7 +307,7 @@ G_MODULE_EXPORT void on_search_activate(GtkMenuItem * menuitem, gpointer user_da
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_verse_style_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_verse_style_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle between verse and paragraph style
@@ -338,12 +315,14 @@ G_MODULE_EXPORT void on_search_activate(GtkMenuItem * menuitem, gpointer user_da
  * Return value
  *   void
  */
+
+extern gboolean style_display;
+
 G_MODULE_EXPORT void
 on_verse_style_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 {
-	extern gboolean style_display;
-	if(style_display) {
-		gchar *file = g_strdup_printf("%s/modops.conf", 
+	if (style_display) {
+		gchar *file = g_strdup_printf("%s/modops.conf",
 					      settings.gSwordDir);
 		gchar *url = g_strdup_printf("sword://%s/%s",
 					     settings.MainWindowModule,
@@ -355,7 +334,7 @@ on_verse_style_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 				     ? "verse"
 				     : "paragraph"));
 		if (settings.havebible) {
-			main_url_handler(url, TRUE);		
+			main_url_handler(url, TRUE);
 		}
 		g_free(url);
 		g_free(file);
@@ -369,7 +348,7 @@ on_verse_style_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_linked_tabs_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_linked_tabs_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle linking tabs together.
@@ -383,6 +362,8 @@ on_linked_tabs_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 	settings.linkedtabs = menuitem->active;
 	xml_set_value("Xiphos", "misc", "pinnedtabs",
 		      (settings.linkedtabs ? "1" : "0"));
+	if (settings.showparatab)
+		gui_force_parallel_tab_sync();
 }
 
 /******************************************************************************
@@ -392,7 +373,7 @@ on_linked_tabs_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_read_aloud_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_read_aloud_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle reading scripture out loud.
@@ -417,7 +398,7 @@ on_read_aloud_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_show_verse_numbers_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_show_verse_numbers_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle showing verse numbers together.
@@ -441,7 +422,7 @@ on_show_verse_numbers_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_versehighlight_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_versehighlight_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle special current verse highlight.
@@ -465,7 +446,7 @@ on_versehighlight_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void gui_parallel_tab_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void gui_parallel_tab_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle special current verse highlight.
@@ -476,18 +457,19 @@ on_versehighlight_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 G_MODULE_EXPORT void
 gui_parallel_tab_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 {
-	if(!settings.browsing) return;
-	if(!settings.showparatab && !menuitem->active) {
+	if (!settings.browsing) return;
+	if (!settings.showparatab && !menuitem->active) {
 		xml_set_value("Xiphos", "misc", "showparatab", "0");
 		return;
 	}
-		
+
 	settings.showparatab = menuitem->active;
 	xml_set_value("Xiphos", "misc", "showparatab",
 		      (settings.showparatab ? "1" : "0"));
-	if(settings.showparatab)
+	if (settings.showparatab) {
 		gui_open_parallel_view_in_new_tab();
-	else 		
+		gui_force_parallel_tab_sync();
+	} else
 		gui_close_passage_tab  (gtk_notebook_page_num (
 					GTK_NOTEBOOK (widgets.notebook_main),
 					widgets.parallel_tab));
@@ -500,7 +482,7 @@ gui_parallel_tab_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_side_preview_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_side_preview_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle special previewer in sidebar.
@@ -524,7 +506,7 @@ on_side_preview_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_double_space_text_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *   void on_double_space_text_activate(GtkMenuItem *menuitem, gpointer user_data)
  *
  * Description
  *   toggle double-spacing of text.
@@ -549,7 +531,7 @@ on_double_space_text_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_quit_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_quit_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *   do a nice orderly shut down and exit xiphos
@@ -566,8 +548,8 @@ on_quit_activate(GtkMenuItem * menuitem, gpointer user_data)
 	/* shutdown the sword stuff */
 	main_shutdown_backend();
 	gtk_main_quit();
-	gtk_exit(0);
 	gtk_widget_destroy(widgets.app);
+	exit(0);
 }
 
 
@@ -578,11 +560,11 @@ on_quit_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_about_xiphos_activate(GtkMenuItem * menuitem, 
- *					gpointer user_data)	
+ *   void on_about_xiphos_activate(GtkMenuItem * menuitem,
+ *					gpointer user_data)
  *
  * Description
- *   display xiphos about dialog 
+ *   display xiphos about dialog
  *
  * Return value
  *   void
@@ -604,7 +586,7 @@ on_about_xiphos_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_save_session_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_save_session_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *   ask for a file name (with file-chooser) and save the current tabs to that file
@@ -619,14 +601,14 @@ on_save_session_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gchar *tabs_dir;
 
 	tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
-	
-	if (access(tabs_dir, F_OK) == -1) {
-		if ((Mkdir(tabs_dir, S_IRWXU)) == -1) {
+
+	if (g_access(tabs_dir, F_OK) == -1) {
+		if ((g_mkdir(tabs_dir, S_IRWXU)) == -1) {
 			fprintf(stderr, "can't create tabs dir");
 			return;
 		}
 	}
-	
+
 	dialog = gtk_file_chooser_dialog_new ("Save Session",
 				      NULL,
 				      GTK_FILE_CHOOSER_ACTION_SAVE,
@@ -653,11 +635,11 @@ on_save_session_activate(GtkMenuItem * menuitem, gpointer user_data)
  *  redisplay_to_realign
  *
  * Synopsis
- *   void redisplay_to_realign()	
+ *   void redisplay_to_realign()
  *
  * Description
  *    when en/disabling panes, we must redisplay in order that text
- *    (especially current verse) not suddenly find themselves out of view.
+ *    (especially current verse) not suddenly find itself out of view.
  *
  * Return value
  *   void
@@ -672,19 +654,21 @@ redisplay_to_realign()
 	realign_busy = TRUE;
 
 	/* first realize the pane size updates. */
-	while (gtk_events_pending())
-		gtk_main_iteration();
+	sync_windows();
+
 	/* then just redisplay everything as-is. */
 	gchar *url = g_strdup_printf("sword://%s/%s",
 				     settings.MainWindowModule,
 				     settings.currentverse);
-	main_url_handler(url, TRUE);		
-	g_free(url);
-	url = g_strdup_printf("sword://%s/%s",
-			      settings.DictWindowModule,
-			      settings.dictkey);
-	main_url_handler(url, TRUE);		
+	main_url_handler(url, TRUE);
 	g_free(url);
+	if (settings.DictWindowModule) {
+		url = g_strdup_printf("sword://%s/%s",
+				      settings.DictWindowModule,
+				      settings.dictkey);
+		main_url_handler(url, TRUE);
+		g_free(url);
+	}
 
 	realign_busy = FALSE;
 }
@@ -696,7 +680,7 @@ redisplay_to_realign()
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_open_session_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_open_session_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *   ask for file name (with file-chooser) and load tabs from that file
@@ -711,9 +695,9 @@ on_open_session_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gchar *tabs_dir;
 
 	tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
-	
-	if (access(tabs_dir, F_OK) == -1) {
-		if ((Mkdir(tabs_dir, S_IRWXU)) == -1) {
+
+	if (g_access(tabs_dir, F_OK) == -1) {
+		if ((g_mkdir(tabs_dir, S_IRWXU)) == -1) {
 			fprintf(stderr, "can't create tabs dir");
 			return;
 		}
@@ -748,7 +732,7 @@ on_open_session_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_show_bible_text_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_show_bible_text_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *    toggle Bibletext window
@@ -763,7 +747,7 @@ on_show_bible_text_activate(GtkMenuItem * menuitem, gpointer user_data)
 	redisplay_to_realign();
 }
 
- 
+
 G_MODULE_EXPORT void
 on_preview_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -779,7 +763,7 @@ on_preview_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_show_commentary_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_show_commentary_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *    toggle commentary window *** we need to change the name of this
@@ -803,7 +787,7 @@ on_show_commentary_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_show_dictionary_lexicon_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_show_dictionary_lexicon_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *    toggle lower_workbook view (on or off)
@@ -826,10 +810,10 @@ on_show_dictionary_lexicon_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_module_manager_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_module_manager_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -847,7 +831,7 @@ on_module_manager_activate(GtkMenuItem * menuitem, gpointer user_data)
  * Synopsis
  *   #include "gui/main_menu.h"
  *
- *   void on_open_studypad_activate(GtkMenuItem * menuitem, gpointer user_data)	
+ *   void on_open_studypad_activate(GtkMenuItem * menuitem, gpointer user_data)
  *
  * Description
  *    open studypad editor - if studypad dialog exist bring it to the
@@ -889,17 +873,17 @@ GtkWidget *gui_create_main_menu(void)
 	gchar *glade_file;
 	GladeXML *gxml;
  //   	const gchar *mname = NULL;
-	
+
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
 	g_return_val_if_fail (glade_file != NULL, NULL);
-	
+
 	gxml = glade_xml_new (glade_file, "menu_main", NULL);
-		
+
 	g_free (glade_file);
 	g_return_val_if_fail (gxml != NULL, NULL);
-	
+
 	GtkWidget *menu 	= glade_xml_get_widget (gxml, "menu_main");
-	
+
 	widgets.viewtexts_item = glade_xml_get_widget (gxml, "show_bible_text");
 	widgets.viewpreview_item = glade_xml_get_widget (gxml, "preview");
 	widgets.viewcomms_item = glade_xml_get_widget (gxml, "commentary");
@@ -911,12 +895,12 @@ GtkWidget *gui_create_main_menu(void)
 	widgets.versehighlight_item = glade_xml_get_widget (gxml, "highlight_current_verse");
 	widgets.parallel_tab_item = glade_xml_get_widget (gxml, "show_parallel_view_in_a_tab");
 	widgets.side_preview_item = glade_xml_get_widget (gxml, "show_previewer_in_sidebar");
-	
+
 	widgets.doublespace_item = glade_xml_get_widget (gxml, "double_space_text");
 #ifndef USE_GTKMOZEMBED
 	gtk_widget_hide(widgets.doublespace_item);
 #endif /* !USE_GTKMOZEMBED */
-	
+
 	/* map tab's show state into view menu. */
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.viewtexts_item),
@@ -936,7 +920,7 @@ GtkWidget *gui_create_main_menu(void)
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.side_preview_item),
 				       settings.show_previewer_in_sidebar);
-		
+
 	/* update other status toys */
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.versestyle_item),
@@ -958,10 +942,13 @@ GtkWidget *gui_create_main_menu(void)
 				       (widgets.doublespace_item),
 				       settings.doublespace);
 #endif /* USE_GTKMOZEMBED */
-	
+
     	/* connect signals and data */
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
-	
+
+	//set up global function to handle all link buttons
+	gtk_link_button_set_uri_hook (link_uri_hook, NULL, NULL);
+
 	return menu;
 }
