@@ -26,7 +26,11 @@
 #include <gtk/gtk.h>
 
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif
 #else
 #include <gtkhtml/gtkhtml.h>
 #include "gui/html.h"
@@ -63,11 +67,9 @@
 #include "gui/tabbed_browser.h"
 #include "gui/menu_popup.h"
 
-#ifdef USE_GTKHTML3_14_23
 #include "editor/slib-editor.h"
-#else
-#include "editor/bonobo-editor.h"
-#endif /* !USE_GTKHTML3_14_23 */
+
+#include "gui/debug_glib_null.h"
 
 WIDGETS widgets;
 
@@ -141,12 +143,12 @@ void gui_show_hide_preview(gboolean choice)
 		xml_set_value("Xiphos", "misc", "showpreview", "0");
 	} else {
 		if (main_window_created) {
-			if(settings.show_previewer_in_sidebar) 
+			if (settings.show_previewer_in_sidebar)
 				gtk_widget_show(widgets.box_side_preview);
-			else 
+			else
 				gtk_widget_show(widgets.vbox_previewer);
 		}
-			
+
 		xml_set_value("Xiphos", "misc", "showpreview", "1");
 	}
 }
@@ -246,11 +248,11 @@ void gui_set_bible_comm_layout(void)
 				       settings.biblepane_hight);
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned2),
 				       settings.commpane_hight);
-	
+
 	if ((settings.showcomms == TRUE)  ||  (settings.showdicts == TRUE)) {
 		gtk_widget_show(widgets.vpaned2);
 	}
-	
+
 	gtk_paned_set_position(GTK_PANED(widgets.hpaned),
 			       (settings.showtexts
 				? settings.biblepane_width
@@ -260,34 +262,34 @@ void gui_set_bible_comm_layout(void)
 			       (settings.showcomms
 				? settings.commpane_hight
 				: 0));
-	
+
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned2),
 			       (settings.showdicts
 				? settings.commpane_hight
 				: settings.gs_hight));
-	
+
 	if ((settings.showcomms == FALSE)  && (settings.showdicts == FALSE)) {
 		gtk_widget_hide(widgets.vpaned2);
 		gtk_paned_set_position(GTK_PANED
 				       (widgets.hpaned),
-				       settings.gs_width);	   
+				       settings.gs_width);
 	}
-	
+
 	if ((settings.showcomms == TRUE)
 		   || (settings.showdicts == TRUE)) {
 		gtk_paned_set_position(GTK_PANED
 				       (widgets.hpaned),
-				       settings.biblepane_width);	   
+				       settings.biblepane_width);
 	}
-	if(((settings.showcomms == FALSE) && (settings.showtexts == FALSE)) ||
+	if (((settings.showcomms == FALSE) && (settings.showtexts == FALSE)) ||
 	   ((settings.comm_showing == FALSE) && (settings.showtexts == FALSE)))
 		gtk_widget_hide(nav_toolbar);
 	else
 		gtk_widget_show(nav_toolbar);
-	
+
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),
 				      (settings.comm_showing ? 0 : 1));
-		
+
 }
 
 
@@ -309,12 +311,37 @@ void gui_set_bible_comm_layout(void)
 
 void gui_change_window_title(gchar * module_name)
 {
-	gchar *title;//[200];
+	gchar *title;
+
+	if (cur_passage_tab) {
+		/* borrowed from tabbed_browser.c:pick_tab_label() */
+		/* echo the current tab's module (full name) in title bar */
+		if (cur_passage_tab->showtexts || cur_passage_tab->comm_showing) {
+			title = (cur_passage_tab->showtexts
+				 ? cur_passage_tab->text_mod
+				 : (cur_passage_tab->commentary_mod
+				    ? cur_passage_tab->commentary_mod
+				    : "[no commentary]"));
+		} else {
+			title = (cur_passage_tab->showcomms
+				 ? (cur_passage_tab->book_mod
+				    ? cur_passage_tab->book_mod
+				    : "[no book]")
+				 : (cur_passage_tab->dictlex_mod
+				    ? cur_passage_tab->dictlex_mod
+				    : "[no dict]"));
+		}
+	} else
+		title = module_name;
+
 	/*
 	 * set program title to current module name
 	 */
-	title = g_strdup_printf("%s - %s", main_get_module_description(module_name),
-						settings.program_title);
+	title = main_get_module_description(title);
+	if (!title)
+		title = main_get_module_description(settings.MainWindowModule);
+	title = g_strdup_printf("%s - %s", (title ? title : "[no title]"),
+				settings.program_title);
 	gtk_window_set_title(GTK_WINDOW(widgets.app), title);
 	g_free(title);
 }
@@ -331,9 +358,9 @@ static gboolean  delete_event (GtkWidget *widget,
 	/* shutdown the sword stuff */
 	main_shutdown_backend();
 	gtk_main_quit();
-	gtk_exit(0);
 	gtk_widget_destroy(widgets.app);
-	return TRUE;	
+	exit(0);
+	return TRUE;
 }
 
 /******************************************************************************
@@ -438,14 +465,14 @@ static gboolean on_configure_event(GtkWidget * widget,
 	sprintf(layout, "%d", settings.app_y);
 	xml_set_value("Xiphos", "layout", "app_y", layout);
 	xml_save_settings_doc(settings.fnconfigure);
-	
+
 	return FALSE;
 }
 
 static void on_notebook_bible_parallel_switch_page(GtkNotebook * notebook,
 					GtkNotebookPage * page,
 					gint page_num, GList **tl)
-{ 
+{
 #if 0
 	if (page_num == 0)
 		gui_set_drop_target(widgets.html_text);
@@ -457,9 +484,9 @@ static void on_notebook_bible_parallel_switch_page(GtkNotebook * notebook,
 static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
 					GtkNotebookPage * page,
 					gint page_num, GList **tl)
-{ 
+{
 	gchar *url = NULL;
-	
+
 	if (page_num == 0) {
 #if 0
 		gtk_drag_dest_unset(GTK_WIDGET(widgets.html_book));
@@ -476,11 +503,11 @@ static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
 		if (!settings.showtexts)
 			gtk_widget_hide(nav_toolbar);
 	}
-		
-	gui_update_tab_struct(NULL, 
-			      settings.CommWindowModule, 
-			      NULL, 
-			      NULL, 
+
+	gui_update_tab_struct(NULL,
+			      settings.CommWindowModule,
+			      NULL,
+			      NULL,
 			      NULL,
 			      NULL,
 			      settings.comm_showing,
@@ -488,7 +515,7 @@ static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
 			      settings.showpreview,
 			      settings.showcomms,
 			      settings.showdicts);
-	if(settings.comm_showing)
+	if (settings.comm_showing)
 		main_display_commentary(settings.CommWindowModule, settings.currentverse);
 	else if (settings.book_mod && *settings.book_mod) {
 		url = g_strdup_printf("sword://%s/%ld", settings.book_mod,
@@ -535,8 +562,8 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 {
 	/* these are the mods we actually use for global keys, we always only check for these set */
 	guint state = event->state & (GDK_SHIFT_MASK  | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK );
-	
-	switch(event->hardware_keycode) {
+
+	switch (event->hardware_keycode) {
 	case GS_KEY_SHIFT: /* shift keys - we need this for locking strongs (and other stuff) while moving mouse */
 	case GS_KEY_SHIFT_R: /* to previewer */
 		shift_key_pressed = TRUE;
@@ -697,10 +724,10 @@ gboolean on_vbox1_key_release_event(GtkWidget * widget,
                                         GdkEventKey * event,
                                         gpointer user_data)
 {
-        switch(event->hardware_keycode) {			
-		case GS_KEY_SHIFT: 
-		case GS_KEY_SHIFT_R: 
-			shift_key_pressed = FALSE;				
+        switch (event->hardware_keycode) {
+		case GS_KEY_SHIFT:
+		case GS_KEY_SHIFT_R:
+			shift_key_pressed = FALSE;
 		break;
 	}
   return FALSE;
@@ -729,15 +756,14 @@ void create_mainwindow(void)
 	GtkWidget *menu;
 	GtkWidget *hbox25;
 	GtkWidget *tab_button_icon;
-	GtkTooltips *tooltips;
 	GtkWidget *label;
 #ifdef USE_GTKMOZEMBED
-	GtkWidget *frame;	
+	GtkWidget *frame;
+	GtkWidget *eventbox;
 #else
 	GtkWidget *scrolledwindow;
 #endif /* USE_GTKMOZEMBED */
 	GtkWidget *box_book;
-	GtkWidget *image;
 	GdkPixbuf* pixbuf;
 	/*
 	GTK_SHADOW_NONE
@@ -748,7 +774,6 @@ void create_mainwindow(void)
 	*/
 	settings.shadow_type = GTK_SHADOW_IN;
 
-	tooltips = gtk_tooltips_new ();
 	GS_print(("%s xiphos-%s\n", "Starting", VERSION));
 	GS_print(("%s\n\n", "Building Xiphos interface"));
 
@@ -757,16 +782,15 @@ void create_mainwindow(void)
 	widgets.app = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (widgets.app), _("Xiphos - Bible Study Software"));
 
-	gtk_object_set_data(GTK_OBJECT(widgets.app),
-			    "widgets.app", widgets.app);
+	g_object_set_data(G_OBJECT(widgets.app),
+			  "widgets.app", widgets.app);
 	gtk_widget_set_size_request(widgets.app, 680, 425);
 	GTK_WIDGET_SET_FLAGS(widgets.app, GTK_CAN_FOCUS);
 	gtk_window_set_resizable(GTK_WINDOW(widgets.app), TRUE);
 
 	imagename = image_locator("gs2-48x48.png");
-	image = gtk_image_new_from_file (imagename);
+	pixbuf = gdk_pixbuf_new_from_file (imagename, NULL);
 	g_free(imagename);
-	pixbuf = gtk_image_get_pixbuf (GTK_IMAGE(image));
 	gtk_window_set_icon (GTK_WINDOW(widgets.app), pixbuf);
 
 	vbox_gs = gtk_vbox_new(FALSE, 0);
@@ -799,7 +823,7 @@ void create_mainwindow(void)
 	 * between similar to bookmarks
 	 */
 	widgets.hboxtb = gtk_hbox_new(FALSE, 0);
-	if(settings.browsing)
+	if (settings.browsing)
 		gtk_widget_show(widgets.hboxtb);
 	gtk_box_pack_start(GTK_BOX(widgets.vboxMain), widgets.hboxtb, FALSE, FALSE, 0);
 
@@ -811,8 +835,7 @@ void create_mainwindow(void)
 	gtk_container_add(GTK_CONTAINER(widgets.button_new_tab), tab_button_icon);
 	gtk_button_set_relief(GTK_BUTTON(widgets.button_new_tab), GTK_RELIEF_NONE);
 	gtk_box_pack_start(GTK_BOX(widgets.hboxtb), widgets.button_new_tab, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, widgets.button_new_tab, _("Open a new tab"),
-				NULL);
+	gtk_widget_set_tooltip_text(widgets.button_new_tab, _("Open a new tab"));
 
 	widgets.notebook_main = gtk_notebook_new();
 	gtk_widget_show(widgets.notebook_main);
@@ -857,7 +880,7 @@ void create_mainwindow(void)
 	widgets.vbox_text = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(widgets.vbox_text);
 	gtk_paned_pack1(GTK_PANED(widgets.vpaned),
-					widgets.vbox_text, TRUE, TRUE);
+			widgets.vbox_text, TRUE, TRUE);
 
 	/*
 	 * bible/parallel notebook
@@ -867,13 +890,15 @@ void create_mainwindow(void)
 	gtk_box_pack_start(GTK_BOX(widgets.vbox_text),
 			   widgets.notebook_bible_parallel, TRUE,
 			   TRUE, 0);
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widgets.notebook_bible_parallel),
-                                             GTK_POS_BOTTOM);
-	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.
-				    notebook_bible_parallel), TRUE);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.
-				      notebook_bible_parallel), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (widgets.notebook_bible_parallel), 1);
+	gtk_notebook_set_tab_pos(
+		GTK_NOTEBOOK(widgets.notebook_bible_parallel),
+				 GTK_POS_BOTTOM);
+	gtk_notebook_set_show_tabs(
+		GTK_NOTEBOOK(widgets.notebook_bible_parallel), TRUE);
+	gtk_notebook_set_show_border(
+		GTK_NOTEBOOK(widgets.notebook_bible_parallel), FALSE);
+	gtk_container_set_border_width (
+		GTK_CONTAINER (widgets.notebook_bible_parallel), 1);
 
 	g_signal_connect(GTK_OBJECT(widgets.notebook_bible_parallel),
 			   "switch_page",
@@ -884,12 +909,9 @@ void create_mainwindow(void)
 	 * text notebook
 	 */
 	widgets.notebook_text = gui_create_bible_pane();
-        gtk_container_add(GTK_CONTAINER(widgets.notebook_bible_parallel),
+
+	gtk_container_add(GTK_CONTAINER(widgets.notebook_bible_parallel),
 			  widgets.notebook_text);
-	gtk_notebook_set_scrollable(GTK_NOTEBOOK
-				    (widgets.notebook_text), TRUE);
-	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_text),FALSE);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_text),FALSE);
 
 	label = gtk_label_new(_("Standard View"));
 	gtk_widget_show(label);
@@ -915,12 +937,16 @@ void create_mainwindow(void)
 	gtk_widget_show(frame);
 	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
 	gtk_box_pack_start(GTK_BOX(widgets.vbox_previewer), frame,
-				TRUE, TRUE,
-			   	0);
+				TRUE, TRUE, 0);
+
+
+	eventbox = gtk_event_box_new();
+	gtk_widget_show(eventbox);
+	gtk_container_add(GTK_CONTAINER(frame), eventbox);
 
 	widgets.html_previewer_text
 			= GTK_WIDGET ( gecko_html_new( NULL, FALSE, VIEWER_TYPE));
-	gtk_container_add(GTK_CONTAINER(frame), widgets.html_previewer_text);
+	gtk_container_add(GTK_CONTAINER(eventbox), widgets.html_previewer_text);
 #else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
