@@ -23,7 +23,7 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "gui/navbar_book.h"
 
@@ -73,13 +73,13 @@ static void menu_deactivate_callback(GtkWidget * widget, gpointer user_data)
  *
  * Description
  *   position drop down menu under toogle button
- *   
+ *
  *
  * Return value
  *   void
  */
 
-static 
+static
 void menu_position_under(GtkMenu * menu, int * x, int * y,
 				gboolean * push_in, gpointer user_data)
 {
@@ -102,20 +102,20 @@ static gboolean lookup_entry_press_callback(GtkWidget * widget,
 					     GdkEventKey * event,
 					     gpointer user_data)
 {
-	if(!settings.havebook)
-		return FALSE;	
+	if (!settings.havebook)
+		return FALSE;
 	/* this does not work on my system - hope I'm not messing things up
 	   for others - 104 is the enter key on the number pad
-	switch(event->hardware_keycode) {
+	switch (event->hardware_keycode) {
 	case 98:
 		gtk_button_clicked(GTK_BUTTON(navbar_book.button_up));
 		return TRUE;
 		break;
-	case 104: 
+	case 104:
 		gtk_button_clicked(GTK_BUTTON(navbar_book.button_down));
 		return TRUE;
 		break;
-	case 100: 
+	case 100:
 		gtk_button_clicked(GTK_BUTTON(navbar_book.button_left));
 		return TRUE;
 		break;
@@ -123,11 +123,11 @@ static gboolean lookup_entry_press_callback(GtkWidget * widget,
 		gtk_button_clicked(GTK_BUTTON(navbar_book.button_right));
 		return TRUE;
 		break;
-	} 
+	}
 	*/
 	GS_message(("lookup_entry_press_callback\nkeycode: %d",event->hardware_keycode));
 	return FALSE;
-	
+
 
 }
 
@@ -155,9 +155,9 @@ static gboolean select_button_press_callback(GtkWidget * widget,
 					     gpointer user_data)
 {
 	GtkWidget *menu;
-	
-	if(!settings.havebook)
-		return FALSE;	
+
+	if (!settings.havebook)
+		return FALSE;
 	menu = main_book_drop_down_new();
 	g_signal_connect(menu, "deactivate",
 			 G_CALLBACK(menu_deactivate_callback), widget);
@@ -192,8 +192,8 @@ static gboolean select_button_press_callback(GtkWidget * widget,
 static
 void on_button_parent_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_parent();
 }
 
@@ -217,8 +217,8 @@ void on_button_parent_clicked(GtkButton * button, gpointer user_data)
 static
 void on_button_child_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_first_child();
 }
 
@@ -242,8 +242,8 @@ void on_button_child_clicked(GtkButton * button, gpointer user_data)
 static
 void on_button_prev_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_prev();
 }
 
@@ -267,8 +267,8 @@ void on_button_prev_clicked(GtkButton * button, gpointer user_data)
 static
 void on_button_next_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_next();
 }
 
@@ -277,24 +277,24 @@ void on_button_next_clicked(GtkButton * button, gpointer user_data)
 /******************************************************************************
  * Name
  *    on_entry_activate
- *    
+ *
  * Synopsis
  *   #include "gui/navbar_book.h"
  *
  *  void on_entry_activate (GtkEntry *entry, gpointer  user_data)
  *
  * Description
- *    get entry text and call main_navbar_book_entry_activate(); 
+ *    get entry text and call main_navbar_book_entry_activate();
  *    in main/navbar_book.cc
  *
  * Return value
  *   void
  */
 
-void  on_entry_activate (GtkEntry *entry, gpointer  user_data) 
+void on_entry_activate (GtkEntry *entry, gpointer  user_data)
 {
 	const gchar* entry_buf = NULL;
-	
+
 	entry_buf = gtk_entry_get_text (entry);
 	main_navbar_book_entry_activate (entry_buf);
 }
@@ -324,7 +324,6 @@ GtkWidget *gui_navbar_book_new(void)
 	GtkWidget *arrow1;
 	GtkWidget *image2;
 
-	navbar_book.tooltips = gtk_tooltips_new();
 	vbox1 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox1);
 
@@ -355,8 +354,8 @@ GtkWidget *gui_navbar_book_new(void)
 	gtk_widget_show(navbar_book.button_left);
 	gtk_box_pack_start(GTK_BOX(hbox1), navbar_book.button_left, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(navbar_book.tooltips, navbar_book.button_left,
-			     _("Go outward, to the section containing this one"), NULL);
+	gtk_widget_set_tooltip_text(navbar_book.button_left,
+			     _("Go outward, to the section containing this one"));
 
 	gtk_button_set_relief(GTK_BUTTON(navbar_book.button_left),
 			      GTK_RELIEF_NONE);
@@ -371,8 +370,7 @@ GtkWidget *gui_navbar_book_new(void)
 	gtk_widget_show(navbar_book.button_up);
 	gtk_box_pack_start(GTK_BOX(hbox1), navbar_book.button_up, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(navbar_book.tooltips, navbar_book.button_up,
-			     _("Go to previous item"), NULL);
+	gtk_widget_set_tooltip_text(navbar_book.button_up, _("Go to previous item"));
 	gtk_button_set_relief(GTK_BUTTON(navbar_book.button_up),
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(navbar_book.button_up),
@@ -386,8 +384,7 @@ GtkWidget *gui_navbar_book_new(void)
 	gtk_widget_show(navbar_book.button_down);
 	gtk_box_pack_start(GTK_BOX(hbox1), navbar_book.button_down, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(navbar_book.tooltips, navbar_book.button_down,
-			     _("Go to next item"), NULL);
+	gtk_widget_set_tooltip_text(navbar_book.button_down, _("Go to next item"));
 	gtk_button_set_relief(GTK_BUTTON(navbar_book.button_down),
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(navbar_book.button_down),
@@ -401,9 +398,7 @@ GtkWidget *gui_navbar_book_new(void)
 	gtk_widget_show(navbar_book.button_right);
 	gtk_box_pack_start(GTK_BOX(hbox1), navbar_book.button_right, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(navbar_book.tooltips,
-			     navbar_book.button_right,
-			     _("Go inward, to the first subsection"), NULL);
+	gtk_widget_set_tooltip_text(navbar_book.button_right, _("Go inward, to the first subsection"));
 
 	gtk_button_set_relief(GTK_BUTTON(navbar_book.button_right),
 			      GTK_RELIEF_NONE);
