@@ -23,7 +23,8 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "gui/navbar_book_dialog.h"
 
@@ -73,13 +74,13 @@ static void menu_deactivate_callback(GtkWidget * widget, gpointer user_data)
  *
  * Description
  *   position drop down menu under toogle button
- *   
+ *
  *
  * Return value
  *   void
  */
 
-static 
+static
 void menu_position_under(GtkMenu * menu, int * x, int * y,
 				gboolean * push_in, gpointer user_data)
 {
@@ -123,9 +124,9 @@ static gboolean select_button_press_callback(GtkWidget * widget,
 {
 	GtkWidget *menu;
 
-	if(!settings.havebook)
-		return FALSE;	
-	menu = main_navbar_book_dialog_drop_down_new(user_data);	
+	if (!settings.havebook)
+		return FALSE;
+	menu = main_navbar_book_dialog_drop_down_new(user_data);
 	g_signal_connect(menu, "deactivate",
 			 G_CALLBACK(menu_deactivate_callback), widget);
 	if ((event->type == GDK_BUTTON_PRESS) && event->button == 1) {
@@ -159,8 +160,8 @@ static gboolean select_button_press_callback(GtkWidget * widget,
 static
 void on_button_parent_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_dialog_parent(user_data);
 }
 
@@ -184,8 +185,8 @@ void on_button_parent_clicked(GtkButton * button, gpointer user_data)
 static
 void on_button_child_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_dialog_first_child(user_data);
 }
 
@@ -209,8 +210,8 @@ void on_button_child_clicked(GtkButton * button, gpointer user_data)
 static
 void on_button_prev_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_dialog_prev(user_data);
 }
 
@@ -234,8 +235,8 @@ void on_button_prev_clicked(GtkButton * button, gpointer user_data)
 static
 void on_button_next_clicked(GtkButton * button, gpointer user_data)
 {
-	if(!settings.havebook)
-		return;	
+	if (!settings.havebook)
+		return;
 	main_navbar_book_dialog_next(user_data);
 }
 
@@ -264,7 +265,6 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	GtkWidget *arrow1;
 	GtkWidget *image2;
 
-	d->navbar_book.tooltips = gtk_tooltips_new();
 	vbox1 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox1);
 
@@ -295,8 +295,8 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	gtk_widget_show(d->navbar_book.button_left);
 	gtk_box_pack_start(GTK_BOX(hbox1), d->navbar_book.button_left, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(d->navbar_book.tooltips, d->navbar_book.button_left,
-			     _("Go outward, to the section containing this one"), NULL);
+	gtk_widget_set_tooltip_text(d->navbar_book.button_left,
+			     _("Go outward, to the section containing this one"));
 
 	gtk_button_set_relief(GTK_BUTTON(d->navbar_book.button_left),
 			      GTK_RELIEF_NONE);
@@ -311,8 +311,7 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	gtk_widget_show(d->navbar_book.button_up);
 	gtk_box_pack_start(GTK_BOX(hbox1), d->navbar_book.button_up, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(d->navbar_book.tooltips, d->navbar_book.button_up,
-			     _("Go to previous item"), NULL);
+	gtk_widget_set_tooltip_text(d->navbar_book.button_up, _("Go to previous item"));
 	gtk_button_set_relief(GTK_BUTTON(d->navbar_book.button_up),
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(d->navbar_book.button_up),
@@ -326,8 +325,7 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	gtk_widget_show(d->navbar_book.button_down);
 	gtk_box_pack_start(GTK_BOX(hbox1), d->navbar_book.button_down, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(d->navbar_book.tooltips, d->navbar_book.button_down,
-			     _("Go to next item"), NULL);
+	gtk_widget_set_tooltip_text(d->navbar_book.button_down, _("Go to next item"));
 	gtk_button_set_relief(GTK_BUTTON(d->navbar_book.button_down),
 			      GTK_RELIEF_NONE);
 	gtk_button_set_focus_on_click(GTK_BUTTON(d->navbar_book.button_down),
@@ -341,9 +339,7 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 	gtk_widget_show(d->navbar_book.button_right);
 	gtk_box_pack_start(GTK_BOX(hbox1), d->navbar_book.button_right, FALSE,
 			   FALSE, 0);
-	gtk_tooltips_set_tip(d->navbar_book.tooltips,
-			     d->navbar_book.button_right,
-			     _("Go inward, to the first subsection"), NULL);
+	gtk_widget_set_tooltip_text(d->navbar_book.button_right, _("Go inward, to the first subsection"));
 
 	gtk_button_set_relief(GTK_BUTTON(d->navbar_book.button_right),
 			      GTK_RELIEF_NONE);
