@@ -23,10 +23,14 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif
 #else
 #include <gtkhtml/gtkhtml.h>
 #include "gui/html.h"
@@ -124,12 +128,12 @@ void on_paratab_activate(GtkMenuItem * menuitem)
 void on_changeint1mod_activate(GtkMenuItem * menuitem,
 				      gpointer user_data)
 {
-	
+
 	gchar *mod_name = NULL;
 //	GS_message(("mod_name",(gchar *) user_data));
 	mod_name = main_module_name_from_description((gchar *) user_data);
-	
-	if(!mod_name) 
+
+	if (!mod_name)
 		return;
 	main_change_parallel_module(PARALLEL1, mod_name);
 }
@@ -160,7 +164,7 @@ static void on_changeint2mod_activate(GtkMenuItem * menuitem,
 	gchar *mod_name = NULL;
 
 	mod_name = main_module_name_from_description((gchar *) user_data);
-	if(!mod_name) 
+	if (!mod_name)
 		return;
 	main_change_parallel_module(PARALLEL2, mod_name);
 }
@@ -189,7 +193,7 @@ static void on_changeint3mod_activate(GtkMenuItem * menuitem,
 	gchar *mod_name = NULL;
 
 	mod_name = main_module_name_from_description((gchar *) user_data);
-	if(!mod_name) 
+	if (!mod_name)
 		return;
 	main_change_parallel_module(PARALLEL3, mod_name);
 }
@@ -218,7 +222,7 @@ static void on_changeint4mod_activate(GtkMenuItem * menuitem,
 	gchar *mod_name = NULL;
 
 	mod_name = main_module_name_from_description((gchar *) user_data);
-	if(!mod_name) 
+	if (!mod_name)
 		return;
 	main_change_parallel_module(PARALLEL4, mod_name);
 }
@@ -248,25 +252,23 @@ static void on_changeint5mod_activate(GtkMenuItem * menuitem,
 
 	mod_name = main_module_name_from_description((gchar *) user_data);
 
-	if (!mod_name) 
+	if (!mod_name)
 		return;
 	main_change_parallel_module(PARALLEL5, mod_name);
 }
 
 
 void gui_popup_menu_parallel(void)
-{	
+{
 	GtkWidget *menu;
 	GtkWidget *copy7;
 	GtkWidget *undockInt = NULL;
 	GtkWidget *module_options;
 	GtkWidget *separator2;
-	GtkTooltips *tooltips;	
 	GtkWidget *module_options_menu;
-	
-	tooltips = gtk_tooltips_new();
+
 	menu = gtk_menu_new();
-	gtk_object_set_data(GTK_OBJECT(menu), "pmInt", menu);
+	g_object_set_data(G_OBJECT(menu), "pmInt", menu);
 
 	copy7 = gtk_menu_item_new_with_label(_("Copy"));
 	gtk_widget_hide(copy7);
@@ -276,7 +278,7 @@ void gui_popup_menu_parallel(void)
 	gtk_widget_hide(separator2);
 	gtk_container_add(GTK_CONTAINER(menu), separator2);
 	gtk_widget_set_sensitive(separator2, FALSE);
-	
+
 	if (!settings.showparatab) {
 		undockInt = gtk_menu_item_new_with_label(_("Detach/Attach"));
 		gtk_widget_show(undockInt);
@@ -291,7 +293,7 @@ void gui_popup_menu_parallel(void)
 	module_options_menu = gtk_menu_new();
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(module_options),
 				  module_options_menu);
-				  
+
 	main_load_g_ops_parallel(module_options_menu);
 
 	separator2 = gtk_menu_item_new();
@@ -299,7 +301,7 @@ void gui_popup_menu_parallel(void)
 	gtk_container_add(GTK_CONTAINER(menu), separator2);
 	gtk_widget_set_sensitive(separator2, FALSE);
 	/* build change parallel modules submenu */
-	main_load_menu_form_mod_list(menu, _("Change parallel 1"),			       
+	main_load_menu_form_mod_list(menu, _("Change parallel 1"),
 				     G_CALLBACK(on_changeint1mod_activate));
 	main_load_menu_form_mod_list(menu, _("Change parallel 2"),
 				     G_CALLBACK(on_changeint2mod_activate));
@@ -313,7 +315,7 @@ void gui_popup_menu_parallel(void)
 /*	g_signal_connect(GTK_OBJECT(copy7), "activate",
 			   G_CALLBACK(gui_copyhtml_activate),
 			   NULL);*/
-	
+
 	if (!settings.showparatab) {
 		if (undockInt) {
 			g_signal_connect(GTK_OBJECT(undockInt), "activate",
@@ -323,7 +325,7 @@ void gui_popup_menu_parallel(void)
 			GS_warning(("undockInt is NULL?"));
 		}
 	}
-	
+
 	gtk_menu_popup((GtkMenu*)menu, NULL, NULL, NULL, NULL, 0,
 		       gtk_get_current_event_time());
 }
@@ -344,7 +346,7 @@ static gboolean on_key_press_event           (GtkWidget       *widget,
                                         GdkEventKey     *event,
                                         gpointer         user_data)
 {
-	switch(event->hardware_keycode) {
+	switch (event->hardware_keycode) {
 		case 50:
 		case 62:
 			shift_key_pressed = TRUE;
@@ -358,7 +360,7 @@ static gboolean on_key_release_event         (GtkWidget       *widget,
                                         GdkEventKey     *event,
                                         gpointer         user_data)
 {
-	switch(event->hardware_keycode) {
+	switch (event->hardware_keycode) {
 		case 50:
 		case 62:
 			shift_key_pressed = FALSE;
@@ -400,7 +402,7 @@ _popupmenu_requested_cb(GtkHTML *html,
  *   void gui_create_parallel_page(guint page_num)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -416,7 +418,7 @@ void gui_create_parallel_page(void)
 #endif
 
 	/*
-	 * parallel page 
+	 * parallel page
 	 */
 	settings.dockedInt = TRUE;
 #ifdef USE_GTKMOZEMBED
