@@ -29,11 +29,12 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <gtk/gtk.h>
 #include <glade/glade-xml.h>
 
 #include "gui/bibletext.h"
+#include "gui/dialog.h"
 #include "gui/xiphos.h"
 #include "gui/preferences_dialog.h"
 #include "gui/utilities.h"
@@ -45,7 +46,6 @@
 #include "gui/sidebar.h"
 #include "gui/tabbed_browser.h"
 #include "gui/widgets.h"
-#include "gui/preferences_cell_renderer.h"
 
 #include "main/sword.h"
 #include "main/lists.h"
@@ -56,61 +56,7 @@
 #include "main/xml.h"
 #include "main/url.hh"
 
-//gtk_toggle_button_set_active
-typedef enum {
-	SHOW_BIBLE_TABS,
-	SHOW_COMMENTARY_TABS,
-	SHOW_DICTIONARY_TABS,
-	SHOW_BOOK_TABS,
-	USE_DEFAULT_DICTIONARY,
-	USE_VERSE_STYLE,
-	USE_LINKED_TABS,
-	READ_ALOUD,
-	SHOW_VERSE_NUM,
-	VERSE_HIGHLIGHT,
-	DOUBLE_SPACE,
-	SHOW_SPLASH_SCREEN,
-	SHOW_BIBLE_PANE,
-	SHOW_COMMENTARY_PANE,
-	SHOW_DICTIONARY_PANE,
-	SHOW_IN_VIEWER,
-	SHOW_IN_DICTIONARY,
-	SHOW_DEVOTION,
-	USE_STUDYPAD,
-	USE_STUDYPAD_DIALOG,
-	USE_PERCOMM_DIALOG,
-	TABBED_BROWSING
-} which_check_button;
-
-typedef enum {
-	TEXT_FORGROUND,
-	TEXT_BACKGROUND,
-	TEXT_CURRENT_VERSE,
-	VERSE_NUMBERS,
-	HREF_LINKS,
-	HIGHLIGHT_FG,
-	HIGHLIGHT_BG
-} which_color_combo;
-
-
-typedef enum {
-	TEXT_MODULE,
-	PARALLEL_1_MODULE,
-	PARALLEL_2_MODULE,
-	PARALLEL_3_MODULE,
-	PARALLEL_4_MODULE,
-	PARALLEL_5_MODULE,
-	COMMENTARY_MODULE,
-	DICTIONARY_MODULE,
-	DEFAULT_DICTIONARY_MODULE,
-	PERCOMM_MODULE,
-	DEVOTION_MODULE,
-	GREEK_LEX__MODULE,
-	HEBREW_LEX__MODULE,
-	COMBO_ENTRY_SP_DIR,
-	BASE_FONT_SIZE,
-	VERSE_NUMBER_SIZE
-} which_entry;
+#include "gui/debug_glib_null.h"
 
 typedef struct _preferences_combo COMBOBOXS;
 struct _preferences_combo {
@@ -131,6 +77,7 @@ struct _preferences_combo {
 	GtkWidget *combo_entry_sp_dir;
 	GtkWidget *base_font_size;
 	GtkWidget *verse_number_size;
+	GtkWidget *special_locale;
 };
 
 typedef struct _preferences_color_pickers COLOR_PICKERS;
@@ -724,11 +671,12 @@ on_checkbutton4_toggled(GtkToggleButton *togglebutton,
  *   void
  */
 
+extern gboolean style_display;
+
 void
 on_checkbutton5_toggled(GtkToggleButton * togglebutton,
 			gpointer user_data)
 {
-	extern gboolean style_display;
 	xml_set_value("Xiphos", "misc", "versestyle",
 		      (togglebutton->active ? "1" : "0"));
 	settings.versestyle = togglebutton->active;
@@ -791,13 +739,13 @@ on_checkbutton_showparatab_toggled(GtkToggleButton * togglebutton,
 {
 	xml_set_value("Xiphos", "misc", "showparatab",
 		      (togglebutton->active ? "1" : "0"));
-	if(togglebutton->active)
+	if (togglebutton->active)
 		gui_open_parallel_view_in_new_tab();
 	else
 		gui_close_passage_tab(1);
-		
-	
-}	
+
+
+}
 
 
 /******************************************************************************
@@ -1185,6 +1133,7 @@ on_basecombobox1_changed(GtkComboBox * combobox,
 	if (!buf)
 		return;
 	xml_set_value("Xiphos", "fontsize", "basefontsize", buf);
+	g_free(buf);
 
 	if (settings.base_font_size_str)
 		g_free(settings.base_font_size_str);
@@ -1196,7 +1145,7 @@ on_basecombobox1_changed(GtkComboBox * combobox,
 			      settings.currentverse);
 	main_url_handler(url, TRUE);
 	g_free(url);
-	g_free(buf);
+	main_display_dictionary(settings.DictWindowModule, settings.dictkey);
 }
 
 
@@ -1651,6 +1600,67 @@ on_combobox15_changed(GtkComboBox * combobox,
 }
 
 
+/******************************************************************************
+ * Name
+ *   on_combobox16_changed
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_combobox16_changed(GtkEditable * editable, gpointer user_data)
+ *
+ * Description
+ *   combobox16 (special locale),
+ *   has changed - update settings
+ *
+ * Return value
+ *  void
+ */
+
+void
+on_combobox16_changed(GtkComboBox * combobox,
+		      gpointer user_data)
+{
+	gchar *buf = NULL;
+	GtkTreeIter iter;
+	GtkTreeModel *model = gtk_combo_box_get_model(combobox);
+	gboolean clear, set;
+	char **locale, brief_locale[3], *real_locale;
+
+	gtk_combo_box_get_active_iter(combobox, &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, 0, &buf, -1);
+	if (!buf || !strcmp(buf, _("-- Select --")))	/* see fill_combobox */
+		return;
+
+	/* get us back to an xx_YY locale name from the full name.  */
+	/* "buf" is necessarily an entry to be found in locale_set. */
+	for (locale = &locale_set[0]; *locale; ++locale) {
+		brief_locale[0] = (*locale)[0];
+		brief_locale[1] = (*locale)[1];
+		brief_locale[2] = '\0';
+		real_locale = (gpointer)main_get_language_map(brief_locale);
+		if (!strcmp(real_locale, buf)) {
+			g_free(buf);
+			buf = *locale;
+			break;
+		}
+	}
+
+	clear = !strcmp(buf, NONE);
+	set   = ((!settings.special_locale && strcmp(buf, NONE)) ||
+		 (settings.special_locale && (strcmp(settings.special_locale, buf))));
+	if (clear || set)
+		gui_generic_warning(_("Locale will take effect after restart."));
+
+	if (clear)
+		*buf = '\0';
+
+	xml_set_value("Xiphos", "locale", "special", (clear ? NONE : buf));
+	g_free(settings.special_locale);	/* dispose of old content */
+	settings.special_locale = (clear ? g_strdup(NONE) : g_strdup(buf));
+}
+
+
 /******************************************************************************
  * Name
  *   add_columns
@@ -1851,7 +1861,6 @@ setup_color_pickers(void)
                                         &color);
 	}
 
-/*
 	if (string_is_color(settings.bible_verse_num_color)) {
 		gdk_color_parse(settings.bible_verse_num_color, &color);
 		gtk_color_button_set_color(
@@ -1863,7 +1872,6 @@ setup_color_pickers(void)
 			GTK_COLOR_BUTTON(color_picker.verse_numbers),
                                         &color);
 	}
-*/
 
 	if (string_is_color(settings.link_color)) {
 		gdk_color_parse(settings.link_color, &color);
@@ -1942,8 +1950,8 @@ setup_check_buttons(void)
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.show_paratab),
-				     settings.showparatab);	
-	
+				     settings.showparatab);
+
 #if 0
 #ifdef USE_GTKMOZEMBED
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
@@ -1980,7 +1988,7 @@ setup_check_buttons(void)
 			 G_CALLBACK(on_checkbutton_prayerlist_toggled), NULL);
 	g_signal_connect(check_button.show_paratab, "toggled",
 			 G_CALLBACK(on_checkbutton_showparatab_toggled), NULL);
-	
+
 #if 0
 #ifdef USE_GTKMOZEMBED
 	g_signal_connect(check_button.doublespace, "toggled",
@@ -2176,7 +2184,34 @@ setup_module_comboboxes(void)
 			 G_CALLBACK(on_combobox13_changed), NULL);
 	g_signal_connect(combo.greek_lex__module, "changed",
 			 G_CALLBACK(on_combobox14_changed), NULL);
+}
 
+
+void
+setup_locale_combobox(void);
+void
+setup_locale_combobox(void)
+{
+	char **locale, brief_locale[3], *real_locale, *current_locale = NULL;
+	GList *list = g_list_append(NULL, NONE);
+
+	for (locale = &locale_set[0]; *locale; ++locale) {
+		brief_locale[0] = (*locale)[0];
+		brief_locale[1] = (*locale)[1];
+		brief_locale[2] = '\0';
+		real_locale = (gpointer)main_get_language_map(brief_locale);
+		list = g_list_append(list, real_locale);
+		if (settings.special_locale &&
+		    !strcmp(settings.special_locale, *locale))
+			current_locale = real_locale;
+	}
+	fill_combobox(list, GTK_COMBO_BOX(combo.special_locale),
+		      (current_locale ? current_locale : NONE),
+		      NULL, NULL);
+	g_list_free(list);
+
+	g_signal_connect(combo.special_locale, "changed",
+			 G_CALLBACK(on_combobox16_changed), NULL);
 }
 
 
@@ -2237,11 +2272,9 @@ create_preferences_dialog(void)
 	color_picker.text_current_verse = glade_xml_get_widget (gxml, "colorbutton3");
 	g_signal_connect(color_picker.text_current_verse, "color_set",
 			 G_CALLBACK(on_colorbutton3_color_set), NULL);
-/*
 	color_picker.verse_numbers = glade_xml_get_widget (gxml, "colorbutton4");
 	g_signal_connect(color_picker.verse_numbers, "color_set",
 			 G_CALLBACK(on_colorbutton4_color_set), NULL);
-*/
 	color_picker.href_links = glade_xml_get_widget (gxml, "colorbutton5");
 	g_signal_connect(color_picker.href_links, "color_set",
 			 G_CALLBACK(on_colorbutton5_color_set), NULL);
@@ -2267,7 +2300,7 @@ create_preferences_dialog(void)
 	check_button.show_devotion = glade_xml_get_widget(gxml, "checkbutton7");
 	check_button.show_splash_screen = glade_xml_get_widget(gxml, "checkbutton8");
 	check_button.use_chapter_scroll = glade_xml_get_widget(gxml, "checkbutton_scroll");
-#ifdef USE_GTKMOZEMBED	
+#ifdef USE_GTKMOZEMBED
 	gtk_widget_hide(check_button.use_chapter_scroll);
 #endif
 	check_button.use_imageresize = glade_xml_get_widget(gxml, "checkbutton_imageresize");
@@ -2278,7 +2311,7 @@ create_preferences_dialog(void)
 	check_button.show_paratab = glade_xml_get_widget(gxml, "checkbutton_paratab");
 
 	gtk_widget_hide(check_button.show_paratab);
-	
+
 	setup_check_buttons();
 
 	/* verse number size */
@@ -2311,6 +2344,10 @@ create_preferences_dialog(void)
 	combo.greek_lex__module = glade_xml_get_widget (gxml, "combobox14");
 	combo.book_module = glade_xml_get_widget (gxml, "combobox15");
 	setup_module_comboboxes();
+
+	combo.special_locale = glade_xml_get_widget (gxml, "combobox16");
+	setup_locale_combobox();
+
 	/* studypad directory chooserbutton */
 	chooser = glade_xml_get_widget (gxml, "filechooserbutton1");
 	gtk_file_chooser_set_current_folder((GtkFileChooser *)chooser,
