@@ -23,19 +23,15 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
 #include <glade/glade-xml.h>
 
-#ifdef USE_GTKHTML3_14_23
 #include "editor/slib-editor.h"
-#else
-#include "editor/bonobo-editor.h"
-#endif
 
 
 #include "gui/sidebar.h"
 #include "gui/bookmarks_treeview.h"
+#include "gui/export_bookmarks.h"
 #include "gui/utilities.h"
 #include "gui/about_modules.h"
 #include "gui/main_window.h"
@@ -50,10 +46,13 @@
 #include "gui/tabbed_browser.h"
 #include "gui/search_dialog.h"
 
-
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
 #endif
+#endif
 
 #include "main/sword.h"
 #include "main/settings.h"
@@ -65,6 +64,8 @@
 #include "main/xml.h"
 #include "main/module_dialogs.h"
 
+#include "gui/debug_glib_null.h"
+
 
 SIDEBAR sidebar;
 static GtkWidget *button_bookmarks;
@@ -74,26 +75,27 @@ static GtkWidget *button_modules;
 static gchar *buf_module;
 static gchar *buf_caption;
 GList *list_of_verses;
-
+GtkListStore *model_verselist;
+gboolean is_search_result;
 
 extern gboolean shift_key_pressed;
 
 
-static void create_menu_modules(void);
-
+static GtkWidget* create_menu_modules(void);
+void on_export_verselist_activate (GtkMenuItem * menuitem, gpointer user_data);
 
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/sidebar.h"
  *
- *   
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -101,7 +103,7 @@ static void create_menu_modules(void);
 
 void  gui_sync_module_treeview(gint direction)
 {
-	
+
 }
 
 
@@ -124,7 +126,7 @@ void  gui_sync_module_treeview(gint direction)
 void gui_save_treeview_path_string (const gchar * path_str, const gchar * book_name)
 {
 	gchar file[250];
-	
+
 	sprintf(file, "%s/book_path.conf", settings.gSwordDir);
 	save_conf_file_item(file, book_name, "PATH", path_str);
 	GS_message (("\n\nPATH: %s\n\n", path_str));
@@ -142,8 +144,8 @@ void gui_save_treeview_path_string (const gchar * path_str, const gchar * book_n
  *   void gui_collapse_treeview_to_book (GtkTreeView * tree, const gchar * book_name)
  *
  * Description
- *   collapses a book treeview to it's name - it's called by tabbed browsing 
- *   before the next book is expanded 
+ *   collapses a book treeview to it's name - it's called by tabbed browsing
+ *   before the next book is expanded
  *
  * Return value
  *   void
@@ -153,30 +155,30 @@ void gui_save_treeview_path_string (const gchar * path_str, const gchar * book_n
 void gui_collapse_treeview_to_book (GtkTreeView * tree, const gchar * book_name)
 {
 	gchar file[250];
-	gchar *path_string = NULL; 
-	gchar *tmp_path_string = NULL; 
+	gchar *path_string = NULL;
+	gchar *tmp_path_string = NULL;
 	gchar **work_buf = NULL;
 	GtkTreePath *path;
-	
+
 	sprintf(file, "%s/book_path.conf", settings.gSwordDir);
 	path_string = get_conf_file_item (file, (gchar*)book_name, "PATH");
-	
+
 	if (!path_string) return;
-		
+
 	work_buf = g_strsplit ( path_string, ":", 4);
-	
-	tmp_path_string = g_strdup_printf ("%s:%s:%s", 
-					   work_buf[0], 
-					   work_buf[1], 
+
+	tmp_path_string = g_strdup_printf ("%s:%s:%s",
+					   work_buf[0],
+					   work_buf[1],
 					   work_buf[2]);
-	
+
 	path = gtk_tree_path_new_from_string ((gchar *)tmp_path_string);
 	gtk_tree_view_collapse_row (tree, path);
-	
+
 	gtk_tree_path_free(path);
 	g_free (path_string);
 	g_free (tmp_path_string);
-	g_strfreev(work_buf);	
+	g_strfreev(work_buf);
 }
 
 /******************************************************************************
@@ -199,8 +201,8 @@ void gui_collapse_treeview_to_book (GtkTreeView * tree, const gchar * book_name)
 gboolean gui_expand_treeview_to_path (GtkTreeView * tree, const gchar * book_name)
 {
 	gchar file[250];
-	gchar *path_string = NULL; 
-	gchar *tmp_path_string = NULL; 
+	gchar *path_string = NULL;
+	gchar *tmp_path_string = NULL;
 	gchar *mod = NULL;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
@@ -208,23 +210,23 @@ gboolean gui_expand_treeview_to_path (GtkTreeView * tree, const gchar * book_nam
 	GtkTreeSelection *selection;
 	gchar **work_buf = NULL;
 	gint i = 3;
-	
+
 	sprintf(file, "%s/book_path.conf", settings.gSwordDir);
 	path_string = get_conf_file_item (file, (gchar*)book_name, "PATH");
 	if (!path_string) return 0;
-	
+
 	work_buf = g_strsplit ( path_string, ":", -1);
-	GS_message (("\n\nbuf[0]: %s\nbuf[1]: %s\nbuf[2]: %s\n\n", 
-		     work_buf[0], 
-		     work_buf[1], 
+	GS_message (("\n\nbuf[0]: %s\nbuf[1]: %s\nbuf[2]: %s\n\n",
+		     work_buf[0],
+		     work_buf[1],
 		     work_buf[2]));
 	model = gtk_tree_view_get_model (tree);
-	
-	tmp_path_string = g_strdup_printf ("%s:%s:%s", 
-					   work_buf[0], 
-					   work_buf[1], 
+
+	tmp_path_string = g_strdup_printf ("%s:%s:%s",
+					   work_buf[0],
+					   work_buf[1],
 					   work_buf[2]);
-	if (gtk_tree_model_get_iter_from_string (model, &iter, 
+	if (gtk_tree_model_get_iter_from_string (model, &iter,
 						 (gchar *)tmp_path_string)) {
 		gtk_tree_model_get(model, &iter,  3, &mod, -1);
 		if (!g_utf8_collate(mod, book_name)) {
@@ -232,30 +234,30 @@ gboolean gui_expand_treeview_to_path (GtkTreeView * tree, const gchar * book_nam
 			path = gtk_tree_path_new_from_string ((gchar *)tmp_path_string);
 			gtk_tree_view_expand_to_path (tree, path);
 			gtk_tree_selection_select_path (selection, path);
-			
+
 			main_expand_treeview_to_path(model,iter);
 			gtk_tree_path_free(path);
 			while (work_buf[i]) {
-				GS_message (("\n\nwork_buf[%d]: %s\n\n", 
-					     i, 
+				GS_message (("\n\nwork_buf[%d]: %s\n\n",
+					     i,
 					     work_buf[i]));
-				
-				tmp_path_string = 
-					g_strdup_printf ("%s:%s", 
-							 tmp_path_string, 
+
+				tmp_path_string =
+					g_strdup_printf ("%s:%s",
+							 tmp_path_string,
 							 work_buf[i]);
-				gtk_tree_model_get_iter_from_string (model, 
-								     &iter, 
+				gtk_tree_model_get_iter_from_string (model,
+								     &iter,
 								     (gchar *)tmp_path_string);
-			
-				GS_message (("\n\nmod: %s\npath: %s\n\n", 
-					     mod, 
+
+				GS_message (("\n\nmod: %s\npath: %s\n\n",
+					     mod,
 					     tmp_path_string));
 				path = gtk_tree_path_new_from_string (
 						   (gchar *)tmp_path_string);
 				gtk_tree_view_expand_to_path (tree, path);
 				gtk_tree_selection_select_path (selection, path);
-				
+
 				main_expand_treeview_to_path(model,iter);
 				gtk_tree_path_free(path);
 				++i;
@@ -271,11 +273,11 @@ gboolean gui_expand_treeview_to_path (GtkTreeView * tree, const gchar * book_nam
                                        0.0,
                                        0.0);
 	gtk_tree_path_free(path);
-	
-	g_free (tmp_path_string);	
-	
+
+	g_free (tmp_path_string);
+
 	g_strfreev(work_buf);
-	
+
 	return 1;
 }
 #endif /* USE_TREEVIEW_PATH */
@@ -303,7 +305,7 @@ static void on_notebook_switch_page(GtkNotebook * notebook,
 				    GtkNotebookPage * page,
 				    guint page_num, gpointer user_data)
 {
-	switch(page_num) {
+	switch (page_num) {
 	case 0:
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_v_lists), FALSE);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_bookmarks), FALSE);
@@ -444,20 +446,18 @@ void gui_sidebar_showhide(void)
 		xml_set_value("Xiphos", "misc", "show_sidebar",	"0");
 		settings.showshortcutbar = FALSE;
 		gtk_widget_hide(widgets.shortcutbar);
-		while (gtk_events_pending())
-			gtk_main_iteration();
-		settings.biblepane_width = GTK_WIDGET(widgets.vpaned)->allocation.width;	
-	
+		sync_windows();
+		settings.biblepane_width = GTK_WIDGET(widgets.vpaned)->allocation.width;
+
 	} else {
 		xml_set_value("Xiphos", "misc", "show_sidebar",	"1");
 		settings.showshortcutbar = TRUE;
 		gtk_paned_set_position(GTK_PANED(widgets.epaned),
 				       settings.sidebar_width);
 		gtk_widget_show(widgets.shortcutbar);
-		while (gtk_events_pending())
-			gtk_main_iteration();
-		settings.biblepane_width = GTK_WIDGET(widgets.vpaned)->allocation.width;	
-		
+		sync_windows();
+		settings.biblepane_width = GTK_WIDGET(widgets.vpaned)->allocation.width;
+
 	}
 }
 
@@ -599,7 +599,7 @@ static gboolean on_modules_list_button_release(GtkWidget *widget,
 		return FALSE;
 
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected, 2, &caption, 3, &mod, -1);
-	
+
 	//uncomment the following two lines if you want to see how it looks without
 	//triangls or plus symbols
 	//gtk_tree_view_set_show_expanders(sidebar.module_list, FALSE);
@@ -722,7 +722,7 @@ gboolean gui_verselist_button_release_event(GtkWidget * widget,
 
 	if (text) {
 		settings.displaySearchResults = TRUE;
-		main_entry_display(settings.show_previewer_in_sidebar 
+		main_entry_display(settings.show_previewer_in_sidebar
 				     ? sidebar.html_viewer_widget
 				     : widgets.html_previewer_text, //sidebar.html_widget,
 			      settings.sb_search_mod, text, key, TRUE);
@@ -779,7 +779,7 @@ static gboolean on_treeview_button_press_event(GtkWidget * widget,
 			g_free(verse_selected);
 		verse_selected = g_strdup_printf("sword:///%s", key);
 		main_url_handler(verse_selected, TRUE);
-	}	
+	}
 	switch (event->button) {
 	case 3:
 		gtk_menu_popup ((GtkMenu*)sidebar.menu_item_save_search, NULL, NULL, NULL, NULL, 2,
@@ -833,7 +833,8 @@ G_MODULE_EXPORT static void on_save_list_as_bookmarks_activate(GtkMenuItem * men
  *   void
  */
 
-static void on_open_in_dialog_activate(GtkMenuItem * menuitem,
+G_MODULE_EXPORT void
+on_open_in_dialog_activate(GtkMenuItem * menuitem,
 				       gpointer user_data)
 {
 	if (main_get_mod_type(buf_module) == PERCOM_TYPE)
@@ -846,7 +847,7 @@ static void on_open_in_dialog_activate(GtkMenuItem * menuitem,
 				  BOOK_EDITOR);
 	else
 		main_dialogs_open(buf_module, NULL);
-	
+
 	g_free(buf_module);
 	buf_module = NULL;
 }
@@ -868,7 +869,8 @@ static void on_open_in_dialog_activate(GtkMenuItem * menuitem,
  *   void
  */
 
-static void on_open_in_tab_activate(GtkMenuItem * menuitem,
+G_MODULE_EXPORT void
+on_open_in_tab_activate2(GtkMenuItem * menuitem,
 				    gpointer user_data)
 {
 	gui_open_module_in_new_tab(buf_module);
@@ -893,7 +895,8 @@ static void on_open_in_tab_activate(GtkMenuItem * menuitem,
  *   void
  */
 
-static void on_about2_activate(GtkMenuItem * menuitem,
+G_MODULE_EXPORT void
+on_about2_activate(GtkMenuItem * menuitem,
 			       gpointer user_data)
 {
 	gui_display_about_module_dialog(buf_module);
@@ -918,6 +921,12 @@ on_save_list_as_a_series_of_bookmarks_activate (GtkMenuItem * menuitem,
 }
 
 
+G_MODULE_EXPORT void
+on_export_verselist_activate (GtkMenuItem * menuitem,
+                                        gpointer user_data)
+{
+	gui_export_bookmarks_dialog((is_search_result?SEARCH_RESULTS_EXPORT:VERSE_LIST_EXPORT), list_of_verses);
+}
 
 /******************************************************************************
  * Name
@@ -940,46 +949,23 @@ GtkWidget *create_results_menu(void)
 	GtkWidget *menu;
 	gchar *glade_file;
 	GladeXML *gxml;
-	
+
 	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
 	g_return_val_if_fail ((glade_file != NULL), NULL);
-	
+
 	gxml = glade_xml_new (glade_file, "menu_verselist", NULL);
-		
+
 	g_free (glade_file);
 	g_return_val_if_fail ((gxml != NULL), NULL);
-	
+
 	menu = glade_xml_get_widget (gxml, "menu_verselist");
     	/* connect signals and data */
 	glade_xml_signal_autoconnect_full
 		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
-	
+
 	return menu;
 }
 
-
-static GnomeUIInfo menu_modules_uiinfo[] = {
-	{ /* 0 */
-	 GNOME_APP_UI_ITEM, N_("Open in a new tab"),
-	 N_("Open selected module in a new tab"),
-	 (gpointer) on_open_in_tab_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_FILENAME, NULL /* init'd in menu creation */,
-	 0, (GdkModifierType) 0, NULL},
-	{ /* 1 */
-	 GNOME_APP_UI_ITEM, N_("Open in a separate window"),
-	 N_("Open selected module in a separate ['dialog'] window"),
-	 (gpointer) on_open_in_dialog_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_FILENAME, NULL /* init'd in menu creation */,
-	 0, (GdkModifierType) 0, NULL},
-	{ /* 2 */
-	 GNOME_APP_UI_ITEM, N_("About"),
-	 N_("View information about the selected dialog"),
-	 (gpointer) on_about2_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_ABOUT,
-	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_END
-};
-
 /******************************************************************************
  * Name
  *   create_menu_modules
@@ -995,130 +981,87 @@ static GnomeUIInfo menu_modules_uiinfo[] = {
  * Return value
  *   void
  */
-
 static
-void create_menu_modules(void)
+GtkWidget* create_menu_modules(void)
 {
-	GtkWidget *menu_modules;
+	gchar *glade_file;
+	GladeXML *gxml;
 
-	/*
-	 * this is total magic.  set up menu before using it.
-	 * indices are direct from GnomeUIInfo above.
-	 */
-	if (!menu_modules_uiinfo[0].pixmap_info)
-		menu_modules_uiinfo[0].pixmap_info =
-		    image_locator("new_tab_button.png");
-	if (!menu_modules_uiinfo[1].pixmap_info)
-		menu_modules_uiinfo[1].pixmap_info =
-		    image_locator("dlg-un.png");
-	/* end magic */
+	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+	g_return_val_if_fail ((glade_file != NULL), NULL);
 
-	menu_modules = gtk_menu_new();
-	gnome_app_fill_menu(GTK_MENU_SHELL(menu_modules),
-			    menu_modules_uiinfo, NULL, FALSE, 0);
-	if (!settings.browsing)  
-		gtk_widget_hide (menu_modules_uiinfo[0].widget);
-	
-	gtk_menu_popup ((GtkMenu*)menu_modules, NULL, NULL, NULL, NULL, 2,
-		     			gtk_get_current_event_time());
-	// return menu_modules;
-    
+	gxml = glade_xml_new (glade_file, "menu_modules", NULL);
+
+	g_free (glade_file);
+	g_return_val_if_fail ((gxml != NULL), NULL);
+
+	GtkWidget *menu 	= glade_xml_get_widget (gxml, "menu_modules");
+	glade_xml_signal_autoconnect_full
+		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
+
+	gtk_menu_popup ((GtkMenu*)menu, NULL, NULL, NULL, NULL, 2,
+			gtk_get_current_event_time());
+
+	return menu;
 }
 
 
-void
+G_MODULE_EXPORT void
 on_simple_activate(GtkMenuItem *menuitem,
 		   gpointer    user_data)
 {
 	main_prayerlist_basic_create();
 }
 
-void
+G_MODULE_EXPORT void
 on_subject_activate(GtkMenuItem *menuitem,
 		    gpointer    user_data)
 {
 	main_prayerlist_subject_create();
 }
 
-void
+G_MODULE_EXPORT void
 on_monthly_activate(GtkMenuItem *menuitem,
 		    gpointer    user_data)
 {
 	main_prayerlist_monthly_create();
 }
 
-void
+G_MODULE_EXPORT void
 on_journal_activate(GtkMenuItem *menuitem,
 		    gpointer    user_data)
 {
 	main_prayerlist_journal_create();
 }
 
-void
+G_MODULE_EXPORT void
 on_outlined_topic_activate(GtkMenuItem *menuitem,
 			   gpointer    user_data)
 {
 	main_prayerlist_outlined_topic_create();
 }
 
-static GnomeUIInfo new_prayerlist_menu_uiinfo[] =
-{
-  {
-    GNOME_APP_UI_ITEM, N_("Simple"),
-    N_("Create a new simple prayer list"),
-    (gpointer) on_simple_activate, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, "gtk-edit",
-    0, (GdkModifierType) 0, NULL
-  },
-  {
-    GNOME_APP_UI_ITEM, N_("Subject"),
-    NULL,
-    (gpointer) on_subject_activate, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, "gnome-stock-text-bulleted-list",
-    0, (GdkModifierType) 0, NULL
-  },
-  {
-    GNOME_APP_UI_ITEM, N_("Monthly"),
-    N_("Create a new prayer list"),
-    (gpointer) on_monthly_activate, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, "gnome-stock-text-numbered-list",
-    0, (GdkModifierType) 0, NULL
-  },
-  {
-    GNOME_APP_UI_ITEM, N_("Daily Journal"),
-    N_("Create a new prayer list"),
-    (gpointer) on_journal_activate, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, "gnome-stock-text-numbered-list",
-    0, (GdkModifierType) 0, NULL
-  },
-  {
-    GNOME_APP_UI_ITEM, N_("Outlined Topic"),
-    N_("Create a new prayer list"),
-    (gpointer) on_outlined_topic_activate, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, "gnome-stock-text-numbered-list",
-    0, (GdkModifierType) 0, NULL
-  },
-  GNOMEUIINFO_END
-};
-
-static GnomeUIInfo menu_prayerlist_uiinfo[] =
-{
-  GNOMEUIINFO_MENU_NEW_SUBTREE (new_prayerlist_menu_uiinfo),
-  GNOMEUIINFO_END
-};
-
 GtkWidget *create_menu_prayerlist(void)
 {
 	GtkWidget *menu;
+	gchar *glade_file;
+	GladeXML *gxml;
 
-	menu = gtk_menu_new();
-	gnome_app_fill_menu(GTK_MENU_SHELL(menu),
-			    menu_prayerlist_uiinfo, NULL, FALSE, 0);
+	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+	g_return_val_if_fail ((glade_file != NULL), NULL);
+
+	gxml = glade_xml_new (glade_file, "menu_prayerlist", NULL);
+
+	g_free (glade_file);
+	g_return_val_if_fail ((gxml != NULL), NULL);
+
+	menu = glade_xml_get_widget (gxml, "menu_prayerlist");
+	glade_xml_signal_autoconnect_full
+		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
 	return menu;
+
 }
 
-
-
 void
 on_edit_activate(GtkMenuItem *menuitem,
 		 gpointer    user_data)
@@ -1126,47 +1069,23 @@ on_edit_activate(GtkMenuItem *menuitem,
 	editor_create_new(buf_module, NULL, BOOK_EDITOR);
 }
 
-static GnomeUIInfo menu_prayerlist_mod_uiinfo[] = {
-        { /* 0 */
-	 GNOME_APP_UI_ITEM, N_("Open in a new tab"),
-	 N_("Open selected module in a new tab"),
-	 (gpointer) on_open_in_tab_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_FILENAME, NULL /* init'd in menu creation */,
-	 0, (GdkModifierType) 0, NULL},
-	{ /* 1 */
-	 GNOME_APP_UI_ITEM, N_("Open in editor"),
-	 N_("Open selected module in a dialog"),
-	 (gpointer) on_open_in_dialog_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_FILENAME, NULL /* init'd in menu creation */,
-	 0, (GdkModifierType) 0, NULL},
-	{ /* 2 */
-	 GNOME_APP_UI_ITEM, N_("About"),
-	 N_("View information about the selected dialog"),
-	 (gpointer) on_about2_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_ABOUT,
-	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_END
-};
-
 GtkWidget *create_menu_prayerlist_mod(void)
 {
 	GtkWidget *menu;
+	gchar *glade_file;
+	GladeXML *gxml;
 
-	/*
-	 * this is total magic.  set up menu before using it.
-	 * indices are direct from GnomeUIInfo above.
-	 */
-	if (!menu_prayerlist_mod_uiinfo[0].pixmap_info)
-		menu_prayerlist_mod_uiinfo[0].pixmap_info =
-		    image_locator("new_tab_button.png");
-	if (!menu_prayerlist_mod_uiinfo[1].pixmap_info)
-		menu_prayerlist_mod_uiinfo[1].pixmap_info =
-		    image_locator("silk-edit-bookmarks.png");
-	/* end magic */
+	glade_file = gui_general_user_file ("xi-menus.glade", FALSE);
+	g_return_val_if_fail ((glade_file != NULL), NULL);
 
-	menu = gtk_menu_new();
-	gnome_app_fill_menu(GTK_MENU_SHELL(menu),
-			    menu_prayerlist_mod_uiinfo, NULL, FALSE, 0);
+	gxml = glade_xml_new (glade_file, "menu_prayerlist_mod", NULL);
+
+	g_free (glade_file);
+	g_return_val_if_fail ((gxml != NULL), NULL);
+
+	menu = glade_xml_get_widget (gxml, "menu_prayerlist_mod");
+	glade_xml_signal_autoconnect_full
+		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
 	return menu;
 }
 
@@ -1198,7 +1117,7 @@ static gboolean tree_key_press_cb(GtkWidget * widget,
 
 	GS_warning(("%d", event->keyval));
 	if (event) {
-				
+
 		switch (event->keyval) {
 		case 0xff0d:	/* "65293" */
 		case 0xff8d:	/* "65421" */
@@ -1213,18 +1132,14 @@ static gboolean tree_key_press_cb(GtkWidget * widget,
 
 		case 0x20:	/* "32" */
 			gui_open_passage_in_new_tab(key);
-			while (gtk_events_pending()) {
-				gtk_main_iteration();
-			}
+			sync_windows();
 			break;
 
 		case 0xffe1:	/* shift keys */
 		case 0xffe2:
 			GS_warning(("shift key pressed"));
 			shift_key_pressed =  TRUE;
-			while (gtk_events_pending()) {
-				gtk_main_iteration();
-			}
+			sync_windows();
 			break;
 
 		default:
@@ -1233,9 +1148,7 @@ static gboolean tree_key_press_cb(GtkWidget * widget,
 	}
 	g_free(key);
 
-	while (gtk_events_pending()) {
-		gtk_main_iteration();
-	}
+	sync_windows();
 
 	gtk_widget_grab_focus(sidebar.results_list);
 	return FALSE;
@@ -1261,7 +1174,6 @@ static gboolean tree_key_press_cb(GtkWidget * widget,
 static void create_search_results_page(GtkWidget * notebook)
 {
 	GtkWidget *scrolledwindow3;
-	GtkListStore *model;
 	GtkTreeSelection *selection;
 	sidebar.menu_item_save_search = create_results_menu();
 
@@ -1275,9 +1187,9 @@ static void create_search_results_page(GtkWidget * notebook)
 					    settings.shadow_type);
 
 	/* create list model */
-	model = gtk_list_store_new(1, G_TYPE_STRING);
+	model_verselist = gtk_list_store_new(1, G_TYPE_STRING);
 
-	sidebar.results_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(model));
+	sidebar.results_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(model_verselist));
 	gtk_widget_show(sidebar.results_list);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow3), sidebar.results_list);
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(sidebar.results_list), TRUE);
@@ -1287,9 +1199,7 @@ static void create_search_results_page(GtkWidget * notebook)
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(sidebar.results_list));
 
-	//gnome_popup_menu_attach(menu, sidebar.results_list, NULL);
-	//gnome_app_install_menu_hints(GNOME_APP(widgets.app), results_menu_uiinfo);
-	//gtk_menu_attach_to_widget ((GtkMenu*)menu, sidebar.results_list,NULL);	
+
 	g_signal_connect((gpointer) sidebar.results_list,
 			 "key_press_event",
 			 G_CALLBACK(tree_key_press_cb), NULL);
@@ -1345,7 +1255,7 @@ static gboolean paned_button_release_event(GtkWidget * widget,
 
 void gui_show_previewer_in_sidebar(gint choice)
 {
-	if(choice) {	   
+	if (choice) {
 		gtk_widget_show(widgets.box_side_preview);
 #ifdef USE_GTKMOZEMBED
 		gtk_widget_show (widgets.box_side_preview);
@@ -1366,6 +1276,7 @@ void gui_show_previewer_in_sidebar(gint choice)
 				       settings.biblepane_hight);
 	}
 	main_set_previewer_widget(choice);
+	main_init_previewer();
 }
 
 
@@ -1393,38 +1304,45 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	GtkWidget *title_label = NULL;
 #ifdef USE_GTKMOZEMBED
 	GtkWidget *frame;
+	GtkWidget *eventbox;
 #else
 	GtkWidget *scrolledwindow;
 #endif
 
 	GtkWidget *table2;
-	
+
 	vbox1 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox1);
 
 	widgets.paned_sidebar = gtk_vpaned_new();
-	gtk_paned_pack1 (GTK_PANED (paned), widgets.paned_sidebar, FALSE, TRUE);	
-	gtk_widget_show (widgets.paned_sidebar);	
+	gtk_paned_pack1 (GTK_PANED (paned), widgets.paned_sidebar, FALSE, TRUE);
+	gtk_widget_show (widgets.paned_sidebar);
 	gtk_paned_pack1 (GTK_PANED (widgets.paned_sidebar), vbox1, FALSE, TRUE);
-	widgets.box_side_preview = gtk_vbox_new(FALSE, 0);	
-	gtk_paned_pack2 (GTK_PANED (widgets.paned_sidebar), 
+	widgets.box_side_preview = gtk_vbox_new(FALSE, 0);
+	gtk_paned_pack2 (GTK_PANED (widgets.paned_sidebar),
 			widgets.box_side_preview, FALSE, TRUE);
+	gtk_container_set_border_width(GTK_CONTAINER(widgets.box_side_preview), 2);
 	g_signal_connect (GTK_OBJECT (widgets.paned_sidebar),
 			"button_release_event",
 			G_CALLBACK (paned_button_release_event),
 			(gchar *) "paned_sidebar");
 	widgets.shortcutbar = widgets.paned_sidebar;
-	
+
 #ifdef USE_GTKMOZEMBED
 	frame = gtk_frame_new(NULL);
 	gtk_widget_show(frame);
 	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-	gtk_box_pack_start(GTK_BOX(widgets.box_side_preview), frame, 
+	gtk_box_pack_start(GTK_BOX(widgets.box_side_preview), frame,
 				TRUE, TRUE,
 			   	0);
-	//widgets.html_previewer
+
+
+	eventbox = gtk_event_box_new();
+	gtk_widget_show(eventbox);
+	gtk_container_add(GTK_CONTAINER(frame), eventbox);
+
 	sidebar.html_viewer_widget = GTK_WIDGET(gecko_html_new(NULL, FALSE, SB_VIEWER_TYPE));//embed_new(VIEWER_TYPE);
-	gtk_container_add(GTK_CONTAINER(frame), sidebar.html_viewer_widget);
+	gtk_container_add(GTK_CONTAINER(eventbox), sidebar.html_viewer_widget);
 #else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
