@@ -29,7 +29,7 @@
 #include <string.h>
 #include <assert.h>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "gui/utilities.h"
 #include "gui/preferences_dialog.h"
@@ -44,14 +44,121 @@
 #include "main/configs.h"
 #include "main/sword.h"
 #include "main/url.hh"
+#include "main/xml.h"
+
+#ifdef WIN32
+#undef DATADIR
+#include <windows.h>
+#include <shellapi.h>
+#endif /* WIN32 */
 
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif /* WIN32 */
 #else
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/htmltypes.h>
 #endif /* USE_GTKMOZEMBED */
 
+#include <gsf/gsf-utils.h>
+#include <gsf/gsf-outfile-zip.h>
+#include <gsf/gsf-output-stdio.h>
+#include <gsf/gsf-output.h>
+#include <gsf/gsf-input.h>
+#include <gsf/gsf-outfile.h>
+#include <gsf/gsf-input-stdio.h>
+
+#include "gui/debug_glib_null.h"
+
+
+/******************************************************************************
+ * Name
+ *   sync_windows
+ *
+ * Synopsis
+ *   void sync_windows()
+ *
+ * Description
+ *   forces GTK window updates iff the block flag is unset.
+ *   this flag is only checked here; set/unset by others.
+ *
+ * Return value
+ *   void
+ */
+
+gint stop_window_sync = 0;
+
+void
+sync_windows()
+{
+	if (stop_window_sync == 0) {
+		while (gtk_events_pending())
+			gtk_main_iteration();
+	}
+}
+
+/******************************************************************************
+ * Name
+ *  utilities_parse_treeview
+ *
+ * Synopsis
+ *   #include "gui/bookmarks_menu.h"
+ *
+ *   void utilities_parse_treeview(xmlNodePtr parent, GtkTreeIter * tree_parent)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+void utilities_parse_treeview(xmlNodePtr parent, GtkTreeIter * tree_parent, GtkTreeModel *model)
+{
+	static xmlNodePtr cur_node;
+	GtkTreeIter child;
+	gchar *caption = NULL;
+	gchar *key = NULL;
+	gchar *module = NULL;
+	gchar *mod_desc = NULL;
+	gchar *description = NULL;
+
+	gtk_tree_model_iter_children(GTK_TREE_MODEL(model), &child,
+                                             tree_parent);
+
+	do {
+		gtk_tree_model_get(GTK_TREE_MODEL(model), &child,
+			   		2, &caption,
+					3, &key,
+					4, &module,
+					5, &mod_desc,
+					6, &description,
+					-1);
+		if (gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model),
+							&child)) {
+			cur_node = xml_add_folder_to_parent(parent,
+							caption);
+			utilities_parse_treeview(cur_node, &child, model);
+
+		}
+		else
+			xml_add_bookmark_to_parent(parent,
+						description,
+						key,
+						module,
+						mod_desc);
+
+		g_free(caption);
+		g_free(key);
+		g_free(module);
+		g_free(mod_desc);
+		g_free(description);
+	} while (gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &child));
+}
+
 
 gint gui_of2tf(const gchar * on_off)
 {
@@ -74,9 +181,7 @@ void gui_reassign_strdup(gchar **where, gchar *what)
 void gui_set_progressbar_text(GtkWidget * pb, gchar * text)
 {
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(pb), text);
-	while (gtk_events_pending()) {
-		gtk_main_iteration();
-	}  
+	sync_windows();
 }
 
 void gui_set_statusbar (const gchar * message)
@@ -86,21 +191,19 @@ void gui_set_statusbar (const gchar * message)
 	context_id =
 		gtk_statusbar_get_context_id (GTK_STATUSBAR (widgets.appbar),
                                        		message);
-	
+
 	context_id =
 		gtk_statusbar_push (GTK_STATUSBAR(widgets.appbar),
                                     context_id,
                                     message);
 	GS_message (("context_id: %d\nmessage: %s",context_id,message));
-	
+
 }
 
 void gui_set_progressbar_fraction(GtkWidget * pb, gdouble fraction)
 {
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pb), fraction);
-	while (gtk_events_pending()) {
-		gtk_main_iteration();
-	}  
+	sync_windows();
 }
 
 
@@ -112,13 +215,13 @@ void gui_set_combo_index(GtkWidget * combo, gint index)
 
 void gui_clear_combo(GtkWidget * combo)
 {
-	GtkTreeModel* model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));	
+	GtkTreeModel* model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
 	gtk_list_store_clear(GTK_LIST_STORE(model));
 }
 
 void gui_add_item_to_combo(GtkWidget * combo, gchar * item)
 {
-	GtkTreeIter iter;	
+	GtkTreeIter iter;
 	GtkTreeModel* model = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
 	gtk_list_store_append(GTK_LIST_STORE(model), &iter);
 	gtk_list_store_set(GTK_LIST_STORE(model), &iter, 0, (gchar*)item, -1);
@@ -126,10 +229,10 @@ void gui_add_item_to_combo(GtkWidget * combo, gchar * item)
 
 
 /*
- * taken from galeon 
+ * taken from galeon
  * glade_signal_connect_func: used by glade_xml_signal_autoconnect_full
  */
-void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj, 
+void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj,
 			   const gchar *signal_name, const gchar *signal_data,
 			   GObject *conn_obj, gboolean conn_after,
 			   gpointer user_data)
@@ -147,7 +250,7 @@ void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj,
 
 	/*g_print( "glade_signal_connect_func: cb_name = '%s', signal_name = '%s', signal_data = '%s'\n",
 	  cb_name, signal_name, signal_data ); */
-	
+
 	if (g_module_symbol (mod_self, cb_name, &handler_func))
 	{
 		/* found callback */
@@ -156,14 +259,14 @@ void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj,
 			if (conn_after)
 			{
 				g_signal_connect_object
-                                        (obj, signal_name, 
+                                        (obj, signal_name,
                                          handler_func, conn_obj,
                                          G_CONNECT_AFTER);
 			}
 			else
 			{
 				g_signal_connect_object
-                                        (obj, signal_name, 
+                                        (obj, signal_name,
                                          handler_func, conn_obj,
                                          G_CONNECT_SWAPPED);
 			}
@@ -172,19 +275,19 @@ void gui_glade_signal_connect_func (const gchar *cb_name, GObject *obj,
 		{
 			/* no conn_obj; use standard connect */
 			gpointer data = NULL;
-			
+
 			data = user_data;
-			
+
 			if (conn_after)
 			{
 				g_signal_connect_after
-					(obj, signal_name, 
+					(obj, signal_name,
 					 handler_func, data);
 			}
 			else
 			{
 				g_signal_connect
-					(obj, signal_name, 
+					(obj, signal_name,
 					 handler_func, data);
 			}
 		}
@@ -210,7 +313,7 @@ gchar * gui_general_user_file (const char *fname, gboolean critical)
 	gchar *alternative[10];
 	gchar *file;
 	gint i;
-	
+
 	/* create cache hash table if it doesnt already exist */
 	if (already_found == NULL)
 	{
@@ -233,13 +336,13 @@ gchar * gui_general_user_file (const char *fname, gboolean critical)
 	}
 
 	/* try the default */
-	file = g_build_filename(getenv(HOMEVAR), ".xiphos", fname, NULL);
-	
+	file = g_build_filename(g_getenv(HOMEVAR), ".xiphos", fname, NULL);
+
 	/* success? */
 	if (g_file_test (file, G_FILE_TEST_EXISTS))
 	{
 		/* add it to the set of found files */
-		g_hash_table_insert (already_found, g_strdup (fname), 
+		g_hash_table_insert (already_found, g_strdup (fname),
 				     g_strdup (file));
 		return file;
 	}
@@ -248,7 +351,7 @@ gchar * gui_general_user_file (const char *fname, gboolean critical)
 	/* specify alternate locations in order of precedence */
 	i = 0;
 	alternative[i++] = g_strdup (fname);
-#ifdef MAINTAINER_MODE
+#ifdef DEBUG
 	GS_message(("MAINTAINER_MODE"));
 	/* generally only developers have any use for these */
 	alternative[i++] = g_build_filename("..", fname, NULL);
@@ -256,17 +359,21 @@ gchar * gui_general_user_file (const char *fname, gboolean critical)
 	alternative[i++] = g_build_filename("..", "ui", fname, NULL);
 	alternative[i++] = g_build_filename("..", "..", "ui", fname, NULL);
 #endif
+#ifdef WIN32
+	alternative[i++] = g_build_filename(xiphos_win32_get_subdir("share"),
+					    "xiphos", fname, NULL);
+#else
 	alternative[i++] = g_build_filename("..", "share", "xiphos", fname, NULL);
-	/* above line for WIN32, mostly. */
+#endif
 	alternative[i++] = g_build_filename(SHARE_DIR, fname, NULL);
 	alternative[i++] = NULL;  /* NULL terminator needed */
-	
+
 	/* select one of the alternatives */
 	file = NULL;
-	
+
 	for (i = 0; alternative[i] != NULL; i++)
 	{
-		if (file == NULL &&  g_file_test (alternative[i], G_FILE_TEST_EXISTS)) 
+		if (file == NULL &&  g_file_test (alternative[i], G_FILE_TEST_EXISTS))
 		{
 			file = alternative[i];
 		}
@@ -295,7 +402,7 @@ gchar * gui_general_user_file (const char *fname, gboolean critical)
 		}
 
 		/* add it to the set of found files */
-		g_hash_table_insert (already_found, g_strdup (fname), 
+		g_hash_table_insert (already_found, g_strdup (fname),
 				     g_strdup (file));
 	}
 	/* if nothing then theres an error */
@@ -338,8 +445,8 @@ language_add_folders(GtkTreeModel * model,
 	(void) gtk_tree_model_iter_children(model, &iter_iter, &iter);
 	for (j = 0; languages[j]; ++j) {
 		gtk_tree_store_append(GTK_TREE_STORE(model), &child_iter, &iter);
-		gtk_tree_store_set(GTK_TREE_STORE(model), 
-				   &child_iter, 
+		gtk_tree_store_set(GTK_TREE_STORE(model),
+				   &child_iter,
 				   0,
 				   ((g_utf8_validate(languages[j], -1, NULL))
 				    ? languages[j]
@@ -360,7 +467,7 @@ language_add_folders(GtkTreeModel * model,
  *		      GtkTreeIter iter, gchar * module_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -369,9 +476,9 @@ static void add_module_to_prayerlist_folder(GtkTreeModel * model,
 					  GtkTreeIter iter,
 					  gchar * module_name)
 {
-	
+
 	GtkTreeIter child_iter;
-	
+
 	gtk_tree_store_append(GTK_TREE_STORE(model),
 			      &child_iter, &iter);
 	gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
@@ -390,7 +497,7 @@ static void add_module_to_prayerlist_folder(GtkTreeModel * model,
  *		      GtkTreeIter iter, gchar * language, gchar * module_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -422,8 +529,8 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &child_iter, &iter_iter);
 			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, 
-					   0, (gchar *) module_name, 
+					   &child_iter,
+					   0, (gchar *) module_name,
 					   -1);
 			g_free(str_data);
 			return;
@@ -443,7 +550,7 @@ static void add_module_to_language_folder(GtkTreeModel * model,
  *   void load_module_tree(GtkWidget * tree)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -466,7 +573,7 @@ void gui_load_module_tree(GtkWidget * tree)
 
 	store = gtk_tree_store_new(1, G_TYPE_STRING);
 	gtk_tree_store_clear(store);
-	
+
 	/*  Biblical Texts folders */
 	gtk_tree_store_append(store, &text, NULL);
 	gtk_tree_store_set(store, &text, 0, _("Biblical Texts"), -1);
@@ -496,9 +603,9 @@ void gui_load_module_tree(GtkWidget * tree)
 	gtk_tree_store_set(store, &image, 0, _("Images"), -1);
 
 	/*  Prayer lists folder */
-	if(settings.prayerlist) {
+	if (settings.prayerlist) {
 		gtk_tree_store_append(store, &prayerlist, NULL);
-		gtk_tree_store_set(store, &prayerlist, 0, _("Prayer List/Journal"));
+		gtk_tree_store_set(store, &prayerlist, 0, _("Prayer List/Journal"), -1);
 	}
 
 	tmp = mod_mgr_list_local_modules(settings.path_to_mods, TRUE);
@@ -569,7 +676,7 @@ void gui_load_module_tree(GtkWidget * tree)
 	g_list_free(tmp);
 
 	/* prayer list folders */
-	if(settings.prayerlist) {
+	if (settings.prayerlist) {
 		tmp = get_list(PRAYER_LIST);
 		while (tmp != NULL) {
 			add_module_to_prayerlist_folder(GTK_TREE_MODEL(store),
@@ -591,10 +698,10 @@ void gui_load_module_tree(GtkWidget * tree)
  * Synopsis
  *   #include ".h"
  *
- *   MOD_FONT * get_font(gchar *mod_name)	
+ *   MOD_FONT * get_font(gchar *mod_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -616,7 +723,7 @@ MOD_FONT *get_font(gchar * mod_name)
 	mf->new_gdk_font = NULL;
 	mf->new_font_size = NULL;
 	mf->no_font = 0;
-	
+
 	mf->old_font = get_conf_file_item(file, mod_name, "Font");
 	mf->old_gdk_font = get_conf_file_item(file, mod_name, "GdkFont");
 	mf->old_font_size = get_conf_file_item(file, mod_name, "Fontsize");
@@ -647,21 +754,21 @@ MOD_FONT *get_font(gchar * mod_name)
 			mf->old_font_size = g_strdup("+0");
 		}
 	}
-	
+
 	return mf;
 }
 
 /******************************************************************************
  * Name
- *  
+ *
  *
  * Synopsis
  *   #include ".h"
  *
- *   	
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -669,10 +776,10 @@ MOD_FONT *get_font(gchar * mod_name)
 
 void free_font(MOD_FONT *mf)
 {
-	
-	if(mf->old_font) g_free(mf->old_font);
-	if(mf->old_gdk_font) g_free(mf->old_gdk_font);
-	if(mf->old_font_size) g_free(mf->old_font_size);
+
+	if (mf->old_font) g_free(mf->old_font);
+	if (mf->old_gdk_font) g_free(mf->old_gdk_font);
+	if (mf->old_font_size) g_free(mf->old_font_size);
 	//mf->new_font = NULL;
 	//mf->new_gdk_font = NULL;
 	//mf->new_font_size = NULL;
@@ -692,154 +799,19 @@ void free_font(MOD_FONT *mf)
  *   remove line feeds so we can display string in appbar
  *
  * Return value
- *   gchar * 
+ *   gchar *
  */
- 
+
 gchar * remove_linefeeds(gchar * buf)
-{	
+{
 	gchar * key = NULL;
-	
+
 	key = g_strdelimit(buf, "\n", ' ');
-	
+
 	return (key ? g_strdup(key) : NULL);
-		
+
 }
 
-
-/******************************************************************************
- * Name
- *   gui_add_item2gnome_menu
- *
- * Synopsis
- *   #include "gui/utilities.h
- *
- *   void gui_add_item2gnome_menu(GtkWidget * MainFrm, gchar * itemname, 
- *	gchar * itemdata, gchar * menuname, GCallback mycallback)
- *
- * Description
- *   adds an item to the main menu bar
- *
- * Return value
- *   void
- */
-
-void gui_add_item2gnome_menu(GtkWidget * MainFrm, gchar * itemname, 
-	gchar * itemdata, gchar * menuname, GCallback mycallback)
-{
-	GnomeUIInfo *menuitem;
-
-	menuitem = g_new(GnomeUIInfo, 2);
-	menuitem->type = GNOME_APP_UI_ITEM;
-	menuitem->moreinfo = (gpointer) mycallback;
-	menuitem->user_data = itemdata;
-	menuitem->label = itemname;
-	menuitem->pixmap_type = GNOME_APP_PIXMAP_STOCK;
-	menuitem->pixmap_info = GNOME_STOCK_BOOK_OPEN;
-	menuitem->accelerator_key = 0;
-	menuitem[1].type = GNOME_APP_UI_ENDOFINFO;
-	gnome_app_insert_menus_with_data(GNOME_APP(MainFrm), menuname,
-					 menuitem, NULL);
-}
-
-
-/******************************************************************************
- * Name
- *   gui_add_separator2menu
- *
- * Synopsis
- *   #include "gui/utilities.h
- *
- *   void gui_add_separator2menu(GtkWidget * MainFrm, gchar * subtreelabel)
- *
- * Description
- *   add separator line to menu
- *
- * Return value
- *   void
- */
-
-void gui_add_separator2menu(GtkWidget * MainFrm, gchar * subtreelabel)
-{
-	GnomeUIInfo *bookmarkitem;
-	bookmarkitem = g_new(GnomeUIInfo, 2);
-	bookmarkitem->type = GNOME_APP_UI_SEPARATOR;
-	bookmarkitem->pixmap_type = GNOME_APP_PIXMAP_NONE;
-	bookmarkitem->accelerator_key = 0;
-	bookmarkitem[1].type = GNOME_APP_UI_ENDOFINFO;
-	gnome_app_insert_menus_with_data(GNOME_APP(MainFrm), subtreelabel,
-					 bookmarkitem, NULL);
-	//g_free(bookmarkitem); 
-}
-
-
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "gui/utilities.h
- *
- *   void add_mods_to_menus(GList * modlist, gchar * menu,
- *				GCallback callback) 
- *
- * Description
- *   add a list of modules to a menu
- *
- * Return value
- *   void
- */
-
-void gui_add_mods_to_menus(GList * modlist, gchar * menu,
-				GCallback callback) 
-{	
-	gchar	
-		view_remember_last_item[80];
-	//gint	i = 0;
-	GList 	*tmp = NULL;
-
-	sprintf(view_remember_last_item,"%s", menu);
-	
-	
-	tmp = modlist;
-	while (tmp != NULL) {	
-		gui_add_item2gnome_menu(widgets.app, 
-			(gchar *) tmp->data, 
-			(gchar *) tmp->data,
-			view_remember_last_item, 
-			callback);
-		/* remember last item - so next item will be placed below it */
-		sprintf(view_remember_last_item,"%s%s", 
-				menu, 
-				(gchar *) tmp->data);	
-		//++i;
-		tmp = g_list_next(tmp);	
-	}
-	g_list_free(modlist);
-}			
-
-
-/******************************************************************************
- * Name
- *   gui_remove_menu_items
- *
- * Synopsis
- *   #include "gui/utilities.h
- *
- *   void gui_remove_menu_items(gchar * startitem, gint numberofitems)
- *
- * Description
- *   remove a number(numberofitems) of items form a menu or submenu(startitem)
- *
- * Return value
- *   void
- */
-
-void gui_remove_menu_items(gchar * startitem, gint numberofitems)
-{				
-	gnome_app_remove_menus(GNOME_APP(widgets.app), startitem,
-			       numberofitems);
-}			
-
 /******************************************************************************
  * Name
  *  add_mods_2_gtk_menu
@@ -851,7 +823,7 @@ void gui_remove_menu_items(gchar * startitem, gint numberofitems)
 				GCallback callback)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -862,21 +834,21 @@ void gui_add_mods_2_gtk_menu(gint mod_type, GtkWidget * menu,
 {
 	GList 	*tmp = NULL;
 	GtkWidget * item;
-	
+
     	if (mod_type == -1) return;
-    
+
 	tmp = get_list(mod_type);
-	while (tmp != NULL) {	
+	while (tmp != NULL) {
 		item =
 		    gtk_menu_item_new_with_label((gchar *) tmp->data);
 		gtk_widget_show(item);
 		g_signal_connect(GTK_OBJECT(item), "activate",
 				   G_CALLBACK
 				   (callback),
-				   (gchar *) tmp->data);		
-		gtk_container_add(GTK_CONTAINER(menu), item); 
-		tmp = g_list_next(tmp);	
-	}	
+				   (gchar *) tmp->data);
+		gtk_container_add(GTK_CONTAINER(menu), item);
+		tmp = g_list_next(tmp);
+	}
 }
 
 /******************************************************************************
@@ -894,7 +866,7 @@ void gui_add_mods_2_gtk_menu(gint mod_type, GtkWidget * menu,
  *   A numeric character reference (NCR) is a common markup construct used in html
  *   pages. It consists of a short sequence of characters that represent a single
  *   character from the Universal Character Set (UCS) of Unicode.
- *   
+ *
  *   NCR markup : &#<unicode-value>;  ex: &#233;
  *
  * Return value
@@ -919,7 +891,7 @@ ncr_to_utf8(gchar * text)
 		unicode = 0;
 		for (ncr = ncr + 2;			// just past "&#"
 		     (*ncr != '\0') && (*ncr >= '0') && (*ncr <='9');
-		     ncr++) 
+		     ncr++)
 			unicode = (unicode * 10) + ((*ncr) - '0');
 
 		// converts unicode char to utf8
@@ -953,7 +925,7 @@ void reading_selector(char *modname,
 	gchar *url;
 	gboolean primary = 0, secondary = 0, all = 0;
     	gboolean is_dialog = (dialog ? 1 : 0);
-    
+
 	switch ((int) GPOINTER_TO_INT(user_data))
 	{
 	case 0:
@@ -978,9 +950,9 @@ void reading_selector(char *modname,
 	main_save_module_options(modname, "All Readings", all, is_dialog);
 	if (is_dialog)
 		main_dialogs_url_handler(dialog, url, TRUE);
-	else 	    
+	else
 		main_url_handler(url, TRUE);
-			      
+
 	g_free(url);
 }
 
@@ -995,7 +967,7 @@ struct language_set {
 
 /* one-shot setup during initialization. */
 void
-language_init()
+language_init(void)
 {
 	int i;
 	for (i = 0; i < N_LANGSET_MODTYPES; ++i) {
@@ -1084,7 +1056,7 @@ language_make_list(GList *modlist,
 	/* append */
 	while (modlist != NULL) {
 		info = (MOD_MGR *) modlist->data;
- 
+
 		/* mod.mgr: special extra lists */
 		if ((update != NULL) && (uninstalled != NULL)) {
 			if (!info->installed) {
@@ -1153,13 +1125,12 @@ language_make_list(GList *modlist,
  * caller must free the returned string.
  */
 char *
-image_locator(char *image)
+image_locator(const char *image)
 {
 #ifndef WIN32
 	return g_strdup_printf("%s/%s", PACKAGE_PIXMAPS_DIR, image);
 #else
-	gchar d[PATH_MAX+2];
-	return g_build_filename(getcwd(d, PATH_MAX), "..", "share",
+	return g_build_filename(xiphos_win32_get_subdir("share"),
 				"pixmaps", "xiphos", image, NULL);
 #endif /* WIN32 */
 }
@@ -1183,18 +1154,23 @@ pixmap_finder(char *image)
  * get a pixbuf from specified file.
  */
 GdkPixbuf *
-pixbuf_finder(char *image, GError **error)
+pixbuf_finder(const char *image, int size, GError **error)
 {
 	GdkPixbuf *p;
 	char *image_file;
 
 	image_file = image_locator(image);
-	p = gdk_pixbuf_new_from_file(image_file, error);
+	if (size == 0)
+		p = gdk_pixbuf_new_from_file(image_file, error);
+	else
+		p = gdk_pixbuf_new_from_file_at_scale (image_file,
+					       size, size,
+					       TRUE,
+					       error);
 	g_free(image_file);
 	return p;
 }
 
-
 //
 // utility function to write out HTML.
 //
@@ -1213,13 +1189,14 @@ HtmlOutput(char *text,
 	gecko_html_open_stream(html,"text/html");
 #else
 	GtkHTML *html = GTK_HTML(gtkText);
-	PangoContext* pc = gtk_widget_create_pango_context(gtkText);
+	PangoContext* pc = gtk_widget_get_pango_context(gtkText);
 	PangoFontDescription *desc = pango_context_get_font_description(pc);
+
 	pango_font_description_set_family(
 	    desc, ((mf && mf->old_font) ? mf->old_font : "Serif"));
 	gtk_widget_modify_font(gtkText, desc);
+
 	GtkHTMLStream *stream = gtk_html_begin(html);
-	//GtkHTMLStreamStatus status;
 	gboolean was_editable = gtk_html_get_editable(html);
 	if (was_editable)
 		gtk_html_set_editable(html, FALSE);
@@ -1240,17 +1217,223 @@ HtmlOutput(char *text,
 		len -= write_size;
 	}
 
+	/* use anchor if asked, but if so, special anchor takes priority. */
 #ifdef USE_GTKMOZEMBED
 	gecko_html_close(html);
-	if (anchor)
-		gecko_html_jump_to_anchor(html, anchor);
+	if (anchor || settings.special_anchor)
+		gecko_html_jump_to_anchor(html, (settings.special_anchor
+						 ? settings.special_anchor
+						 : anchor));
 #else
 	gtk_html_end(html, stream, GTK_HTML_STREAM_OK);
 	gtk_html_set_editable(html, was_editable);
-	if (anchor)
-		gtk_html_jump_to_anchor(html, anchor);
+	if (anchor || settings.special_anchor)
+		gtk_html_jump_to_anchor(html, (settings.special_anchor
+					       ? settings.special_anchor
+					       : anchor));
 	gtk_html_flush(html);
 #endif
+
+	/* the special anchor gets exactly one use. */
+	settings.special_anchor = NULL;
+}
+
+void set_window_icon (GtkWindow *window)
+{
+	gchar *imagename;
+	GdkPixbuf *pixbuf;
+
+	imagename = image_locator("xiphos-x-16.png");
+	pixbuf = gdk_pixbuf_new_from_file (imagename, NULL);
+	g_free (imagename);
+	gtk_window_set_icon (window, pixbuf);
+
+}
+
+/**************************************************************************
+ * Name
+ *  xiphos_open_default
+ *
+ * Synopsis
+ *  #include "glib.h"
+ *  #include <gnome.h>
+ *  #include <windows.h>
+ *  #include <shellapi.h>
+ *
+ * xiphos_open_default (gchar *file)
+ *
+ * Description
+ *  this is a generic "open anything with the default program" function;
+ *  on Windows, it uses the ShellExecuteW API (more robust than the gnome
+ *  or gtk implementations on Windows)
+ *  on *nix, it uses gnome_url_show; in the future, this could be changed
+ *  to gtk_show_uri as gnome_url_show is deprecated
+ *
+ * Return value
+ *   void
+ */
+gboolean xiphos_open_default (const gchar *file)
+{
+#ifdef WIN32
+	gunichar2 *w_file;
+	gint rt;
+	w_file = g_utf8_to_utf16(file, -1, NULL, NULL, NULL);
+	GS_message(("opening file %ls", w_file));
+	rt = (gint)ShellExecuteW(NULL, L"open", w_file, NULL, NULL, SW_SHOWDEFAULT);
+	return rt > 32;
+
+#else
+	GError *error = NULL;
+	gtk_show_uri (NULL, file, gtk_get_current_event_time(), &error);
+	if (error != NULL) {
+		GS_warning(("%s", error->message));
+		g_error_free (error);
+		return FALSE;
+	}
+	else
+		return TRUE;
+#endif
+}
+
+/**
+ * xiphos_win32_get_subdir
+ * @subdir: a #gchar, the name of the subdir desired
+ *
+ * get the full path of the subdir; for instance, 'bin'
+ * would return something like C:/Program Files/Crosswire/Xiphos/bin
+ *
+ * Since 3.1.2
+ */
+#ifdef WIN32
+gchar* xiphos_win32_get_subdir(const gchar *subdir)
+{
+	gchar *ret_dir = g_win32_get_package_installation_directory_of_module(NULL);
+	ret_dir = g_strconcat(ret_dir, "\0", NULL);
+	ret_dir = g_build_filename(ret_dir, subdir, NULL);
+	return ret_dir;
+}
+#endif
+
+/**
+ * archive_addfile
+ * @output: a #GsfOutfile, the parent of the desired child
+ * @file: a #gchar, the on disk path of the file to add
+ * @name: a #gchar, the name (without path) of the file to add
+ *
+ * add a single file to the #GsfOutfile
+ *
+ * Since 3.1.2
+ */
+void archive_addfile(GsfOutfile *output, const gchar *file, const gchar *name)
+{
+	GsfInput *inputchild = NULL;
+	GsfOutput *outputchild = NULL;
+
+	inputchild = GSF_INPUT(gsf_input_stdio_new(file, NULL));
+	outputchild = gsf_outfile_new_child(output, name, FALSE);
+	gsf_input_copy(inputchild, outputchild);
+	gsf_output_close(outputchild);
+	g_object_unref(inputchild);
+	g_object_unref(outputchild);
+}
+
+/**
+ * archive_adddir
+ * @output: a #GsfOutfile, the parent of the desired child
+ * @path: a #gchar, the on disk path of the desired child directory
+ * @name: a #gchar, the name (without path) of the desired child dir
+ *
+ * add a child directory and all subdirs and files to the GsfOutfile;
+ * recursive
+ *
+ * Since 3.1.2
+ */
+void archive_adddir(GsfOutfile *output, gchar *path, const gchar *name)
+{
+	GDir *dir;
+	const gchar *file;
+	gchar *complete_file;
+	GsfOutfile *child;
+
+	child = GSF_OUTFILE(gsf_outfile_new_child(output, name, TRUE));
+	dir = g_dir_open(path, 0, NULL);
+	while ((file = g_dir_read_name(dir))) {
+		complete_file = g_build_filename(path, file, NULL);
+		if (g_file_test(complete_file, G_FILE_TEST_IS_DIR))
+			archive_adddir(GSF_OUTFILE(child), complete_file, file);
+		else
+			archive_addfile(GSF_OUTFILE(child), complete_file, file);
+	}
+	g_dir_close(dir);
+}
+
+
+/**
+ * xiphos_create_archive
+ * @conf_file: a #gchar with the location of the module's .conf
+ * @datapath: a #gchar with the location of the module's data
+ * @zip: a #gchar with the name of the zip file
+ * @destination: #gchar with the location to store the zip
+ *
+ * archive the specified module in the specified location
+ *
+ * Since 3.1.2
+ */
+void xiphos_create_archive(gchar* conf_file, gchar* datapath, gchar *zip,
+			   const gchar *destination)
+{
+	GsfOutfile *outputfile;
+	GsfOutput *output;
+	GsfOutfile *tmp;
+	gchar** path;
+	gchar* moddirname;
+	GString *modpath;
+	int i;
+	gsf_init();
+
+	/* the module dir is the last part of the path */
+	path = g_strsplit(datapath, "/", -1);
+	moddirname = g_strdup(path[g_strv_length(path) - 1]);
+
+	/* create a relative path without preceding "." */
+	/* or the trailing dir name */
+	modpath = g_string_new(NULL);
+	for (i = 1; i <= (g_strv_length(path) - 2); i++)
+	{
+		modpath = g_string_append(modpath, path[i]);
+		if (i < g_strv_length(path) -2) /* avoid a trailing / */
+			modpath = g_string_append(modpath, "/");
+	}
+
+	/* open zip file for writing */
+	output = gsf_output_stdio_new(zip, NULL);
+	outputfile = gsf_outfile_zip_new(output, NULL);
+
+	/* add the module directory */
+	tmp = GSF_OUTFILE(gsf_outfile_new_child(outputfile, modpath->str, TRUE));
+
+	/* add all data files */
+	archive_adddir(tmp,
+		       g_build_filename(destination, datapath, NULL),
+		       moddirname);
+	gsf_output_close(GSF_OUTPUT(tmp));
+	g_object_unref(tmp);
+
+	/* add conf file */
+	tmp = GSF_OUTFILE(gsf_outfile_new_child(outputfile, "mods.d", TRUE));
+	archive_addfile(tmp,
+			g_build_filename(destination, "mods.d", conf_file, NULL),
+			conf_file);
+
+	/* cleanup */
+	gsf_output_close(GSF_OUTPUT(outputfile));
+	gsf_output_close(output);
+	g_object_unref(tmp);
+	g_object_unref(outputfile);
+	g_object_unref(output);
+	g_strfreev(path);
+	g_free(moddirname);
+
 }
 
 /******   end of file   ******/
