@@ -28,11 +28,16 @@
 extern "C"
 {
 #endif
-void on_dialog_response(GtkDialog * dialog, 
-			gint response_id, 
+void on_dialog_response(GtkDialog * dialog,
+			gint response_id,
 			gpointer user_data);
 void gui_bookmark_dialog(gchar * label, gchar * module_name, gchar * key);
 void gui_mark_verse_dialog(gchar * module_name, gchar * key);
+void on_buffer_changed (GtkTextBuffer *textbuffer, gpointer user_data);
+void on_mark_verse_response(GtkDialog * dialog, gint response_id, gpointer user_data);
+void on_dialog_enter(void);
+void on_mark_verse_enter(void);
+gboolean on_treeview_button_release_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 
 #ifdef __cplusplus
 }
