@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * bookmarks_treeview.h - gui for bookmarks 
+ * bookmarks_treeview.h - gui for bookmarks
  *
  * Copyright (C) 2003-2009 Xiphos Developer Team
  *
@@ -25,7 +25,7 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <libxml/parser.h>
 enum {
 	COL_OPEN_PIXBUF,
@@ -65,12 +65,14 @@ void gui_load_removed(const xmlChar * file);
 void gui_add_columns(GtkTreeView * tree);
 void gui_add_item_to_tree(GtkTreeIter * iter, GtkTreeIter * parent,
 			     BOOKMARK_DATA * data);
-void gui_verselist_to_bookmarks(GList * verses, gint save_as_single);	
+void gui_verselist_to_bookmarks(GList * verses, gint save_as_single);
 GtkWidget *gui_create_bookmark_tree(void);
 void gui_parse_bookmarks(GtkTreeView *tree, const xmlChar * file,
 			    GtkTreeIter *parent);
 GtkWidget* gui_create_dialog_add_bookmark(gchar * label,
 				gchar * module_name, gchar * key);
+void gui_save_old_bookmarks_to_new(GNode * gnode);
+
 #ifdef __cplusplus
 }
 #endif
