@@ -27,10 +27,12 @@ extern "C" {
 #endif
 
 #include "main/module_dialogs.h"
-	
+
 void gui_commentary_dialog_sync_toggled(GtkToggleButton * button, DIALOG_DATA * c);
 void gui_create_commentary_dialog(DIALOG_DATA * d, gboolean do_edit);
-	
+void gui_display_commentary_with_struct(DIALOG_DATA *d, gchar *key);
+void gui_close_comm_dialog(DIALOG_DATA * d);
+
 #ifdef __cplusplus
 }
 #endif
