@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * export_dialog.h - 
+ * export_dialog.h -
  *
  * Copyright (C) 2007-2009 Xiphos Developer Team
  *
@@ -24,13 +24,16 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif	
-	
+#endif
+
 gchar *gui_get_export_filename(void);
 void gui_export_dialog(void);
+void _get_export_filename(void);
+void on_dialog_export_passage_response(GtkDialog * dialog, gint response_id, gpointer user_data);
+gint _check_for_distribution_license(gchar * mod_name);
 
 #ifdef __cplusplus
 }
 #endif
-	
+
 #endif /* _EXPORT_DIALOG_H_ */
