@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * find_dialog.h - 
+ * find_dialog.h -
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -22,9 +22,9 @@
 #ifndef _FIND_DIALOG_H_
 #define _FIND_DIALOG_H_
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-void gui_find_dlg(GtkWidget *htmlwidget, gchar *mod_name, 
+void gui_find_dlg(GtkWidget *htmlwidget, gchar *mod_name,
 		  gboolean regular, gchar *text);
 
 #endif
