@@ -24,11 +24,7 @@
 
 #include <config.h>
 
-#ifdef USE_GTKHTML3_14_23
 #include "editor/slib-editor.h"
-#else
-#include "editor/bonobo-editor.h"
-#endif
 
 GtkWidget *gui_navbar_versekey_editor_new(EDITOR * editor);
 
