@@ -30,7 +30,9 @@ void gui_create_parallel_page(void);
 void gui_create_parallel_popup(void);
 void gui_popup_menu_parallel(void);
 void on_undockInt_activate(GtkMenuItem * menuitem);
-	
+void on_paratab_activate(GtkMenuItem * menuitem);
+void on_changeint1mod_activate(GtkMenuItem * menuitem, gpointer user_data);
+
 #ifdef __cplusplus
 }
 #endif
