@@ -3,7 +3,7 @@
 
 
 #define E_MAKE_TYPE(l,str,t,ci,i,parent) \
-GtkType l##_get_type(void)\
+GType l##_get_type(void)\
 {\
 	static GType type = 0;				\
 	if (!type){					\
@@ -27,7 +27,8 @@ GtkType l##_get_type(void)\
 }
 
 void gui_splash_init(void);
-void gui_splash_done(void);
+gboolean gui_splash_done(void);
 void gui_splash_step(gchar *text, gdouble progress, gint step);
+gboolean expose_event_callback (GtkWidget *widget, GdkEventExpose *event, gpointer data);
 
 #endif
