@@ -24,6 +24,8 @@
 #endif
 
 #include <glib.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
 #include <osishtmlhref.h>
 #include <osisvariants.h>
 #include <thmlvariants.h>
@@ -35,13 +37,12 @@
 #include <string.h>
 #include <ctype.h>
 #include <assert.h>
-#include <Magick++.h>
 
 #ifndef WIN32
 #include <sys/socket.h>
 #include <netinet/in.h>
 #else
-#include <Winsock2.h>
+#include <winsock2.h>
 #endif /* !WIN32 */
 #include <errno.h>
 
@@ -61,7 +62,11 @@
 # ifdef PACKAGE_VERSION
 #  undef PACKAGE_VERSION
 # endif
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif /* WIN32 */
 #else
 #ifdef __cplusplus
 extern "C" {
@@ -84,6 +89,8 @@ extern "C" {
 
 #include "backend/sword_main.hh"
 
+#include "gui/debug_glib_null.h"
+
 // for one-time content rendering.
 extern ModuleCache::CacheMap ModuleMap;
 
@@ -123,66 +130,16 @@ int marked_cache_chapter = -1;
 
 using namespace sword;
 using namespace std;
-using namespace Magick;
-
-#if 1
-// The easy ImageMagick API solution in Linux/UNIX environments.
 
 int
 ImageDimensions(const char *path, int *x, int *y)
 {
-	try {
-		Image image(path);
-		*x = image.baseColumns();
-		*y = image.baseRows();
+
+	if (gdk_pixbuf_get_file_info (path, x, y))
 		return 0;
-	}
-	catch (Exception &error_) {
-		GS_warning(("Caught exception: %s", error_.what()));
+	else
 		return -1;
-	}
 }
-#else
-// The ugly "shell command for `identify'" solution.
-
-// shell command to obtain size spec: prints exactly "123x456".
-// bad accommodation to Solaris (old sed): we cannot use \(this\|that\|other\).
-#define	IDENTIFY	"identify \"%s\" 2>&1 | head -1 | sed -e \"s/^.*BMP //\" -e \"s/^.*GIF //\" -e \"s/^.*JPEG //\" -e \"s/^.*PNG //\" -e \"s/ .*$//\""
-
-int
-ImageDimensions(const char *path, int *x, int *y)
-{
-	char buf[350];	// enough for path+100 bytes of command.
-	FILE *result;
-	int retval = 0;
-
-	if (strlen(path) > 250) {		// um...no.  forget it.
-		*x = *y = 1;
-		return -1;
-	}
-
-	sprintf(buf, IDENTIFY, path);
-	if (((result = popen(buf, "r")) == NULL) ||	// can't run.
-	    (fgets(buf, 384, result) == NULL)    ||	// can't read.
-	    (buf[0] < '0')                       ||	// not ...
-	    (buf[0] > '9'))   {				// ... numeric.
-		*x = *y = 1;
-		retval = -1;
-		goto out;
-	}
-	sscanf(buf, "%dx%d\n", x, y);
-
-	// cancel absurdities.
-	if ((*x < 1) || (*x > 5000))
-		*x = 1;
-	if ((*y < 1) || (*y > 5000))
-		*y = 1;
-
-out:
-	pclose(result);
-	return retval;
-}
-#endif
 
 //
 // user annotation cache filling.
@@ -208,8 +165,9 @@ struct replace {
 void
 marked_cache_fill(gchar *modname, gchar *key)
 {
-	gchar *s, *t, *err;
-	char *key_book;
+	gchar *s, *t, *err, *mhold;
+	char *key_book = g_strdup(main_get_osisref_from_key((const char *)modname,
+							    (const char *)key));
 	int key_chapter, key_verse;
 
 	// free the old cache.  first free contents, then the map itself.
@@ -224,14 +182,11 @@ marked_cache_fill(gchar *modname, gchar *key)
 	}
 	marked_cache.clear();
 
-	// tear apart the key
-	key_book = g_strdup(key);
-	*(s = strrchr(key_book, ' ')) = '\0';
-	t = ++s;
-	s = strchr(t, ':');
-	*(s++) = '\0';
-	key_chapter = atoi(t);
-	key_verse   = atoi(s);
+	// tear apart the key (e.g. "Gen.1.1").
+	*(s = strrchr(key_book, '.')) = '\0';
+	*(t = strrchr(key_book, '.')) = '\0';
+	key_chapter = atoi(t+1);
+	key_verse   = atoi(s+1);
 
 	// remember exactly what chapter this cache is for
 	g_free(marked_cache_modname);
@@ -242,7 +197,7 @@ marked_cache_fill(gchar *modname, gchar *key)
 
 	// load up the annotation content
 	marked_element *e = new marked_element;
-    	if (xml_set_section_ptr("markedverses") && xml_get_label()) {
+    	if (xml_set_section_ptr("osisrefmarkedverses") && xml_get_label()) {
 		do {
 			e->module = xml_get_label();
 			s = xml_get_list();
@@ -250,22 +205,25 @@ marked_cache_fill(gchar *modname, gchar *key)
 			g_free(s);
 
 			gchar *m = e->module;
+			mhold = g_strdup(m);
 
-			// tear apart "NASB Revelation of John 1:1"
-			if ((s = strrchr(m, ' ')) == NULL)	// rightmost space
+			// tear apart "NASB Gen.1.1"
+			if ((s = strrchr(m, '.')) == NULL)	// rightmost dot
 				goto fail;
 			*s = '\0';
-			if ((s = strchr((t = s+1), ':')) == NULL) // chapter:verse
+			if ((t = strrchr(m, '.')) == NULL)	// chapter:verse
 				goto fail;
-			*(s++) = '\0';
-			e->chapter = atoi(t);
-			e->verse   = atoi(s);
+			*t = '\0';
+			e->chapter = atoi(t+1);
+			e->verse   = atoi(s+1);
 			if ((s = strchr(m, ' ')) == NULL)	// leftmost space
 				goto fail;
 			*(s++) = '\0';
 			e->book = s;
 			// now properly delimited: module & book, plus numeric c:v.
 
+			g_free(mhold);
+
 			// for fast reference: is this annotation relevant?
 			if ((key_chapter != e->chapter) ||
 			    (*m && (strcasecmp(m, modname) != 0)) ||
@@ -278,7 +236,7 @@ marked_cache_fill(gchar *modname, gchar *key)
 				for (int i = 0; i < NUM_REPLACE; ++i) {
 					for (s = strchr(e->annotation->str, replacement[i].c);
 					     s;
-					     s = strchr(s, replacement[i].c)) {
+					     s = strchr(e->annotation->str, replacement[i].c)) {
 						(void) g_string_erase(e->annotation,
 								      s - (e->annotation->str), 1);
 						(void) g_string_insert(e->annotation,
@@ -298,7 +256,8 @@ marked_cache_fill(gchar *modname, gchar *key)
 	return;
 
 fail:
-	err = g_strdup_printf(_("Improperly encoded personal annotation label:\n'%s'"), s);
+	err = g_strdup_printf(_("Improperly encoded personal annotation label:\n'%s'"),
+			      mhold);
 	gui_generic_warning(err);
 	g_free(err);
 	g_free(key_book);
@@ -603,7 +562,7 @@ block_dump(SWBuf& rendered,
 	if (*morph) g_free((char *)*morph);
 	*morph = NULL;
 
-	rendered += "</span> ";
+	rendered += "</span> <span class=\"word\">&nbsp;</span>";
 }
 
 //
@@ -630,7 +589,8 @@ block_render_secondary(const char *text,
 		   *strongs = NULL,
 		   *morph   = NULL;
 	int bracket;
-	const char *s, *t;
+	const char *s;
+	char *t, *u;
 
 	for (s = text; *s; ++s) {
 		switch (*s) {
@@ -652,11 +612,26 @@ block_render_secondary(const char *text,
 
 				static char end[5] = "</X>";
 				end[2] = *(s+1);
-				if ((t = strstr(s, end)) == NULL) {
+			again:
+				if ((t = strstr((char *)s, end)) == NULL) {
 					GS_warning(("No %s in %s\n", end, s));
 					break;
                                 }
 
+				// yet another nightmare:
+				// if the markup results in e.g. doubled <i>
+				// (bogus "<hi><hi>word</hi></hi>"),
+				// then we will mis-assess termination.
+				// so we search for the same markup embedded within.
+				// if we find an internal set, we just wipe it out.
+				static char embedded[4] = "<X>";
+				embedded[1] = *(s+1);
+				if ((u = g_strstr_len(s+3, t-(s+3), embedded))) {
+					*u = *(u+1) = *(u+2) =
+					    *t = *(t+1) = *(t+2) = *(t+3) = ' ';
+					goto again;	// yuck, yes, i know...
+				}
+
 				// nasb eph 5:31: whole verse is an italicized
 				// quotation of gen 2:24...containing strongs.
 				// in event of font switch, output bare switch
@@ -678,10 +653,10 @@ block_render_secondary(const char *text,
 					rendered += end;
 					s = t+3;
 				}
-                                break;
+				break;
 			} else if (!strncmp(s+1, "small>", 6)) {
 				// strongs and morph are bounded by "<small>".
-				if ((t = strstr(s, "</small>")) == NULL) {
+				if ((t = strstr((char *)s, "</small>")) == NULL) {
 					GS_warning(("No </small> in %s\n", s));
 					break;
 				}
@@ -863,9 +838,6 @@ GTKEntryDisp::DisplayByChapter(SWModule &imodule)
 	if (strongs_and_morph)
 		set_morph_order(imodule);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("<div align=right>");
-
 	for (key->Verse(1);
 	     (key->Book()    == curBook)    &&
 	     (key->Chapter() == curChapter) &&
@@ -898,9 +870,7 @@ GTKEntryDisp::DisplayByChapter(SWModule &imodule)
 			     : rework /* left as-is */);
 	}
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("</div>");
-	swbuf.append("</font></body></html>");
+	swbuf.append("</div></font></body></html>");
 
 	buf = g_strdup_printf("%d", curVerse);
 	HtmlOutput((char *)swbuf.c_str(), gtkText, mf, buf);
@@ -969,6 +939,10 @@ GTKEntryDisp::Display(SWModule &imodule)
 	swbuf.append(buf);
 	g_free(buf);
 
+	swbuf.appendFormatted("<div dir=%s>",
+			      ((is_rtol && !ops->transliteration)
+			       ? "rtl"
+			       : "ltr"));
 	//
 	// the rest of this routine is irrelevant if we are
 	// instead heading off to show a whole chapter
@@ -1027,7 +1001,7 @@ GTKEntryDisp::Display(SWModule &imodule)
 					   GDK_WINDOW(gtkText->window))
 		     : rework /* left as-is */);
 
-	swbuf.append("</font></body></html>");
+	swbuf.append("</div></font></body></html>");
 
 	HtmlOutput((char *)swbuf.c_str(), gtkText, mf, NULL);
 
@@ -1044,54 +1018,36 @@ GTKChapDisp::getVerseBefore(SWModule &imodule)
 	gchar *utf8_key;
 	gchar *buf;
 	char *num;
-	SWMgr *mgr = be->get_main_mgr();
 
-	const char *ModuleName = imodule.Name();
-	SWModule *mod_top = mgr->getModule(ModuleName);
-	mod_top->setSkipConsecutiveLinks(true);
-	*mod_top = sword::TOP;
-
-	sword::VerseKey key_top( mod_top->KeyText() );
-	SWModule *mod = mgr->getModule(ModuleName);
-	mod->setKey(imodule.getKey());
-	VerseKey *key = (VerseKey *)(SWKey *)*mod;
+	sword::VerseKey *key = (VerseKey *)(SWKey *)imodule;
+	int curVerse = key->Verse();
 	int chapter = key->Chapter();
-	key->Verse(1);
+	int curBook = key->Book();
+	int curTest = key->Testament();
+	const char *ModuleName = imodule.Name();
 
-	if (!key->_compare(key_top)) {
-		if ((!strcmp(settings.MainWindowModule, "KJV"))){
-			buf=g_strdup_printf("<div style=\"text-align: center\">"
-					    "<b><font size=\"%+d\">%s</font></b>"
-					    "<hr></div>",
-					    1 + ((mf->old_font_size)
-						 ? atoi(mf->old_font_size) +
-						 settings.base_font_size
-						 : settings.base_font_size),
-					    mod->Description());
-			swbuf.append(buf);
-			g_free(buf);
-		}
-		else {
-			num = main_format_number(chapter);
-			buf=g_strdup_printf("<div style=\"text-align: center\">"
-					    "<p><b><font size=\"%+d\">%s</font></b></p>"
-					    "<b>%s %s</b></div>",
-					    1 + ((mf->old_font_size)
-						 ? atoi(mf->old_font_size) +
-						 settings.base_font_size
-						 : settings.base_font_size),
-					    mod->Description(),
-					    _("Chapter"),
-					    num);
-			g_free(num);
-			swbuf.append(buf);
-			g_free(buf);
-		}
+	key->Verse(1);
+	imodule--;
+
+	if (imodule.Error()) {
+		num = main_format_number(chapter);
+		buf=g_strdup_printf("<div style=\"text-align: center\">"
+				    "<p><b><font size=\"%+d\">%s</font></b></p>"
+				    "<b>%s %s</b></div>",
+				    1 + ((mf->old_font_size)
+					 ? atoi(mf->old_font_size) +
+					 settings.base_font_size
+					 : settings.base_font_size),
+				    imodule.Description(),
+				    _("Chapter"),
+				    num);
+		g_free(num);
+		swbuf.append(buf);
+		g_free(buf);
 	} else {
-		(*mod)--;
 
 		if (strongs_and_morph)
-			set_morph_order(*mod);
+			set_morph_order(imodule);
 
 		ModuleCache::CacheVerse& cVerse = ModuleMap
 		    [ModuleName]
@@ -1100,26 +1056,18 @@ GTKChapDisp::getVerseBefore(SWModule &imodule)
 		    [key->Chapter()]
 		    [key->Verse()];
 
-#if 1
 		if (!cVerse.CacheIsValid(cache_flags))
 			cVerse.SetText((strongs_or_morph
-					? block_render((const char *)*mod)
-					: (const char *)*mod),
+					? block_render((const char *)imodule)
+					: (const char *)imodule),
 				       cache_flags);
-#else
-		if (!cVerse.CacheIsValid(cache_flags)) {
-			const char *text = (strongs_or_morph
-					    ? block_render((const char *)mod)
-					    : (const char *)mod);
-			CleanupContent(text, ops, imodule.Name());
-			cVerse.SetText(text, cache_flags);
-		}
-#endif
 
 		utf8_key = strdup((char*)key->getText());
 
-		if (is_rtol && !ops->transliteration)
-			swbuf.append("<div align=right>");
+		swbuf.appendFormatted("<div dir=%s>",
+				      ((is_rtol && !ops->transliteration)
+				       ? "rtl"
+				       : "ltr"));
 
 		num = main_format_number(key->Verse());
 		buf=g_strdup_printf(settings.showversenum
@@ -1148,12 +1096,12 @@ GTKChapDisp::getVerseBefore(SWModule &imodule)
 		swbuf.append(buf);
 		g_free(buf);
 
-		if (is_rtol && !ops->transliteration)
-			swbuf.append("</div>");
+		swbuf.append("</div>");
 
-		(*mod)++;
 	}
 
+	imodule++;
+
 	if (!ops->headings)
 		return;
 
@@ -1178,28 +1126,22 @@ GTKChapDisp::getVerseBefore(SWModule &imodule)
 		    [key->Chapter()]
 		    [key->Verse()];
 
-#if 1
 		if (!cVerse.CacheIsValid(cache_flags))
 			cVerse.SetText((strongs_or_morph
-					? block_render((const char *)*mod)
-					: (const char *)*mod),
+					? block_render((const char *)imodule)
+					: (const char *)imodule),
 				       cache_flags);
-#else
-		if (!cVerse.CacheIsValid(cache_flags)) {
-			const char *text = (strongs_or_morph
-					    ? block_render((const char *)mod)
-					    : (const char *)mod);
-			CleanupContent(text, ops, imodule.Name());
-			cVerse.SetText(text, cache_flags);
-		}
-#endif
-
 		buf=g_strdup_printf("%s<br />", cVerse.GetText());
 		swbuf.append(buf);
 		g_free(buf);
 	}
 
 	key->AutoNormalize(oldAutoNorm);
+
+	key->Book(curBook);
+	key->Chapter(chapter);
+	key->Verse(curVerse);
+	key->Testament(curTest);
 }
 
 void
@@ -1207,48 +1149,36 @@ GTKChapDisp::getVerseAfter(SWModule &imodule)
 {
 	gchar *utf8_key;
 	gchar *buf;
-	SWMgr *mgr = be->get_main_mgr();
 	const char *ModuleName = imodule.Name();
-	SWModule *mod_bottom = mgr->getModule(ModuleName);
-		mod_bottom->setSkipConsecutiveLinks(true);
-	*mod_bottom = sword::BOTTOM;
-	sword::VerseKey key_bottom( mod_bottom->KeyText() );
-	SWModule *mod = mgr->getModule(ModuleName);
-	mod->setKey(imodule.getKey());
-	VerseKey *key = (VerseKey *)(SWKey *)*mod;
+	sword::VerseKey *key = (VerseKey *)(SWKey *)imodule;
 
-	if (key_bottom._compare(key) < 1) {
+	imodule++;
+	if (imodule.Error()) {
 		buf=g_strdup_printf(
 			"%s<hr><div style=\"text-align: center\"><p><b>%s</b></p></div>",
 			// extra break when excess strongs/morph space.
 			(strongs_or_morph ? "<br>" : ""),
-			mod->Description());
+			imodule.Description());
 		swbuf.append(buf);
 		g_free(buf);
 	} else {
+		imodule--;
 		char *num = main_format_number(key->Chapter());
-		if ((!strcmp(settings.MainWindowModule, "KJV"))){
-			buf=g_strdup_printf(
-				"%s<hr><b>%s %s.</b><br><br>",
-				(strongs_or_morph ? "<br>" : ""),
-				_("Chapter"), num);
-			swbuf.append(buf);
-			g_free(buf);
-		}
-		else {
-			buf=g_strdup_printf(
-				"%s<hr><div style=\"text-align: center\"><b>%s %s</b></div>",
-				(strongs_or_morph ? "<br>" : ""),
-				_("Chapter"), num);
-			swbuf.append(buf);
-			g_free(buf);
-		}
+
+		buf=g_strdup_printf(
+			"%s<hr><div style=\"text-align: center\"><b>%s %s</b></div>",
+			(strongs_or_morph ? "<br>" : ""),
+			_("Chapter"), num);
+		swbuf.append(buf);
+		g_free(buf);
 		g_free(num);
 
 		utf8_key = strdup((char*)key->getText());
 
-		if (is_rtol && !ops->transliteration)
-			swbuf.append("<div align=right>");
+		swbuf.appendFormatted("<div dir=%s>",
+				      ((is_rtol && !ops->transliteration)
+				       ? "rtl"
+				       : "ltr"));
 
 		num = main_format_number(key->Verse());
 		buf=g_strdup_printf(settings.showversenum
@@ -1267,7 +1197,7 @@ GTKChapDisp::getVerseAfter(SWModule &imodule)
 		g_free(buf);
 
 		if (strongs_and_morph)
-			set_morph_order(*mod);
+			set_morph_order(imodule);
 
 		ModuleCache::CacheVerse& cVerse = ModuleMap
 		    [ModuleName]
@@ -1276,25 +1206,13 @@ GTKChapDisp::getVerseAfter(SWModule &imodule)
 		    [key->Chapter()]
 		    [key->Verse()];
 
-#if 1
 		if (!cVerse.CacheIsValid(cache_flags))
 			cVerse.SetText((strongs_or_morph
-					? block_render((const char *)*mod)
-					: (const char *)*mod),
+					? block_render((const char *)imodule)
+					: (const char *)imodule),
 				       cache_flags);
-#else
-		if (!cVerse.CacheIsValid(cache_flags)) {
-			const char *text = (strongs_or_morph
-					    ? block_render((const char *)mod)
-					    : (const char *)mod);
-			CleanupContent(text, ops, imodule.Name());
-			cVerse.SetText(text, cache_flags);
-		}
-#endif
-
 		swbuf.append(cVerse.GetText());
-		if (is_rtol && !ops->transliteration)
-			swbuf.append("</div>");
+		swbuf.append("</div>");
 	}
 }
 
@@ -1468,9 +1386,32 @@ ReadAloud(unsigned int verse, const char *suppliedtext)
 			*s = ' ';
 		// in case it isn't obvious, i'd really like a  standard
 		// function that walks a string for multiple individual chars.
+
+		// walk the string, looking for dislocated "LORD" as "L<spaces>ORD".
+		// this occurs in "smallcaps" use in many bibles.
+		for (s = strchr(text->str, 'L'); s; s = strchr(s+1, 'L')) {
+			gchar *begin = s++;
+			while (*s == ' ')
+				++s;
+			if (!strncmp(s, "ORD", 3)) {
+				*begin = ' ';
+				*(s-1) = 'L';
+			}
+		}
+		// same song, second verse: G<spaces>OD.
+		for (s = strchr(text->str, 'G'); s; s = strchr(s+1, 'G')) {
+			gchar *begin = s++;
+			while (*s == ' ')
+				++s;
+			if (!strncmp(s, "OD", 2)) {
+				*begin = ' ';
+				*(s-1) = 'G';
+			}
+		}
+
 		GS_message(("ReadAloud: clean: %s\n", text->str));
 		// scribble clean text to the socket.
-		if (FestivalSpeak(text->str, strlen(text->str), tts_socket) == false) 
+		if (FestivalSpeak(text->str, strlen(text->str), tts_socket) == false)
 		{
 			char msg[256];
 			sprintf(msg, "TTS disappeared?\nTTS write failed: %s",
@@ -1523,7 +1464,6 @@ StartFestival()
 	festival_args[1] = g_strdup("--server");
 	festival_args[2] = NULL;
 #endif
-	GS_message((festival_args[0]));
 	g_spawn_async ( NULL,
 			festival_args,
 			NULL,
@@ -1620,7 +1560,6 @@ GTKChapDisp::Display(SWModule &imodule)
 		paragraphMark = "";
 
 	swbuf = "";
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_text), 0);
 
 	buf=g_strdup_printf(HTML_START
 			    "<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
@@ -1643,8 +1582,10 @@ GTKChapDisp::Display(SWModule &imodule)
 	swbuf.append(buf);
 	g_free(buf);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("<div align=right>");
+	swbuf.appendFormatted("<div dir=%s>",
+			      ((is_rtol && !ops->transliteration)
+			       ? "rtl"
+			       : "ltr"));
 
 	main_set_global_options(ops);
 	getVerseBefore(imodule);
@@ -1799,9 +1740,7 @@ GTKChapDisp::Display(SWModule &imodule)
 	key->Chapter(curChapter);
 	key->Verse(curVerse);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("</div>");
-	swbuf.append("</font></body></html>");
+	swbuf.append("</div></font></body></html>");
 
 #ifdef USE_GTKMOZEMBED
 	if (strongs_and_morph)
@@ -1852,8 +1791,10 @@ DialogEntryDisp::DisplayByChapter(SWModule &imodule)
 	if (strongs_and_morph)
 		set_morph_order(imodule);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("<div align=right>");
+	swbuf.appendFormatted("<div dir=%s>",
+			      ((is_rtol && !ops->transliteration)
+			       ? "rtl"
+			       : "ltr"));
 
 	for (key->Verse(1);
 	     (key->Book()    == curBook)    &&
@@ -1887,9 +1828,7 @@ DialogEntryDisp::DisplayByChapter(SWModule &imodule)
 			     : rework /* left as-is */);
 	}
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("</div>");
-	swbuf.append("</font></body></html>");
+	swbuf.append("</div></font></body></html>");
 
 	buf = g_strdup_printf("%d", curVerse);
 	HtmlOutput((char *)swbuf.c_str(), gtkText, mf, buf);
@@ -2008,7 +1947,7 @@ DialogChapDisp::Display(SWModule &imodule)
 	char *ModuleName = imodule.Name();
 	ops = main_new_globals(ModuleName, 1);
 	cache_flags = ConstructFlags(ops);
-    
+
 	is_rtol = main_is_mod_rtol(ModuleName);
 	mf = get_font(ModuleName);
 
@@ -2069,8 +2008,10 @@ DialogChapDisp::Display(SWModule &imodule)
 	swbuf.append(buf);
 	g_free(buf);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("<div align=right>");
+	swbuf.appendFormatted("<div dir=%s>",
+			      ((is_rtol && !ops->transliteration)
+			       ? "rtl"
+			       : "ltr"));
 
 	for (key->Verse(1);
 	     (key->Book() == curBook) &&
@@ -2217,9 +2158,7 @@ DialogChapDisp::Display(SWModule &imodule)
 	key->Chapter(curChapter);
 	key->Verse(curVerse);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("</div>");
-	swbuf.append("</font></body></html>");
+	swbuf.append("</div></font></body></html>");
 
 #ifdef USE_GTKMOZEMBED
 	if (strongs_and_morph)
@@ -2339,7 +2278,6 @@ GTKPrintChapDisp::Display(SWModule &imodule)
 		paragraphMark = "";
 
 	swbuf = "";
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_text), 0);
 
 	buf=g_strdup_printf(HTML_START
 			      "<body bgcolor=\"%s\" text=\"%s\" link=\"%s\">"
@@ -2355,8 +2293,10 @@ GTKPrintChapDisp::Display(SWModule &imodule)
 	swbuf.append(buf);
 	g_free(buf);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("<div ALIGN=right>");
+	swbuf.appendFormatted("<div dir=%s>",
+			      ((is_rtol && !ops->transliteration)
+			       ? "rtl"
+			       : "ltr"));
 
 	gecko_html_write(html,swbuf.c_str(),swbuf.length());
 
@@ -2432,10 +2372,7 @@ GTKPrintChapDisp::Display(SWModule &imodule)
 	key->Chapter(curChapter);
 	key->Verse(curVerse);
 
-	if (is_rtol && !ops->transliteration)
-		swbuf.append("</div></font></body></html>");
-	else
-		swbuf.append("</font></body></html>");
+	swbuf.append("</div></font></body></html>");
 
 	if (swbuf.length())
 		gecko_html_write(html,swbuf.c_str(),swbuf.length());
