@@ -23,14 +23,13 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 #include "main/lists.h"
 #include "main/sword.h"
 #include "main/settings.h"
 #include "main/xml.h"
-
 #include "backend/sword_main.hh"
 
 
@@ -91,11 +90,10 @@ GList *get_list(gint type)
 
 
 void main_init_lists(void)
-{	
+{
 	gboolean start_backend = FALSE;
-	char *sword_locale = FALSE;
 	mod_lists = &mods;
-	
+
 	/* set glist to null */
 	mods.biblemods = NULL;
 	mods.commentarymods = NULL;
@@ -119,24 +117,21 @@ void main_init_lists(void)
 	settings.havebook = FALSE;
 	settings.havepercomm = FALSE;
 	settings.haveprayerlist = FALSE;
-	
-	if(backend) {
+
+	if (backend) {
 		mods.options = backend->get_module_options();
 	} else {
-		const char* lang = g_getenv("LANG");
 		start_backend = TRUE;
 		backend = new BackEnd();
-		sword_locale = backend->set_sword_locale(lang);
 	}
 	backend->init_lists(mod_lists);
-	if(start_backend) {
-		free((char*)sword_locale);
+	if (start_backend) {
 		delete backend;
 		backend = NULL;
 	}
 
 	settings.havebible = g_list_length(mods.biblemods);
-	
+
 	settings.havecomm = g_list_length(mods.commentarymods);
 
 	settings.havedict = g_list_length(mods.dictionarymods);
@@ -144,10 +139,10 @@ void main_init_lists(void)
 	settings.havebook = g_list_length(mods.bookmods);
 
 	settings.havepercomm = g_list_length(mods.percommods);
-	
+
 	settings.haveprayerlist = g_list_length(mods.prayermods);
-	
-	if(g_list_length(mods.devotionmods)== 1) {		
+
+	if (g_list_length(mods.devotionmods)== 1) {
 		xml_set_value("Xiphos", "modules", "devotional",(char*)mods.devotionmods->data );
 		settings.devotionalmod = xml_get_value("modules", "devotional");
 	}
@@ -166,8 +161,8 @@ void main_init_lists(void)
 void main_shutdown_list(void)
 {
 	/* free lists */
-	if(!mod_lists) return;
-		
+	if (!mod_lists) return;
+
 	while (mod_lists->options != NULL) {
 		g_free((char *) mod_lists->options->data);
 		mod_lists->options = g_list_next(mod_lists->options);
