@@ -23,10 +23,14 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif
 #else
 #ifdef __cplusplus
 extern "C" {
@@ -53,6 +57,8 @@ extern "C" {
 #include "main/xml.h"
 #include "main/display.hh"
 
+#include "gui/debug_glib_null.h"
+
 #define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><STYLE type=\"text/css\"><!--A { text-decoration:none }--></STYLE></head>"
 
 extern GtkWidget *entrycbIntBook;
@@ -90,13 +96,13 @@ static const gchar *tf2of(int true_false)
  *
  * Synopsis
  *   #include "main/parallel_view.h"
- *   
+ *
  *   void set_global_option(char * option, gboolean choice)
  *
  * Description
  *   sets a sword global option and saves it to settings.xml
- *   
- *   
+ *
+ *
  *
  * Return value
  *   void
@@ -105,16 +111,16 @@ static const gchar *tf2of(int true_false)
 static void set_global_option(char * option, gboolean choice)
 {
 	const char *on_off = tf2of(choice);
-	SWMgr *mgr = backend_p->get_display_mgr();
+	SWMgr *mgr = backend_p->get_mgr();
 	char *buf= g_strdup (option);
 
 //	GS_message (("option://%s\n\n",option));
-		     
+
 	mgr->setGlobalOption(buf, on_off);
-		     
-	xml_set_value("Xiphos", 
-		      "parallel", 
-		      (char*)g_strdelimit (buf,"' ", '_'), 
+
+	xml_set_value("Xiphos",
+		      "parallel",
+		      (char*)g_strdelimit (buf,"' ", '_'),
 		      (char*)(choice ? "1" : "0"));
 	g_free (buf);
 }
@@ -124,13 +130,13 @@ static void set_global_textual_reading (const char * option, int choice)
 {
 	//gboolean primary = 0, secondary = 0, all = 0;
 	char *buf= g_strdup (option);
-	SWMgr *mgr = backend_p->get_display_mgr();
-	
-	xml_set_value("Xiphos", 
-		      "parallel", 
-		      (char*)g_strdelimit (buf,"' ", '_'), 
+	SWMgr *mgr = backend_p->get_mgr();
+
+	xml_set_value("Xiphos",
+		      "parallel",
+		      (char*)g_strdelimit (buf,"' ", '_'),
 		      (char*)(choice ? "1" : "0"));
-    
+
 	/*switch (choice)
 	{
 	case 0:
@@ -148,11 +154,11 @@ static void set_global_textual_reading (const char * option, int choice)
 		break;
 	}*/
 	GS_message (("set_global_textual_reading\noption://%s",option));
-	
+
 	mgr->setGlobalOption("Textual Variants", option);
-		     
+
 	g_free (buf);
-	
+
 }
 
 
@@ -162,13 +168,13 @@ static void set_global_textual_reading (const char * option, int choice)
  *
  * Synopsis
  *   #include ".h"
- *   
+ *
  *   gchar *main_parallel_change_verse(void)
  *
  * Description
  *   this is for the parallel dialog only
  *
- *   
+ *
  *
  * Return value
  *   gchar *
@@ -240,11 +246,11 @@ void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
 {
 	gchar *option = (gchar*) user_data;
 	gboolean choice = menuitem->active;
-	
-	
+
+
 	if (!strcmp(option, "Strong's Numbers")) {
 		settings.parallel_strongs = choice;
-		set_global_option(option, choice);		
+		set_global_option(option, choice);
 	}
 
 	if (!strcmp(option, "Footnotes")) {
@@ -276,32 +282,32 @@ void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
 		settings.parallel_crossref = choice;
 		set_global_option(option, choice);
 	}
-	
+
 	if (!strcmp(option,"Transliteration")) {
 		settings.parallel_transliteration = choice;
 		set_global_option(option, choice);
-	}	
-	
+	}
+
 	if (!strcmp(option,"Words of Christ in Red")) {
 		settings.parallel_red_words = choice;
 		set_global_option(option, choice);
-	}	
-	
+	}
+
 	if (!strcmp(option,"Morpheme Segmentation")) {
 		settings.parallel_segmentation = choice;
 		set_global_option(option, choice);
-	}	
-	
+	}
+
 	if (!strcmp(option,"Headings")) {
 		settings.parallel_headings = choice;
 		set_global_option(option, choice);
-	}	
-	
+	}
+
 	if (!strcmp(option,"Lemmas")) {
 		settings.parallel_lemmas = choice;
 		set_global_option(option, choice);
 	}
-	
+
 	if (!strcmp(option,"Primary Reading")) {
 		settings.parallel_variants_primary = choice;
 		set_global_textual_reading (option, choice);
@@ -314,7 +320,7 @@ void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
 		settings.parallel_variants_all = choice;
 		set_global_textual_reading (option, choice);
 	}
-	
+
 
 	/* display change */
 	if (settings.dockedInt) {
@@ -343,7 +349,7 @@ void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
 void main_set_parallel_options_at_start(void)
 {
 	char *value;
-	SWMgr *mgr = backend_p->get_display_mgr();
+	SWMgr *mgr = backend_p->get_mgr();
 
 	GList *tmp = backend->get_module_options();
 	while (tmp) {
@@ -352,23 +358,23 @@ void main_set_parallel_options_at_start(void)
 		//GS_message(("\n\n%s\n%s\n", (char*)tmp->data, option));
 		value = xml_get_value("parallel", option);
 		int choice = (value ? atoi(value) : 0);
-		if (!strcmp((char*)tmp->data,"Textual Variants")) {		
+		if (!strcmp((char*)tmp->data,"Textual Variants")) {
 			if (atoi (xml_get_value("parallel", "Primary_Reading")))
-				mgr->setGlobalOption ("Textual Variants", 
+				mgr->setGlobalOption ("Textual Variants",
 						      "Primary Reading");
 			else if (atoi (xml_get_value("parallel", "Secondary_Reading")))
-				mgr->setGlobalOption ("Textual Variants", 
+				mgr->setGlobalOption ("Textual Variants",
 						      "Secondary Reading");
-			else 		
-				mgr->setGlobalOption ("Textual Variants", 
+			else
+				mgr->setGlobalOption ("Textual Variants",
 						      "All Readings");
 		} else
 			mgr->setGlobalOption((char*)tmp->data, choice ? "On" : "Off");
 		g_free(option);
-		tmp = g_list_next(tmp); 
+		tmp = g_list_next(tmp);
 	}
-	
-	
+
+
 }
 
 
@@ -380,7 +386,7 @@ void main_set_parallel_options_at_start(void)
  * Synopsis
  *   #include "main/parallel_view.h"
  *
- *   void main_load_g_ops_parallel(GtkWidget *menu)	
+ *   void main_load_g_ops_parallel(GtkWidget *menu)
  *
  * Description
  *    create global options menu and set check marks
@@ -391,160 +397,160 @@ void main_set_parallel_options_at_start(void)
 
 void main_load_g_ops_parallel(GtkWidget *menu)
 {
-	GtkWidget * item;	
+	GtkWidget * item;
 	GtkWidget * variants_menu;
 	GSList *group = NULL;
-	
+
 	item = gtk_check_menu_item_new_with_label(_("Strong's Numbers"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
 
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_strongs;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*) "Strong's Numbers");
-		
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Footnotes"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_footnotes;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Footnotes");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Morphological Tags"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
 
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_morphs;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*)  "Morphological Tags");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Hebrew Vowel Points"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_hebrewpoints;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*)  "Hebrew Vowel Points");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Hebrew Cantillation"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_cantillationmarks;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Hebrew Cantillation");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Greek Accents"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_greekaccents;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*)  "Greek Accents");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Cross-references"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_crossref;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Cross-references");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Lemmas"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_lemmas;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*) "Lemmas");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Headings"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_headings;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*)  "Headings");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Morpheme Segmentation"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_segmentation;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			  (char*) "Morpheme Segmentation" );
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Words of Christ in Red"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_red_words;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Words of Christ in Red");
-	
-	
+
+
 	item = gtk_check_menu_item_new_with_label(_("Transliteration"));
-	gtk_widget_show(item);		
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_transliteration;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Transliteration");
-	
-	
+
+
 	item = gtk_menu_item_new_with_label(_("Textual Variants"));
-	gtk_widget_show(item);			
-	gtk_container_add(GTK_CONTAINER(menu), item); 
-	
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
 	variants_menu = gtk_menu_new();
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(item),
 				  variants_menu);
-	
+
 	item = gtk_radio_menu_item_new_with_mnemonic (group, _("Primary Reading" ));
   	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
 	gtk_widget_show(item);
-	gtk_container_add(GTK_CONTAINER(variants_menu), item); 
+	gtk_container_add(GTK_CONTAINER(variants_menu), item);
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_variants_primary;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Primary Reading");
-	
+
 	item = gtk_radio_menu_item_new_with_mnemonic (group, _("Secondary Reading" ));
   	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
 	gtk_widget_show(item);
-	gtk_container_add(GTK_CONTAINER(variants_menu), item); 
+	gtk_container_add(GTK_CONTAINER(variants_menu), item);
 	GTK_CHECK_MENU_ITEM(item)->active = settings.parallel_variants_secondary;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "Secondary Reading");
-	
+
 	item = gtk_radio_menu_item_new_with_mnemonic (group, _("All Readings" ));
   	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
-	gtk_widget_show(item);	
-	gtk_container_add(GTK_CONTAINER(variants_menu), item); 		
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(variants_menu), item);
 	GTK_CHECK_MENU_ITEM (item)->active = settings.parallel_variants_all;
 	g_signal_connect(GTK_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
@@ -573,7 +579,7 @@ void main_load_g_ops_parallel(GtkWidget *menu)
 
 void main_check_parallel_modules(void)
 {
-	if(settings.parallel1Module) 
+	if (settings.parallel1Module)
 		parallel1 =
 		    main_is_module(settings.parallel1Module);
 	else
@@ -624,10 +630,10 @@ void main_check_parallel_modules(void)
 
 void main_change_parallel_module(GSParallel parallel, gchar * mod_name)
 {
-	if(!mod_name) 
+	if (!mod_name)
 		return;
-	switch(parallel) {
-	case PARALLEL1:	
+	switch (parallel) {
+	case PARALLEL1:
 		xml_set_value("Xiphos", "modules", "int1",
 			      mod_name);
 		settings.parallel1Module =
@@ -635,7 +641,7 @@ void main_change_parallel_module(GSParallel parallel, gchar * mod_name)
 		parallel1 =
 		    main_is_module(settings.parallel1Module);
 		break;
-	case PARALLEL2:	
+	case PARALLEL2:
 		xml_set_value("Xiphos", "modules", "int2",
 			      mod_name);
 		settings.parallel2Module =
@@ -643,7 +649,7 @@ void main_change_parallel_module(GSParallel parallel, gchar * mod_name)
 		parallel2 =
 		    main_is_module(settings.parallel2Module);
 		break;
-	case PARALLEL3:	
+	case PARALLEL3:
 		xml_set_value("Xiphos", "modules", "int3",
 			      mod_name);
 		settings.parallel3Module =
@@ -651,7 +657,7 @@ void main_change_parallel_module(GSParallel parallel, gchar * mod_name)
 		parallel3 =
 		    main_is_module(settings.parallel3Module);
 		break;
-	case PARALLEL4:	
+	case PARALLEL4:
 		xml_set_value("Xiphos", "modules", "int4",
 			      mod_name);
 		settings.parallel4Module =
@@ -659,7 +665,7 @@ void main_change_parallel_module(GSParallel parallel, gchar * mod_name)
 		parallel4 =
 		    main_is_module(settings.parallel4Module);
 		break;
-	case PARALLEL5:	
+	case PARALLEL5:
 		xml_set_value("Xiphos", "modules", "int5",
 			      mod_name);
 		settings.parallel5Module =
@@ -706,22 +712,22 @@ void main_update_parallel_page(void)
 	gchar *buf;
 	gchar *file = NULL;
 	gchar *data = NULL;
-	
-	
+
+
 	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_parallel))) return ;
 	GeckoHtml *html = GECKO_HTML(widgets.html_parallel);
 	gecko_html_open_stream(html,"text/html");
-	
+
 	settings.cvparallel = settings.currentverse;
-	
-	if (settings.havebible) {	
+
+	if (settings.havebible) {
 		sprintf(tmpBuf, HTML_START
 			"<body bgcolor=\"%s\" text=\"%s\" link=\"%s\"><table>",
 			settings.bible_bg_color,
 			settings.bible_text_color, settings.link_color);
-		
+
 		utf8len = strlen(tmpBuf);
-		if (utf8len) {	
+		if (utf8len) {
 			data = g_strconcat(tmpBuf,NULL);
 		}
 
@@ -770,7 +776,7 @@ void main_update_parallel_page(void)
 
 			++j;
 			is_rtol = main_is_mod_rtol(mod_name);
-			
+
 			file = g_strdup_printf("%s/fonts.conf", settings.gSwordDir);
 			font_name = get_conf_file_item(file, mod_name, "Font");
 			if (!font_name || !strcmp(font_name, "none")) {
@@ -815,7 +821,7 @@ void main_update_parallel_page(void)
 
 				utf8len = strlen(tmpBuf);
 				if (utf8len) {
-					data = g_strconcat(data, tmpBuf, NULL);	
+					data = g_strconcat(data, tmpBuf, NULL);
 				}
 			}
 
@@ -830,7 +836,7 @@ void main_update_parallel_page(void)
 
 			utf8len = strlen(tmpBuf);
 			if (utf8len) {
-					data = g_strconcat(data, tmpBuf, NULL);	
+					data = g_strconcat(data, tmpBuf, NULL);
 			}
 
 			if (use_gtkhtml_font)
@@ -844,7 +850,7 @@ void main_update_parallel_page(void)
 
 			utf8len = strlen(tmpBuf);
 			if (utf8len) {
-				data = g_strconcat(data, tmpBuf, NULL);	
+				data = g_strconcat(data, tmpBuf, NULL);
 			}
 
 			utf8str =
@@ -853,12 +859,12 @@ void main_update_parallel_page(void)
 							currentverse);
 			if (is_rtol) {
 				buf = g_strdup_printf(
-					"%s","<br><DIV ALIGN=right>");			
+					"%s","<br><DIV ALIGN=right>");
 				if (strlen(buf)) {
 					data = g_strconcat(data, buf, NULL);
 					free(buf);
 				}
-			}	
+			}
 			if (strlen(utf8str)) {
 				data = g_strconcat(data, utf8str, NULL);
 				free(utf8str);
@@ -866,12 +872,12 @@ void main_update_parallel_page(void)
 
 			if (is_rtol) {
 				buf = g_strdup_printf(
-					"%s","</DIV><br>");			
+					"%s","</DIV><br>");
 				if (strlen(buf)) {
 					data = g_strconcat(data, buf, NULL);
 					free(buf);
 				}
-			}	
+			}
 			sprintf(tmpBuf,
 				"</font><small>[<a href=\"xiphos.url?action=showParallel&"
 				"type=swap&value=%s\">%s</a>]</small></td></tr>",
@@ -879,7 +885,7 @@ void main_update_parallel_page(void)
 
 			utf8len = strlen(tmpBuf);
 			if (utf8len) {
-				data = g_strconcat(data, tmpBuf, NULL);	
+				data = g_strconcat(data, tmpBuf, NULL);
 			}
 		}
 
@@ -887,13 +893,13 @@ void main_update_parallel_page(void)
 
 		utf8len = strlen(tmpBuf);
 		if (utf8len) {
-			data = g_strconcat(data, tmpBuf, NULL);	
+			data = g_strconcat(data, tmpBuf, NULL);
 			gecko_html_write(html,data,-1);
-		}	
+		}
 	}
 	gecko_html_close(html);
 	if (data)
-		g_free(data);		
+		g_free(data);
 	if (font_name)
 		free(font_name);
 	if (font_size)
@@ -931,7 +937,7 @@ void main_update_parallel_page(void)
 	gchar *file = NULL;
 
 	settings.cvparallel = settings.currentverse;
-	
+
 	if (settings.havebible) {
 		/* setup gtkhtml widget */
 		GtkHTML *html = GTK_HTML(widgets.html_parallel);
@@ -1020,7 +1026,7 @@ void main_update_parallel_page(void)
 					GS_message(("use_gtkhtml_font = FALSE"));
 				}
 			}
-						
+
 			font_size_tmp = get_conf_file_item(file, mod_name, "Fontsize");
 			g_free(file);
 			if (!font_size_tmp) {
@@ -1032,7 +1038,7 @@ void main_update_parallel_page(void)
 			    g_strdup_printf("%+d",
 					    (font_size_tmp ? atoi(font_size_tmp) : 0)
 					     + settings.base_font_size);
-		
+
 			if (j == 0 || j == 2 || j == 4)
 				rowcolor = (gchar *)"#F1F1F1";
 			else
@@ -1090,23 +1096,23 @@ void main_update_parallel_page(void)
 			    backend_p->get_render_text(mod_name,
 							settings.
 							currentverse);
-/*#ifdef  DEBUG			
-			if(!strcmp(mod_name,"KJV2006"))
+/*#ifdef  DEBUG
+			if (!strcmp(mod_name,"KJV2006"))
 				g_message("\nmod: %s\nRAW: %s\nRENDERED: %s", mod_name,
 						backend_p->get_raw_text(mod_name,
 								settings.currentverse),utf8str);
 #endif
-*/			
-			if(is_rtol) {
+*/
+			if (is_rtol) {
 				buf = g_strdup_printf(
-					"%s","<br><DIV ALIGN=right>");			
+					"%s","<br><DIV ALIGN=right>");
 				if (strlen(buf)) {
 					gtk_html_write(GTK_HTML(html),
 						       htmlstream, buf,
 						       strlen(buf));
 					free(buf);
 				}
-			}	
+			}
 			if (strlen(utf8str)) {
 				gtk_html_write(GTK_HTML(html),
 					       htmlstream, utf8str,
@@ -1114,16 +1120,16 @@ void main_update_parallel_page(void)
 				free(utf8str);
 			}
 
-			if(is_rtol) {
+			if (is_rtol) {
 				buf = g_strdup_printf(
-					"%s","</DIV><br>");			
+					"%s","</DIV><br>");
 				if (strlen(buf)) {
 					gtk_html_write(GTK_HTML(html),
 						       htmlstream, buf,
 						       strlen(buf));
 					free(buf);
 				}
-			}	
+			}
 			sprintf(tmpBuf,
 				"</font><small>[<a href=\"xiphos.url?action=showParallel&"
 				"type=swap&value=%s\">%s</a>]</small></td></tr>",
@@ -1141,7 +1147,7 @@ void main_update_parallel_page(void)
 				free(font_size);
 			if (font_size_tmp)
 				free(font_size_tmp);
-			
+
 		}
 
 		sprintf(tmpBuf, "</table></body></html>");
@@ -1193,7 +1199,7 @@ static void int_display(SWBuf& text, gchar *key, char *mod_name[])
 	char *cur_book;
 	gboolean is_module[5] = { FALSE, FALSE, FALSE, FALSE, FALSE };
 
-	if(!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.notebook_bible_parallel))) return;
+	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.notebook_bible_parallel))) return;
 
 	// need #verses to process in this book.
 	VerseKey vkey;
@@ -1356,24 +1362,24 @@ void main_update_parallel_page_detached(void)
 	mod_name[2] = (parallel3 ? settings.parallel3Module : space);
 	mod_name[3] = (parallel4 ? settings.parallel4Module : space);
 	mod_name[4] = (parallel5 ? settings.parallel5Module : space);
-    
+
     	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[0]);
     	gtk_label_set_markup(GTK_LABEL(plabels.label_1), buf);
-    
+
     	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[1]);
     	gtk_label_set_markup(GTK_LABEL(plabels.label_2), buf);
-    
+
     	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[2]);
     	gtk_label_set_markup(GTK_LABEL(plabels.label_3), buf);
-    	
+
     	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[3]);
     	gtk_label_set_markup(GTK_LABEL(plabels.label_4), buf);
-    
+
     	snprintf(buf, 499, "<span color='blue' weight='bold'>%s</span>", mod_name[4]);
     	gtk_label_set_markup(GTK_LABEL(plabels.label_5), buf);
-    
+
 #ifdef USE_GTKMOZEMBED
-	if(!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_parallel_dialog))) return;
+	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_parallel_dialog))) return;
 #endif
 
 	snprintf(buf, 499, HTML_START
@@ -1381,18 +1387,18 @@ void main_update_parallel_page_detached(void)
 		settings.bible_bg_color, settings.bible_text_color,
 		settings.link_color);
 	text += buf;
-	
+
 	for (j = 0; j < 5; ++j){
 		snprintf(buf, 499,
 			"<td valign=\"top\" width=\"20%%\" bgcolor=\"#f1f1f1\"><font color=\"%s\" size=\"%+d\"><b>%s</b></td>",
-			settings.bible_verse_num_color, 
+			settings.bible_verse_num_color,
 			settings.verse_num_font_size + settings.base_font_size,
 			mod_name[j]);
 		text += buf;
 	}
 
 	text += "</tr>";
-	int_display(text, settings.cvparallel, mod_name);	
+	int_display(text, settings.cvparallel, mod_name);
 	text += "</table></body></html>";
 
 	snprintf(buf, 499, "%d", ((settings.intCurVerse > 1)
@@ -1532,7 +1538,7 @@ void main_init_parallel_view(void)
  *   void main_delete_parallel_view(void)
  *
  * Description
- *   delete the sword backend for the parallel view  
+ *   delete the sword backend for the parallel view
  *
  * Return value
  *   void
@@ -1541,5 +1547,5 @@ void main_init_parallel_view(void)
 void main_delete_parallel_view(void)
 {
 	delete backend_p;
-	
+
 }
