@@ -24,7 +24,7 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <glib/gstdio.h>
 #include <swmodule.h>
 #include <swmgr.h>
@@ -34,6 +34,7 @@
 #include <iostream>
 #include <string>
 #include <stdio.h>
+#include <unistd.h>
 
 
 #include "main/mod_mgr.h"
@@ -48,6 +49,8 @@
 
 #include "backend/sword_main.hh"
 
+#include "gui/debug_glib_null.h"
+
 #ifndef NO_SWORD_NAMESPACE
 using sword::TreeKeyIdx;
 using sword::RawGenBook;
