@@ -1,6 +1,6 @@
-/* 
+/*
  * Xiphos Bible Study Tool
- * previewer.h - 
+ * previewer.h -
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
- 
+
 #ifndef _PREVIEWER_H
 #define _PREVIEWER_H
 
@@ -27,13 +27,14 @@ extern "C"
 {
 #endif
 
+void main_init_previewer(void);
 void main_set_previewer_widget(int in_sidebar);
 GtkWidget *main_get_previewer_widget(void);
 void main_clear_viewer(void);
 void main_information_viewer(const char * mod_name, const char * text, const char * key,
 		             const char * action, const char * type, const char * morph_text,
 			     const char * morph);
-void mark_search_words(GString * str, gboolean eliminate);
+void mark_search_words(GString * str);
 void main_entry_display(gpointer data, char * mod_name,
 		   char * text, char * key, gboolean show_key);
 
