@@ -22,12 +22,16 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <regex.h>
 #include <swbuf.h>
 #include <swmodule.h>
 #ifdef USE_GTKMOZEMBED
+#ifdef WIN32
+#include "geckowin/gecko-html.h"
+#else
 #include "gecko/gecko-html.h"
+#endif
 #else
 #ifdef __cplusplus
 extern "C" {
@@ -38,14 +42,14 @@ extern "C" {
 }
 #endif
 #endif
-	
+
 #include "main/previewer.h"
 #include "main/search_dialog.h"
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/xml.h"
 #include "main/url.hh"
- 
+
 #include "gui/search_dialog.h"
 #include "gui/bookmark_dialog.h"
 #include "gui/bookmarks_treeview.h"
@@ -53,13 +57,15 @@ extern "C" {
 #include "gui/widgets.h"
 #include "gui/dialog.h"
 #include "gui/utilities.h"
-
+#include "gui/export_bookmarks.h"
 
 #include "backend/sword_main.hh"
 
+#include "gui/debug_glib_null.h"
+
 #define SEARCHING _("Searching the ")
 #define SMODULE _(" Module")
-#define FINDS _("found in ")		
+#define FINDS _("found in ")
 #define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
 
 static BackEnd *backendSearch = NULL;
@@ -80,6 +86,83 @@ int drag_module_type;
 static GList *list_of_finds;
 static GList *list_for_bookmarking = NULL;
 
+
+
+/******************************************************************************
+ * Name
+ *   main_export_current_adv_search
+ *
+ * Synopsis
+ *   #include "main/search_dialog.h"
+ *
+ *   void  main_export_current_adv_search(GString * str, gboolean html)
+ *
+ * Description
+ *   exports search results to html or plain text
+ *
+ *
+ * Return value
+ *   void
+ */
+
+gboolean main_export_current_adv_search (GString * str, gboolean html, gboolean with_scripture)
+{
+	GList *verses = NULL;
+	GList *tmp = NULL;
+	RESULTS *list_item;
+	gboolean ret = FALSE;
+	gchar *desc;
+
+	tmp = g_list_first(list_for_bookmarking);
+	if (html)
+		str = g_string_append(str, "<html><body>");
+	while (tmp) {
+		verses = (GList*) tmp->data;
+
+		GString *verse_string = g_string_new("");
+		gboolean first_entry = TRUE;
+
+		while (verses) {
+			list_item = (RESULTS *) verses->data;
+			if (main_is_Bible_key(list_item->key)) {
+				ret = TRUE;
+				if (first_entry) {
+					if (html)
+						g_string_printf(verse_string, "<ul><b>%s</b>", list_item->module);
+					else
+						g_string_printf(verse_string, "%s\n", list_item->module);
+					first_entry = FALSE;
+					str = g_string_append(str, verse_string->str);
+				} else {
+					desc = g_strdup_printf("%s %s",
+					    			list_item->key,
+					    			list_item->module);
+					if (html)
+						gui_set_html_item ( str,
+								desc,
+								list_item->module,
+								list_item->key,
+								with_scripture);
+					else
+						gui_set_plain_text_item ( str,
+								desc,
+								list_item->module,
+								list_item->key,
+								with_scripture);
+
+				}
+			}
+			verses = g_list_next(verses);
+		}
+		g_string_free(verse_string, TRUE);
+		if (html)
+			str = g_string_append(str, "</ul>");
+		tmp = g_list_next(tmp);
+	}
+	return ret;
+}
+
+
 /******************************************************************************
  * Name
  *   main_save_current_adv_search_as_bookmarks
@@ -91,22 +174,22 @@ static GList *list_for_bookmarking = NULL;
  *
  * Description
  *   saves search results as bookmarks - single bookmark per module
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void main_save_current_adv_search_as_bookmarks (void)
-{	
+{
 	GList *verses = NULL;
 	RESULTS *list_item;
 	gchar *module_name = NULL;
-	
+
 	list_for_bookmarking = g_list_first(list_for_bookmarking);
 	while (list_for_bookmarking) {
 		verses = (GList*) list_for_bookmarking->data;
-		
+
 		GString *name = g_string_new(NULL);
 		GString *verse_string = g_string_new("");
 		gboolean first_entry = TRUE;
@@ -213,16 +296,16 @@ void main_range_text_changed(GtkEditable * editable)
  *   void set_search_global_option(gchar * option, gchar * choice)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 static void set_search_global_option(const gchar * option, gboolean choice)
-{	
+{
 	const char *on_off;
-	SWMgr *mgr = backendSearch->get_display_mgr();
+	SWMgr *mgr = backendSearch->get_mgr();
 
 	if (choice) {
 		on_off = "On";
@@ -381,10 +464,10 @@ void main_delete_range(void)
  * Synopsis
  *   #include "gui/search_dialog.h"
  *
- *   void 
+ *   void
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -397,7 +480,7 @@ static void add_module_finds(GList * versekeys)
 	GtkListStore *list_store;
 	GtkTreeIter iter;
 	GList *tmp = g_list_first(versekeys);
-	
+
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
 				    (search1.listview_verses));
@@ -405,12 +488,12 @@ static void add_module_finds(GList * versekeys)
 
 	gtk_list_store_clear(list_store);
 
-	while (tmp) {	
+	while (tmp) {
 		buf =  (char*) tmp->data;
 		gtk_list_store_append(list_store, &iter);
-		gtk_list_store_set(list_store, 
+		gtk_list_store_set(list_store,
 				   &iter,
-				   0,buf, 
+				   0,buf,
 				   -1);
 		tmp = g_list_next(tmp);
 	}
@@ -453,15 +536,15 @@ static void add_ranges(void)
 			buf[1] = xml_get_list();
 
 			gtk_list_store_append(list_store, &iter);
-			gtk_list_store_set(list_store, 
+			gtk_list_store_set(list_store,
 					   &iter,
-					   0, buf[0], 
-					   1, buf[1], 
+					   0, buf[0],
+					   1, buf[1],
 					   -1);
 			g_free(buf[0]);
 			g_free(buf[1]);
 		}
-		
+
 		gui_clear_combo(search1.combo_range);
 		while (xml_next_item()) {
 			if (xml_get_label()) {
@@ -469,9 +552,9 @@ static void add_ranges(void)
 				buf[1] = xml_get_list();
 
 				gtk_list_store_append(list_store, &iter);
-				gtk_list_store_set(list_store, 
-						   &iter, 
-						   0, buf[0], 
+				gtk_list_store_set(list_store,
+						   &iter,
+						   0, buf[0],
 						   1, buf[1],
 						   -1);
 				gui_add_item_to_combo(search1.combo_range,
@@ -519,10 +602,10 @@ static void add_modlist(void)
 			buf[1] = xml_get_list();
 
 			gtk_list_store_append(list_store, &iter);
-			gtk_list_store_set(list_store, 
+			gtk_list_store_set(list_store,
 					   &iter,
-					   0, buf[0], 
-					   1, buf[1], 
+					   0, buf[0],
+					   1, buf[1],
 					   -1);
 			g_free(buf[0]);
 			g_free(buf[1]);
@@ -535,9 +618,9 @@ static void add_modlist(void)
 				buf[1] = xml_get_list();
 
 				gtk_list_store_append(list_store, &iter);
-				gtk_list_store_set(list_store, 
-						   &iter, 
-						   0, buf[0], 
+				gtk_list_store_set(list_store,
+						   &iter,
+						   0, buf[0],
 						   1, buf[1],
 						   -1);
 				gui_add_item_to_combo(search1.combo_list,
@@ -571,7 +654,7 @@ static void add_modlist(void)
 void main_change_mods_select_label(char *mod_name)
 {
 	gchar *str;
-	
+
 	if (GTK_TOGGLE_BUTTON(search1.rb_current_module)->active) {
 		str = g_strdup_printf("<b>%s</b>%s",Q_("Search: "),mod_name);
 		gtk_label_set_markup(GTK_LABEL(search1.label_mod_select), str);
@@ -583,15 +666,15 @@ void main_change_mods_select_label(char *mod_name)
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/search_dialog.h"
  *
- *   
+ *
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -657,14 +740,14 @@ void main_add_mod_to_list(GtkWidget * tree_widget, gchar * mod_name)
 	gchar *mod_list = NULL;
 	GList *mods = NULL;
 	GtkTreeSelection *selection_modules_lists;
-	
+
 	model_modules_lists =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
 	store_modules_lists = GTK_LIST_STORE(model_modules_lists);
 
 	selection_modules_lists = gtk_tree_view_get_selection
 	    (GTK_TREE_VIEW(search1.module_lists));
-	    
+
 	model_mods =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(tree_widget));
 	list_store = GTK_LIST_STORE(model_mods);
@@ -679,9 +762,9 @@ void main_add_mod_to_list(GtkWidget * tree_widget, gchar * mod_name)
 
 			if (mod_list) {
 				gtk_tree_selection_get_selected
-	   			       (selection_modules_lists, NULL, 
+	   			       (selection_modules_lists, NULL,
 					          &selected_modules_lists);
-				
+
 				gtk_list_store_set(store_modules_lists,
 						   &selected_modules_lists,
 						   1, mod_list, -1);
@@ -709,7 +792,7 @@ void main_drag_drop_display_in_main(const char * uri)
  *		      GtkWidget * tree_widget)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -736,7 +819,7 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
 
 	if (!gtk_tree_selection_get_selected(selection, NULL, &selected))
 		return;
-	
+
 	model_mods =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
 				    (search1.listview_modules));
@@ -750,12 +833,12 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
 	selection_modules_lists = gtk_tree_view_get_selection
 	    (GTK_TREE_VIEW(search1.module_lists));
 
-	if (gtk_tree_model_iter_has_child(model, &selected)) 
+	if (gtk_tree_model_iter_has_child(model, &selected))
 		return;
 
 	gtk_tree_model_get(model, &selected, 0, &mod, -1);
 	if (mod) {
-		mod_description = 
+		mod_description =
 			backendSearch->module_description(mod);
 
 		if (GTK_TOGGLE_BUTTON(search1.rb_current_module)->active) {
@@ -771,9 +854,9 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
 
 			if (mod_list) {
 				gtk_tree_selection_get_selected
-	   			       (selection_modules_lists, NULL, 
+	   			       (selection_modules_lists, NULL,
 					          &selected_modules_lists);
-				
+
 				gtk_list_store_set(store_modules_lists,
 						   &selected_modules_lists,
 						   1, mod_list, -1);
@@ -798,7 +881,7 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
  *		     					 gpointer data)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -812,7 +895,7 @@ void main_selection_finds_list_changed(GtkTreeSelection *
 	GtkTreeModel *model;
 	GtkTreeIter selected;
 	GtkTreePath *path;
-	
+
  	if (!gtk_tree_selection_get_selected (selection,&model,&selected))
 		return;
 	gtk_tree_model_get(model, &selected, 0, &text, -1);
@@ -822,13 +905,13 @@ void main_selection_finds_list_changed(GtkTreeSelection *
 	tmp = g_list_nth(list_of_finds,atoi(path_str));
 	tmp = (GList*)tmp->data;
 	add_module_finds(tmp);
-	
+
 	if (text)
 		g_free(text);
 	if (path_str)
 		g_free(path_str);
 	gtk_tree_path_free(path);
-	
+
 }
 
 
@@ -843,14 +926,14 @@ void main_selection_finds_list_changed(GtkTreeSelection *
  *		     					 gpointer data)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
-					    GtkTreeModel * model, 
+					    GtkTreeModel * model,
 					    gboolean is_double_click)
 {
 	gchar *text, *buf, *module, *key;
@@ -872,7 +955,7 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 
 	// key begins 2 chars after module.
 	key = buf + 2;
-					     
+
 	if (verse_selected)
 		g_free(verse_selected);
 	drag_module_type = backendSearch->module_type(module);
@@ -889,12 +972,12 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 	g_free((gchar *)temp_key);
 
 	text_str = g_string_new(backendSearch->get_render_text(module,key));
-	mark_search_words(text_str, FALSE);
+	mark_search_words(text_str);
 
 #ifdef USE_GTKMOZEMBED
 	GString *html_text = g_string_new(HTML_START);
 	g_string_append(html_text, text_str->str);
-	g_string_append(html_text, "</html>");	
+	g_string_append(html_text, "</html>");
 	gecko_html_open_stream(GECKO_HTML(search1.preview_html), "text/html");
 	gecko_html_write(GECKO_HTML(search1.preview_html),
 			 html_text->str, html_text->len);
@@ -915,7 +998,7 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/search_dialog.h"
@@ -924,7 +1007,7 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
  *		     					 gpointer data)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -984,18 +1067,18 @@ void main_selection_modules_lists_changed(GtkTreeSelection *
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/search_dialog.h"
  *
- *   
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
- *   
+ *
  */
 
 gchar *get_modlist_string(GList * mods)
@@ -1029,7 +1112,7 @@ gchar *get_modlist_string(GList * mods)
  *   void add_modlist_to_label(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -1061,10 +1144,10 @@ void main_comboboxentry2_changed(GtkComboBox * combobox, gpointer user_data)
 	gchar *str = NULL;
 	gchar *mod_list_str = NULL;
 	const gchar *name = NULL;
-	
+
 	if (!GTK_TOGGLE_BUTTON(search1.rb_custom_list)->active)
 		return;
-	name = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combobox)->child)); 
+	name = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combobox)->child));
 	mod_list = get_custom_list_from_name(name);
 	mod_list_str = get_modlist_string(mod_list);
 	if (strlen(mod_list_str) > 60)
@@ -1081,15 +1164,15 @@ void main_comboboxentry2_changed(GtkComboBox * combobox, gpointer user_data)
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/search_dialog.h"
  *
- *   
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -1124,7 +1207,7 @@ static void check_search_global_options(void)
  *   GList *get_current_search_mod(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GList *
@@ -1150,7 +1233,7 @@ static GList *get_current_search_mod(void)
  *   GList *get_current_list(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   GList *
@@ -1291,10 +1374,10 @@ static void set_up_dialog_search(GList *modlist)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   char *main_get_rendered_text(char *module_name, char *key)	
+ *   char *main_get_rendered_text(char *module_name, char *key)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1311,7 +1394,7 @@ void _clear_find_lists(void)
 {
 	GList *tmp = NULL;
 	gchar *tmp_buf = NULL;
-	
+
 	list_of_finds = g_list_first(list_of_finds);
 	while (list_of_finds) {
 		tmp = (GList*) list_of_finds->data;
@@ -1333,7 +1416,7 @@ void _clear_bookmarking_lists(void)
 {
 	GList *tmp = NULL;
 	RESULTS *results;
-	
+
 	list_for_bookmarking = g_list_first(list_for_bookmarking);
 	while (list_for_bookmarking) {
 		tmp = (GList*) list_for_bookmarking->data;
@@ -1376,10 +1459,10 @@ void main_do_dialog_search(void)
 	char *num;
 	gchar msg[300];
 	RESULTS *results;
-	
+
 	_clear_find_lists();
 	_clear_bookmarking_lists();
-	
+
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
 				    (search1.listview_results));
@@ -1391,16 +1474,16 @@ void main_do_dialog_search(void)
 				    (search1.listview_verses));
 	list_store2 = GTK_LIST_STORE(model2);
 	gtk_list_store_clear(list_store2);
-	
+
 	search_string =
 	    gtk_entry_get_text(GTK_ENTRY(search1.search_entry));
-	
+
 	if (strlen(search_string) < 1)
 		return;
 	str = g_string_new("");
 
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(search1.notebook), 1);
-	search_type = 
+	search_type =
 	    GTK_TOGGLE_BUTTON(search1.rb_regexp)->active ? 0 :
 	    GTK_TOGGLE_BUTTON(search1.rb_exact_phrase)->active ? -1 :
 	    GTK_TOGGLE_BUTTON(search1.rb_words)->active ? -2 :
@@ -1412,9 +1495,9 @@ void main_do_dialog_search(void)
 
 	// For attribute-based searches, e.g. "Word//Lemma/G140",
 	// we must constrain the match to whole words.  Otherwise,
-	// we will inadvertently return e.g. 140 plus 1401 and 1404.		
-	if(search_type == -3) {
-		if(GTK_TOGGLE_BUTTON(search1.rb_strongs)->active) {
+	// we will inadvertently return e.g. 140 plus 1401 and 1404.
+	if (search_type == -3) {
+		if (GTK_TOGGLE_BUTTON(search1.rb_strongs)->active) {
 			search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
 			attribute_search_string = g_strdup_printf(
 #ifdef SWORD_MULTIVERSE
@@ -1423,12 +1506,12 @@ void main_do_dialog_search(void)
 					"Word//Lemma/%s",
 #endif
 					search_string);
-		} else if(GTK_TOGGLE_BUTTON(search1.rb_morphs)->active) {
+		} else if (GTK_TOGGLE_BUTTON(search1.rb_morphs)->active) {
 			search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
 			attribute_search_string = g_strdup_printf(
 					"Word//Morph/%s",
 					search_string);
-		} else if(GTK_TOGGLE_BUTTON(search1.rb_footnotes)->active) {
+		} else if (GTK_TOGGLE_BUTTON(search1.rb_footnotes)->active) {
 			attribute_search_string = g_strdup_printf(
 					"Footnote//body/%s",
 					search_string);
@@ -1458,6 +1541,12 @@ void main_do_dialog_search(void)
 	terminate_search = FALSE;
 	search_active = TRUE;
 
+	// must ensure that no accents or vowel points are enabled.
+	SWMgr *mgr = backendSearch->get_mgr();
+	mgr->setGlobalOption("Greek Accents", "Off");
+	mgr->setGlobalOption("Hebrew Vowel Points", "Off");
+	mgr->setGlobalOption("Arabic Vowel Points", "Off");
+
 	while (search_mods != NULL) {
 		module = (gchar *) search_mods->data;
 
@@ -1494,32 +1583,34 @@ void main_do_dialog_search(void)
 			}
 		}
 		GS_message(("search_type = %d",search_type));
-		
-		finds = backendSearch->do_module_search(module, 
+
+		finds = backendSearch->do_module_search(module,
 					(attribute_search_string
-					 ? attribute_search_string
-					 : search_string),
-					search_type, 
-					search_params, 
+					 ? mgr->getModule(module)->
+						StripText(attribute_search_string)
+					 : mgr->getModule(module)->
+						StripText(search_string)),
+					search_type,
+					search_params,
 					TRUE);
-		
+
 		tmp_list = g_list_first(tmp_list);
 		tmp_list = NULL;
 		tmp_bookmark_list = g_list_first(tmp_bookmark_list);
 		tmp_bookmark_list = NULL;
-		
-		mod_type = backendSearch->module_type(module);	
+
+		mod_type = backendSearch->module_type(module);
 		while ((key_buf = backendSearch->get_next_listkey()) != NULL) {
-			if (mod_type == TEXT_TYPE)			
+			if (mod_type == TEXT_TYPE)
 				g_string_printf(str, "%s: %s  %s", module,  key_buf, backendSearch->get_strip_text(module, key_buf));
-			else			
-				g_string_printf(str, "%s: %s", module,  key_buf);				
+			else
+				g_string_printf(str, "%s: %s", module,  key_buf);
 			tmp_list = g_list_append(tmp_list, (char*) g_strdup(str->str));
-						  
+
 			results = g_new(RESULTS,1);
 			results->module = g_strdup(module);
 			results->key = g_strdup(key_buf);
-			tmp_bookmark_list = g_list_append(tmp_bookmark_list, 
+			tmp_bookmark_list = g_list_append(tmp_bookmark_list,
 							(RESULTS*) results);
 		}
 		list_of_finds = g_list_append(list_of_finds, (GList*)tmp_list);
@@ -1531,9 +1622,9 @@ void main_do_dialog_search(void)
 				num, FINDS, module);
 		g_free(num);
 		gtk_list_store_append(list_store, &iter);
-		gtk_list_store_set(list_store, 
+		gtk_list_store_set(list_store,
 				   &iter,
-				   0, str->str, 
+				   0, str->str,
 				   -1);
 		++x;
 		if (x == 1) { // add verse list for hits in first module to verse listview
@@ -1547,12 +1638,13 @@ void main_do_dialog_search(void)
 	}
 	search_active = FALSE;
 
-	if(attribute_search_string)
+	if (attribute_search_string)
 		g_free((gchar*)attribute_search_string);
 	g_list_free(search_mods);
 	gui_set_progressbar_text(search1.progressbar, _("Search finished"));
 	gui_set_progressbar_fraction(search1.progressbar, 0);
-	g_string_free(str, TRUE);	
+	g_string_free(str, TRUE);
+	gtk_widget_grab_focus(search1.listview_verses);
 }
 
 /******************************************************************************
@@ -1579,12 +1671,12 @@ void main_open_search_dialog(void)
 			delete backendSearch;
 
 		backendSearch = new BackEnd();
-		
+
 		/* create and show search dialog */
 		gui_create_search_dialog();
 		backendSearch->init_SWORD(2);
-		
-		
+
+
 		/* initiate module count to 0 */
 		search1.module_count = 0;
 
@@ -1622,21 +1714,21 @@ void main_close_search_dialog(void)
  * Synopsis
  *   #include "main/search.h"
  *
- *   void search_percent_update(char percent, void *userData)	
+ *   void search_percent_update(char percent, void *userData)
  *
  * Description
  *    updates the progress bar during shortcut bar search
  *
  * Return value
  *   void
- */ 
+ */
 
 void main_dialog_search_percent_update(char percent, void *userData)
 {
 	char maxHashes = *((char *) userData);
 	float num;
 	static char printed = 0;
-	
+
 	if (terminate_search) {
 		backendSearch->terminate_search();
 		// this is WAY WRONG but at least it cleans up the dying window. */
@@ -1651,6 +1743,5 @@ void main_dialog_search_percent_update(char percent, void *userData)
 		}
 		printed = 0;
 	}
-	while (gtk_events_pending())
-		gtk_main_iteration();
+	sync_windows();
 }
