@@ -22,9 +22,10 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <regex.h>
 #include <ctype.h>
+#include <swmodule.h>
 
 
 #ifdef __cplusplus
@@ -34,14 +35,14 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-	
+
 
 #include "main/search_dialog.h"
 #include "main/search_sidebar.h"
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/xml.h"
- 
+
 #include "gui/search_dialog.h"
 #include "gui/search_sidebar.h"
 #include "gui/sidebar.h"
@@ -51,9 +52,15 @@ extern "C" {
 
 #include "backend/sword_main.hh"
 
+#include "gui/debug_glib_null.h"
+
+#ifdef HAVE_DBUS
+#include "gui/ipc.h"
+#endif
+
 #define SEARCHING N_("Searching the ")
 #define SMODULE N_(" Module")
-#define FINDS N_("found in ")		
+#define FINDS N_("found in ")
 #define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
 
 static BackEnd *backendSearch;
@@ -71,7 +78,7 @@ int search_dialog;
  * Synopsis
  *   #include "sidebar_search.h"
  *
- *   void fill_search_results_list(int finds) 
+ *   void fill_search_results_list(int finds)
  *
  * Description
  *   display a list of keys found during search
@@ -89,11 +96,16 @@ static void fill_search_results_list(int finds)
 	GtkListStore *list_store;
 	GtkTreeIter iter;
 	GtkTreeSelection *selection;
-	GtkTreePath *path;	
+	GtkTreePath *path;
 	gchar *buf1 = _("matches");
 	RESULTS *list_item;
 	gchar *num;
-	
+
+	if (!backendSearch)
+		main_init_sidebar_search_backend();
+
+	is_search_result = TRUE;
+
 	if (list_of_verses) {
 		GList *chaser = list_of_verses;
 		while (chaser) {
@@ -106,59 +118,73 @@ static void fill_search_results_list(int finds)
 		g_list_free(list_of_verses);
 		list_of_verses = NULL;
 	}
-	
+
 	gtk_widget_set_sensitive(sidebar.menu_item_save_search,FALSE);
 	selection = gtk_tree_view_get_selection
-                                          (GTK_TREE_VIEW(sidebar.results_list));
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(sidebar.results_list));
-	list_store = GTK_LIST_STORE(model);
-	gtk_list_store_clear(list_store);
+		(GTK_TREE_VIEW(sidebar.results_list));
+	list_store = gtk_list_store_new(1, G_TYPE_STRING);
+
 	backendSearch->set_listkey_position((char) 1);	/* TOP */
 	while ((key_buf = backendSearch->get_next_listkey()) != NULL) {
 		tmpbuf = (gchar*) key_buf;
 		gtk_list_store_append(list_store, &iter);
 		gtk_list_store_set(list_store, &iter, 0,
-					   tmpbuf, -1);
+				   tmpbuf, -1);
 		list_item = g_new(RESULTS,1);
 		list_item->module = g_strdup(settings.sb_search_mod);
 		list_item->key = g_strdup(tmpbuf);
-		list_of_verses = g_list_append(list_of_verses, 
-						(RESULTS *) list_item);
+		list_of_verses = g_list_append(list_of_verses,
+					       (RESULTS *) list_item);
 	}
-	
+
+	model = GTK_TREE_MODEL(list_store);
+	gtk_tree_view_set_model (GTK_TREE_VIEW(sidebar.results_list), model);
+
 	num = main_format_number(finds);
 	sprintf(buf, "%s %s", num, buf1);
 	g_free(num);
 	gui_set_statusbar (buf);
-	//gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar), buf);
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_sidebar),3);
 	/* cleanup progress bar */
-	gtk_progress_bar_update(GTK_PROGRESS_BAR(ss.progressbar_search),
+	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(ss.progressbar_search),
 				0.0);
-	/* display first item in list by selection row*/	
-	if(!gtk_tree_model_get_iter_first(model,&iter))
+	/* display first item in list by selection row*/
+	if (!gtk_tree_model_get_iter_first(model,&iter))
 		return;
-	
+
 	gtk_widget_set_sensitive(sidebar.menu_item_save_search,TRUE);
-	path = gtk_tree_model_get_path(model,&iter);				
+	path = gtk_tree_model_get_path(model,&iter);
 	gtk_tree_selection_select_path(selection,
-                                             path);
-	gtk_tree_path_free(path);	 
+				       path);
+	gtk_tree_path_free(path);
 	gui_verselist_button_release_event(NULL,NULL,NULL);
+	return;
 }
 
+#ifdef HAVE_DBUS
+GList* get_list_of_references()
+{
+	RESULTS* list_item;
+	GList *tmp = list_of_verses;
+	GList *references = NULL;
+	while (tmp) {
+		list_item = (RESULTS*)tmp->data;
+		references = g_list_append(references, list_item->key);
+		tmp = g_list_next(tmp);
+	}
+	return g_list_first(references);
+}
+#endif
 
 /******************************************************************************
  * Name
- *    on_search_botton_clicked
+ *    main_do_sidebar_search
  *
  * Synopsis
- *   #include "shortcutbar_search.h"
- *
- *   void on_search_botton_clicked(GtkButton * button, gpointer user_data)
+ *    main_do_sidebar_search(gpointer user_data)
  *
  * Description
- *   prepare to begin search
+ *   search from sidebar
  *
  * Return value
  *   void
@@ -167,25 +193,28 @@ static void fill_search_results_list(int finds)
 void main_do_sidebar_search(gpointer user_data)
 {
 	GString *new_search = g_string_new(NULL);
-	int search_params, finds;
+	gint search_params, finds;
 	const char *search_string = NULL;
-	char *search_module;	
-	
+	char *search_module;
+
+	if (!backendSearch)
+		main_init_sidebar_search_backend();
+
 	gtk_widget_set_sensitive(sidebar.menu_item_save_search,FALSE);
 	search_dialog = FALSE;
 	search_string = gtk_entry_get_text(GTK_ENTRY(ss.entrySearch));
-	
-	if(strlen(search_string) < 1) 
+
+	if (strlen(search_string) < 1)
 		return;
-	
+
 	if (GTK_TOGGLE_BUTTON(ss.radiobutton_search_text)->active) {
 		strcpy(settings.sb_search_mod,
 		       settings.MainWindowModule);
 	}
 	else if (GTK_TOGGLE_BUTTON(ss.radiobutton_search_comm)->active) {
 		strcpy(settings.sb_search_mod,settings.CommWindowModule);
-	} 	
-	
+	}
+
 	search_module = settings.sb_search_mod;
 
 	backendSearch->clear_scope();
@@ -208,7 +237,7 @@ void main_do_sidebar_search(gpointer user_data)
 
 	snprintf(settings.searchText, 255, "%s", search_string);
 
-	settings.searchType = 
+	settings.searchType =
 		GTK_TOGGLE_BUTTON(ss.rbRegExp)->active ? 0 :
 	    	GTK_TOGGLE_BUTTON(ss.rbPhraseSearch)->active ? -1 : -2;
 
@@ -237,17 +266,40 @@ void main_do_sidebar_search(gpointer user_data)
 	terminate_search = FALSE;
 	search_active = TRUE;
 
-	finds = backendSearch->do_module_search(search_module, search_string,
-				 settings.searchType, search_params, FALSE);
+	// must ensure that no accents or vowel points are enabled.
+	SWMgr *mgr = backendSearch->get_mgr();
+	mgr->setGlobalOption("Greek Accents", "Off");
+	mgr->setGlobalOption("Hebrew Vowel Points", "Off");
+	mgr->setGlobalOption("Arabic Vowel Points", "Off");
+
+	finds = backendSearch->do_module_search(search_module,
+						mgr->getModule(search_module)->
+						     StripText(search_string),
+						settings.searchType,
+						search_params,
+						FALSE);
 	g_string_free(new_search, TRUE);
 
 	search_active = FALSE;
 
-	fill_search_results_list(finds);
+	fill_search_results_list (finds);
+
+#ifdef HAVE_DBUS
+	IpcObject *obj = ipc_get_main_ipc();
+	if (obj){
+		obj->references = get_list_of_references();
+		ipc_object_search_performed(obj, settings.searchText,
+					    &finds, NULL);
+	}
+#endif
+
 }
 
 void main_sidebar_perscomm_dump(void)
 {
+	if (!backendSearch)
+		main_init_sidebar_search_backend();
+
 	strcpy(settings.sb_search_mod,settings.MainWindowModule);
 	backendSearch->clear_scope();
 	backendSearch->clear_search_list();
@@ -256,43 +308,48 @@ void main_sidebar_perscomm_dump(void)
 		/* find one character */	".",
 		/* regexp */			0,
 		/* case is irrelevant */	0,
-		/* happening in sidebar */	FALSE));
+						 /* happening in sidebar */	FALSE));
 }
 
 void main_init_sidebar_search_backend(void)
 {
-	backendSearch = new BackEnd();
-	
+	if (!backendSearch)
+	{
+		backendSearch = new BackEnd();
+		main_search_sidebar_fill_bounds_combos();
+	}
 }
 
 void main_delete_sidebar_search_backend(void)
 {
 	delete backendSearch;
-	
 }
 
 void main_search_sidebar_fill_bounds_combos(void)
 {
-	VerseKey key; 
+	VerseKey key;
 	char *book = NULL;
 	char *module_name;
 	int i = 0;
 	int testaments;
-	
+
+	if (!backendSearch)
+		main_init_sidebar_search_backend();
+
 	//module_name = settings.sb_search_mod;
 	module_name = g_strdup(settings.MainWindowModule);
 
 	testaments = backendSearch->module_get_testaments(module_name);
-	
+
 	GtkTreeModel* upper_model = gtk_combo_box_get_model(
 			GTK_COMBO_BOX(ss.entryUpper));
 	gtk_list_store_clear(GTK_LIST_STORE(upper_model));
 	GtkTreeModel* lower_model = gtk_combo_box_get_model(
 			GTK_COMBO_BOX(ss.entryLower));
 	gtk_list_store_clear(GTK_LIST_STORE(lower_model));
-	
+
 	if (backendSearch->module_has_testament(module_name, 1)) {
-		while(i < key.BMAX[0]) { 			
+		while (i < key.BMAX[0]) {
 #ifdef SWORD_MULTIVERSE
 			key.Testament(1);
 			key.Book(i+1);
@@ -306,10 +363,10 @@ void main_search_sidebar_fill_bounds_combos(void)
 			g_free(book);
 		}
 	}
-	
+
 	i = 0;
 	if (backendSearch->module_has_testament(module_name, 2)) {
-		while(i < key.BMAX[1]) {			
+		while (i < key.BMAX[1]) {
 #ifdef SWORD_MULTIVERSE
 			key.Testament(2);
 			key.Book(i+1);
@@ -324,7 +381,7 @@ void main_search_sidebar_fill_bounds_combos(void)
 		}
 	}
 	gtk_combo_box_set_active(GTK_COMBO_BOX(ss.entryLower),0);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(ss.entryUpper),65);	
+	gtk_combo_box_set_active(GTK_COMBO_BOX(ss.entryUpper),65);
 }
 
 
@@ -335,14 +392,14 @@ void main_search_sidebar_fill_bounds_combos(void)
  * Synopsis
  *   #include "main/search.h"
  *
- *   void search_percent_update(char percent, void *userData)	
+ *   void search_percent_update(char percent, void *userData)
  *
  * Description
  *    updates the progress bar during shortcut bar search
  *
  * Return value
  *   void
- */ 
+ */
 
 void main_sidebar_search_percent_update(char percent, void *userData)
 {
@@ -350,19 +407,20 @@ void main_sidebar_search_percent_update(char percent, void *userData)
 	float num;
 	char buf[80];
 	static char printed = 0;
-	
+	if (!backendSearch)
+		main_init_sidebar_search_backend();
+
 	if (terminate_search) {
 		backendSearch->terminate_search();
 	} else {
 		while ((((float) percent) / 100) * maxHashes > printed) {
 		    sprintf(buf, "%f", (((float) percent) / 100));
 		    num = (float) percent / 100;
-		    gtk_progress_bar_update((GtkProgressBar *)
+		    gtk_progress_bar_set_fraction((GtkProgressBar *)
 					    ss.progressbar_search, num);
 		    printed++;
 		}
 	}
-	while (gtk_events_pending())
-		gtk_main_iteration();
+	sync_windows();
 	printed = 0;
 }
