@@ -24,7 +24,7 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include <fcntl.h>
 #include <stdio.h>
@@ -39,6 +39,7 @@
 #include "gui/dialog.h"
 #include "gui/mod_mgr.h"
 #include "gui/utilities.h"
+#include "gui/preferences_dialog.h"
 
 #include "main/lists.h"
 #include "main/settings.h"
@@ -47,6 +48,9 @@
 
 #include <glib/gstdio.h>
 
+#include "gui/debug_glib_null.h"
+#include <locale.h>
+
 
 /******************************************************************************
  * defines
@@ -84,28 +88,22 @@ static int init_bookmarks(int new_bookmarks);
  *   gint
  */
 
-int settings_init(int new_configs, int new_bookmarks)
+int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 {
 	int retval = 0;
 	char *sword_dir = NULL;
-	char *gs_old = NULL;
 	char *tmp = NULL;
 	char *env;
+	struct stat buf;
+	gboolean buf_says_empty = FALSE;
 
 	settings.first_run = FALSE;
 	/* set program title */
 	strcpy(settings.program_title, "Xiphos");
 
-	/* find out what kind of peculiar language environment we have */
-	re_encode_digits = FALSE;
-	if (((env = (char*) g_getenv("LC_ALL")) != NULL) &&
-	    // for now, farsi-sensitive only
-	    (strncmp (env, "fa", 2) == 0)) {
-		re_encode_digits = TRUE;
-	}
-
 	/* Get home dir */
 	if ((settings.homedir = (char*) g_getenv(HOMEVAR)) == NULL) {
+		gui_init(argc, argv);
 		gui_generic_warning(_("$HOME is not set!"));
 		/* if not found in env exit */
 		exit(0);
@@ -118,54 +116,45 @@ int settings_init(int new_configs, int new_bookmarks)
 
 	/* if gSwordDir does not exist, create it. */
 	if (access(settings.gSwordDir, F_OK) == -1) {
-		gs_old = g_strdup_printf("%s/.xiphos-2.0", settings.homedir);
-		if (access(gs_old, F_OK) == 0) {
-			if (rename(gs_old, settings.gSwordDir) == 0)
-				gui_generic_warning(_("Xiphos has renamed .xiphos-2.0 to .xiphos"));
-			else {
-				char msg[300];
-				sprintf(msg, _("Xiphos can not rename  .xiphos-2.0 to .xiphos:\n%s\n\nXiphos cannot continue."),
-					strerror(errno));
-				gui_generic_warning(msg);
-				/* necessarily giving up. */
-				gtk_exit(1);
-			}
-		} else if ((Mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
+		if ((Mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
 			char msg[300];
+			gui_init(argc, argv);
 			sprintf(msg, _("Xiphos can not create  .xiphos:\n%s\n\nXiphos cannot continue."),
 				strerror(errno));
 			gui_generic_warning(msg);
 			/* if we can not create gSwordDir exit */
 			gtk_exit(1);
 		}
-		g_free(gs_old);
 	}
 
 	/* if .sword does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD);
 	if (access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
+			gui_init(argc, argv);
 			gui_generic_warning(_("can not create " DOTSWORD));
-		} 
+		}
 	}
 	g_free(sword_dir);
 	/* if .sword/mods.d does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/mods.d");
 	if (access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
+			gui_init(argc, argv);
 			gui_generic_warning(_("can not create " DOTSWORD "/mods.d"));
-		} 
-	}	
+		}
+	}
 	g_free(sword_dir);
 	/* if .sword/modules does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, DOTSWORD "/modules");
 	if (access(sword_dir, F_OK) == -1) {
 		if ((Mkdir(sword_dir, S_IRWXU)) != 0) {
+			gui_init(argc, argv);
 			gui_generic_warning(_("can not create " DOTSWORD "/modules"));
-		} 
+		}
 	}
 	g_free(sword_dir);
-	
+
 	/* moved here from crud locations in backend. */
 	main_init_language_map();
 
@@ -173,74 +162,116 @@ int settings_init(int new_configs, int new_bookmarks)
 
 	init_bookmarks(new_bookmarks);
 
+	/* get the first cut at the set of modules available. */
+	/* maybe insufficient, contain no bibles: ok for now. */
+	main_init_lists();
+
 	/* set fnconfigure to gSwordDir and settings.xml */
-	settings.fnconfigure = g_new(char, strlen(settings.gSwordDir) +
-				     strlen("settings.xml") + 2);
-	sprintf(settings.fnconfigure, "%s/%s", settings.gSwordDir,
-		"settings.xml");
-	
+	settings.fnconfigure = g_strdup_printf("%s/settings.xml", settings.gSwordDir);
+
+	/* check for a bad settings file. */
+	if ((stat(settings.fnconfigure, &buf) == 0) &&	/* exists... */
+	    (buf.st_size == 0)) {			/* ...but empty? */
+		char *backup_name = g_strdup_printf("%s.SAVE", settings.fnconfigure);
+
+		/* toss out the bad one and look for recovery. */
+		unlink(settings.fnconfigure);
+		if (stat(backup_name, &buf) == 0) {
+			buf_says_empty = (buf.st_size == 0);
+			rename(backup_name, settings.fnconfigure);
+			gui_init(argc, argv);
+			gui_generic_warning(_("Empty settings file -- backup recovery attempted.\nSome information may have been lost."));
+		}
+		else gui_generic_warning(_("Empty settings file -- no backup?!? Information lost!"));
+		g_free(backup_name);
+	}
+
 	/* if settings.xml does not exist create it */
-	if ((access(settings.fnconfigure, F_OK) == -1) || new_configs) {
+	if (buf_says_empty ||
+	    (access(settings.fnconfigure, F_OK) == -1) ||
+	    new_configs) {
 		/* must be first run */
-		GS_print(("\nFirst Run: need to create settings!\n"));
+		GS_print((buf_says_empty
+			  ? "\nSETTINGS FILE EXISTS BUT IS EMPTY - RECREATING.\n"
+			  : "\nFirst Run: need to create settings!\n"));
 		settings.first_run = TRUE;
 
-		main_init_lists();
-		if (settings.havebible == 0) {
-			if (gui_yes_no_dialog(GS_NET_PERMISSION, NULL)) {
-				main_shutdown_list();
-				gui_open_mod_mgr_initial_run();
-				main_init_lists();
-				if (settings.havebible == 0) {
-					gui_generic_warning
-					    (_("There are still no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
-					exit(1);
-				} else
-					gui_generic_warning
-					    (_("Bible module installation complete."));
-			} else {
-				gui_generic_warning
-				    (_("Without any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
-				exit(1);
-			}
-		}
-		main_shutdown_list();
-
-		main_init_lists();
 		xml_create_settings_file(settings.fnconfigure);
-		//retval = gui_first_run();
-		main_shutdown_list();
 		xml_save_settings_doc(settings.fnconfigure);
 		xml_free_settings_doc();
 	}
-	
+	xml_parse_settings_file(settings.fnconfigure);
+
+	/* ensure that the user has a bible with which to work */
+	if (settings.havebible == 0) {
+		gui_init(argc, argv);
+		if (gui_yes_no_dialog(GS_NET_PERMISSION, NULL)) {
+			main_shutdown_list();
+			gui_open_mod_mgr_initial_run();
+			main_init_lists();
+			if (settings.havebible == 0) {
+				gui_generic_warning
+				    (_("There are still no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
+				exit(1);
+			} else
+				gui_generic_warning
+				    (_("Bible module installation complete."));
+		} else {
+			gui_generic_warning
+			    (_("Without any Bible modules to display,\nXiphos cannot proceed,\nand will now exit."));
+			exit(1);
+		}
+	}
+
 	/* check for template.pad file for studypad */
 	tmp = g_new(char, strlen(settings.gSwordDir) +
 				     strlen("template.pad") + 2);
 	sprintf(tmp, "%s/%s", settings.gSwordDir,
 		"template.pad");
-	
+
 	/* if template.pad does not exist create it */
 	if ((access(tmp, F_OK) == -1)) {
 		g_file_set_contents(tmp, " ", strlen(" "), NULL);
 	}
-	
+
 	/* check for template.pad file for studypad */
 	/* set fnconfigure to gSwordDir and settings.xml */
 	tmp = g_new(char, strlen(settings.gSwordDir) +
 				     strlen("template.pad") + 2);
 	sprintf(tmp, "%s/%s", settings.gSwordDir,
 		"template.pad");
-	
+
 	/* if template.pad does not exist create it */
 	if ((access(tmp, F_OK) == -1)) {
 		g_file_set_contents(tmp, " ", strlen(" "), NULL);
 	}
-    
-	xml_parse_settings_file(settings.fnconfigure);
+
 	load_settings_structure();
 
-	gconf_setup();
+	/*
+	 * if the user had forced a locale, we must set it now.
+	 */
+	if (settings.special_locale && strcmp(settings.special_locale, NONE)) {
+		g_setenv("LANG", settings.special_locale, TRUE);
+		gchar *test = setlocale(LC_ALL, settings.special_locale);
+		if (test == NULL) {
+			gchar lfix[32];
+			sprintf(lfix, "%s.UTF-8", settings.special_locale); //for Ubuntu
+			test = setlocale(LC_ALL, lfix);
+		}
+		if (test != NULL) {
+			g_setenv("LC_ALL", test, TRUE);
+			GS_message(("set locale to %s", settings.special_locale));
+		}
+	}
+
+	/* find out what kind of peculiar language environment we have */
+	re_encode_digits = FALSE;
+	if (((env = (char*) g_getenv("LANG")) != NULL) &&
+	    // for now, farsi-sensitive only
+	    (strncmp (env, "fa", 2) == 0)) {
+		re_encode_digits = TRUE;
+	}
 
 	return retval;
 }
@@ -248,18 +279,18 @@ int settings_init(int new_configs, int new_bookmarks)
 
 /******************************************************************************
  * Name
- *    
+ *
  *
  * Synopsis
  *   #include "main/settings.h"
  *
- *   	
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
- *   
+ *
  */
 
 int init_bookmarks(int new_bookmarks)
@@ -283,7 +314,7 @@ int init_bookmarks(int new_bookmarks)
 			return 0;
 		}
 	}
-					
+
 	/* set removed dir to settings.swbmDir + /removed */
 	removed = g_new(char, strlen(settings.swbmDir) +
 				 strlen("/removed") + 2);
@@ -293,11 +324,11 @@ int init_bookmarks(int new_bookmarks)
 			g_warning("can't create removed dir");
 			//return 0;
 		}
-	}	
-	
-	if (new_bookmarks) 
+	}
+
+	if (new_bookmarks)
 		xml_new_bookmark_file();
-		
+
 	/* check for xml bookmarks */
 	file_buf = g_new(char, strlen(settings.swbmDir) +
 			 strlen("/bookmarks.xml") + 2);
@@ -324,39 +355,42 @@ int init_bookmarks(int new_bookmarks)
 	if (access(file_buf, F_OK) == 0) {
 		settings.have_bibletime = TRUE;
 	}
-	
+
 	/* clean up */
 	if (file_buf)
 		g_free(file_buf);
 	if (removed)
 		g_free(removed);
-	
+
 	return 1;
 }
 
 
 /******************************************************************************
  * Name
- *    
+ *
  *
  * Synopsis
  *   #include "main/settings.h"
  *
- *   	
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
- *   
+ *
  */
 
 void load_settings_structure(void)
 {
 	char *buf = NULL;
-	
+
 	settings.gs_version = VERSION;
-	settings.MainWindowModule = xml_get_value("modules", "bible");
+	if ((settings.MainWindowModule = xml_get_value("modules", "bible")) == NULL) {
+		/* by the time we are here, we *must* have at least 1 bible */
+		settings.MainWindowModule = g_strdup(get_list(TEXT_LIST)->data);
+	}
 	settings.CommWindowModule = xml_get_value("modules", "comm");
 	settings.DictWindowModule = xml_get_value("modules", "dict");
 	settings.parallel1Module = xml_get_value("modules", "int1");
@@ -391,36 +425,51 @@ void load_settings_structure(void)
 	settings.useDefaultDict = atoi((buf = xml_get_value("lexicons","usedefaultdict"))
 				       ? buf : "0");
 
-	/* mod mgr stuff */ 
+	/* unusual locale setting */
+	if ((buf = xml_get_value("locale", "special")))
+		settings.special_locale = g_strdup(buf);
+	else {
+		xml_add_new_section_to_settings_doc("locale");
+		xml_add_new_item_to_section("locale", "special", NONE);
+		settings.special_locale = g_strdup(NONE);
+	}
+
+	/* mod mgr stuff */
 	if ((buf = xml_get_value("modmgr", "mod_mgr_source")))
 		settings.mod_mgr_source = atoi(buf);
 	else {
 		xml_add_new_section_to_settings_doc("modmgr");
 		xml_add_new_item_to_section("modmgr", "mod_mgr_source", "1");
 		settings.mod_mgr_source = 1;
-	}	 
+	}
 	if ((buf = xml_get_value("modmgr", "mod_mgr_destination")))
 		settings.mod_mgr_destination = atoi(buf);
 	else {
 		xml_add_new_item_to_section("modmgr", "mod_mgr_destination", "0");
 		settings.mod_mgr_destination = 0;
-	}		
+	}
 	if ((buf = xml_get_value("modmgr", "mod_mgr_local_source_index")))
 		settings.mod_mgr_local_source_index = atoi(buf);
 	else {
 		xml_add_new_item_to_section("modmgr", "mod_mgr_local_source_index", "0");
 		settings.mod_mgr_local_source_index = 0;
-	}		
+	}
 	if ((buf = xml_get_value("modmgr", "mod_mgr_remote_source_index")))
 		settings.mod_mgr_remote_source_index = atoi(buf);
 	else {
 		xml_add_new_item_to_section("modmgr", "mod_mgr_remote_source_index", "0");
 		settings.mod_mgr_remote_source_index = 0;
-	}	
-	
+	}
+	if ((buf = xml_get_value("modmgr", "mod_mgr_intro")))
+		settings.mod_mgr_intro = atoi(buf);
+	else {
+		xml_add_new_item_to_section("modmgr", "mod_mgr_intro", "0");
+		settings.mod_mgr_intro = 0;
+	}
+
 	/* end mod mgr stuff */
-	
-	
+
+
 	settings.currentverse = xml_get_value("keys", "verse");
 	settings.dictkey = xml_get_value("keys", "dictionary");
 
@@ -460,7 +509,7 @@ void load_settings_structure(void)
 	}
 	settings.gs_hight = atoi((buf = xml_get_value("layout", "hight")) ? buf : "500");
 	settings.gs_width = atoi((buf = xml_get_value("layout", "width")) ? buf : "500");
-	
+
 	if ((buf = xml_get_value("layout", "app_x")))
 		settings.app_x = atoi(buf);
 	else {
@@ -473,7 +522,7 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("layout", "app_y", "40");
 		settings.app_y = 40;
 	}
-	
+
 	settings.biblepane_width = atoi((buf = xml_get_value("layout", "textpane"))
 					? buf : "0");
 	settings.upperpane_hight = atoi((buf = xml_get_value("layout", "uperpane"))
@@ -492,7 +541,7 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("layout", "commentaryhight", "240");
 		settings.commpane_hight = 240;
 	}
-	
+
 	if ((buf = xml_get_value("fontsize", "versenum"))) {
 		settings.verse_num_font_size_str = buf;
 		settings.verse_num_font_size = atoi(buf);
@@ -515,7 +564,7 @@ void load_settings_structure(void)
 		settings.base_font_size = 1;
 #endif /* WIN32 */
 	}
- 
+
 	settings.bible_text_color = xml_get_value("HTMLcolors", "text_fg");
 	settings.bible_bg_color =
 	    xml_get_value("HTMLcolors", "background");
@@ -538,50 +587,50 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("HTMLcolors", "highlight_bg", "#060680");
 		settings.highlight_bg = g_strdup("#060680");
 	}
-	
+
 	/*  parallel ops  */
-	
+
 	if ((buf = xml_get_value("parallel", "Strong_s_Numbers")))
 		settings.parallel_strongs = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Strong_s_Numbers", "0");
 		settings.parallel_strongs = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Morphological_Tags")))
 		settings.parallel_morphs = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Morphological_Tags", "0");
 		settings.parallel_morphs = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Hebrew_Vowel_Points")))
 		settings.parallel_hebrewpoints = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Hebrew_Vowel_Points", "1");
 		settings.parallel_hebrewpoints = 1;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Hebrew_Cantillation")))
 		settings.parallel_cantillationmarks = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Hebrew_Cantillation", "0");
 		settings.parallel_cantillationmarks = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Footnotes")))
 		settings.parallel_footnotes = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Footnotes", "0");
 		settings.parallel_footnotes = 0;
-	}	
+	}
 
 	if ((buf = xml_get_value("parallel", "Cross-references")))
 		settings.parallel_crossref = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Cross-references", "1");
 		settings.parallel_crossref = 1;
-	}		
+	}
 
 	if ((buf = xml_get_value("parallel", "Transliteration")))
 		settings.parallel_transliteration = atoi(buf);
@@ -589,69 +638,69 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("parallel", "Transliteration", "0");
 		settings.parallel_transliteration = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Words_of_Christ_in_Red")))
 		settings.parallel_red_words = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Words_of_Christ_in_Red", "0");
 		settings.parallel_red_words = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Morpheme_Segmentation")))
 		settings.parallel_segmentation = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Morpheme_Segmentation", "0");
 		settings.parallel_segmentation = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Headings")))
 		settings.parallel_headings = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Headings", "0");
 		settings.parallel_headings = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Lemmas")))
 		settings.parallel_lemmas = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Lemmas", "0");
 		settings.parallel_lemmas = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Primary_Reading")))
 		settings.parallel_variants_primary = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Primary_Reading", "1");
 		settings.parallel_variants_primary = 1;
-	}	
-	
+	}
+
 	if ((buf = xml_get_value("parallel", "Secondary_Reading")))
 		settings.parallel_variants_secondary = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Secondary_Reading", "0");
 		settings.parallel_variants_secondary = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "All_Readings")))
 		settings.parallel_variants_all = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "All_Readings", "0");
 		settings.parallel_variants_all = 0;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "Greek_Accents")))
 		settings.parallel_greekaccents = atoi(buf);
 	else {
 		xml_add_new_item_to_section("parallel", "Greek_Accents", "1");
 		settings.parallel_greekaccents = 1;
 	}
-	
+
 	if ((buf = xml_get_value("parallel", "parallel")))
 		settings.parallelpage = atoi(buf);
 
-	
+
 	/*  Misc stuff  */
-	
+
 	settings.showtexts = atoi((buf = xml_get_value("misc", "showtexts")) ? buf : "1");
 	settings.showcomms = atoi((buf = xml_get_value("misc", "showcomms")) ? buf : "1");
 	settings.showdicts = atoi((buf = xml_get_value("misc", "showdicts")) ? buf : "1");
@@ -668,16 +717,16 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("misc", "show_side_preview", "0");
 		settings.show_previewer_in_sidebar = 0;
 	}
-    
+
 	if (xml_get_value("misc", "showparatab"))
 		settings.showparatab = atol(xml_get_value("misc", "showparatab"));
 	else {
 		xml_add_new_item_to_section("misc", "showparatab", "0");
 		settings.showparatab = 0;
-	}	
-	
+	}
+
 	settings.showsplash = atoi((buf = xml_get_value("misc", "splash")) ? buf : "1");
-	
+
 	settings.showdevotional =
 	    atoi((buf = xml_get_value("misc", "dailydevotional")) ? buf : "1");
 	settings.versestyle =
@@ -748,14 +797,14 @@ void load_settings_structure(void)
 	} else {
 		xml_add_new_item_to_section("misc","show_sidebar","1");
 		settings.showshortcutbar = 1;
-	}		
+	}
 	if ((buf = xml_get_value("misc", "sidebar_docked"))) {
 		settings.docked = atoi(buf);
 	} else {
 		xml_add_new_item_to_section("misc","sidebar_docked","1");
 		settings.docked = 1;
 	}
-	
+
 	if ((buf = xml_get_value("misc", "prayerlist"))) {
 		settings.prayerlist =  atoi(buf);
 	} else {
@@ -763,7 +812,7 @@ void load_settings_structure(void)
 		settings.prayerlist = 1;
 	}
 
-	
+
 	if ((buf = xml_get_value("tabs", "browsing"))) {
 		settings.browsing =  atoi(buf);
 	} else {
@@ -771,90 +820,3 @@ void load_settings_structure(void)
 		settings.browsing = 1;
 	}
 }
-
-
-/******************************************************************************
- * Name
- *    gconf_setup
- *
- * Synopsis
- *   #include "main/settings.h"
- *
- *   void gconf_setup()
- *
- * Description
- *   verifies and initializes the GConf subsystem, so that "sword://" and
- *   similar can be handled by url-comprehending programs such as browsers.
- *   dialogs for permission/success/failure => conditional on debug build.
- *
- * Return value
- *   void
- */
-
-#define	GS_GCONF_PERMISSION	_("URL references using \"sword://\" (similar to web page\nreferences) can be used by programs to look up\nscripture references. Your system currently has no\nprogram set to handle these references.\n\nWould you like Xiphos to set itself as the\nprogram to handle these references?")
-
-#define	GS_GCONF_SUCCESS	_("Xiphos has successfully set itself\nas the handler of sword:// and bible:// URLs.\n\nYou may wish to run the program \"gconf-editor\"\nto examine keys under /desktop/gnome/url-handlers,\nif you need to change these.")
-
-char *gconf_keys[GS_GCONF_MAX][2] = {
-    { "/desktop/gnome/url-handlers/bible/command",        "xiphos \"%s\"" },
-    { "/desktop/gnome/url-handlers/bible/enabled",        (char *) 1 },
-    { "/desktop/gnome/url-handlers/bible/needs_terminal", (char *) 0 },
-    { "/desktop/gnome/url-handlers/sword/command",        "xiphos \"%s\"" },
-    { "/desktop/gnome/url-handlers/sword/enabled",        (char *) 1 },
-    { "/desktop/gnome/url-handlers/sword/needs_terminal", (char *) 0 }
-};
-
-void gconf_setup()
-{
-	int i;
-	gchar *str;
-	gboolean retval;
-	GConfClient* client = gconf_client_get_default();
-
-	if (client == NULL)
-		return;		/* we're not running under GConf */
-
-	/*
-	 * This is deliberately somewhat simple-minded, at least for now.
-	 * We care about one thing: Is anything set to handle "bible://"?
-	 *
-	 * Unfortunate consequence of changing xiphos2 => xiphos:
-	 * We must fix broken keys.
-	 */
-	if ((((str = gconf_client_get_string(client, gconf_keys[0][0],
-					    NULL)) == NULL) ||
-	     (strncmp(str, "gnomesword", 10) == 0))
-#ifdef DEBUG
-	    && gui_yes_no_dialog(GS_GCONF_PERMISSION, NULL)
-#endif /* DEBUG */
-	    ) {
-		/*
-		 * Mechanical as can be, one after another.
-		 */
-		for (i = 0; i < GS_GCONF_MAX; ++i) {
-			retval = (((i % 3) == 0)	/* contrived hack */
-				  ? gconf_client_set_string
-					(client,
-					 gconf_keys[i][0],
-					 gconf_keys[i][1],
-					 NULL)
-				  : gconf_client_set_bool
-					(client,
-					 gconf_keys[i][0],
-					 (gconf_keys[i][1] ? TRUE : FALSE),
-					 NULL));
-#ifdef DEBUG
-			if (!retval) {
-				char msg[256];
-				sprintf(msg, _("Xiphos failed to complete handler init for key #%d:\n%s"),
-					i, gconf_keys[i][0]);
-				gui_generic_warning(msg);
-				return;
-			}
-#endif /* DEBUG */
-		}
-#ifdef DEBUG
-		gui_generic_warning(GS_GCONF_SUCCESS);
-#endif /* DEBUG */
-	}
-}
