@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * sword.cc - glue 
+ * sword.cc - glue
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -24,7 +24,7 @@
 #endif
 
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 
@@ -33,26 +33,6 @@
 #include <stringmgr.h>
 #include <localemgr.h>
 
-#ifdef USE_GTKMOZEMBED
-#include <gtkmozembed.h>
-
-#ifdef NS_HIDDEN
-# undef NS_HIDDEN
-#endif
-#ifdef NS_IMPORT_
-# undef NS_IMPORT_
-#endif
-#ifdef NS_EXPORT_
-# undef NS_EXPORT_
-#endif
-
-#include <gtkmozembed_internal.h>
-#include <nsIDOMMouseEvent.h>
-#ifndef HAVE_GECKO_1_9
-#include <dom/nsIDOMKeyEvent.h>
-#endif
-#endif
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -88,14 +68,19 @@ extern "C" {
 #include "main/sword.h"
 #include "main/url.hh"
 #include "main/xml.h"
- 
+
 #include "main/parallel_view.h"
 #include "backend/sword_main.hh"
 #include "backend/gs_stringmgr.h"
 
-char *OLD_CODESET;
-using namespace sword; 
-	
+#include "gui/debug_glib_null.h"
+
+#ifdef HAVE_DBUS
+#include "gui/ipc.h"
+#endif
+
+using namespace sword;
+
 #define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
 
 extern GtkWidget *cbe_book;
@@ -118,19 +103,19 @@ gboolean companion_activity = FALSE;
  *   void main_book_heading(char * mod_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void main_book_heading(char * mod_name)
-{	
-	VerseKey *vkey;	
-	SWMgr *mgr = backend->get_display_mgr();
-	
+{
+	VerseKey *vkey;
+	SWMgr *mgr = backend->get_mgr();
+
 	backend->display_mod = mgr->Modules[mod_name];
-	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);	
+	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
 	vkey->Headings(1);
 	vkey->AutoNormalize(0);
 	vkey->Verse(0);
@@ -149,20 +134,20 @@ void main_book_heading(char * mod_name)
  *   void main_chapter_heading(char * mod_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void main_chapter_heading(char * mod_name)
-{	
-	VerseKey *vkey;	
-	SWMgr *mgr = backend->get_display_mgr();
-	
+{
+	VerseKey *vkey;
+	SWMgr *mgr = backend->get_mgr();
+
 	backend->display_mod = mgr->Modules[mod_name];
 	backend->display_mod->setKey(settings.currentverse);
-	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);	
+	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
 	vkey->Headings(1);
 	vkey->AutoNormalize(0);
 	vkey->Verse(0);
@@ -177,19 +162,19 @@ void main_chapter_heading(char * mod_name)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   void main_save_note(const gchar * module_name, 
- *				          const gchar * key_str , 
- *				          const gchar * note_str )	
+ *   void main_save_note(const gchar * module_name,
+ *				          const gchar * key_str ,
+ *				          const gchar * note_str )
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
-void main_save_note(	const gchar * module_name, 
-			const gchar * key_str, 
+void main_save_note(	const gchar * module_name,
+			const gchar * key_str,
 			const gchar * note_str )
 {
 	// Massage encoded spaces ("%20") back to real spaces.
@@ -208,8 +193,8 @@ void main_save_note(	const gchar * module_name,
 		    key_str,
 		    note_str));
 	backend->save_note_entry(module_name, key_str, note_str);
-	
-	if ((!strcmp(settings.CommWindowModule, module_name)) &&  
+
+	if ((!strcmp(settings.CommWindowModule, module_name)) &&
 	    (!strcmp(settings.currentverse, key_str)))
 		main_display_commentary(module_name, key_str);
 }
@@ -221,10 +206,10 @@ void main_save_note(	const gchar * module_name,
  * Synopsis
  *   #include "main/sword.h"
  *
- *   void main_delete_note(DIALOG_DATA * d)	
+ *   void main_delete_note(DIALOG_DATA * d)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -237,24 +222,24 @@ void main_delete_note(	const gchar * module_name, const gchar * key_str)
 		    module_name,
 		    key_str));
 	backend->delete_entry();
-	
-	if ((!strcmp(settings.CommWindowModule,module_name)) &&  
+
+	if ((!strcmp(settings.CommWindowModule,module_name)) &&
 	    (!strcmp(settings.currentverse, key_str)))
 		main_display_commentary(module_name, key_str);
 }
 
-	
+
 /******************************************************************************
  * Name
  *  set_module_unlocked
  *
  * Synopsis
  *   #include "bibletext.h"
- *   
- *   void set_module_unlocked(char *mod_name, char *key)	
+ *
+ *   void set_module_unlocked(char *mod_name, char *key)
  *
  * Description
- *   unlocks locked module - 
+ *   unlocks locked module -
  *
  * Return value
  *   void
@@ -262,8 +247,8 @@ void main_delete_note(	const gchar * module_name, const gchar * key_str)
 
 void main_set_module_unlocked(char * mod_name, char * key)
 {
-	SWMgr *mgr = backend->get_display_mgr();
-	mgr->setCipherKey(mod_name, key);	
+	SWMgr *mgr = backend->get_mgr();
+	mgr->setCipherKey(mod_name, key);
 }
 
 
@@ -274,14 +259,14 @@ void main_set_module_unlocked(char * mod_name, char * key)
  * Synopsis
  *   #include "main/configs.h"
  *
- *   void main_save_module_key(gchar * mod_name, gchar * key)	
+ *   void main_save_module_key(gchar * mod_name, gchar * key)
  *
  * Description
  *    to unlock locked modules
  *
  * Return value
  *   void
- */ 
+ */
 
 void main_save_module_key(char * mod_name, char * key)
 {
@@ -296,10 +281,10 @@ void main_save_module_key(char * mod_name, char * key)
  * Synopsis
  *   #include "toolbar_nav.h"
  *
- *   gchar *main_update_nav_controls(const gchar * key)	
+ *   gchar *main_update_nav_controls(const gchar * key)
  *
  * Description
- *   updates the nav toolbar controls 
+ *   updates the nav toolbar controls
  *
  * Return value
  *   gchar *
@@ -308,20 +293,26 @@ void main_save_module_key(char * mod_name, char * key)
 gchar *main_update_nav_controls(const gchar * key)
 {
 	char *val_key = backend->get_valid_key(key);
-	
-	/* 
-	 *  remember verse 
+
+	/*
+	 *  remember verse
 	 */
 	xml_set_value("Xiphos", "keys", "verse", val_key);
 	settings.currentverse = xml_get_value("keys", "verse");
-	
+
 	settings.apply_change = FALSE;
-	
+
 	navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,settings.MainWindowModule);
 	navbar_versekey.key = g_string_assign(navbar_versekey.key,val_key);
 	main_navbar_versekey_set(navbar_versekey, val_key);
-	
+
 	settings.apply_change = TRUE;
+
+#ifdef HAVE_DBUS
+	IpcObject* ipc = ipc_get_main_ipc();
+	if (ipc)
+		ipc_object_navigation_signal (ipc, (const gchar*)val_key, NULL);
+#endif
 	return val_key;
 }
 
@@ -333,7 +324,7 @@ gchar *main_update_nav_controls(const gchar * key)
  * Synopsis
  *   #include "main/module.h"
  *
- *   char *get_module_key(void)	
+ *   char *get_module_key(void)
  *
  * Description
  *    returns module key
@@ -371,7 +362,7 @@ char *main_get_active_pane_key(void)
  * Synopsis
  *   #include "main/module.h"
  *
- *   char *get_module_name(void)	
+ *   char *get_module_name(void)
  *
  * Description
  *    returns module name
@@ -410,14 +401,14 @@ char *main_get_active_pane_module(void)
  * Synopsis
  *   #include ".h"
  *
- *   void module_name_from_description(gchar *mod_name, gchar *description)	
+ *   void module_name_from_description(gchar *mod_name, gchar *description)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
- */ 
+ */
 
 char *main_module_name_from_description(char *description)
 {
@@ -431,14 +422,14 @@ char *main_module_name_from_description(char *description)
  * Synopsis
  *   #include "sword.h"
  *
- *   const char *main_get_sword_version(void)	
+ *   const char *main_get_sword_version(void)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   const char *
- */ 
+ */
 
 const char *main_get_sword_version(void)
 {
@@ -449,15 +440,15 @@ const char *main_get_sword_version(void)
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/.h"
  *
- *   
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char*
@@ -476,16 +467,16 @@ char *main_get_treekey_local_name(unsigned long offset)
  * Synopsis
  *   #include "sword.h"
  *
- *   char *get_search_results_text(char * mod_name, char * key)	
+ *   char *get_search_results_text(char * mod_name, char * key)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   char *
  */
- 
-char *main_get_search_results_text(char * mod_name, char * key)	
+
+char *main_get_search_results_text(char * mod_name, char * key)
 {
 	return g_strdup(backend->get_render_text((char *)mod_name,(char *)key));
 }
@@ -506,11 +497,11 @@ char *main_get_search_results_text(char * mod_name, char * key)
  *
  * Return value
  *   gchar *
- */ 
+ */
 
 char *main_get_path_to_mods(void)
 {
-	SWMgr *mgr = backend->get_main_mgr();
+	SWMgr *mgr = backend->get_mgr();
 	char *path = mgr->prefixPath;
 	return (path ? g_strdup(path) : NULL);
 }
@@ -529,7 +520,7 @@ char *main_get_path_to_mods(void)
  *
  * Return value
  *   void
- */ 
+ */
 
 typedef std::map < SWBuf, SWBuf > ModLanguageMap;
 ModLanguageMap languageMap;
@@ -540,7 +531,7 @@ void main_init_language_map() {
 	gchar *s, *end, *abbrev, *name, *newline;
 	gchar *mapspace;
 	size_t length;
-	
+
 	if ((language_file = gui_general_user_file("languages", FALSE)) == NULL) {
 		gui_generic_warning
 		    (_("Xiphos's file for language\nabbreviations is missing."));
@@ -608,6 +599,55 @@ const char *main_get_language_map(const char *language) {
 }
 
 
+/******************************************************************************
+ * Name
+ *   set_sword_locale
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   char *set_sword_locale(const char *sys_locale)
+ *
+ * Description
+ *   set sword's idea of the locale in which the user operates
+ *
+ * Return value
+ *   char *
+ */
+char *set_sword_locale(const char *sys_locale)
+{
+	int ncmp[3] = { 100, 5, 2 };	// fixed data
+
+	if (sys_locale) {
+		SWBuf locale;
+		StringList localelist = LocaleMgr::getSystemLocaleMgr()->getAvailableLocales();
+		StringList::iterator it;
+
+		// length-limited match
+		for (int i = 0; i < 3; ++i) {
+			for (it = localelist.begin(); it != localelist.end(); ++it) {
+				locale = *it;
+				if (!strncmp(sys_locale, locale.c_str(), ncmp[i])) {
+					LocaleMgr::getSystemLocaleMgr()->
+					    setDefaultLocaleName(locale.c_str());
+					return g_strdup(locale.c_str());
+				}
+			}
+		}
+
+	}
+
+	// either we were given a null sys_locale, or it didn't match anything.
+	char *err = g_strdup_printf("%s `%s'.\n%s.",
+				    _("No matching locale found for"),
+				    sys_locale,
+				    _("Book names and menus may not be translated"));
+	gui_generic_warning(err);
+	g_free(err);
+	return NULL;
+}
+
+
 /******************************************************************************
  * Name
  *   backend_init
@@ -615,10 +655,10 @@ const char *main_get_language_map(const char *language) {
  * Synopsis
  *   #include "main/sword.h"
  *
- *   void main_init_backend(void)	
+ *   void main_init_backend(void)
  *
  * Description
- *   start sword 
+ *   start sword
  *
  * Return value
  *   void
@@ -626,22 +666,21 @@ const char *main_get_language_map(const char *language) {
 
 void main_init_backend(void)
 {
-	const char *lang = getenv("LANG");
-	
-	if (!lang) lang = "C";
-
 	StringMgr::setSystemStringMgr( new GS_StringMgr() );
 
+	const char *lang = getenv("LANG");
+	if (!lang) lang = "C";
+	sword_locale = set_sword_locale(lang);
+	lang = LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName();
+
 	backend = new BackEnd();
+
 	backend->init_SWORD(0);
-	sword_locale = backend->set_sword_locale(lang);
 	settings.path_to_mods = main_get_path_to_mods();
 	GS_print(("%s sword-%s\n", "Starting", backend->get_sword_version()));
 	GS_print(("%s\n", "Initiating SWORD"));
 	GS_print(("%s: %s\n","path to sword", settings.path_to_mods));
-	GS_print(("%s %s\n", "System locale is", lang));
-	GS_print(("%s %s\n", "SWORD locale is", sword_locale));
-	GS_print(("OLD_CODESET = %s\n\n", (OLD_CODESET ? OLD_CODESET : "-none-")));
+	GS_print(("%s %s\n", "SWORD locale is", lang));
 	GS_print(("%s\n", "Checking for SWORD Modules"));
 	settings.spell_language = strdup(lang);
 	main_init_lists();
@@ -655,7 +694,7 @@ void main_init_backend(void)
  * Synopsis
  *   #include "sword.h"
  *
- *   void shutdown_sword(void)	
+ *   void shutdown_sword(void)
  *
  * Description
  *   close down sword by deleting backend;
@@ -669,10 +708,10 @@ void main_shutdown_backend(void)
 	if (sword_locale)
 		free((char*)sword_locale);
 	sword_locale = NULL;
-	if (backend) 
-	        delete backend; 
+	if (backend)
+	        delete backend;
 	backend = NULL;
-		
+
 	GS_print(("%s\n", "SWORD is shutdown"));
 }
 
@@ -693,31 +732,31 @@ void main_shutdown_backend(void)
  */
 
 void main_dictionary_entry_changed(char * mod_name)
-{	
+{
 	gchar *key = NULL;
 
-	if (!mod_name) 
+	if (!mod_name)
 		return;
 	if (strcmp(settings.DictWindowModule, mod_name)) {
 		xml_set_value("Xiphos", "modules", "dict", mod_name);
 		settings.DictWindowModule = xml_get_value("modules", "dict");
-	}	
+	}
 
 	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
-	
+
 	backend->set_module_key(mod_name, key);
 	g_free(key);
 	key = backend->get_module_key();
 
 	xml_set_value("Xiphos", "keys", "dictionary", key);
 	settings.dictkey = xml_get_value("keys", "dictionary");
-	
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
-	
+
 	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
 	g_free(key);
-} 
+}
 
 
 
@@ -729,12 +768,12 @@ static void dict_key_list_select(GtkMenuItem * menuitem, gpointer user_data)
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/sword.h"
  *
- *   
+ *
  *
  * Description
  *   text in the dictionary entry has changed and the entry activated
@@ -744,15 +783,15 @@ static void dict_key_list_select(GtkMenuItem * menuitem, gpointer user_data)
  */
 
 GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
-{	
+{
 	gint count = 9, i;
 	gchar *new_key;
 	gchar *key = NULL;
 	GtkWidget *menu;
 	GtkWidget * item;
-	
+
 	menu = gtk_menu_new();
-	
+
 	if (!settings.havedict || !mod_name)
 		return NULL;
 	if (strcmp(settings.DictWindowModule,mod_name)) {
@@ -760,28 +799,28 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 					mod_name);
 		settings.DictWindowModule = xml_get_value(
 					"modules", "dict");
-	}	
+	}
 	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
-	
+
 	GS_message(("\nold_key: %s\nkey: %s",old_key,key));
 	backend->set_module_key(mod_name, key);
 	g_free(key);
 	key = backend->get_module_key();
-	
+
 	xml_set_value("Xiphos", "keys", "dictionary", key);
 	settings.dictkey = xml_get_value("keys", "dictionary");
-	
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
-	
+
 	new_key = g_strdup((char*)backend->display_mod->KeyText());
-	
+
 	for (i = 0; i < (count / 2)+1; i++) {
 		(*backend->display_mod)--;
 	}
 
 	for (i = 0; i < count; i++) {
-		free(new_key);			
+		free(new_key);
 		(*backend->display_mod)++;
 		new_key = g_strdup((char*)backend->display_mod->KeyText());
 		/* add menu item */
@@ -790,14 +829,14 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 		gtk_widget_show(item);
 		g_signal_connect(GTK_OBJECT(item), "activate",
 				   G_CALLBACK(dict_key_list_select),
-				   g_strdup(new_key));		
-		gtk_container_add(GTK_CONTAINER(menu), item); 
+				   g_strdup(new_key));
+		gtk_container_add(GTK_CONTAINER(menu), item);
 	}
-	
+
 	free(new_key);
 	g_free(key);
 	return menu;
-} 
+}
 
 /******************************************************************************
  * Name
@@ -821,19 +860,19 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 
 
 void main_dictionary_button_clicked(gint direction)
-{	
+{
 	gchar *key = NULL;
-	
+
 	if (!settings.havedict || !settings.DictWindowModule)
 		return;
-		
-	backend->set_module_key(settings.DictWindowModule, 
+
+	backend->set_module_key(settings.DictWindowModule,
 				settings.dictkey);
 	if (direction == 0)
 		(*backend->display_mod)--;
 	else
 		(*backend->display_mod)++;
-	key = g_strdup((char*)backend->display_mod->KeyText());	
+	key = g_strdup((char*)backend->display_mod->KeyText());
 	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
 	gtk_widget_activate(widgets.entry_dict);
 	g_free(key);
@@ -844,6 +883,9 @@ void main_display_book(const char * mod_name, const char * key)     //, unsigned
 	if (!settings.havebook || !mod_name)
 		return;
 
+	if (key == NULL)  // && offset == -1)
+		key = "0";
+
 	GS_message(("main_display_book\nmod_name: %s\nkey: %s", mod_name, key));
 
 	if (!backend->is_module(mod_name))
@@ -855,9 +897,6 @@ void main_display_book(const char * mod_name, const char * key)     //, unsigned
 		xml_set_value("Xiphos", "modules", "book", mod_name);
 		gui_reassign_strdup(&settings.book_mod, (gchar *)mod_name);
 	}
-	
-	if (key == NULL)  // && offset == -1)
-		key = "0";
 
 	if (!isdigit(key[0])) {
 		xml_set_value("Xiphos", "keys", "book", key);
@@ -874,10 +913,10 @@ void main_display_book(const char * mod_name, const char * key)     //, unsigned
 		settings.book_key = xml_get_value("keys", "book");
 		xml_set_value("Xiphos", "keys", "offset", key);
 
-		backend->set_module(mod_name);	
+		backend->set_module(mod_name);
 		backend->set_treekey(settings.book_offset);
 	}
-	
+
 	backend->display_mod->Display();
 	main_setup_navbar_book(settings.book_mod, settings.book_offset);
 	//if (settings.browsing)
@@ -895,23 +934,23 @@ void main_display_book(const char * mod_name, const char * key)     //, unsigned
 }
 
 void main_display_commentary(const char * mod_name, const char * key)
-{	
+{
 	if (!settings.havecomm || !settings.comm_showing)
 		return;
-	
+
 	if (!mod_name)
 		mod_name = ((settings.browsing && (cur_passage_tab != NULL))
 			    ? g_strdup(cur_passage_tab->commentary_mod)
 			    : xml_get_value("modules", "comm"));
-	
+
 	if (!mod_name || !backend->is_module(mod_name))
 		return;
 	if (!settings.CommWindowModule)
 		settings.CommWindowModule = g_strdup((gchar*)mod_name);
-	
+
 	settings.comm_showing = TRUE;
 	settings.whichwindow = COMMENTARY_WINDOW;
-						
+
 	if (strcmp(settings.CommWindowModule, mod_name)) {
 		xml_set_value("Xiphos", "modules", "comm", mod_name);
 		gui_reassign_strdup(&settings.CommWindowModule, (gchar *)mod_name);
@@ -933,10 +972,10 @@ void main_display_commentary(const char * mod_name, const char * key)
 		}
 		if (companion) g_free(companion);
 	}
-	
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
-	
+
 	//if (settings.browsing)
 		gui_update_tab_struct(NULL,
 				      mod_name,
@@ -976,7 +1015,7 @@ void main_display_dictionary(const char * mod_name, const char * key)
 		time_t curtime;
 		struct tm *loctime;
 		char *feature;
-		if ((feature = (char *)backend->get_main_mgr()->
+		if ((feature = (char *)backend->get_mgr()->
 					getModule(mod_name)->
 					getConfigEntry("Feature")) &&
 		    !strcmp(feature, "DailyDevotion")) {
@@ -995,7 +1034,7 @@ void main_display_dictionary(const char * mod_name, const char * key)
 		xml_set_value("Xiphos", "modules", "dict", mod_name);
 		gui_reassign_strdup(&settings.DictWindowModule, (gchar *)mod_name);
 	}
-	
+
 	 // old_key is uppercase
  	key = g_utf8_strup(key, -1);
 	old_key = gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict));
@@ -1005,7 +1044,7 @@ void main_display_dictionary(const char * mod_name, const char * key)
 		gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
 		gtk_widget_activate(widgets.entry_dict);
 	}
-	
+
 	//if (settings.browsing)
 		gui_update_tab_struct(NULL,
 				      NULL,
@@ -1026,26 +1065,26 @@ void main_display_bible(const char * mod_name, const char * key)
 	gchar *file = NULL;
 	gchar *style = NULL;
 	gchar *val_key = NULL;
-	
+
 #ifndef USE_GTKMOZEMBED
 	extern guint scroll_adj_signal;
 	extern GtkAdjustment* adjustment;
-	
-	/* keeps us out of a crash causing loop */	
+
+	/* keeps us out of a crash causing loop */
 	g_signal_handler_block(adjustment, scroll_adj_signal);
-#endif	
+#endif
 	if (!GTK_WIDGET_REALIZED(GTK_WIDGET(widgets.html_text))) return;
 	if (!mod_name)
 		mod_name = ((settings.browsing && (cur_passage_tab != NULL))
 			    ? g_strdup(cur_passage_tab->text_mod)
-			    : xml_get_value("modules", "bible"));	
-	
-	
+			    : xml_get_value("modules", "bible"));
+
+
 	if (!settings.havebible || !mod_name)
 		return;
 	if (!backend->is_module(mod_name))
 		return;
-	
+
 	if (!settings.MainWindowModule)
 		settings.MainWindowModule = g_strdup((gchar*)mod_name);
 
@@ -1055,7 +1094,7 @@ void main_display_bible(const char * mod_name, const char * key)
 		settings.currentverse = xml_get_value(
 					"keys", "verse");
 	}
-	
+
 	if (strcmp(settings.MainWindowModule, mod_name)) {
 		xml_set_value("Xiphos", "modules", "bible", mod_name);
 		gui_reassign_strdup(&settings.MainWindowModule, (gchar *)mod_name);
@@ -1076,34 +1115,33 @@ void main_display_bible(const char * mod_name, const char * key)
 			companion_activity = FALSE;
 		}
 		if (companion) g_free(companion);
-		
+
 		navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,
 							      settings.MainWindowModule);
-		
+
 		navbar_versekey.key = g_string_assign(navbar_versekey.key,
 						      settings.currentverse);
-		
+
 		main_search_sidebar_fill_bounds_combos();
 	}
-	
+
 	settings.whichwindow = MAIN_TEXT_WINDOW;
-	gui_change_window_title(settings.MainWindowModule);
-	
+
 	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
 	style = get_conf_file_item(file, mod_name, "style");
 	if ((style) && strcmp(style,"verse"))
 		settings.versestyle = FALSE;
-	else	
+	else
 		settings.versestyle = TRUE;
 	g_free(style);
 	g_free(file);
-	
+
 	style_display = FALSE;
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.versestyle_item),
 				       settings.versestyle);
 	style_display = TRUE;
-	
+
 	if (backend->module_has_testament(mod_name,
 				backend->get_key_testament(key))) {
 			backend->set_module_key(mod_name, key);
@@ -1113,13 +1151,13 @@ void main_display_bible(const char * mod_name, const char * key)
 			val_key = main_update_nav_controls("Matthew 1:1");
 		else
 			val_key = main_update_nav_controls("Genesis 1:1");
-		
+
 		backend->set_module_key(mod_name, val_key);
 		backend->display_mod->Display();
-		g_free(val_key);			
+		g_free(val_key);
 	}
-	
-	GS_message(("mod_name = %s",mod_name));	
+
+	GS_message(("mod_name = %s",mod_name));
 	//if (settings.browsing) {
 		gui_update_tab_struct(mod_name,
 				      NULL,
@@ -1135,13 +1173,16 @@ void main_display_bible(const char * mod_name, const char * key)
 		gui_set_tab_label(settings.currentverse, FALSE);
 	//}
 
+	gui_change_window_title(settings.MainWindowModule);
+	// (called _after_ tab data updated so not overwritten with old tab)
+
 	/*
 	 * change parallel verses
 	 */
-	if (settings.dockedInt) 
+	if (settings.dockedInt)
 		main_update_parallel_page();
 	else {
-		if(settings.showparatab)
+		if (settings.showparatab)
 			gui_keep_parallel_tab_in_sync();
 		else
 			gui_keep_parallel_dialog_in_sync();
@@ -1206,12 +1247,12 @@ void main_display_devotional(void)
 	 * Print it out in a nice format.
 	 */
 	strftime(buf, 10, "%m.%d", loctime);
-	
-	
+
+
 	text = backend->get_render_text(settings.devotionalmod, buf);
 //	g_message("modname: %s\nloctime: %s\ntext: %s",settings.devotionalmod, buf, text);
 	if (text) {
-		main_entry_display(settings.show_previewer_in_sidebar 
+		main_entry_display(settings.show_previewer_in_sidebar
 				     ? sidebar.html_viewer_widget
 				     : widgets.html_previewer_text,
 			      settings.devotionalmod, text, buf, TRUE);
@@ -1220,15 +1261,15 @@ void main_display_devotional(void)
 }
 
 void main_refresh_all(void)
-{ 
+{
 	main_display_bible(settings.MainWindowModule, settings.currentverse);
 	main_display_commentary(settings.CommWindowModule, settings.currentverse);
-	main_display_book(settings.book_mod, settings.book_key);	
+	main_display_book(settings.book_mod, settings.book_key);
 	main_display_dictionary(settings.DictWindowModule, settings.dictkey);
 }
-    
+
 void main_setup_displays(void)
-{ 
+{
 	backend->textDisplay = new GTKChapDisp(widgets.html_text,backend);
 	backend->commDisplay = new GTKEntryDisp(widgets.html_comm,backend);
 	backend->bookDisplay = new GTKEntryDisp(widgets.html_book,backend);
@@ -1278,7 +1319,7 @@ gint main_check_for_global_option(gchar * mod_name, gchar * option)
  * Return value
  *   int
  */
- 
+
 int main_is_module(char * mod_name)
 {
 	return backend->is_module(mod_name);
@@ -1302,7 +1343,7 @@ int main_is_module(char * mod_name)
 
 int main_has_search_framework(char *mod_name)
 {
-	SWMgr *mgr = backend->get_main_mgr();
+	SWMgr *mgr = backend->get_mgr();
 	SWModule *mod = mgr->getModule(mod_name);
 	return (mod && mod->hasSearchFramework());
 }
@@ -1325,7 +1366,7 @@ int main_has_search_framework(char *mod_name)
 
 int main_optimal_search(char *mod_name)
 {
-	SWMgr *mgr = backend->get_main_mgr();
+	SWMgr *mgr = backend->get_mgr();
 	SWModule *mod = mgr->Modules.find(mod_name)->second;
 	return mod->isSearchOptimallySupported("God", -4, 0, 0);
 }
@@ -1337,14 +1378,14 @@ int main_optimal_search(char *mod_name)
  * Synopsis
  *   #include "main/module.h"
  *
- *   gchar *get_mod_about_info(char * mod_name)	
+ *   gchar *get_mod_about_info(char * mod_name)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   gchar *
- */ 
+ */
 
 char *main_get_mod_about_info(char * mod_name)
 {
@@ -1408,11 +1449,11 @@ int main_is_mod_rtol(const char * module_name)
  *   int main_has_cipher_tag(char *mod_name)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   int
- */ 
+ */
 
 int main_has_cipher_tag(char *mod_name)
 {
@@ -1427,10 +1468,10 @@ int main_has_cipher_tag(char *mod_name)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   char *main_get_striptext(char *module_name, char *key)	
+ *   char *main_get_striptext(char *module_name, char *key)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1449,10 +1490,10 @@ char *main_get_striptext(char *module_name, char *key)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   char *main_get_striptext(char *module_name, char *key)	
+ *   char *main_get_striptext(char *module_name, char *key)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1470,10 +1511,10 @@ char *main_get_striptext_from_string(char *module_name, char *string)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   char *main_get_rendered_text(char *module_name, char *key)	
+ *   char *main_get_rendered_text(char *module_name, char *key)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1492,10 +1533,10 @@ char *main_get_rendered_text(const char *module_name, const char *key)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   char *main_get_raw_text(char *module_name, char *key)	
+ *   char *main_get_raw_text(char *module_name, char *key)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1513,10 +1554,10 @@ char *main_get_raw_text(char *module_name, char *key)
  * Synopsis
  *   #include "main/sword.h"
  *
- *   char *main_get_raw_text(char *module_name, char *key)	
+ *   char *main_get_raw_text(char *module_name, char *key)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1537,15 +1578,15 @@ char *main_get_book_key_from_offset(unsigned long offset)
  *   int main_get_mod_type(char * mod_name)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   int
- */ 
+ */
 
 int main_get_mod_type(char * mod_name)
 {
-	
+
 	return backend->module_type(mod_name);
 }
 
@@ -1557,14 +1598,14 @@ int main_get_mod_type(char * mod_name)
  * Synopsis
  *   #include "main/module.h"
  *
- *   gchar *main_get_module_description(gchar * module_name)	
+ *   gchar *main_get_module_description(gchar * module_name)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   gchar *
- */ 
+ */
 
 char *main_get_module_description(char * module_name)
 {
@@ -1577,7 +1618,7 @@ char *main_get_module_description(char * module_name)
  *
  * Synopsis
  *   #include "main/sword.h"
- *   char *main_format_number(int x)	
+ *   char *main_format_number(int x)
  *
  * Description
  *   returns a digit string in either "latinate arabic" (normal) or
@@ -1587,7 +1628,7 @@ char *main_get_module_description(char * module_name)
  *
  * Return value
  *   char *
- */ 
+ */
 
 int re_encode_digits = FALSE;
 
@@ -1628,7 +1669,7 @@ main_format_number(int x)
  *
  * Return value
  *   int
- */ 
+ */
 
 int
 main_deformat_number(char *digitstring)
@@ -1664,7 +1705,7 @@ main_deformat_number(char *digitstring)
  *
  * Return value
  *   int
- */ 
+ */
 static char blank_html_content[] = "<html><head></head><body> </body></html>";
 
 void main_flush_widgets_content(void)
@@ -1692,8 +1733,28 @@ void main_flush_widgets_content(void)
  *
  * Return value
  *   gboolean
- */ 
+ */
 gboolean main_is_Bible_key(gchar *key)
 {
 	return (gboolean)(backend->is_Bible_key(key, settings.currentverse) != 0);
 }
+
+/******************************************************************************
+ * Name
+ *  main_get_osisref_from_key
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *   void main_get_osisref_from_key()
+ *
+ * Description
+ *   returns OSISRef-formatted key value.
+ *
+ * Return value
+ *   const char *
+ */
+const char *
+main_get_osisref_from_key(const char *module, const char *key)
+{
+    return backend->get_osisref_from_key(module, key);
+}
