@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
- 
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -26,7 +26,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <string.h>	
+#include <string.h>
 #include <ctype.h>
 #include <url.h>
 
@@ -35,13 +35,9 @@
 #include <swmgr.h>
 #include <swmodule.h>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-#ifdef USE_GTKHTML3_14_23
 #include "editor/slib-editor.h"
-#else
-#include "editor/bonobo-editor.h"
-#endif
 
 #include "gui/about_modules.h"
 #include "gui/xiphos.h"
@@ -66,6 +62,8 @@
 
 #include "backend/sword_main.hh"
 
+#include "gui/debug_glib_null.h"
+
 gint in_url;
 
 using namespace sword;
@@ -73,20 +71,20 @@ using namespace sword;
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/url.hh"
  *
- *   
+ *
  *
  * Description
- *  
+ *
  *
  * Return value
- *   
+ *
  */
- 
+
 static void alert_url_not_found(const gchar * url)
 {
 	GS_DIALOG *dialog;
@@ -109,7 +107,7 @@ static void alert_url_not_found(const gchar * url)
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/url.hh"
@@ -117,12 +115,12 @@ static void alert_url_not_found(const gchar * url)
  *   gint (const gchar * filename, gboolean clicked)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
  */
- 
+
  static gint show_studypad(const gchar * filename, gboolean clicked)
 {
 	editor_create_new(filename, NULL, STUDYPAD_EDITOR);
@@ -157,17 +155,12 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
 {
 	if (clicked) {
 #ifdef WIN32
-		// as of october 2008, gnome_url_show() doesn't behave
-		// properly on linux, because it does not respect the user's
-		// preferences properly.  so this is used on windows only.
-		// it kicks off the standard windows fax/pic viewer.
-
 		gboolean result;
-		gchar *file_as_url = g_strdup_printf("file://%s", filename);
-
-		GS_print(("file = %s\n", file_as_url));
-		result = gnome_url_show(file_as_url, NULL);
-		g_free(file_as_url);
+		gchar *win_path = g_strdup(filename);
+		//ShellExecute can handle all / or all \\ but not a combination
+		win_path = g_strdelimit(win_path,  "/", '\\');
+		result = xiphos_open_default ((const gchar*)win_path);
+		g_free(win_path);
 		if (result == FALSE) {
 			gui_generic_warning((char *)"Could not display that image");
 		}
@@ -209,7 +202,6 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
 #endif
 	} else {
 		gui_set_statusbar (filename);
-		//gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar),filename);
 	}
 	return 1;
 }
@@ -226,25 +218,23 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
  *						gboolean clicked)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
  */
- 
+
  static gint show_mod_info(const gchar * module, const gchar * description,
 						gboolean clicked)
 {
 	if (clicked) {
 		GS_print(("module = %s\n",module));
-		gui_display_about_module_dialog((gchar*)module);		
+		gui_display_about_module_dialog((gchar*)module);
 	} else {
 		/* some mod descriptions contain fun(ny) characters */
 		GString *desc_clean = hex_decode(description);
 		GS_print(("description = %s\n", desc_clean->str));
 		gui_set_statusbar (desc_clean->str);
-		/*gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar),
-					desc_clean->str);*/
 		g_string_free(desc_clean, TRUE);
 	}
 	return 1;
@@ -261,31 +251,30 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
  *   gint show_parallel(const gchar * value, const gchar * type,gboolean clicked)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
  */
- 
- static gint show_parallel(const gchar * svalue, const gchar * stype, 
+
+ static gint show_parallel(const gchar * svalue, const gchar * stype,
 							gboolean clicked)
 {
-	if(!strcmp(stype,"swap")) {
-		if(clicked) {
-			main_swap_parallel_with_main((gchar *) svalue);		
+	if (!strcmp(stype,"swap")) {
+		if (clicked) {
+			main_swap_parallel_with_main((gchar *) svalue);
 		} else {
-			gchar *buf = g_strdup_printf( 
+			gchar *buf = g_strdup_printf(
 				_("Show %s in main window"), svalue);
 			gui_set_statusbar (buf);
-			//gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar), buf);
 			g_free(buf);
 		}
 	}
-	if(!strcmp(stype,"verse")) {
-		if(clicked) {
+	if (!strcmp(stype,"verse")) {
+		if (clicked) {
 			gtk_entry_set_text(GTK_ENTRY(navbar_parallel.lookup_entry),svalue);
 			gtk_widget_activate(navbar_parallel.lookup_entry);
-		} 
+		}
 	}
 	return 1;
 }
@@ -301,33 +290,33 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
  *   gint show_morph(const gchar * type, const gchar * value, gboolean clicked)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
  */
- 
- static gint show_morph(const gchar * stype, const gchar * svalue, 
+
+ static gint show_morph(const gchar * stype, const gchar * svalue,
 				gboolean clicked)
-{	
+{
 	const gchar *modbuf = NULL;
 	gchar *mybuf = NULL;
-	
+
 	if (!strcmp(stype,"Greek") ||
 	     strstr(stype,"x-Robinson") ||
 	     strstr(stype,"robinson") ||
 	     strstr(stype,"Robinson")) {
 		if (backend->get_key_testament(settings.currentverse) == 2) {
-			if (backend->is_module("Robinson")) 
+			if (backend->is_module("Robinson"))
 				modbuf = "Robinson";
 		} else {
-			if (backend->is_module("Packard")) 
+			if (backend->is_module("Packard"))
 				modbuf = "Packard";
 		}
 	}
 	//GS_message(("modbuf = %s", modbuf));
 	if (clicked) {
-		main_display_dictionary(modbuf, (gchar*)svalue);		
+		main_display_dictionary(modbuf, (gchar*)svalue);
 	} else {
 		mybuf = main_get_rendered_text(modbuf, (gchar*)svalue);
 		//GS_message(("mybuf = %s", mybuf));
@@ -356,49 +345,49 @@ static gint show_separate_image(const gchar * filename, gboolean clicked)
  *   gint show_strongs(const gchar * type, const gchar * value, gboolean clicked)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
- */ 
- 
-static gint show_strongs(const gchar * stype, const gchar * svalue, 
+ */
+
+static gint show_strongs(const gchar * stype, const gchar * svalue,
 			gboolean clicked)
-{	
+{
 	const gchar *modbuf = NULL;
 	gchar *mybuf = NULL;
 	gchar *val = NULL;
 
 	val = g_strdup(svalue);
-	/*if((val1 = strchar(val,'|')) != NULL)	{
+	/*if ((val1 = strchar(val,'|')) != NULL)	{
 		val1 = (val1) ? (val1 + 1) : val;
-		
+
 	}*/
-	
-	if(!strcmp(settings.MainWindowModule,"NASB")) {
-		if(!strcmp(stype,"Greek")) 
+
+	if (!strcmp(settings.MainWindowModule,"NASB")) {
+		if (!strcmp(stype,"Greek"))
 			modbuf = "NASGreek";
-		else 
+		else
 			modbuf = "NASHebrew";
 	} else {
 		if (stype && (*stype != '\0')) {
-			if(!strcmp(stype,"Greek")) 
+			if (!strcmp(stype,"Greek"))
 				modbuf = settings.lex_greek;
-			else  
+			else
 				modbuf = settings.lex_hebrew;
 		} else
 			modbuf = "InvStrongsRealGreek";
 	}
-	
+
 	if (clicked) {
-		main_display_dictionary(modbuf, (gchar*)svalue);		
+		main_display_dictionary(modbuf, (gchar*)svalue);
 	} else {
 		mybuf = main_get_rendered_text(modbuf, (gchar*)svalue);
 		if (mybuf) {
-			main_information_viewer(  
-					modbuf, 
-					mybuf, 
-					(gchar*)svalue, 
+			main_information_viewer(
+					modbuf,
+					mybuf,
+					(gchar*)svalue,
 					"showStrongs",
 					(gchar*)stype,
 					NULL,
@@ -421,31 +410,31 @@ static gint show_strongs(const gchar * stype, const gchar * svalue,
  *   gint note_uri(const gchar * url)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
  */
- 
-static gint show_note(const gchar * module, const gchar * passage, 
+
+static gint show_note(const gchar * module, const gchar * passage,
 		const gchar * stype, const gchar * svalue, gboolean clicked)
-{	
+{
 	gchar *tmpbuf = NULL;
 	gchar *buf = NULL;
 	gchar *work_buf = NULL;
 	GString *str = g_string_new(NULL);
 	GList *tmp = NULL;
 	RESULTS *list_item;
-	
+
 	if (!in_url)
 		return 1;
-	
-	if (!backend->is_module((gchar*)module)) 
+
+	if (!backend->is_module((gchar*)module))
 		module = settings.MainWindowModule;
-	
+
 	if (passage && (strlen(passage) < 5))
 		passage = settings.currentverse;
-	
+
 	//
 	// if we are asking for a note/xref in n:0,
 	// we must stop autonormalization for a moment.
@@ -455,7 +444,7 @@ static gint show_note(const gchar * module, const gchar * passage,
 	char oldAutoNorm = 0;
 
 	if (stop_autonorm) {
-		SWMgr *mgr = backend->get_display_mgr();
+		SWMgr *mgr = backend->get_mgr();
 		backend->display_mod = mgr->Modules[module];
 		backend->display_mod->setKey(passage);
 		vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
@@ -466,7 +455,7 @@ static gint show_note(const gchar * module, const gchar * passage,
 	} else
 		backend->set_module_key((gchar*)module, (gchar*)passage);
 
-	if(strchr(stype,'x') && clicked) {
+	if (strchr(stype,'x') && clicked) {
 		tmpbuf = backend->get_entry_attribute("Footnote",
 						      (gchar*)svalue,
 						      "refList");
@@ -477,12 +466,12 @@ static gint show_note(const gchar * module, const gchar * passage,
 							   tmpbuf);
 			g_free(tmpbuf);
 		}
-	} else if(strchr(stype,'n') && !clicked) {
+	} else if (strchr(stype,'n') && !clicked) {
 		tmpbuf = backend->get_entry_attribute("Footnote",
 						      (gchar*)svalue,
 						      "body");
 		buf = backend->render_this_text((gchar*)module,(gchar*)tmpbuf);
-		if(tmpbuf) g_free(tmpbuf);
+		if (tmpbuf) g_free(tmpbuf);
 		if (buf) {
 			main_information_viewer((gchar*)module,
 						buf,
@@ -491,9 +480,9 @@ static gint show_note(const gchar * module, const gchar * passage,
 						(gchar*)stype,
 						NULL,
 						NULL);
-			if(buf) g_free(buf);
+			if (buf) g_free(buf);
 		}
-	} else if(strchr(stype,'x') && !clicked) {
+	} else if (strchr(stype,'x') && !clicked) {
 		tmpbuf = backend->get_entry_attribute("Footnote",
 						      (gchar*)svalue,
 						      "refList");
@@ -521,7 +510,7 @@ static gint show_note(const gchar * module, const gchar * passage,
 				settings.bible_text_color,
 				(const char *) tmp->data);
 			str = g_string_append(str,buf);
-			if(buf) g_free(buf);
+			if (buf) g_free(buf);
 			buf = NULL;
 			//++i;
 			g_free((char *) tmp->data);
@@ -537,9 +526,9 @@ static gint show_note(const gchar * module, const gchar * passage,
 				      _("Back to "),
 				      settings.currentverse);
 		str = g_string_append(str,buf);
-		if(buf) g_free(buf);
+		if (buf) g_free(buf);
 
-		if(tmpbuf) g_free(tmpbuf);
+		if (tmpbuf) g_free(tmpbuf);
 		if (str) {
 			main_information_viewer((gchar*)module,
 						str->str,
@@ -553,7 +542,7 @@ static gint show_note(const gchar * module, const gchar * passage,
 
 	if (stop_autonorm && vkey)
 		vkey->AutoNormalize(oldAutoNorm);
-	if(work_buf)
+	if (work_buf)
 		g_free(work_buf);
 	g_string_free(str, 1);
 	return 1;
@@ -570,22 +559,22 @@ static gint show_note(const gchar * module, const gchar * passage,
  *   gint reference_uri(const gchar * url)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
  */
- 
+
 static gint show_ref(const gchar * module, const gchar * list, gboolean clicked)
-{	
+{
 	if (!clicked)
 		return 1;
-	
-	if (!backend->is_module(module)) 
+
+	if (!backend->is_module(module))
 		module = settings.MainWindowModule;
 	main_display_verse_list_in_sidebar(settings.currentverse,
 						  (gchar*)module,
-						  (gchar*)list); 
+						  (gchar*)list);
 	return 1;
 }
 
@@ -598,40 +587,39 @@ static gint show_ref(const gchar * module, const gchar * list, gboolean clicked)
  * Synopsis
  *   #include "main/url.hh"
  *
- *   gint show_module_and_key(const gchar * module, const gchar * key, 
+ *   gint show_module_and_key(const gchar * module, const gchar * key,
 					const gchar * type, gboolean clicked)
  *
  * Description
- *   
- *   
+ *
+ *
  *
  * Return value
  *   gint
  */
 
-static int show_module_and_key(const char * module, const char * key, 
+static int show_module_and_key(const char * module, const char * key,
 					const char * stype, gboolean clicked)
 {
 	gchar *tmpkey = NULL;
 	gint mod_type;
-	
-	if (module && (strlen((char*)module) < 3) && 
+
+	if (module && (strlen((char*)module) < 3) &&
 	    backend->is_Bible_key(key, settings.currentverse)) {
 		module = settings.MainWindowModule;
 	}
 	if (!clicked) {
-		//gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar), url);
 		return 1;
 	}
-	
+
 	if (backend->is_module(module)) {
 		if (!strcmp(stype,"newTab")) {
-			main_open_bookmark_in_new_tab((gchar*)module, 
+			main_open_bookmark_in_new_tab((gchar*)module,
 					(gchar*)key);
 			return 1;
 		}
 		if (!strcmp(stype,"newDialog"))  {
-			if(module && (main_get_mod_type((gchar*)module) == PERCOM_TYPE)) {			
+			if (module && (main_get_mod_type((gchar*)module) == PERCOM_TYPE)) {
 				editor_create_new(module,key,TRUE);
 				return 1;
 			}
@@ -642,19 +630,6 @@ static int show_module_and_key(const char * module, const char * key,
 		mod_type = backend->module_type((gchar*)module);
 		switch (mod_type) {
 			case TEXT_TYPE:
-				if (strpbrk(key, "-;,")) {	// >1 verse marked
-					main_display_verse_list_in_sidebar
-					    (settings.currentverse,
-					     (gchar*)module, (gchar*)key);
-				} else {
-					tmpkey = main_update_nav_controls(key);
-					main_display_bible(module, tmpkey);
-					main_display_commentary(NULL, tmpkey);
-					main_keep_bibletext_dialog_in_sync((gchar*)tmpkey);
-					if (tmpkey) g_free((gchar*)tmpkey);
-					editor_sync_with_main();
-				}
-				break;
 			case COMMENTARY_TYPE:
 			case PERCOM_TYPE:
 				if (strpbrk(key, "-;,")) {	// >1 verse marked
@@ -662,17 +637,12 @@ static int show_module_and_key(const char * module, const char * key,
 					    (settings.currentverse,
 					     (gchar*)module, (gchar*)key);
 				} else {
-					tmpkey = main_update_nav_controls(key);
-					main_display_bible(NULL, tmpkey);
-					main_display_commentary(module, tmpkey);
-					main_keep_bibletext_dialog_in_sync((gchar*)tmpkey);
-					if (tmpkey) g_free((gchar*)tmpkey);
-					if (gtk_notebook_get_current_page
-					    (GTK_NOTEBOOK
-					     (widgets.notebook_comm_book)) != 0)
-					    gtk_notebook_set_current_page(
-						GTK_NOTEBOOK (widgets.
-							      notebook_comm_book), 0);
+					gchar *url =
+					    g_strdup_printf("sword://%s/%s",
+							    (module ? module : ""),
+							    key);
+					sword_uri(url, TRUE);
+					g_free(url);
 				}
 				break;
 			case DICTIONARY_TYPE:
@@ -681,9 +651,9 @@ static int show_module_and_key(const char * module, const char * key,
 				break;
 			case BOOK_TYPE:
 			case PRAYERLIST_TYPE:
-				main_display_book((gchar*)module, (gchar*)key); 
-				if(gtk_notebook_get_current_page (GTK_NOTEBOOK 
-						(widgets.notebook_comm_book)) 
+				main_display_book((gchar*)module, (gchar*)key);
+				if (gtk_notebook_get_current_page (GTK_NOTEBOOK
+						(widgets.notebook_comm_book))
 				   		!= 1)
 					gtk_notebook_set_current_page(
 							GTK_NOTEBOOK (widgets.
@@ -699,37 +669,36 @@ static int show_module_and_key(const char * module, const char * key,
 
  /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/url.hh"
  *
- *   gint (const gchar * type, const gchar * value, 
+ *   gint (const gchar * type, const gchar * value,
 			gboolean clicked)
  *
  * Description
- *  
+ *
  *
  * Return value
  *   gint
- */ 
- 
+ */
+
 static gint show_in_previewer(const gchar * url)
-{	
-	
-	gchar **work_buf = NULL;       
+{
+
+	gchar **work_buf = NULL;
 	gchar *mybuf = NULL;
 
 	work_buf = g_strsplit (url,"/",4);
-	//GS_message(("work_buf :%s, %s",work_buf[MODULE],work_buf[KEY]));	
-	
+
 	mybuf = main_get_rendered_text(work_buf[MODULE], work_buf[KEY]);
-	
+
 	if (mybuf) {
-		main_information_viewer(  
-				(gchar*)work_buf[MODULE], 
-				mybuf, 
-				(gchar*)work_buf[KEY], 
+		main_information_viewer(
+				(gchar*)work_buf[MODULE],
+				mybuf,
+				(gchar*)work_buf[KEY],
 				NULL,
 				NULL,
 				NULL,
@@ -760,14 +729,20 @@ static gint show_in_previewer(const gchar * url)
  *   gint
  */
 
-static gint sword_uri(const gchar * url, gboolean clicked)
+gint sword_uri(const gchar * url, gboolean clicked)
 {
 	const gchar *key = NULL;
 	gchar *tmpkey = NULL;
 	gint mod_type;
 	gint verse_count;
-	gchar **work_buf = NULL;                                                  
-		
+	gchar **work_buf = NULL;
+
+	// don't recurse between paratab and here.
+	static gboolean handling_uri = FALSE;
+
+	if (handling_uri) return 0;
+	handling_uri = TRUE;
+
 	if (!clicked) {
 		gchar *name = g_strstr_len(url, 10, "://");
 		if (!name)
@@ -780,73 +755,102 @@ static gint sword_uri(const gchar * url, gboolean clicked)
 			int mod_type = backend->module_type(name);
 			if (slash)
 				*slash = '/';
-			
+
 			if (mod_type == DICTIONARY_TYPE)
-				show_in_previewer(url);			
+				show_in_previewer(url);
 			else
 				gui_set_statusbar (url);
 		}
+		handling_uri = FALSE;
 		return 1;
 	}
-	
+
 	work_buf = g_strsplit (url,"/",4);
-	GS_message(("work_buf: %s, %s",work_buf[MODULE],work_buf[KEY]));
 	if (!work_buf[MODULE] && !work_buf[KEY]) {
 		alert_url_not_found(url);
 		g_strfreev(work_buf);
+		handling_uri = FALSE;
 		return 0;
 	}
-	if(!work_buf[KEY]) {
-		tmpkey = work_buf[MODULE];		
+	if (!work_buf[KEY]) {
+		tmpkey = work_buf[MODULE];
 	} else
 		tmpkey = work_buf[KEY];
-	
+	if ((settings.special_anchor = strchr(tmpkey, '#')) ||
+	    (settings.special_anchor = strchr(tmpkey, '!')))
+		*(settings.special_anchor++) = '\0';
+
+	GS_message(("work_buf: %s, %s",
+		    work_buf[MODULE],
+		    (work_buf[KEY] ? work_buf[KEY] : "-null-")));
+
 	verse_count = 1; //backend->is_Bible_key(mykey, settings.currentverse);
-	if(backend->is_module(work_buf[MODULE])) {
+	if (backend->is_module(work_buf[MODULE])) {
 		mod_type = backend->module_type(work_buf[MODULE]);
-		switch(mod_type) {
+		switch (mod_type) {
 			case TEXT_TYPE:
 				key = main_update_nav_controls(tmpkey);
+				main_display_bible(work_buf[MODULE], key);
 				if (settings.comm_showing)
 					main_display_commentary(NULL, key);
-				main_display_bible(work_buf[MODULE], key);
 				main_keep_bibletext_dialog_in_sync((gchar*)key);
 				editor_sync_with_main();
-				
-				if(key) g_free((gchar*)key);
-			break;				
-			case COMMENTARY_TYPE:	
+
+				if (key) g_free((gchar*)key);
+			break;
+			case COMMENTARY_TYPE:
+				if (gtk_notebook_get_current_page
+				    (GTK_NOTEBOOK
+				     (widgets.notebook_comm_book)) != 0) {
+					gchar *save = settings.special_anchor;
+					gtk_notebook_set_current_page(
+					    GTK_NOTEBOOK (widgets.
+							  notebook_comm_book), 0);
+					settings.special_anchor = save;
+				}
+				settings.comm_showing = TRUE;
 				key = main_update_nav_controls(tmpkey);
 				main_display_commentary(work_buf[MODULE],key);
 				main_display_bible(NULL, key);
 				main_keep_bibletext_dialog_in_sync((gchar*)key);
-				if(key) g_free((gchar*)key);
+				if (key) g_free((gchar*)key);
 			break;
 			case DICTIONARY_TYPE:
 				main_display_dictionary(work_buf[MODULE],
 							tmpkey);
 			break;
 			case BOOK_TYPE:
-				main_display_book(work_buf[MODULE], tmpkey); 
+				if (gtk_notebook_get_current_page
+				    (GTK_NOTEBOOK
+				     (widgets.notebook_comm_book)) != 1) {
+					gchar *save = settings.special_anchor;
+					gtk_notebook_set_current_page(
+					    GTK_NOTEBOOK (widgets.
+							  notebook_comm_book), 1);
+					settings.special_anchor = save;
+				}
+				settings.comm_showing = FALSE;
+				main_display_book(work_buf[MODULE], tmpkey);
 			break;
 		}
 	} else { /* module name not found or not given */
-		if(verse_count) { 
+		if (verse_count) {
 			key = main_update_nav_controls(tmpkey);
 			/* display in current Bible and Commentary */
 			main_display_commentary(NULL, key);
 			main_display_bible(NULL, key);
 			main_keep_bibletext_dialog_in_sync((gchar*)key);
-			
+
 			editor_sync_with_main();
-			
-			if(key) g_free((gchar*)key);
+
+			if (key) g_free((gchar*)key);
 		} else {
 			alert_url_not_found(url);
 		}
-	} 
+	}
 	g_strfreev(work_buf);
 	settings.addhistoryitem = TRUE;
+	handling_uri = FALSE;
 	return 1;
 }
 
@@ -878,14 +882,13 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 	gchar* strongs = NULL;
 	int retval = 0;		// assume failure.
 
-	GS_message(("main_url_handler()"));
-	GS_message(("url = %s", url));
+	GS_message(("main_url_handler => %s", url));
 
 	if (strstr(url, "sword://") ||
 	    strstr(url, "bible://")) {
 		GString *url_clean = hex_decode(url);
 		GS_message(("url_clean = %s", url_clean->str));
-		
+
 		retval = sword_uri(url_clean->str, clicked);
 		g_string_free(url_clean, TRUE);
 	}
@@ -921,14 +924,14 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 		strongs = g_strdup((gchar*)m_url.getParameterValue("lemma"));
 		stype = g_strdup((gchar*)m_url.getParameterValue("type"));
 		svalue = g_strdup((gchar*)m_url.getParameterValue("value"));
-		
+
 		// XXX gross hack-fix
 		// AraSVD is named "Smith & Van Dyke", using a literal '&'.
 		// this is technically a Sword bug: Sword should encode it.
 		// we work around it here: replace '&' with '+'.  *sigh*
 		//if (svalue = strstr(, " & "))
 		//	*(svalue+1) = '-';
-			 
+
 		GS_message(("action = %s", action));
 		GS_message(("type = %s", stype));
 		GS_message(("value = %s", svalue));
@@ -954,9 +957,17 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 		else if (!strcmp(action, "showUserNote")) {
 			module = g_strdup(m_url.getParameterValue("module"));
 			passage = g_strdup((gchar*)m_url.getParameterValue("passage"));
+
+			// need localized key, not the osisref that we've got.
+			ModMap::iterator it = backend->get_mgr()->Modules.find
+						((module && *module) ? module : "KJV");
+			SWModule *m = (*it).second;
+			VerseKey *vk = (VerseKey *)m->getKey();
+			*vk = passage;
+
 			main_information_viewer(module,
 						(gchar*)svalue,
-						(gchar*)passage, 
+						(gchar*)m->getKeyText(),
 						"showUserNote",
 						(gchar*)"u",
 						NULL,
@@ -996,7 +1007,10 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 		}
 
 		else if (!strcmp(action, "showImage")) {
-			show_separate_image(svalue+5, clicked);	// skip "file:"
+			show_separate_image((!strncmp(svalue, "file:", 5)
+					     ? svalue+5
+					     : svalue),
+					    clicked);
 		}
 
 		if (action) g_free(action);
@@ -1007,7 +1021,7 @@ gint main_url_handler(const gchar * url, gboolean clicked)
 		g_string_free(tmpstr, TRUE);
 		retval = 1;
 	} else if (clicked)
-		gnome_url_show(url, NULL);
+		xiphos_open_default (url);
 
 	return retval;
 }
@@ -1037,7 +1051,7 @@ const gchar *main_url_encode(const gchar * pram)
 	else
 		return g_strdup("");
 }
- 
+
 /******************************************************************************
  * Name
  *   hex_decode
@@ -1076,7 +1090,7 @@ hex_decode(const gchar *url)
 						  (gchar) from_hex);
 				url_chase += 2;
 			} else {
-				// failed %xx enconding; normal character.
+				// failed %xx encoding; normal character.
 				// should we instead do nothing with this '%'?
 				g_string_append_c(url_clean, '%');
 			}
