@@ -1,6 +1,6 @@
 /*
  * Xiphos Bible Study Tool
- * xml.c - 
+ * xml.c -
  *
  * Copyright (C) 2000-2009 Xiphos Developer Team
  *
@@ -23,6 +23,8 @@
 #include <config.h>
 #endif
 
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <libxml/parser.h>
 
 #include "main/lists.h"
@@ -37,7 +39,7 @@ struct _bookmark_data {
 	gboolean is_leaf;
 };
 typedef struct _bookmark_data BOOKMARK_DATA;
-	
+
 static BOOKMARK_DATA *es;
 static xmlDocPtr xml_settings_doc;
 static xmlNodePtr section_ptr;
@@ -51,10 +53,10 @@ static xmlDocPtr bookmark_doc;
  * Synopsis
  *   #include "gui/bookmarks.h"
  *
- *   void xml_new_bookmark_file(void)	
+ *   void xml_new_bookmark_file(void)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -69,7 +71,7 @@ void xml_new_bookmark_file(void)
 	xmlAttrPtr xml_attr;
 	const char *xml_filename;
 	gchar buf[256];
-	
+
 	sprintf(buf, "%s/%s/bookmarks.xml", settings.gSwordDir,
 		"bookmarks");
 	xml_filename = buf;
@@ -88,23 +90,23 @@ void xml_new_bookmark_file(void)
 
 	xml_root = xml_add_folder_to_parent(xml_node, _("Personal"));
 	xml_folder = xml_add_folder_to_parent(xml_root, _("What must I do to be saved?"));
-	xml_add_bookmark_to_parent(xml_folder, 
+	xml_add_bookmark_to_parent(xml_folder,
 					_("Acts 16:31"),
 					_("Acts 16:31"),
 					NULL,
 					NULL);
-	xml_add_bookmark_to_parent(xml_folder, 
+	xml_add_bookmark_to_parent(xml_folder,
 					_("Eph 2:8,9"),
 					_("Eph 2:8,9"),
 					NULL,
 					NULL);
-	xml_add_bookmark_to_parent(xml_folder, 
+	xml_add_bookmark_to_parent(xml_folder,
 					_("Romans 1:16"),
 					_("Romans 1:16"),
 					NULL,
 					NULL);
 	xml_folder = xml_add_folder_to_parent(xml_root, _("What is the Gospel?"));
-	xml_add_bookmark_to_parent(xml_folder, 
+	xml_add_bookmark_to_parent(xml_folder,
 					_("1 Cor 15:1-4"),
 					_("1 Cor 15:1-4"),
 					NULL,
@@ -121,18 +123,18 @@ void xml_new_bookmark_file(void)
  * Synopsis
  *   #include "main/xml.h"
  *
- *   xmlNodePtr xml_add_folder_to_parent(xmlNodePtr parent, 
+ *   xmlNodePtr xml_add_folder_to_parent(xmlNodePtr parent,
  *						BOOKMARK_DATA * es)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   xmlNodePtr
  */
 
 xmlNodePtr xml_add_folder_to_parent(xmlNodePtr parent, gchar * caption)
-{ 
+{
 	xmlNodePtr cur_node;
 	xmlAttrPtr xml_attr;
 
@@ -151,17 +153,17 @@ xmlNodePtr xml_add_folder_to_parent(xmlNodePtr parent, gchar * caption)
  * Synopsis
  *   #include "main/xml.h"
  *
- *   void xml_add_bookmark_to_parent(xmlNodePtr parent, 
- *						BOOKMARK_DATA * es)	
+ *   void xml_add_bookmark_to_parent(xmlNodePtr parent,
+ *						BOOKMARK_DATA * es)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
  */
 
-void xml_add_bookmark_to_parent(xmlNodePtr parent, gchar * caption, 
+void xml_add_bookmark_to_parent(xmlNodePtr parent, gchar * caption,
 			gchar * key, gchar * module, gchar * mod_desc)
 {
 	xmlNodePtr xml_node;
@@ -202,10 +204,10 @@ void xml_add_bookmark_to_parent(xmlNodePtr parent, gchar * caption,
  * Synopsis
  *   #include "main/xml.h"
  *
- *   void get_node_data(GNode * node)	
+ *   void get_node_data(GNode * node)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -224,10 +226,10 @@ static void get_node_data(GNode * node)
  * Synopsis
  *   #include "main/xml.h"
  *
- *   void parse_gnode_tree(GNode * node, xmlNodePtr parent)	
+ *   void parse_gnode_tree(GNode * node, xmlNodePtr parent)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -264,7 +266,7 @@ static void parse_gnode_tree(GNode * node, xmlNodePtr parent)
  * Synopsis
  *   #include "main/xml.h"
  *
- *   void xml_save_gnode_to_bookmarks(GNode * node, gchar *file_buf)	
+ *   void xml_save_gnode_to_bookmarks(GNode * node, gchar *file_buf)
  *
  * Description
  *    for compatability with old bookmarks
@@ -281,7 +283,7 @@ void xml_save_gnode_to_bookmarks(GNode * gnode, gchar * file_buf)
 	xmlAttrPtr root_attr;
 	const char *xml_filename;
 	gchar *mod_desc = NULL;
-	
+
 	if (!gnode)
 		return;
 	xml_filename = file_buf;
@@ -308,7 +310,7 @@ void xml_save_gnode_to_bookmarks(GNode * gnode, gchar * file_buf)
 			if (strlen(es->module) > 2)
 				mod_desc = main_get_module_description(es->module);
 		}
-		xml_add_bookmark_to_parent(root_node, 
+		xml_add_bookmark_to_parent(root_node,
 						es->caption,
 						es->key,
 						es->module,
@@ -352,29 +354,29 @@ void xml_save_gnode_to_bookmarks(GNode * gnode, gchar * file_buf)
  *   void xml_write_bookmark_doc(const xmlChar * xml_filename)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
 void xml_write_bookmark_doc(const xmlChar * xml_filename)
-{	
+{
 	GS_print(("\nsaving = %s\n", xml_filename));
 	xmlSaveFormatFile((const char *) xml_filename, bookmark_doc,1);
 }
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/xml.h"
  *
- *   void 
+ *   void
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -396,15 +398,15 @@ void xml_free_bookmark_doc(void)
  *   xmlNodePtr xml_load_bookmark_file(char * bookmark_file)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   xmlNodePtr
  */
 
-xmlNodePtr xml_load_bookmark_file(const xmlChar * bookmark_file) 
+xmlNodePtr xml_load_bookmark_file(const xmlChar * bookmark_file)
 {
-	
+
 	xmlNodePtr cur = NULL;
 
 	bookmark_doc = xmlParseFile((const char *) bookmark_file);
@@ -487,10 +489,12 @@ int xml_create_settings_file(char *path)
 	xml_attr = xmlNewProp(cur_node,
 			      (const xmlChar *) "label",
 			      (const xmlChar *) _("Sample Module List"));
+	tmp = get_list(TEXT_LIST);
 	xml_attr = xmlNewProp(cur_node,
 			      (const xmlChar *) "list",
-			      (const xmlChar *)(gchar *)(get_list(TEXT_LIST)->data));
-
+			      (tmp
+			       ? (const xmlChar *)(gchar *)(tmp->data)
+			       : (const xmlChar *)(gchar *)"-ReplaceMe-"));
 
 	section_node = xmlNewChild(root_node, NULL,
 				   (const xmlChar *) "editor", NULL);
@@ -499,6 +503,15 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "UseStudypadDialog", (const xmlChar *) "1");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "spell_language", (const xmlChar *) "unknown");
 
+	section_node = xmlNewChild(root_node, NULL, (const xmlChar *) "locale", NULL);
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "special", (const xmlChar *) "");
+
+	section_node = xmlNewChild(root_node, NULL, (const xmlChar *) "modmgr", NULL);
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_source", (const xmlChar *) "1");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_destination", (const xmlChar *) "0");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_local_source_index", (const xmlChar *) "0");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_remote_source_index", (const xmlChar *) "0");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *) "mod_mgr_intro", (const xmlChar *) "0");
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *) "fontsize", NULL);
 	xmlNewTextChild(section_node, NULL, (const xmlChar *) "versenum", (const xmlChar *) "+0");
@@ -558,7 +571,7 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"hebrew", NULL);
 
 	section_node = xmlNewChild(root_node, NULL,
-				   (const xmlChar *) "markedverses", NULL); /* initially empty */
+				   (const xmlChar *) "osisrefmarkedverses", NULL);
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *)"misc", NULL);
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"dailydevotional", (const xmlChar *)"0");
@@ -577,53 +590,53 @@ int xml_create_settings_file(char *path)
 
 	section_node = xmlNewChild(root_node, NULL, (const xmlChar *)"modules", NULL);
 	tmp = get_list(GBS_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"book", (const xmlChar *)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"book", NULL);
 	tmp = get_list(COMM_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"comm", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL,(const xmlChar *) "comm", NULL);
 	tmp = get_list(DEVOTION_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"devotional", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"devotional", NULL);
 	tmp = get_list(DICT_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"dict", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"dict", NULL);
 	tmp = get_list(TEXT_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int1", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int1", NULL);
-	if((tmp = g_list_next(tmp)) != NULL)
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int2",(const xmlChar *)(gchar*)tmp->data);		
+	if ((tmp = g_list_next(tmp)) != NULL)
+		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int2",(const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int2", NULL);
-	if((tmp = g_list_next(tmp)) != NULL)
+	if ((tmp = g_list_next(tmp)) != NULL)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int3", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int3", NULL);
-	if((tmp = g_list_next(tmp)) != NULL)
+	if ((tmp = g_list_next(tmp)) != NULL)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int4", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int4", NULL);
-	if((tmp = g_list_next(tmp)) != NULL)
+	if ((tmp = g_list_next(tmp)) != NULL)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int5", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"int5", NULL);
 	tmp = get_list(TEXT_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"bible", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"bible", NULL);
 	tmp = get_list(PERCOMM_LIST);
-	if(tmp)
+	if (tmp)
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"percomm", (const xmlChar *)(gchar*)tmp->data);
 	else
 		xmlNewTextChild(section_node, NULL, (const xmlChar *)"percomm", NULL);
@@ -645,8 +658,70 @@ int xml_create_settings_file(char *path)
 	return 1;
 }
 
+/******************************************************************************
+ * Name
+ *   xml_convert_to_osisref
+ *
+ * Synopsis
+ *   #include "main/xml.h"
+ *
+ *   void xml_convert_to_osisref()
+ *
+ * Description
+ *   convert "Gen 1:1" format to OSISRef "Gen.1.1" format.
+ *   backward compatibility support from 3.1.1's first (bad) cut that
+ *   failed to localize.  for shame, the pain i cause myself...
+ *
+ * Return value
+ *   void
+ */
 
+void xml_convert_to_osisref(void)
+{
+	gchar *label, *content, *s, *t;
+	gchar reference[100];
+	GList *deletable = NULL, *hold;
 
+	/* pull entries from old "markedverses" set */
+	/* re-insert into new "osisrefmarkedverses" */
+    	if (xml_set_section_ptr("markedverses") && xml_get_label()) {
+		do {
+			label = xml_get_label();
+			content = g_strdup(xml_get_list());
+
+			/* detect "NASB Revelation of John 1:1" */
+			if (((s = strrchr(label, ' ')) != NULL) &&	/* rightmost space */
+			    ((s = strchr((t = s+1), ':')) != NULL) &&	/* chapter:verse */
+			    ((t = strchr(label, ' ')) < s)) {		/* leftmost space */
+
+				/* having gotten this far, we successfully */
+				/* detected a wrongly-formatted label.  convert. */
+
+				/* mark old bogus version for removal. */
+				deletable = g_list_prepend(deletable, g_strdup(label));
+
+				/* cons up a new version. */
+				*t = '\0';
+				g_snprintf(reference, 100, "%s %s",
+					   label /* this is just the module name now */,
+					   main_get_osisref_from_key((const char *)label,
+								     (const char *)t+1));
+				xml_set_list_item("osisrefmarkedverses", "markedverse",
+						  reference, content);
+			}
+			g_free(content);
+		} while (xml_next_item() && xml_get_label());
+	}
+
+	hold = deletable;
+	while (deletable) {
+		xml_remove_node("markedverses", "markedverse", deletable->data);
+		g_free(deletable->data);
+		deletable = g_list_next(deletable);
+	}
+	xml_remove_section("markedverses");
+	g_list_free(hold);
+}
 
 
 /******************************************************************************
@@ -659,7 +734,7 @@ int xml_create_settings_file(char *path)
  *   xmlNodePtr xml_find_section(char *type_doc, char *section)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   xmlNodePtr
@@ -703,11 +778,11 @@ static xmlNodePtr xml_find_section(const char *type_doc, const char *section)
  * Synopsis
  *   #include "main/xml.h"
  *
- *   xmlNodePtr xml_find_item(xmlNodePtr parent, char * item, 
+ *   xmlNodePtr xml_find_item(xmlNodePtr parent, char * item,
  *							char * label)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   xmlNodePtr
@@ -748,7 +823,7 @@ static xmlNodePtr xml_find_item(xmlNodePtr parent, const char *item,
  *   char *xml_get_list_from_label(char * section, char * item, char * label)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -794,11 +869,11 @@ char *xml_get_list_from_label(const char *section, const char *item, const char
  * Synopsis
  *   #include "main/xml.h"
  *
- *   void xml_set_list_item(char * section, char * item, char * label, 
+ *   void xml_set_list_item(char * section, char * item, char * label,
  *				char * value)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -995,7 +1070,7 @@ static xmlNodePtr xml_find_prop(const char *type_doc, const char *section,
  *   char *xml_get_value(char *section, char *item)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   char *
@@ -1027,7 +1102,7 @@ char *xml_get_value(const char *section, const char *item)
  *		   char *value)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -1085,18 +1160,37 @@ int xml_parse_settings_file(char *file_name)
  *   void xml_save_settings_doc(char *file_name)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
  */
 
-void xml_save_settings_doc(char *file_name)
+void xml_save_settings_doc(char *name)
 {
-	//const xmlChar *file;
+	int retval;
+	struct stat buf;
+	char *backup_name = g_strdup_printf("%s.SAVE", name);
 
-	//file = (const xmlChar *) file_name;
-	xmlSaveFormatFile(file_name, xml_settings_doc,1);
+	/* preserve a good backup if possible. */
+	unlink(backup_name);
+	rename(name, backup_name);
+	g_free(backup_name);
+
+	/* save the new one. */
+	xmlSaveFormatFile(name, xml_settings_doc,1);
+
+	/* did it save properly? */
+	if (((retval = stat(name, &buf)) < 0) ||
+	    ((retval == 0) && (buf.st_size == 0))) {
+		char *msg = g_strdup_printf(_("Save of settings failed! stat %d, size %d\n%s"),
+					    retval, (int)buf.st_size,
+					    _("Attempting to revert to previous save."));
+		unlink(name);
+		rename(backup_name, name);
+		gui_generic_warning(msg);
+		g_free(msg);
+	}
 }
 
 
@@ -1110,7 +1204,7 @@ void xml_save_settings_doc(char *file_name)
  *   void xml_free_settings_doc(void)
  *
  * Description
- *   
+ *
  *
  * Return value
  *   void
@@ -1125,12 +1219,12 @@ void xml_add_new_section_to_settings_doc(char * section)
 {
 	xmlNodePtr root_node = NULL;
 	xmlNodePtr section_node = NULL;
-	
+
 	root_node = xmlDocGetRootElement(xml_settings_doc);
 	if (root_node == NULL) {
 		fprintf(stderr, _("empty document \n"));
 		return;
-	}	
+	}
 	section_node = xmlNewChild(root_node, NULL,
 				   (const xmlChar *) section, NULL);
 }
@@ -1138,42 +1232,42 @@ void xml_add_new_section_to_settings_doc(char * section)
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "main/xml.h"
  *
- *   
+ *
  *
  * Description
- *   
+ *
  *
  * Return value
- *   
+ *
  */
 
 void xml_add_new_item_to_section(char * section, char * item_name, char * value)
 {
 	xmlNodePtr section_node = NULL;
-	
+
 	section_node = xml_find_section("Xiphos", section);
-	
-	if(section_node) 		
-		xmlNewTextChild(section_node, NULL, (const xmlChar *)item_name, 
+
+	if (section_node)
+		xmlNewTextChild(section_node, NULL, (const xmlChar *)item_name,
 						    (const xmlChar *)value);
 }
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/bookmarks.h"
  *
- *   	
+ *
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -1185,10 +1279,37 @@ void xml_remove_node(const char *section, const char *item, const char *label)
 	xmlNodePtr cur_item = NULL;
 	if ((cur =
 	     xml_find_section( "Xiphos", section)) != NULL) {
-		if ((cur_item = xml_find_item(cur, item, label)) != NULL) {			
+		if ((cur_item = xml_find_item(cur, item, label)) != NULL) {
 			xmlUnlinkNode(cur_item);
-			xmlFreeNode(cur_item);      
-		} 	  
-	}	
-	
+			xmlFreeNode(cur_item);
+		}
+	}
+
+}
+
+/******************************************************************************
+ * Name
+ *   xml_remove_section
+ *
+ * Synopsis
+ *   #include "gui/bookmarks.h"
+ *
+ *   void xml_remove_section(char *section)
+ *
+ * Description
+ *   annihilates an entire section from the document.
+ *
+ * Return value
+ *   void
+ */
+
+void xml_remove_section(const char *section)
+{
+	xmlNodePtr cur = NULL;
+
+	if ((cur = xml_find_section("Xiphos", section)) != NULL) {
+		xmlUnlinkNode(cur);
+		xmlFreeNode(cur);
+	}
+
 }
